OC.L10N.register(
    "spreed",
    {
    "a conversation" : "samtal",
    "(Duration %s)" : "(tímalengd %s)",
    "You attended a call with {user1}" : "Þú varst í símtali við {user1}",
    "_%n guest_::_%n guests_" : ["%n gestur","%n gestir"],
    "You attended a call with {user1} and {user2}" : "Þú varst í símtali við {user1} og {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Þú varst í símtali við {user1}, {user2} og {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Þú varst í símtali við {user1}, {user2}, {user3} og {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Þú varst í símtali við {user1}, {user2}, {user3}, {user4} og {user5}",
    "_%n other_::_%n others_" : ["%n annar","%n aðrir"],
    "{actor} invited you to {call}" : "{actor} bauð þér að taka þátt í {call}",
    "Other activities" : "Aðrar athafnir",
    "Talk" : "Spjalla",
    "Guest" : "Gestur",
    "Talk updates ✅" : "Uppfærslur á Talk-spjallforriti ✅",
    "{actor} created the conversation" : "{actor} bjó til samtalið",
    "You created the conversation" : "Þú bjóst til samtalið",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} endurnefndi samtalið \"%1$s\" sem \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Þú endurnefndir samtalið \"%1$s\" sem \"%2$s\"",
    "You started a call" : "Þú hófst samtal",
    "{actor} started a call" : "{actor} hóf samtal",
    "{actor} joined the call" : "{actor} kom inn í samtalið",
    "You joined the call" : "Þú komst inn í samtalið",
    "{actor} left the call" : "{actor} hætti í samtalinu",
    "You left the call" : "Þú hættir í samtalinu",
    "{actor} unlocked the conversation" : "{actor} aflæsti samtalinu",
    "You unlocked the conversation" : "Þú aflæstir samtalinu",
    "{actor} locked the conversation" : "{actor} læsti samtalinu",
    "You locked the conversation" : "Þú læstir samtalinu",
    "{actor} allowed guests" : "{actor} leyfði gesti",
    "You allowed guests" : "Þú leyfðir gesti",
    "{actor} disallowed guests" : "{actor} bannaði gesti",
    "You disallowed guests" : "Þú bannaðir gesti",
    "{actor} set a password" : "{actor} setti lykilorð",
    "You set a password" : "Þú stilltir lykilorð",
    "{actor} removed the password" : "{actor} fjarlægði lykilorð",
    "You removed the password" : "Þú} fjarlægðir lykilorð",
    "{actor} added {user}" : "{actor} bætti {user} við",
    "You joined the conversation" : "Þú komst inn í samtalið",
    "{actor} joined the conversation" : "{actor} kom inn í samtalið",
    "You added {user}" : "Þú bættir {user} við",
    "{actor} added you" : "{actor} bætti þér við",
    "You left the conversation" : "Þú hættir í samtalinu",
    "{actor} left the conversation" : "{actor} hætti í samtalinu",
    "{actor} removed {user}" : "{actor} fjarlægði {user}",
    "You removed {user}" : "Þú fjarlægðir {user}",
    "{actor} removed you" : "{actor} fjarlægði þig",
    "{actor} promoted {user} to moderator" : "{actor} gerði {user} að umsjónarmanni",
    "You promoted {user} to moderator" : "Þú gerðir {user} að umsjónarmanni",
    "{actor} promoted you to moderator" : "{actor} gerði þig að umsjónarmanni",
    "{actor} demoted {user} from moderator" : "{actor} lét {user} hætta sem umsjónarmann",
    "You demoted {user} from moderator" : "Þú lést {user} hætta sem umsjónarmann",
    "{actor} demoted you from moderator" : "{actor} lét þig hætta sem umsjónarmann",
    "{actor} shared a file which is no longer available" : "{actor} deildi skrá sem ekki er lengur tiltæk",
    "You shared a file which is no longer available" : "Þú deildir skrá sem ekki er lengur tiltæk",
    "Message deleted by author" : "Skilaboðum eytt af höfundi",
    "Administration" : "Stjórnun",
    "System" : "Kerfið",
    "%s (guest)" : "%s (gestur)",
    "Talk conversations" : "Samtöl",
    "Talk to %s" : "Tala við %s",
    "Storage quota exceeded" : "Geymslukvóti er uppurinn",
    "File not found" : "Skrá finnst ekki",
    "File is not shared, or shared but not with the user" : "Skránni er ekki deilt, eða henni er deilt en ekki með notandanum",
    "Poll" : "Poll",
    "File is too big" : "Skrá er of stór",
    "Invalid file provided" : "Ógild skrá gefin",
    "Invalid image" : "Ógild mynd",
    "Unknown filetype" : "Óþekkt skráategund",
    "Say hi to your friends and colleagues!" : "Segðu hæ við vini þína og samstarfsmenn!",
    "Conversation invitation" : "Boð í samtal",
    "Description" : "Lýsing",
    "Meeting" : "Fundur",
    "Password request: %s" : "Beiðni um lykilorð: %s",
    "Private conversation" : "Einkasamtal",
    "Deleted user (%s)" : "Eyddi notanda (%s)",
    "Dismiss notification" : "Afgreiða tilkynningu",
    "Accept" : "Samþykkja",
    "Decline" : "Hafna",
    "New message" : "Ný skilaboð",
    "Reminder" : "Áminning",
    "Notification" : "Tilkynning",
    "{user} sent you a private message" : "{user} sendi þér einkaskilaboð",
    "{user} sent a message in conversation {call}" : "{user} sendi skilaboð í samtali {call}",
    "A deleted user sent a message in conversation {call}" : "Eyddur notandi sendi skilaboð í samtali {call}",
    "{guest} (guest) sent a message in conversation {call}" : " {guest} (gestur) sendi skilaboð í samtali {call}",
    "A guest sent a message in conversation {call}" : "Gestur sendi skilaboð í samtali {call}",
    "{guest} (guest) replied to your message in conversation {call}" : " {guest} (gestur) svaraði skilaboðunum þinum í samtalinu {call}",
    "{user} mentioned you in a private conversation" : "{user} minntist á þig í einkasamtali",
    "{user} mentioned you in conversation {call}" : "{user} minntist á þig í samtali {call}",
    "A deleted user mentioned you in conversation {call}" : "Eyddur notandi minntist á þig í samtali {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (gestur) minntist á þig í samtali {call}",
    "A guest mentioned you in conversation {call}" : "Gestur minntist á þig í samtali {call}",
    "View chat" : "Skoða spjall",
    "{user} invited you to a group conversation: {call}" : "{user} bauð þér að taka þátt í hópsímtali: {call}",
    "Join call" : "Taka þátt í símtali",
    "Answer call" : "Svara símtali",
    "Call back" : "Hringja til baka",
    "A group call has started in {call}" : "Hópsímtal er byrjað í {call}",
    "Open settings" : "Opna stillingar",
    "error" : "villa",
    "Default" : "Sjálfgefið",
    "Presentation" : "Kynning",
    "Conversations" : "Samtöl",
    "Messages" : "Skilaboð",
    "Avatar image is not square" : "Auðkennismynd er ekki ferningslaga",
    "Other" : "Annað",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Sameinuðu arabísku furstadæmin",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antígva og Barbúda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albanía",
    "Armenia" : "Armenía",
    "Angola" : "Angóla",
    "Antarctica" : "Suðurskautslandið",
    "Argentina" : "Argentína",
    "American Samoa" : "Bandarísku Samóaeyjar",
    "Austria" : "Austurríki",
    "Australia" : "Ástralía",
    "Aruba" : "Arúba",
    "Åland Islands" : "Álandseyjar",
    "Azerbaijan" : "Aserbaídsjan",
    "Bosnia and Herzegovina" : "Bosnía og Herzegónía",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladess",
    "Belgium" : "Belgía",
    "Burkina Faso" : "Búrkína Fasó",
    "Bulgaria" : "Búlgaría",
    "Bahrain" : "Barein",
    "Burundi" : "Búrúndí",
    "Benin" : "Benín",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermúda",
    "Brunei Darussalam" : "Brúnei Darussalam",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sankti Eustatius og Saba",
    "Brazil" : "Brasilía",
    "Bahamas" : "Bahamaeyjar",
    "Bhutan" : "Bútan",
    "Bouvet Island" : "Bouvet eyja",
    "Botswana" : "Botsvana",
    "Belarus" : "Hvíta-Rússland",
    "Belize" : "Belís",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Kókoseyjar",
    "Central African Republic" : "Mið-Afríkulýðveldið",
    "Congo" : "Kongó",
    "Switzerland" : "Sviss",
    "Côte d'Ivoire" : "Fílabeinsströndin",
    "Cook Islands" : "Cook-eyjar",
    "Chile" : "Síle",
    "Cameroon" : "Kamerún",
    "China" : "Kína",
    "Colombia" : "Kólumbía",
    "Costa Rica" : "Kosta Ríka",
    "Cuba" : "Kúba",
    "Cabo Verde" : "Grænhöfðaeyjar",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Jólaey",
    "Cyprus" : "Kýpur",
    "Czechia" : "Tékkland",
    "Germany" : "Þýskaland",
    "Djibouti" : "Djíbútí",
    "Denmark" : "Danmörk",
    "Dominica" : "Dóminíka",
    "Dominican Republic" : "Dóminíkanska lýðveldið",
    "Algeria" : "Alsír",
    "Ecuador" : "Ekvador",
    "Estonia" : "Eistland",
    "Egypt" : "Egyptaland",
    "Western Sahara" : "Vestur-Sahara",
    "Eritrea" : "Erítrea",
    "Spain" : "Spánn",
    "Ethiopia" : "Eþíópía",
    "Finland" : "Finnland",
    "Fiji" : "Fídjieyjar",
    "Falkland Islands (Malvinas)" : "Falklandseyjar",
    "Faroe Islands" : "Færeyjar",
    "France" : "Frakkland",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Samveldi Stóra-Bretlands og Norður-Írlands",
    "Grenada" : "Grenada",
    "Georgia" : "Georgía",
    "French Guiana" : "Franska Gvæjana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Gana",
    "Gibraltar" : "Gíbraltar",
    "Greenland" : "Grænland",
    "Gambia" : "Gambía",
    "Guinea" : "Gínea",
    "Guadeloupe" : "Gvadelúpeyjar",
    "Equatorial Guinea" : "Miðbaugs-Gínea",
    "Greece" : "Grikkland",
    "South Georgia and the South Sandwich Islands" : "Suður-Georgía og Suður-Sandwich eyjar",
    "Guatemala" : "Gvatemala",
    "Guam" : "Gvam",
    "Guinea-Bissau" : "Gínea-Bissá",
    "Guyana" : "Gvæjana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Heard-eyja og McDonald-eyjur",
    "Honduras" : "Hondúras",
    "Croatia" : "Króatía",
    "Haiti" : "Haítí",
    "Hungary" : "Ungverjaland",
    "Indonesia" : "Indónesía",
    "Ireland" : "Írland",
    "Israel" : "Ísrael",
    "Isle of Man" : "Mön",
    "India" : "Indland",
    "British Indian Ocean Territory" : "Bresku Indlandshafseyjar",
    "Iraq" : "Írak",
    "Iceland" : "Ísland",
    "Italy" : "Ítalía",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamaíka",
    "Jordan" : "Jórdanía",
    "Japan" : "Japan",
    "Kenya" : "Kenía",
    "Kyrgyzstan" : "Kirgisistan",
    "Cambodia" : "Kambódía",
    "Kiribati" : "Kíribatí",
    "Comoros" : "Kómoreyjar",
    "Saint Kitts and Nevis" : "Sankti Kitts og Neviseyjur",
    "Korea, Republic of" : "Kórea, lýðveldið",
    "Kuwait" : "Kúveit",
    "Cayman Islands" : "Cayman-eyjar",
    "Kazakhstan" : "Kasakstan",
    "Lao People's Democratic Republic" : "Alþýðulýðveldið Laó",
    "Lebanon" : "Líbanon",
    "Saint Lucia" : "Sankti Lúsía",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Srí Lanka",
    "Liberia" : "Líbería",
    "Lesotho" : "Lesótó",
    "Lithuania" : "Litháen",
    "Luxembourg" : "Lúxemborg",
    "Latvia" : "Lettland",
    "Libya" : "Líbía",
    "Morocco" : "Marokkó",
    "Monaco" : "Mónakó",
    "Moldova, Republic of" : "Moldóvía, lýðveldið",
    "Montenegro" : "Svartfjallaland",
    "Saint Martin (French part)" : "Sankti Martin (franski hluti)",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Marshall eyjar",
    "North Macedonia" : "Norður-Makedónía",
    "Mali" : "Malí",
    "Myanmar" : "Mjanmar",
    "Mongolia" : "Mongólía",
    "Macao" : "Makaó",
    "Northern Mariana Islands" : "Norður Maríanaeyjar",
    "Martinique" : "Martiník",
    "Mauritania" : "Máritanía",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Máritus",
    "Maldives" : "Maldíveyjar",
    "Malawi" : "Malaví",
    "Mexico" : "Mexíkó",
    "Malaysia" : "Malasía",
    "Mozambique" : "Mósambík",
    "Namibia" : "Namibía",
    "New Caledonia" : "Nýja-Kaledónía",
    "Niger" : "Níger",
    "Norfolk Island" : "Norfolkeyja",
    "Nigeria" : "Nígería",
    "Nicaragua" : "Nígarakúa",
    "Netherlands" : "Holland",
    "Norway" : "Noregur",
    "Nepal" : "Nepal",
    "Nauru" : "Nárú",
    "Niue" : "Niue",
    "New Zealand" : "Nýja-Sjáland",
    "Oman" : "Óman",
    "Panama" : "Panama",
    "Peru" : "Perú",
    "French Polynesia" : "Franska Pólýnesía",
    "Papua New Guinea" : "Papúa Nýja-Gínea",
    "Philippines" : "Filippseyjar",
    "Pakistan" : "Pakistan",
    "Poland" : "Pólland",
    "Saint Pierre and Miquelon" : "Sankti Pierre og Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Puerto Ríko",
    "Palestine, State of" : "Palestínuríki",
    "Portugal" : "Portúgal",
    "Palau" : "Palá",
    "Paraguay" : "Paragvæ",
    "Qatar" : "Katar",
    "Réunion" : "Réunion",
    "Romania" : "Rúmenía",
    "Serbia" : "Serbía",
    "Russian Federation" : "Rússneska sambandið",
    "Rwanda" : "Rúanda",
    "Saudi Arabia" : "Sádí-Arabía",
    "Solomon Islands" : "Salómonseyjar",
    "Seychelles" : "Seychelles-eyjar",
    "Sudan" : "Súdan",
    "Sweden" : "Svíþjóð",
    "Singapore" : "Singapúr",
    "Saint Helena, Ascension and Tristan da Cunha" : "Sankti Helena, Ascension og Tristan da Cunha",
    "Slovenia" : "Slóvenía",
    "Svalbard and Jan Mayen" : "Svalbarði og Jan Mayen",
    "Slovakia" : "Slóvakía",
    "Sierra Leone" : "Síerra Leóne",
    "San Marino" : "San Marínó",
    "Senegal" : "Senegal",
    "Somalia" : "Sómalía",
    "Suriname" : "Súrínam",
    "South Sudan" : "Suður-Súdan",
    "Sao Tome and Principe" : "Saó Tóme og Prinsípe",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "Sankti Maarten (hollenski hluti)",
    "Syrian Arab Republic" : "Sýrlenska arabalýðveldið",
    "Eswatini" : "Eswatini",
    "Turks and Caicos Islands" : "Turks og Kaikós eyjar",
    "Chad" : "Tsjad",
    "French Southern Territories" : "Frönsku suðurhafshéruðin",
    "Togo" : "Tógó",
    "Thailand" : "Tæland",
    "Tajikistan" : "Tadsjikistan",
    "Tokelau" : "Tókelá",
    "Timor-Leste" : "Tímor-Leste",
    "Turkmenistan" : "Túrkmenistan",
    "Tunisia" : "Túnis",
    "Tonga" : "Tonga",
    "Turkey" : "Tyrkland",
    "Trinidad and Tobago" : "Trínidad og Tóbagó",
    "Tuvalu" : "Túvalú",
    "Taiwan, Province of China" : "Tævan, hérað í Kína",
    "Tanzania, United Republic of" : "Tansanía, sameinaða lýðveldið",
    "Ukraine" : "Úkraína",
    "Uganda" : "Úganda",
    "United States Minor Outlying Islands" : "Ytri-smáeyjar Bandaríkjanna",
    "United States of America" : "Bandaríki Norður-Ameríku",
    "Uruguay" : "Úrúgvæ",
    "Uzbekistan" : "Úsbekistan",
    "Holy See" : "Vatíkanska borgríkið (Holy See)",
    "Saint Vincent and the Grenadines" : "Sankti Vincent og Grenadín",
    "Viet Nam" : "Víetnam",
    "Vanuatu" : "Vanuatú",
    "Wallis and Futuna" : "Wallis- og Fútúnaeyjar",
    "Samoa" : "Samóa",
    "Yemen" : "Jemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Suður-Afríka",
    "Zambia" : "Sambía",
    "Zimbabwe" : "Simbabve",
    "Federation" : "Deilt milli þjóna",
    "Invalid date, date format must be YYYY-MM-DD" : "Ógild dagsetning, dagsetningasniðið verður að vera ÁÁÁÁ-MM-DD",
    "Conversation not found" : "Samtal fannst ekki",
    "Chat, video & audio-conferencing using WebRTC" : "Spjall, mynd- og hljóðfundir með WebRTC",
    "Leave call" : "Hætta símtali",
    "Share this file" : "Deila þessari skrá",
    "The password is wrong. Try again." : "Lykilorðið er rangt. Reyndu aftur.",
    "Password" : "Lykilorð",
    "Submit" : "Senda inn",
    "Error requesting the password." : "Villa kom upp við að biðja um lykilorð.",
    "Request password" : "Biðja um lykilorð",
    "This conversation has ended" : "Þessu samtali er lokið",
    "Everyone" : "Allir",
    "Users and moderators" : "Notendur og umsjónarmenn",
    "Moderators only" : "Aðeins umsjónarmenn",
    "Save changes" : "Vista breytingar",
    "Saving …" : "Vista …",
    "Saved!" : "Vistað!",
    "Limit to groups" : "Takmarka við hópa",
    "Guests can still join public conversations." : "Gestir geta komið inn í opinber samtöl.",
    "Enabled" : "Virkt",
    "Disabled" : "Óvirkt",
    "State" : "Staða",
    "Name" : "Nafn",
    "Beta" : "BETA-prófunarútgáfa",
    "Permissions" : "Heimildir",
    "All messages" : "Öll skilaboð",
    "@-mentions only" : "@-mentions only",
    "Off" : "Slökkt",
    "General settings" : "Almennar stillingar",
    "Enable encryption" : "Virkja dulritun",
    "Pending" : "Í bið",
    "Error" : "Villa",
    "Blocked" : "Útilokaður",
    "Active" : "Virkt",
    "Expired" : "Útrunnið",
    "Never" : "Aldrei",
    "Language" : "Tungumál",
    "Country" : "Country",
    "Status" : "Staða",
    "Created at" : "Búið til",
    "Yes" : "Já",
    "No" : "Nei",
    "Validate SSL certificate" : "Sannreyna SSL-skilríki",
    "Delete this server" : "Eyða þessum þjóni",
    "Test this server" : "Prófa þennan þjón",
    "Shared secret" : "Sameiginlegur leynilykill",
    "STUN server URL" : "URL-slóð STUN-þjóns",
    "STUN servers" : "STUN-þjónar",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN-miðlari er notaður til að ákvarða opinbert vistfang þátttakenda á bak við beini.",
    "TURN server URL" : "URL-slóð TURN-þjóns",
    "TURN server secret" : "Leynilykill á TURN-miðlara",
    "TURN server protocols" : "Samskiptareglur TURN-þjóns",
    "TURN servers" : "TURN-miðlarar",
    "OK" : "Í lagi",
    "Checking …" : "Athuga …",
    "Federated user" : "Notandi í skýjasambandi",
    "Confirm" : "Staðfesta",
    "Reset" : "Endurstilla",
    "Cancel" : "Hætta við",
    "Back" : "Til baka",
    "Now" : "Núna",
    "Loading …" : "Hleð inn …",
    "From" : "Frá",
    "To" : "Til",
    "Calendar" : "Dagatal",
    "Attendees" : "Þátttakendur",
    "Save" : "Vista",
    "No results" : "Engar niðurstöður",
    "Done" : "Lokið",
    "Grid view" : "Reitasýn",
    "This conversation is read-only" : "This conversation is read-only",
    "Reload" : "Endurlesa",
    "Connecting …" : "Tengist ...",
    "Waiting for others to join the call …" : "Bíð eftir að fleiri komi inn í símtalið …",
    "You can invite others in the participant tab of the sidebar" : "Þú getur boðið öðrum að taka þátt af þátttakendaflipa hliðarspjaldsins",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Þú getur boðið öðrum að taka þátt af þátttakendaflipa hliðarspjaldsins eða deilt þessum tengli til að bjóða öðrum!",
    "Share this link to invite others!" : "Deildu þessum tengli til að bjóða öðrum!",
    "Copy link" : "Afrita tengil",
    "Mute audio" : "Þagga hljóð",
    "None" : "Enginn",
    "You have been muted by a moderator" : "You have been muted by a moderator",
    "Disable video" : "Gera myndskeið óvirk",
    "Enable video" : "Virkja myndskeið",
    "You" : "Þú",
    "Show screen" : "Birta skjá",
    "Collapse" : "Fella saman",
    "Expand" : "Fletta út",
    "Drop your files to upload" : "Slepptu skrám til að senda þær inn",
    "Favorite" : "Eftirlæti",
    "Date:" : "Dagsetning:",
    "Note:" : "Athugaðu:",
    "Hide details" : "Fela nánari upplýsingar",
    "Show details" : "Birta nánari upplýsingar",
    "Disable" : "Gera óvirkt",
    "Choose" : "Velja",
    "The file must be a PNG or JPG" : "Skráin verður að vera PNG eða JPG",
    "Restricted" : "Takmarkað",
    "Personal" : "Persónulegt",
    "Danger zone" : "Hættusvæði",
    "Leave conversation" : "Hætta í samtali",
    "Delete conversation" : "Eyða samtali",
    "_%n hour_::_%n hours_" : ["%n klukkustund","%n klukkustundir"],
    "Password protection" : "Verndun með lykilorði",
    "Set a password" : "Setja lykilorð",
    "Invalid language" : "Ógilt tungumál",
    "Start time (optional)" : "Upphafstími (valfrjálst)",
    "Edit" : "Breyta",
    "More information" : "Nánari upplýsingar",
    "Delete" : "Eyða",
    "Log content" : "Efni atvikaskrár",
    "Notifications" : "Tilkynningar",
    "Join" : "Taka þátt",
    "Create a new conversation" : "Hefja nýtt samtal",
    "Create conversation" : "Búa til samtal",
    "Enter your name" : "Settu inn nafnið þitt",
    "Log in" : "Skrá inn",
    "Mark as read" : "Merkja sem lesið",
    "Mark as unread" : "Merkja allt sem ólesið",
    "Remove from favorites" : "Fjarlægja úr eftirlætum",
    "Add to favorites" : "Bæta í eftirlæti",
    "You need to promote a new moderator before you can leave the conversation." : "Þú þarft að uppfæra einhvern í stöðu umsjónarmanna áður en þú getur hætt í samtalinu.",
    "Home" : "Heim",
    "Unread" : "Ólesið",
    "Alphabetically" : "Í stafrófsröð",
    "No matches found" : "Engar samsvaranir fundust",
    "Unread messages" : "Ólesin skilaboð",
    "Clear filter" : "Hreinsa síu",
    "App settings" : "Stillingar forrits",
    "Users" : "Notendur",
    "Groups" : "Hópar",
    "Teams" : "Teymi",
    "No search results" : "Engar leitarniðurstöður",
    "New group conversation" : "Nýtt hópsamtal…",
    "You are currently waiting in the lobby" : "You are currently waiting in the lobby",
    "Select a device" : "Veldu tæki",
    "Test" : "Prófun",
    "Devices" : "Tæki",
    "No audio" : "Ekkert hljóð",
    "Invalid path selected" : "Ógild slóð valin",
    "Blur" : "Móða",
    "Upload" : "Senda inn",
    "Files" : "Skrár",
    "24 hours" : "24 klukkustundir",
    "7 days" : "7 dagar",
    "Reply" : "Svara",
    "More actions" : "Fleiri aðgerðir",
    "Set reminder" : "Setja áminningu",
    "Edit message" : "Breyta skilaboðum",
    "Copy message link" : "Afrita skilaboðatengil",
    "Go to file" : "Fara í skrá",
    "Translate" : "Þýða",
    "Dismiss" : "Hafna",
    "Detect language" : "Greina tungumál",
    "The message could not be translated" : "Ekki var hægt að þýða skilaboðin",
    "Translation copied to clipboard" : "Þýðing afrituð á klippispjald",
    "Translation could not be copied" : "Ekki tókst að afrita þýðinguna",
    "Translate message" : "Þýða skilaboð",
    "Source language to translate from" : "Upprunatungumál til að þýða af",
    "Translate from" : "Þýða úr",
    "Target language to translate into" : "Marktungumál til að þýða yfir á",
    "Translate to" : "Þýða yfir á",
    "Translating" : "Þýðing",
    "Copy translated text" : "Afrita þýddan texta",
    "Send now" : "Senda núna",
    "Message sent" : "Skilaboðin hafa verið send",
    "Contact" : "Tengiliður",
    "{stack} in {board}" : "{stack} á {board}",
    "You voted" : "Þú kaust",
    "No messages" : "Engin skilaboð",
    "Unpin" : "Losa",
    "Create a new group conversation" : "Create a new group conversation",
    "Add participants" : "Bæta við þátttakanda",
    "Enter password" : "Enter password",
    "Send message" : "Senda skilaboð",
    "File to share" : "Skrá til að deila",
    "Add emoji" : "Bæta við tjáningartákni",
    "Send later" : "Senda síðar",
    "Cancel editing" : "Hætta við breytingar",
    "Share from Files" : "Deila úr skrám",
    "Upload from device" : "Senda inn frá tæki",
    "Create new poll" : "Búa til nýja könnun",
    "Smart picker" : "Snjall-veljari",
    "New file" : "Ný skrá",
    "Blank" : "Tóm",
    "Send" : "Senda",
    "Create poll" : "Búa til könnun",
    "Settings" : "Stillingar",
    "Anonymous poll" : "Nafnlaus könnun",
    "End poll" : "End poll",
    "Results" : "Niðurstöður",
    "moderator" : "umsjónarmaður",
    "guest" : "gestanotandi",
    "Remove participant" : "Fjarlægja þátttakanda",
    "Demote from moderator" : "Láta hætta sem umsjónarmann",
    "Promote to moderator" : "Gera að umsjónarmanni",
    "Remove" : "Fjarlægja",
    "Add users or groups" : "Bæta við notendum eða hópum",
    "Integrations" : "Samþættingar",
    "Searching …" : "Leita …",
    "Participants" : "Þátttakendur",
    "Open chat" : "Opna spjall",
    "Chat" : "Spjall",
    "Details" : "Details",
    "Load more results" : "Hlaða inn fleiri niðurstöðum",
    "Projects" : "Verkefni",
    "No shared items" : "No shared items",
    "Link to a conversation" : "Tengill á samtal",
    "Select conversation" : "Veldu samtal",
    "Edit display name" : "Breyta birtingarnafni",
    "Notification settings" : "Stillingar á tilkynningum",
    "Default language" : "Sjálfgefið tungumál",
    "Privacy" : "Gagnaleynd",
    "Search" : "Search",
    "Start call" : "Hefja samtal",
    "End call" : "Ljúka símtali",
    "The call has been running for one hour." : "Símtalið hefur staðið yfir í eina klukkustund.",
    "Screensharing options" : "Valkostir skjádeilingar",
    "Enable screensharing" : "Virkja skjádeilingu",
    "Screensharing requires the page to be loaded through HTTPS." : "Deiling á skjá krefst þess að síðunni sé hlaðið inn með HTTPS.",
    "An error occurred while starting screensharing." : "Villa kom upp við að hefja skjádeilingu.",
    "Show your screen" : "Birta skjáinn þinn",
    "Stop screensharing" : "Hætta skjádeilingu",
    "Keep" : "Halda",
    "Select a region" : "Veldu svæði",
    "Duplicate session" : "Duplicate session",
    "Join a conversation or start a new one" : "Taktu þátt í samtali eða byrjaðu nýtt samtal",
    "Talk conversation" : "Samtal í Talk-spjalli",
    "User" : "Notandi",
    "API token" : "API-teikn",
    "Login" : "Innskráning",
    "Nickname" : "Stuttnefni",
    "Client ID" : "Biðlaraauðkenni",
    "Team ID" : "Auðkenni teymis",
    "Media" : "Margmiðlunargögn",
    "Polls" : "Kannanir",
    "Locations" : "Staðsetningar",
    "Audio" : "Hljóð",
    "Show all files" : "Sýna allar skrár",
    "Group" : "Hópur",
    "Team" : "Teymi",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Error while sharing file" : "Villa við deilingu skráar",
    "Later today – {timeLocale}" : "Síðar í dag – {timeLocale}",
    "Tomorrow – {timeLocale}" : "Á morgun – {timeLocale}",
    "This weekend – {timeLocale}" : "Þessa helgi – {timeLocale}",
    "Next week – {timeLocale}" : "Í næstu viku – {timeLocale}",
    "Error while parsing a PROPFIND error" : "Villa við þáttun á PROPFIND-villu",
    "Please reload the page." : "Þú ættir að hlaða síðunni aftur inn.",
    "Do not disturb" : "Ónáðið ekki",
    "Away" : "Fjarverandi",
    "Access to microphone & camera is only possible with HTTPS" : "Aðgangur að hljóðnema og myndavél er einungis mögulegur í gegnum HTTPS",
    "Please move your setup to HTTPS" : "Endilega færðu uppsetninguna þína yfir í HTTPS",
    "Access to microphone & camera was denied" : "Aðgangur að hljóðnema og myndavél var ekki heimilaður",
    "WebRTC is not supported in your browser" : "WebRTC er ekki stutt í vafranum þínum",
    "Please use a different browser like Firefox or Chrome" : "Veldu einhvern annan vafra eins og Firefox eða Chrome",
    "Error while accessing microphone & camera" : "Villa kom upp þegar reynt var að opna hljóðnema og myndavél",
    "%s Talk on your mobile devices" : "%s Talaðu á snjalltækjunum þínum",
    "Android app" : "Android-forrit",
    "iOS app" : "iOS-forrit",
    "__language_name__" : "Íslenska",
    "Tasks" : "Verkefni",
    "Notes" : "Minnispunktar",
    "Talk conversation for event" : "Samtal fyrir atburð",
    "Set reminder for later today" : "Setja áminningu seinna í dag",
    "Set reminder for tomorrow" : "Setja áminningu fyrir morgundaginn",
    "Set reminder for this weekend" : "Setja áminningu fyrir þessa helgi",
    "Set reminder for next week" : "Setja áminningu fyrir í næstu viku"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
