OC.L10N.register(
    "spreed",
    {
    "a conversation" : "una conversación",
    "(Duration %s)" : "(Duración %s)",
    "You attended a call with {user1}" : "Atendiste una llamada de {user1}",
    "_%n guest_::_%n guests_" : ["%n inivitado","%n inivitados","%n inivitados"],
    "You attended a call with {user1} and {user2}" : "Atendiste una llamada de {user1} y {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Atendiste una llamada de {user1}, {user2} y {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Atendiste una llamada de {user1}, {user2}, {user3} y {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Atendiste una llamada de {user1}, {user2}, {user3}, {user4} y {user5}",
    "_%n other_::_%n others_" : ["%n otro","%n otros","%n otros"],
    "{actor} invited you to {call}" : "{actor} te ha invitado a {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Fuiste invitado a una <strong>conversación</strong> o tuviste una <strong>llamada</strong>",
    "Other activities" : "Otras actividades",
    "Talk" : "Hablar",
    "Guest" : "Invitado",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge y Safari ahora se pueden usar para participar en llamadas de audio y video",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Las conversaciones uno a uno ahora son persistentes y ya no se pueden convertir en conversaciones grupales accidentalmente. Además, cuando uno de los participantes abandona la conversación, la conversación ya no se elimina automáticamente. Solo si ambos participantes salen, la conversación se elimina del servidor",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Ahora puedes notificar a todos los participantes publicando \"@all\" en el chat",
    "- With the \"arrow-up\" key you can repost your last message" : "- Con la tecla \"flecha arriba\" puedes volver a publicar tu último mensaje",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk ahora puede tener comandos, envía \"/help\" como mensaje de chat para ver si tu administrador configuró alguno",
    "- With projects you can create quick links between conversations, files and other items" : "- Con proyectos puedes crear enlaces rápidos entre conversaciones, archivos y otros elementos",
    "- You can now mention guests in the chat" : "- Ahora puedes mencionar a invitados en el chat",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Las conversaciones ahora pueden tener un lobby. Esto permitirá que los moderadores se unan al chat y llamen para preparar la reunión mientras los usuarios y los invitados esperan.",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Ahora puedes responder directamente a mensajes dando a los otros usuarios más contexto sobre tu mensaje",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- La búsqueda de conversaciones y participantes ahora también filtrará tus conversaciones existentes, lo que facilita encontrar conversaciones anteriores",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Ahora puedes agregar grupos de usuarios personalizados a conversaciones cuando la aplicación \"Circles\" está instalada",
    "- Check out the new grid and call view" : "- Echa un vistazo a la nueva cuadrícula y a la vista de llamadas",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Ahora puedes cargar y arrastrar archivos directamente desde tu dispositivo al chat",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Los archivos compartidos se abren directamente en la vista del chat con las aplicaciones de visor",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Ahora puedes buscar chats y mensajes en la búsqueda unificada en la barra superior",
    "- Spice up your messages with emojis from the emoji picker" : "- Dale vida a tus mensajes con emojis del selector de emojis",
    "- You can now change your camera and microphone while being in a call" : "- Ahora usted puede cambiar su cámara y micrófono mientras está en una llamada",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Da contexto a tus conversaciones con una descripción y ábrelas para que los usuarios registrados puedan encontrarlas y unirse",
    "- See a read status and send failed messages again" : "- Ver el estado de lectura y volver a enviar mensajes que fallaron",
    "- Raise your hand in a call with the R key" : "- Levanta la mano en una llamada con la tecla R",
    "- Join the same conversation and call from multiple devices" : "- Únase a la misma conversación y llamada desde varios dispositivos",
    "- Send voice messages, share your location or contact details" : "- Envía mensajes de voz, comparte tu ubicación o detalles de contacto",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Agregue grupos a una conversación y los nuevos miembros del grupo se agregarán automáticamente como participantes",
    "- A preview of your audio and video is shown before joining a call" : "- Se muestra una vista previa de tu audio y video antes de unirte a una llamada",
    "- You can now blur your background in the newly designed call view" : "- Ahora puedes desenfocar el fondo en la nueva vista de llamada diseñada",
    "- Moderators can now assign general and individual permissions to participants" : "- Los moderadores ahora pueden asignar permisos generales e individuales a los participantes",
    "- In the sidebar you can now find an overview of the latest shared items" : "- En la barra lateral, ahora puedes encontrar una descripción general de los últimos elementos compartidos",
    "- Use a poll to collect the opinions of others or settle on a date" : "- Utiliza una encuesta para recopilar las opiniones de otros o acordar una fecha",
    "- Configure an expiration time for chat messages" : "- Configura un tiempo de caducidad para los mensajes de chat",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Inicia llamadas sin notificar a los demás en conversaciones grandes. Puedes enviar notificaciones individuales una vez que la llamada haya comenzado.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Envía mensajes de chat sin notificar a los destinatarios en caso de que no sea urgente",
    "- Emojis can now be autocompleted by typing a \":\"" : "- Los emojis ahora se pueden autocompletar escribiendo \":\"",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- Enlaza varios elementos utilizando el nuevo selector inteligente escribiendo \"/\"",
    "- Conversations can now have an avatar or emoji as icon" : "- Ahora las conversaciones pueden tener un avatar o emoji como icono",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- Ahora están disponibles los fondos virtuales además del fondo desenfocado en las videollamadas",
    "- Reactions are now available during calls" : "- Ahora están disponibles las reacciones durante las llamadas",
    "- Typing indicators show which users are currently typing a message" : "- Los indicadores de escritura muestran qué usuarios están escribiendo actualmente un mensaje",
    "- Groups can now be mentioned in chats" : "- Ahora se pueden mencionar grupos en los chats",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- Las grabaciones de llamadas se transcriben automáticamente si está registrada una aplicación de transcripción",
    "- Chat messages can be translated if a translation provider app is registered" : "- Los mensajes de chat se pueden traducir si está registrada una aplicación de traducción",
    "Talk updates ✅" : "Actualizaciones de Talk ✅",
    "Reaction deleted by author" : "Reacción eliminada por el autor",
    "{actor} created the conversation" : "{actor} creó la conversación",
    "You created the conversation" : "Tú creaste la conversación",
    "An administrator created the conversation" : "Un administrador creó la conversación",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} cambió el nombre de la conversación de \"%1$s\" a \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Tú cambiaste el nombre de la conversación de \"%1$s\" a \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Un administrador cambió el nombre de la conversación de \"%1$s\" a \"%2$s\"",
    "{actor} set the description" : "{actor} estableció la descripción",
    "You set the description" : "Tú estableciste la descripción",
    "An administrator set the description" : "Un administrador estableció la descripción",
    "{actor} removed the description" : "{actor} eliminó la descripción",
    "You removed the description" : "Tú eliminaste la descripción",
    "An administrator removed the description" : "Un administrador eliminó la descripción",
    "You started a call" : "Usted inició una llamada",
    "{actor} started a call" : "{actor} inició una llamada",
    "{actor} joined the call" : "{actor} se unió a una llamada",
    "You joined the call" : "Usted se unió a una llamada",
    "{actor} left the call" : "{actor} dejó la llamada",
    "You left the call" : "Usted dejó la llamada",
    "{actor} unlocked the conversation" : "{actor} desbloqueó la conversación",
    "You unlocked the conversation" : "Tú desbloqueaste la conversación",
    "An administrator unlocked the conversation" : "Un administrador desbloqueó la conversación",
    "{actor} locked the conversation" : "{actor} bloqueó la conversación",
    "You locked the conversation" : "Tú bloqueaste la conversación",
    "An administrator locked the conversation" : "Un administrador bloqueó la conversación",
    "{actor} limited the conversation to the current participants" : "{actor} limitó la conversación a los participantes actuales",
    "You limited the conversation to the current participants" : "Tú limitaste la conversación a los participantes actuales",
    "An administrator limited the conversation to the current participants" : "Un administrador limitó la conversación a los participantes actuales",
    "{actor} opened the conversation to registered users" : "{actor} abrió la conversación a usuarios registrados",
    "You opened the conversation to registered users" : "Tú abriste la conversación a usuarios registrados",
    "An administrator opened the conversation to registered users" : "Un administrador abrió la conversación a usuarios registrados",
    "The conversation is now open to everyone" : "La conversación ahora está abierta para todos",
    "{actor} opened the conversation to everyone" : "{actor} abrió la conversación para todos",
    "You opened the conversation to everyone" : "Tú abriste la conversación para todos",
    "{actor} restricted the conversation to moderators" : "{actor} restringió la conversación a moderadores",
    "You restricted the conversation to moderators" : "Tú restringiste la conversación a moderadores",
    "{actor} started breakout rooms" : "{actor} inició salas de reuniones",
    "You started breakout rooms" : "Tú iniciaste salas de reuniones",
    "{actor} stopped breakout rooms" : "{actor} detuvo las salas de reuniones",
    "You stopped breakout rooms" : "Tú detuviste las salas de reuniones",
    "{actor} allowed guests" : "{actor} permitió invitados",
    "You allowed guests" : "Tú permitiste invitados",
    "An administrator allowed guests" : "Un administrador permitió invitados",
    "{actor} disallowed guests" : "{actor} deshabilitó invitados",
    "You disallowed guests" : "Tú deshabilitaste invitados",
    "An administrator disallowed guests" : "Un administrador deshabilitó invitados",
    "{actor} set a password" : "{actor} estableció una contraseña",
    "You set a password" : "Tú estableciste una contraseña",
    "An administrator set a password" : "Un administrador estableció una contraseña",
    "{actor} removed the password" : "{actor} eliminó la contraseña",
    "You removed the password" : "Tú eliminaste la contraseña",
    "An administrator removed the password" : "Un administrador eliminó la contraseña",
    "{actor} added {user}" : "{actor} añadió a {user}",
    "You joined the conversation" : "Tú te uniste a la conversación",
    "{actor} joined the conversation" : "{actor} se unió a la conversación",
    "You added {user}" : "Tú añadiste a {user}",
    "{actor} added you" : "{actor} te añadió",
    "An administrator added you" : "Un administrador te añadió",
    "An administrator added {user}" : "Un administrador añadió a {user}",
    "You left the conversation" : "Tú dejaste la conversación",
    "{actor} left the conversation" : "{actor} dejó la conversación",
    "{actor} removed {user}" : "{actor} eliminó a {user}",
    "You removed {user}" : "Tú eliminaste a {user}",
    "{actor} removed you" : "{actor} te eliminó",
    "An administrator removed you" : "Un administrador te eliminó",
    "An administrator removed {user}" : "Un administrador eliminó a {user}",
    "{federated_user} accepted the invitation" : "{federated_user} aceptó la invitación",
    "{actor} removed {federated_user}" : "{actor} eliminó a {federated_user}",
    "You removed {federated_user}" : "Tú eliminaste a {federated_user}",
    "An administrator removed {federated_user}" : "Un administrador eliminó a {federated_user}",
    "{federated_user} declined the invitation" : "{federated_user} rechazó la invitación",
    "{actor} added group {group}" : "{actor} agregó al grupo {group}",
    "You added group {group}" : "Tú agregaste al grupo {group}",
    "An administrator added group {group}" : "Un administrador agregó al grupo {group}",
    "{actor} removed group {group}" : "{actor} eliminó al grupo {group}",
    "You removed group {group}" : "Tú eliminaste al grupo {group}",
    "An administrator removed group {group}" : "Un administrador eliminó al grupo {group}",
    "{actor} promoted {user} to moderator" : "{actor} promovió a {user} a moderador",
    "You promoted {user} to moderator" : "Tú promoviste a {user} a moderador",
    "{actor} promoted you to moderator" : "{actor} te promovió a moderador",
    "An administrator promoted you to moderator" : "Un administrador te promovió a moderador",
    "An administrator promoted {user} to moderator" : "Un administrador promovió a {user} a moderador",
    "{actor} demoted {user} from moderator" : "{actor} degradó a {user} de moderador",
    "You demoted {user} from moderator" : "Tú degradaste a {user} de moderador",
    "{actor} demoted you from moderator" : "{actor} te degradó de moderador",
    "An administrator demoted you from moderator" : "Un administrador te degradó de moderador",
    "An administrator demoted {user} from moderator" : "Un administrador degradó a {user} de moderador",
    "{actor} shared a file which is no longer available" : "{actor} compartió un archivo que ya no está disponible",
    "You shared a file which is no longer available" : "Tú compartiste un archivo que ya no está disponible",
    "The shared location is malformed" : "La ubicación compartida está mal formada",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} configuró Matterbridge para sincronizar esta conversación con otros chats",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Tú configuraste Matterbridge para sincronizar esta conversación con otros chats",
    "{actor} updated the Matterbridge configuration" : "{actor} actualizó la configuración de Matterbridge",
    "You updated the Matterbridge configuration" : "Tú actualizaste la configuración de Matterbridge",
    "{actor} removed the Matterbridge configuration" : "{actor} eliminó la configuración de Matterbridge",
    "You removed the Matterbridge configuration" : "Tú eliminaste la configuración de Matterbridge",
    "{actor} started Matterbridge" : "{actor} inició Matterbridge",
    "You started Matterbridge" : "Tú iniciaste Matterbridge",
    "{actor} stopped Matterbridge" : "{actor} detuvo Matterbridge",
    "You stopped Matterbridge" : "Tú detuviste Matterbridge",
    "{actor} deleted a message" : "{actor} eliminó un mensaje",
    "You deleted a message" : "Tú eliminaste un mensaje",
    "{actor} deleted a reaction" : "{actor} eliminó una reacción",
    "You deleted a reaction" : "Tú eliminaste una reacción",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["Estableciste la expiración del mensaje a %n semana","Estableciste la expiración del mensaje a %n semanas","Estableciste la expiración del mensaje a %n semanas"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["Estableciste la expiración del mensaje a %n día","Estableciste la expiración del mensaje a %n días","Estableciste la expiración del mensaje a %n días"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["Estableciste la expiración del mensaje a %n hora","Estableciste la expiración del mensaje a %n horas","Estableciste la expiración del mensaje a %n horas"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["Estableciste la expiración del mensaje a %n minuto","Estableciste la expiración del mensaje a %n minutos","Estableciste la expiración del mensaje a %n minutos"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} estableció la expiración del mensaje a %n semana","{actor} estableció la expiración del mensaje a %n semanas","{actor} estableció la expiración del mensaje a %n semanas"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} estableció la expiración del mensaje a %n día","{actor} estableció la expiración del mensaje a %n días","{actor} estableció la expiración del mensaje a %n días"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} estableció la expiración del mensaje a %n hora","{actor} estableció la expiración del mensaje a %n horas","{actor} estableció la expiración del mensaje a %n horas"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} estableció la expiración del mensaje a %n minuto","{actor} estableció la expiración del mensaje a %n minutos","{actor} estableció la expiración del mensaje a %n minutos"],
    "{actor} disabled message expiration" : "{actor} deshabilitó la expiración del mensaje",
    "You disabled message expiration" : "Tú deshabilitaste la expiración del mensaje",
    "{actor} cleared the history of the conversation" : "{actor} borró el historial de la conversación",
    "You cleared the history of the conversation" : "Tú borraste el historial de la conversación",
    "{actor} set the conversation picture" : "{actor} estableció la imagen de la conversación",
    "You set the conversation picture" : "Tú estableciste la imagen de la conversación",
    "{actor} removed the conversation picture" : "{actor} eliminó la imagen de la conversación",
    "You removed the conversation picture" : "Tú eliminaste la imagen de la conversación",
    "{actor} ended the poll {poll}" : "{actor} finalizó la encuesta {poll}",
    "You ended the poll {poll}" : "Tú finalizaste la encuesta {poll}",
    "{actor} started the video recording" : "{actor} inició la grabación de video",
    "You started the video recording" : "Tú iniciaste la grabación de video",
    "{actor} stopped the video recording" : "{actor} detuvo la grabación de video",
    "You stopped the video recording" : "Tú detuviste la grabación de video",
    "{actor} started the audio recording" : "{actor} inició la grabación de audio",
    "You started the audio recording" : "Tú iniciaste la grabación de audio",
    "{actor} stopped the audio recording" : "{actor} detuvo la grabación de audio",
    "You stopped the audio recording" : "Tú detuviste la grabación de audio",
    "The recording failed" : "La grabación falló",
    "Someone voted on the poll {poll}" : "Alguien votó en la encuesta {poll}",
    "Message deleted by author" : "Mensaje eliminado por el autor",
    "Message deleted by {actor}" : "Mensaje eliminado por {actor}",
    "Message deleted by you" : "Mensaje eliminado por ti",
    "Deleted user" : "Usuario eliminado",
    "Administration" : "Administración",
    "System" : "Sistema",
    "%s (guest)" : "%s (invitado)",
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} finalizó la llamada con %n invitado (Duración {duration})","{actor} finalizó la llamada con %n invitados (Duración {duration})","{actor} finalizó la llamada con %n invitados (Duración {duration})"],
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} finalizó la llamada con {user1} (Duración {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} finalizó la llamada con {user1} y {user2} (Duración {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} finalizó la llamada con {user1}, {user2} y {user3} (Duración {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} finalizó la llamada con {user1}, {user2}, {user3} y {user4} (Duración {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} finalizó la llamada con {user1}, {user2}, {user3}, {user4} y {user5} (Duración {duration})",
    "Message of {user} in {conversation}" : "Mensaje de {user} en {conversation}",
    "Message of {user}" : "Mensaje de {user}",
    "Message of a deleted user in {conversation}" : "Mensaje de un usuario eliminado en {conversation}",
    "Talk conversations" : "Conversaciones de Talk",
    "Talk to %s" : "Hablar con %s",
    "An error occurred. Please contact your administrator." : "Ocurrió un error. Por favor, contacta al administrador.",
    "File is not shared, or shared but not with the user" : "El archivo no está compartido, o está compartido pero no con el usuario",
    "No account available to delete." : "No hay una cuenta disponible para eliminar.",
    "Poll" : "Encuesta",
    "No image file provided" : "No se proporcionó un archivo de imagen",
    "File is too big" : "El archivo es demasiado grande.",
    "Invalid file provided" : "Archivo proporcionado inválido",
    "Invalid image" : "Imagen inválida",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Talk mentions" : "Menciones de Talk",
    "Say hi to your friends and colleagues!" : "¡Saluda a tus amigos y colegas!",
    "No unread mentions" : "Sin menciones no leídas",
    "Call in progress" : "Llamada en progreso",
    "You were mentioned" : "Fuiste mencionado",
    "Write to conversation" : "Escribe en la conversación",
    "Writes event information into a conversation of your choice" : "Escribe información del evento en una conversación de tu elección",
    "Conversation invitation" : "Invitación a la conversación",
    "Description" : "Descripción",
    "You can also dial-in via phone with the following details" : "También puedes llamar por teléfono con los siguientes detalles",
    "Dial-in information" : "Información para llamar",
    "Meeting ID" : "ID de la reunión",
    "Your PIN" : "Tu PIN",
    "Meeting" : "Reunión",
    "Password request: %s" : "Solicitud de contraseña: %s",
    "Private conversation" : "Conversación privada",
    "Deleted user (%s)" : "Usuario eliminado (%s)",
    "Failed to upload call recording" : "Error al cargar la grabación de llamada",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "El servidor de grabación falló al cargar la grabación de la llamada {call}. Por favor, comunícalo a la administración.",
    "Share to chat" : "Compartir en el chat",
    "Dismiss notification" : "Descartar notificación",
    "Call recording now available" : "Grabación de la llamada disponible ahora",
    "The recording for the call in {call} was uploaded to {file}." : "La grabación de la llamada en {call} se ha cargado en {file}.",
    "Transcript now available" : "Transcripción disponible ahora",
    "The transcript for the call in {call} was uploaded to {file}." : "La transcripción de la llamada en {call} se ha cargado en {file}.",
    "Failed to transcript call recording" : "Error en la transcripción de la grabación de llamada",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "El servidor falló en transcribir la grabación en {file} para la llamada en {call}. Por favor, comunícalo a la administración.",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "New message" : "Mensaje nuevo",
    "Reminder" : "Recordatorio",
    "{user} in {call}" : "{user} en {call}",
    "Deleted user in {call}" : "Usuario eliminado de {call}",
    "{guest} (guest) in {call}" : "{guest} (invitado) en {call}",
    "Guest in {call}" : "Invitado en {call}",
    "{user} sent you a private message" : "{user} te envió un mensaje privado",
    "{user} sent a message in conversation {call}" : "{user} envió un mensaje a la conversación {call}",
    "A deleted user sent a message in conversation {call}" : "Un usuario eliminado envió un mensaje a la conversación {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (guest) envió un mensaje a la conversación {call}",
    "A guest sent a message in conversation {call}" : "Un invitado envió un mensaje a la conversación {call}",
    "{user} replied to your private message" : "{user} respondió a tu mensaje privado",
    "{user} replied to your message in conversation {call}" : "{user} respondió su mensaje privado en la conversación {call}",
    "A deleted user replied to your message in conversation {call}" : "Un usuario eliminado respondió a tu mensaje en la conversación {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (invitado) respondió a tu mensaje en la conversación {call}",
    "A guest replied to your message in conversation {call}" : "Un invitado respondió a tu mensaje en la conversación {call}",
    "{user} reacted with {reaction} to your private message" : "{user} reaccionó con {reaction} a tu mensaje privado",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} reaccionó con {reaction} a tu mensaje en la conversación {call}",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "Un usuario eliminado reaccionó con {reaction} a tu mensaje en la conversación {call}",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (invitado) reaccionó con {reaction} a tu mensaje en la conversación {call}",
    "A guest reacted with {reaction} to your message in conversation {call}" : "Un invitado reaccionó con {reaction} a tu mensaje en la conversación {call}",
    "{user} mentioned you in a private conversation" : "{user} te mencionó en una conversación privada",
    "{user} mentioned group {group} in conversation {call}" : "{user} mencionó al grupo {group} en la conversación {call}",
    "{user} mentioned everyone in conversation {call}" : "{user} mencionó a todos en la conversación {call}",
    "{user} mentioned you in conversation {call}" : "{user} te mencionó en la conversación {call}",
    "A deleted user mentioned group {group} in conversation {call}" : "Un usuario eliminado mencionó al grupo {group} en la conversación {call}",
    "A deleted user mentioned everyone in conversation {call}" : "Un usuario eliminado mencionó a todos en la conversación {call}",
    "A deleted user mentioned you in conversation {call}" : "Un usuario eliminado te mencionó en la conversación {call}",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest} (invitado) mencionó al grupo {group} en la conversación {call}",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest} (invitado) mencionó a todos en la conversación {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (invitado) te mencionó en la conversación {call}",
    "A guest mentioned group {group} in conversation {call}" : "Un invitado mencionó al grupo {group} en la conversación {call}",
    "A guest mentioned everyone in conversation {call}" : "Un invitado mencionó a todos en la conversación {call}",
    "A guest mentioned you in conversation {call}" : "Un invitado te mencionó en la conversación {call}",
    "View chat" : "Ver chat",
    "{user} invited you to a group conversation: {call}" : "{user} te invitó a una conversación de grupo: {call}",
    "Join call" : "Unirse a la llamada",
    "Answer call" : "Responder llamada",
    "{user} would like to talk with you" : "{user} desea hablar contigo",
    "Call back" : "Devolver llamada",
    "You missed a call from {user}" : "Perdiste una llamada de {user}",
    "A group call has started in {call}" : "Una llamada en grupo ha iniciado en {call}",
    "You missed a group call in {call}" : "Te perdiste una llamada de grupo en {call}",
    "{email} is requesting the password to access {file}" : "{email} está solicitando la contraseña para acceder a {file}",
    "{email} tried to request the password to access {file}" : "{email} intentó solicitar la contraseña para acceder a {file}",
    "Someone is requesting the password to access {file}" : "Alguien está solicitando la contraseña para acceder a {file}",
    "Someone tried to request the password to access {file}" : "Alguien intentó solicitar la contraseña para acceder a {file}",
    "Open settings" : "Abrir configuraciones",
    "The hosted signaling server is now configured and will be used." : "El servidor de señalización alojado ahora está configurado y se utilizará.",
    "The hosted signaling server was removed and will not be used anymore." : "Se eliminó el servidor de señalización alojado y ya no se utilizará.",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "El estado de la cuenta del servidor de señalización alojado cambió de \"{oldstatus}\" a \"{newstatus}\".",
    "error" : "error",
    "The certificate of {host} expires in {days} days" : "El certificado de {host} expira en {days} días",
    "The certificate of {host} expired" : "El certificado de {host} expiró",
    "Contact via Talk" : "Contacto a través de Talk",
    "Open Talk" : "Abrir Talk",
    "Default" : "Predeterminado",
    "Presentation" : "Presentación",
    "Webinar" : "Seminario web",
    "Conversations" : "Conversaciones",
    "{user}" : "{user}",
    "Messages" : "Mensajes",
    "{user} in {conversation}" : "{user} en {conversation}",
    "Messages in other conversations" : "Mensajes en otras conversaciones",
    "One-to-one rooms always need to show the other users avatar" : "Las salas de uno a uno siempre necesitan mostrar el avatar de los otros usuarios",
    "Invalid emoji character" : "Carácter de emoji no válido",
    "Invalid background color" : "Color de fondo no válido",
    "Avatar image is not square" : "La imagen del avatar no es un cuadrado",
    "Room {number}" : "Sala {number}",
    "Other" : "Otro",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "Error al solicitar la prueba porque el servidor de prueba no se puede alcanzar. Por favor, inténtalo de nuevo más tarde.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Hay un problema con la autenticación de esta instancia. Tal vez no se puede alcanzar desde el exterior para verificar su URL.",
    "Something unexpected happened." : "Algo inesperado ocurrió.",
    "The URL is invalid." : "La URL no es válida.",
    "An HTTPS URL is required." : "Se requiere una URL HTTPS.",
    "The email address is invalid." : "La dirección de correo electrónico no es válida.",
    "The language is invalid." : "El idioma no es válido.",
    "The country is invalid." : "El país no es válido.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Hay un problema con la solicitud de prueba. Por favor, revisa tus registros para obtener más información.",
    "Too many requests are send from your servers address. Please try again later." : "Se están enviando demasiadas solicitudes desde la dirección de tu servidor. Por favor, inténtalo de nuevo más tarde.",
    "There is already a trial registered for this Nextcloud instance." : "Ya hay un registro de prueba para esta instancia de Nextcloud.",
    "Something unexpected happened. Please try again later." : "Algo inesperado ocurrió. Por favor, inténtalo de nuevo más tarde.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "Error al solicitar la prueba porque el servidor de prueba se comportó de manera incorrecta. Por favor, inténtalo de nuevo más tarde.",
    "Trial requested but failed to get account information. Please check back later." : "Se solicitó la prueba pero no se pudo obtener la información de la cuenta. Por favor, revisa más tarde.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Hay un problema con la autenticación de esta solicitud. Tal vez no se pueda alcanzar desde el exterior para verificar su URL.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "No se pudo obtener la información de la cuenta porque el servidor de prueba se comportó de manera incorrecta. Por favor, revisa más tarde.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Hay un problema con la obtención de la información de la cuenta. Por favor, revisa tus registros para obtener más información.",
    "There is no such account registered." : "No existe esa cuenta registrada.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "No se pudo obtener la información de la cuenta porque el servidor de prueba no se puede alcanzar. Por favor, revisa más tarde.",
    "Deleting the hosted signaling server account failed. Please check back later." : "Error al eliminar la cuenta del servidor de señalización alojado. Por favor, revisa más tarde.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "No se pudo eliminar la cuenta porque el servidor de prueba se comportó de manera incorrecta. Por favor, revisa más tarde.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Hay un problema con la eliminación de la cuenta. Por favor, revisa tus registros para obtener más información.",
    "Too many requests are sent from your servers address. Please try again later." : "Se están enviando demasiadas solicitudes desde la dirección de tu servidor. Por favor, inténtalo de nuevo más tarde.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "No se pudo eliminar la cuenta porque el servidor de prueba no se puede alcanzar. Por favor, revisa más tarde.",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "United Arab Emirates",
    "Afghanistan" : "Afghanistan",
    "Antigua and Barbuda" : "Antigua and Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Antarctica",
    "Argentina" : "Argentina",
    "American Samoa" : "American Samoa",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Åland Islands",
    "Azerbaijan" : "Azerbaijan",
    "Bosnia and Herzegovina" : "Bosnia and Herzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgium",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei Darussalam" : "Brunei Darussalam",
    "Bolivia, Plurinational State of" : "Bolivia, Estado Plurinacional de",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius and Saba",
    "Brazil" : "Brazil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Bouvet Island",
    "Botswana" : "Botswana",
    "Belarus" : "Belarus",
    "Belize" : "Belize",
    "Canada" : "Canada",
    "Cocos (Keeling) Islands" : "Cocos (Keeling) Islands",
    "Congo, the Democratic Republic of the" : "Congo, República Democrática del",
    "Central African Republic" : "Central African Republic",
    "Congo" : "Congo",
    "Switzerland" : "Switzerland",
    "Côte d'Ivoire" : "Côte d'Ivoire",
    "Cook Islands" : "Cook Islands",
    "Chile" : "Chile",
    "Cameroon" : "Cameroon",
    "China" : "China",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Cabo Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Christmas Island",
    "Cyprus" : "Cyprus",
    "Czechia" : "Czechia",
    "Germany" : "Germany",
    "Djibouti" : "Djibouti",
    "Denmark" : "Denmark",
    "Dominica" : "Dominica",
    "Dominican Republic" : "Dominican Republic",
    "Algeria" : "Algeria",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estonia",
    "Egypt" : "Egypt",
    "Western Sahara" : "Western Sahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Spain",
    "Ethiopia" : "Ethiopia",
    "Finland" : "Finland",
    "Fiji" : "Fiji",
    "Falkland Islands (Malvinas)" : "Falkland Islands (Malvinas)",
    "Micronesia, Federated States of" : "Estados Federados de Micronesia",
    "Faroe Islands" : "Faroe Islands",
    "France" : "France",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "United Kingdom of Great Britain and Northern Ireland",
    "Grenada" : "Grenada",
    "Georgia" : "Georgia",
    "French Guiana" : "French Guiana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Greenland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Equatorial Guinea",
    "Greece" : "Greece",
    "South Georgia and the South Sandwich Islands" : "South Georgia and the South Sandwich Islands",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Heard Island and McDonald Islands",
    "Honduras" : "Honduras",
    "Croatia" : "Croatia",
    "Haiti" : "Haiti",
    "Hungary" : "Hungary",
    "Indonesia" : "Indonesia",
    "Ireland" : "Ireland",
    "Israel" : "Israel",
    "Isle of Man" : "Isle of Man",
    "India" : "India",
    "British Indian Ocean Territory" : "British Indian Ocean Territory",
    "Iraq" : "Iraq",
    "Iran, Islamic Republic of" : "Irán, República Islámica de",
    "Iceland" : "Iceland",
    "Italy" : "Italy",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordan",
    "Japan" : "Japan",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kyrgyzstan",
    "Cambodia" : "Cambodia",
    "Kiribati" : "Kiribati",
    "Comoros" : "Comoros",
    "Saint Kitts and Nevis" : "Saint Kitts and Nevis",
    "Korea, Democratic People's Republic of" : "República Popular Democrática de Corea",
    "Korea, Republic of" : "Corea del Sur",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Cayman Islands",
    "Kazakhstan" : "Kazakhstan",
    "Lao People's Democratic Republic" : "Lao People's Democratic Republic",
    "Lebanon" : "Lebanon",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Lithuania",
    "Luxembourg" : "Luxembourg",
    "Latvia" : "Latvia",
    "Libya" : "Libya",
    "Morocco" : "Morocco",
    "Monaco" : "Monaco",
    "Moldova, Republic of" : "Moldavia, República de",
    "Montenegro" : "Montenegro",
    "Saint Martin (French part)" : "Saint Martin (French part)",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Marshall Islands",
    "North Macedonia" : "Macedonia del Norte",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Northern Mariana Islands",
    "Martinique" : "Martinique",
    "Mauritania" : "Mauritania",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Maldives",
    "Malawi" : "Malawi",
    "Mexico" : "Mexico",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mozambique",
    "Namibia" : "Namibia",
    "New Caledonia" : "New Caledonia",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolk Island",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Netherlands",
    "Norway" : "Norway",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "New Zealand",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "French Polynesia",
    "Papua New Guinea" : "Papua New Guinea",
    "Philippines" : "Philippines",
    "Pakistan" : "Pakistan",
    "Poland" : "Poland",
    "Saint Pierre and Miquelon" : "Saint Pierre and Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Palestine, State of" : "Palestine, State of",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Réunion" : "Réunion",
    "Romania" : "Romania",
    "Serbia" : "Serbia",
    "Russian Federation" : "Russian Federation",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Saudi Arabia",
    "Solomon Islands" : "Solomon Islands",
    "Seychelles" : "Seychelles",
    "Sudan" : "Sudan",
    "Sweden" : "Sweden",
    "Singapore" : "Singapore",
    "Saint Helena, Ascension and Tristan da Cunha" : "Saint Helena, Ascension and Tristan da Cunha",
    "Slovenia" : "Slovenia",
    "Svalbard and Jan Mayen" : "Svalbard and Jan Mayen",
    "Slovakia" : "Slovakia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Suriname",
    "South Sudan" : "South Sudan",
    "Sao Tome and Principe" : "Sao Tome and Principe",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "Sint Maarten (Dutch part)",
    "Syrian Arab Republic" : "Syrian Arab Republic",
    "Eswatini" : "Esuatini",
    "Turks and Caicos Islands" : "Turks and Caicos Islands",
    "Chad" : "Chad",
    "French Southern Territories" : "French Southern Territories",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tajikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisia",
    "Tonga" : "Tonga",
    "Turkey" : "Turkey",
    "Trinidad and Tobago" : "Trinidad and Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "Taiwán, Provincia de China",
    "Tanzania, United Republic of" : "Tanzania, United Republic of",
    "Ukraine" : "Ukraine",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "United States Minor Outlying Islands",
    "United States of America" : "United States of America",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Holy See",
    "Saint Vincent and the Grenadines" : "Saint Vincent and the Grenadines",
    "Venezuela, Bolivarian Republic of" : "Venezuela, República Bolivariana de",
    "Virgin Islands, British" : "Islas Vírgenes Británicas",
    "Virgin Islands, U.S." : "Islas Vírgenes de los Estados Unidos",
    "Viet Nam" : "Viet Nam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis and Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Yemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "South Africa",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Federation" : "Federación",
    "High-performance backend" : "Backend de alto rendimiento",
    "Error: Cannot connect to server" : "Error: No se puede conectar al servidor",
    "Error: Server did not respond with proper JSON" : "Error: El servidor no respondió con un JSON adecuado",
    "Error: Certificate expired" : "Error: Certificado caducado",
    "Could not get version" : "No se pudo obtener la versión",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Error: Versión en ejecución: {version}; El servidor debe actualizarse para ser compatible con esta versión de Talk",
    "Error: Server responded with: {error}" : "Error: El servidor respondió con: {error}",
    "Error: Unknown error occurred" : "Error: Ocurrió un error desconocido",
    "Recording backend" : "Backend de grabación",
    "SIP configuration" : "Configuración SIP",
    "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
    "Conversation not found" : "Conversación no encontrada",
    "Chat, video & audio-conferencing using WebRTC" : "Chat, videoconferencia y audioconferencia utilizando WebRTC",
    "Leave call" : "Dejar la llamada",
    "Navigating away from the page will leave the call in {conversation}" : "Al salir de la página, dejarás la llamada en {conversation}",
    "Stay in call" : "Permanecer en la llamada",
    "Discuss this file" : "Discutir este archivo",
    "Share this file with others to discuss it" : "Comparte este archivo con otros para discutirlo",
    "Share this file" : "Compartir este archivo",
    "Join conversation" : "Unirse a la conversación",
    "This conversation is password-protected." : "Esta conversación está protegida con contraseña.",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "Hemos detectado varios intentos de contraseña no válidos desde tu dirección IP. Por lo tanto, tu próximo intento está limitado a 30 segundos.",
    "The password is wrong. Try again." : "La contraseña está equivoada. Por favor vuelve a intentarlo. ",
    "Password" : "Contraseña",
    "Submit" : "Enviar",
    "Error requesting the password." : "Error al solicitar la contraseña.",
    "Request password" : "Solicitar contraseña",
    "This conversation has ended" : "Esta conversación ha terminado",
    "Error occurred when joining the conversation" : "Ocurrió un error al unirse a la conversación",
    "Close Talk sidebar" : "Cerrar barra lateral de Talk",
    "Open Talk sidebar" : "Abrir barra lateral de Talk",
    "Everyone" : "Todos",
    "Users and moderators" : "Usuarios y moderadores",
    "Moderators only" : "Solo moderadores",
    "Disable calls" : "Desactivar llamadas",
    "Save changes" : "Guardar cambios",
    "Saving …" : "Saving …",
    "Saved!" : "¡Guardado!",
    "Limit to groups" : "Limitar a grupos",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Cuando se selecciona al menos un grupo, solo las personas de los grupos listados pueden ser parte de las conversaciones.",
    "Guests can still join public conversations." : "Los invitados aún pueden unirse a conversaciones públicas.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Los usuarios que ya no pueden usar Talk aún aparecerán como participantes en sus conversaciones anteriores y también se conservarán sus mensajes de chat.",
    "Limit using Talk" : "Limitar uso de Talk",
    "Limit creating a public and group conversation" : "Limitar creación de conversaciones públicas y de grupo",
    "Limit creating conversations" : "Limitar creación de conversaciones",
    "Limit starting a call" : "Limitar inicio de llamada",
    "Limit starting calls" : "Limitar inicio de llamadas",
    "When a call has started, everyone with access to the conversation can join the call." : "Cuando una llamada ha comenzado, todos con acceso a la conversación pueden unirse a la llamada.",
    "Enabled" : "Habilitado",
    "Disabled" : "Deshabilitado",
    "State" : "Estado",
    "Name" : "Nombre",
    "Beta" : "Beta",
    "Permissions" : "Permisos",
    "All messages" : "Todos los mensajes",
    "@-mentions only" : "Solo @-menciones",
    "Off" : "Apagado",
    "General settings" : "Configuraciones generales",
    "Default notification settings" : "Configuración de notificaciones predeterminadas",
    "Default group notification" : "Notificación de grupo predeterminada",
    "Default group notification for new groups" : "Notificación de grupo predeterminada para nuevos grupos",
    "Integration into other apps" : "Integración en otras aplicaciones",
    "Allow conversations on files" : "Permitir conversaciones en archivos",
    "Allow conversations on public shares for files" : "Permitir conversaciones en comparticiones públicas para archivos",
    "Enable encryption" : "Habilitar encripción",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "Haciendo clic en el botón de arriba, la información del formulario se envía a los servidores de Struktur AG. Puedes encontrar más información en {linkstart}spreed.eu{linkend}.",
    "Pending" : "Pendiente",
    "Error" : "Error",
    "Blocked" : "Bloqueado",
    "Active" : "Activo",
    "Expired" : "Expirado",
    "Never" : "Nunca",
    "The trial could not be requested. Please try again later." : "No se pudo solicitar la prueba. Por favor, inténtalo de nuevo más tarde.",
    "The account could not be deleted. Please try again later." : "No se pudo eliminar la cuenta. Por favor, inténtalo de nuevo más tarde.",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Nuestro socio Struktur AG ofrece un servicio donde se puede solicitar un servidor de señalización alojado. Para ello, solo necesitas completar el siguiente formulario y tu Nextcloud lo solicitará. Una vez que se configure el servidor para ti, las credenciales se llenarán automáticamente. Esto sobrescribirá la configuración actual del servidor de señalización.",
    "URL of this Nextcloud instance" : "URL de esta instancia de Nextcloud",
    "Full name of the user requesting the trial" : "Nombre completo del usuario que solicita la prueba",
    "Email of the user" : "Correo electrónico del usuario",
    "Language" : "Idioma",
    "Country" : "País",
    "Request signaling server trial" : "Solicitar prueba del servidor de señalización",
    "You can see the current status of your hosted signaling server in the following table." : "Puedes ver el estado actual de tu servidor de señalización alojado en la siguiente tabla.",
    "Status" : "Estatus",
    "Created at" : "Creado en",
    "Expires at" : "Expira en",
    "Limits" : "Límites",
    "Delete the signaling server account" : "Eliminar la cuenta del servidor de señalización",
    "_%n user_::_%n users_" : ["%n usuario","%n usuarios","%n usuarios"],
    "Installed version: {version}" : "Versión instalada: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "Puedes instalar Matterbridge para enlazar Nextcloud Talk con otros servicios, visita su {linkstart1}página de GitHub{linkend} para obtener más detalles. La descarga e instalación de la aplicación pueden llevar un tiempo. En caso de que expire, por favor, instálala manualmente desde la {linkstart2}Tienda de aplicaciones de Nextcloud{linkend}.",
    "Matterbridge binary was not found or couldn't be executed." : "No se encontró o no se pudo ejecutar el archivo binario de Matterbridge.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "También puedes configurar manualmente la ruta del archivo binario de Matterbridge a través de la configuración. Consulta la {linkstart}documentación de integración de Matterbridge{linkend} para obtener más información.",
    "Downloading …" : "Descargando…",
    "Install Talk Matterbridge" : "Instalar Matterbridge de Talk",
    "An error occurred while installing the Matterbridge app" : "Ocurrió un error durante la instalación de la aplicación Matterbridge.",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "Ocurrió un error durante la instalación de Talk Matterbridge. Por favor, instálala manualmente.",
    "Failed to execute Matterbridge binary." : "Error al ejecutar el archivo binario de Matterbridge.",
    "Matterbridge integration" : "Integración de Matterbridge",
    "Enable Matterbridge integration" : "Habilitar integración de Matterbridge",
    "Status: Checking connection" : "Estado: Comprobando la conexión",
    "OK: Running version: {version}" : "OK: Versión en ejecución: {version}",
    "Recording backend URL" : "URL del servidor de grabación",
    "Validate SSL certificate" : "Validar certificado SSL",
    "Delete this server" : "Eliminar este servidor",
    "Test this server" : "Probar este servidor",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "Las configuraciones PHP \"upload_max_filesize\" o \"post_max_size\" solo permitirán cargar archivos de hasta {maxUpload}.",
    "Recording backend settings saved" : "Configuración del backend de grabación guardada",
    "Add a new recording backend server" : "Agregar un nuevo servidor de backend de grabación",
    "Shared secret" : "Secreto compartido",
    "SIP configuration saved!" : "Configuración SIP guardada",
    "Restrict SIP configuration" : "Restringir la configuración SIP",
    "Enable SIP configuration" : "Habilitar la configuración SIP",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Solo los usuarios de los siguientes grupos pueden habilitar SIP en las conversaciones que moderan",
    "Phone number (Country)" : "Número de teléfono (País)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Esta información se envía en los correos electrónicos de invitación y se muestra en la barra lateral a todos los participantes.",
    "Error code" : "Código de error",
    "High-performance backend URL" : "URL del backend de alto rendimiento",
    "High-performance backend settings saved" : "Configuración del backend de alto rendimiento guardada",
    "STUN server URL" : "URL del servidor STUN",
    "The server address is invalid" : "La dirección del servidor no es válida",
    "STUN settings saved" : "Configuración STUN guardada",
    "STUN servers" : "Servidores STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Un servidor STUN se está usando para determinar la IP pública de los participantes que estén detrás de un ruteador. ",
    "Add a new STUN server" : "Agregar un nuevo servidor STUN",
    "{schema} scheme must be used with a domain" : "El esquema {schema} debe usarse con un dominio",
    "{option1} and {option2}" : "{option1} y {option2}",
    "{option} only" : "Solo {option}",
    "OK: Successful ICE candidates returned by the TURN server" : "OK: Se han devuelto con éxito candidatos ICE por el servidor TURN",
    "Error: No working ICE candidates returned by the TURN server" : "Error: El servidor TURN no devolvió candidatos ICE válidos",
    "Testing whether the TURN server returns ICE candidates" : "Probando si el servidor TURN devuelve candidatos ICE",
    "TURN server schemes" : "Esquemas del servidor TURN",
    "TURN server URL" : "URL del servidor TURN",
    "TURN server secret" : "Secreto del servidor TURN",
    "TURN server protocols" : "Protocolos del servidor TURN",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "Un servidor TURN se utiliza para proxificar el tráfico de los participantes detrás de un cortafuegos. Si los participantes individuales no pueden conectarse a otros, probablemente se requiera un servidor TURN. Consulta {linkstart}esta documentación{linkend} para obtener instrucciones de configuración.",
    "TURN settings saved" : "Configuración TURN guardada",
    "TURN servers" : "Servidores TURN",
    "Add a new TURN server" : "Agregar un nuevo servidor TURN",
    "Failed" : "Error",
    "OK" : "OK",
    "Checking …" : "Verificando ...",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "Error: WebAssembly está deshabilitado o no es compatible con este navegador. Por favor, habilita WebAssembly o utiliza un navegador con soporte para realizar la comprobación.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "Error: Los archivos \".wasm\" y \".tflite\" no se devolvieron correctamente por el servidor web. Por favor, revisa la sección de \"Requisitos del sistema\" en la documentación de Talk.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "OK: Los archivos \".wasm\" y \".tflite\" se devolvieron correctamente por el servidor web.",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "Parece que la configuración de PHP y Apache no es compatible. Ten en cuenta que PHP solo se puede usar con el módulo MPM_PREFORK y PHP-FPM solo se puede usar con el módulo MPM_EVENT.",
    "Web server setup checks" : "Comprobaciones de configuración del servidor web",
    "Files required for virtual background can be loaded" : "Se pueden cargar los archivos necesarios para el fondo virtual",
    "Assign participants to rooms" : "Asignar participantes a salas",
    "Configure breakout rooms" : "Configurar salas separadas",
    "Number of breakout rooms" : "Número de salas separadas",
    "Assignment method" : "Método de asignación",
    "Automatically assign participants" : "Asignar automáticamente a los participantes",
    "Manually assign participants" : "Asignar manualmente a los participantes",
    "Allow participants to choose" : "Permitir que los participantes elijan",
    "Create rooms" : "Crear salas",
    "Confirm" : "Confirmar",
    "Create breakout rooms" : "Crear salas separadas",
    "Reset" : "Restablecer",
    "Delete breakout rooms" : "Eliminar salas separadas",
    "Room {roomNumber}" : "Sala {roomNumber}",
    "Current breakout rooms and settings will be lost" : "Las salas separadas y la configuración actual se perderán",
    "Cancel" : "Cancelar",
    "Unassigned participants" : "Participantes no asignados",
    "Back" : "Atrás",
    "Assign" : "Asignar",
    "Add participant \"{user}\"" : "Agregar participante \"{user}\"",
    "Now" : "Ahora",
    "Loading …" : "Cargando...",
    "From" : "De",
    "To" : "A",
    "Calendar" : "Calendario",
    "Attendees" : "Asistentes",
    "Save" : "Guardar",
    "Search participants" : "Buscar participantes",
    "No results" : "No hay resultados",
    "Done" : "Hecho",
    "Raise hand" : "Levantar la mano",
    "Raise hand (R)" : "Levantar la mano (R)",
    "Lower hand" : "Bajar la mano",
    "Lower hand (R)" : "Bajar la mano (R)",
    "Exit full screen (F)" : "Salir de pantalla completa (F)",
    "Full screen (F)" : "Pantalla completa (F)",
    "Speaker view" : "Vista de orador",
    "Grid view" : "Vista de cuadrícula",
    "This conversation is read-only" : "Esta conversación es de solo lectura",
    "{nickName} raised their hand." : "{nickName} levantó la mano.",
    "A participant raised their hand." : "Un participante levantó la mano.",
    "Collapse stripe" : "Ocultar franja",
    "Expand stripe" : "Expandir franja",
    "Previous page of videos" : "Página anterior de videos",
    "Next page of videos" : "Página siguiente de videos",
    "Connecting …" : "Conectando...",
    "Waiting for {user} to join the call" : "Esperando a que {user} se una a la llamada",
    "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
    "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otras personas en la pestaña de participante del menú lateral",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "¡Puedes invitar a otros usando la pestaña de participante de la barra lateral o compartiendo esta liga para invitar a otras personas!",
    "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
    "Copy link" : "Copiar liga",
    "You are not allowed to enable audio" : "No tienes permiso para habilitar el audio",
    "No audio. Click to select device" : "Sin audio. Haz clic para seleccionar el dispositivo",
    "Mute audio" : "Silenciar audio",
    "Mute audio (M)" : "Silenciar audio (M)",
    "Unmute audio" : "Activar audio",
    "Unmute audio (M)" : "Activar audio (M)",
    "None" : "Ninguno",
    "Access to camera was denied" : "Fue denegado el acceso a la cámara",
    "Error while accessing camera: It is likely in use by another program" : "Error al acceder a la cámara: Es probable que esté siendo utilizada por otro programa",
    "Error while accessing camera" : "Error mientras se accede a la cámara",
    "You have been muted by a moderator" : "Tienes el micrófono desactivado por un moderador",
    "You are not allowed to enable video" : "No tienes permiso para habilitar el video",
    "No video. Click to select device" : "Sin video. Haz clic para seleccionar el dispositivo",
    "Disable video" : "Deshabilitar video",
    "Disable video (V)" : "Desactivar video (V)",
    "Enable video" : "Habilitar el video",
    "Enable video (V)" : "Habilitar video (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Habilitar video: Tu conexión se interrumpirá brevemente al habilitar el video por primera vez",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Habilitar video (V): Tu conexión se interrumpirá brevemente al habilitar el video por primera vez",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Habilitar video: Tu conexión se interrumpirá brevemente al habilitar el video por primera vez",
    "You" : "Tú",
    "Mute" : "Silenciar",
    "Muted" : "Silenciado",
    "Show screen" : "Mostrar pantalla",
    "Stop following" : "Dejar de seguir",
    "Connection could not be established …" : "No se pudo establecer la conexión…",
    "Connection was lost and could not be re-established …" : "Se perdió la conexión y no se pudo restablecer…",
    "Connection could not be established. Trying again …" : "No se pudo establecer la conexión. Intentando nuevamente…",
    "Connection lost. Trying to reconnect …" : "Se perdió la conexión. Intentando reconectar…",
    "Connection problems …" : "Problemas de conexión…",
    "Collapse" : "Colapsar",
    "Expand" : "Expandir",
    "You need to be logged in to upload files" : "Necesitas estar registrado para subir archivos",
    "Drop your files to upload" : "Suelta tus archivos para subirlos",
    "Conversation messages" : "Mensajes de la conversación",
    "Scroll to bottom" : "Desplazarse hasta abajo",
    "Post message" : "Enviar mensaje",
    "Favorite" : "Hacer favorito",
    "Date:" : "Fecha:",
    "Hide details" : "Ocultar detalles",
    "Show details" : "Mostrar detalles",
    "Error while updating conversation name" : "Error al actualizar el nombre de la conversación",
    "Error while updating conversation description" : "Error al actualizar la descripción de la conversación",
    "Enter a name for this conversation" : "Ingresa un nombre para esta conversación",
    "Edit conversation name" : "Editar nombre de la conversación",
    "Edit conversation description" : "Editar descripción de la conversación",
    "Enter a description for this conversation" : "Ingresa una descripción para esta conversación",
    "Picture" : "Imagen",
    "Disable" : "Deshabilitar",
    "Enable" : "Habilitar",
    "Breakout rooms" : "Salas separadas",
    "Manage breakout rooms" : "Gestionar salas de grupos",
    "Set up breakout rooms for this conversation" : "Configurar salas separadas para esta conversación",
    "Please select a valid PNG or JPG file" : "Por favor, selecciona un archivo PNG o JPG válido",
    "Choose your conversation picture" : "Elegir imagen de la conversación",
    "Choose" : "Seleccionar",
    "Error setting conversation picture" : "Error al establecer la imagen de la conversación",
    "Could not set the conversation picture: {error}" : "Error al recortar la imagen de la conversación",
    "Error cropping conversation picture" : "No se pudo establecer la imagen de la conversación: {error}",
    "Error removing conversation picture" : "Error al eliminar la imagen de la conversación",
    "Set emoji as conversation picture" : "Establecer un emoji como imagen de la conversación",
    "Set background color for conversation picture" : "Establecer el color de fondo para la imagen de la conversación",
    "Upload conversation picture" : "Subir imagen de la conversación",
    "Choose conversation picture from files" : "Elegir imagen de la conversación desde archivos",
    "Remove conversation picture" : "Eliminar imagen de la conversación",
    "The file must be a PNG or JPG" : "El archivo debe ser PNG o JPG",
    "Set picture" : "Establecer imagen",
    "Default permissions modified for {conversationName}" : "Permisos predeterminados modificados para {nombreConversación}",
    "Could not modify default permissions for {conversationName}" : "No se pudieron modificar los permisos predeterminados para {nombreConversación}",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Editar los permisos predeterminados para los participantes en esta conversación. Estas configuraciones no afectan a los moderadores.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Cada vez que se modifiquen los permisos en esta sección, se perderán los permisos personalizados asignados previamente a los participantes individuales.",
    "All permissions" : "Todos los permisos",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Los participantes tienen permisos para iniciar una llamada, unirse a una llamada, habilitar el audio y video, y compartir pantalla.",
    "Restricted" : "Restringido",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Los participantes pueden unirse a las llamadas, pero no pueden habilitar el audio ni el video ni compartir pantalla hasta que un moderador les otorgue permisos manualmente.",
    "Advanced permissions" : "Permisos avanzados",
    "Edit permissions" : "Editar permisos",
    "Conversation settings" : "Configuración de la conversación",
    "Basic Info" : "Información básica",
    "Personal" : "Personal",
    "Moderation" : "Moderación",
    "Breakout Rooms" : "Salas separadas",
    "Matterbridge" : "Matterbridge",
    "Danger zone" : "Zona peligrosa",
    "Leave conversation" : "Dejar la conversación",
    "You need to promote a new moderator before you can leave the conversation" : "Necesitas promover un nuevo moderador antes de poder abandonar la conversación",
    "Delete conversation" : "Borrar conversación",
    "Do you really want to delete \"{displayName}\"?" : "¿Realmente quieres eliminar \"{nombreCompleto}\"?",
    "Error while deleting conversation" : "Error al eliminar la conversación",
    "Delete all chat messages" : "Eliminar todos los mensajes del chat",
    "Do you really want to delete all messages in \"{displayName}\"?" : "¿Realmente quieres eliminar todos los mensajes en \"{nombreCompleto}\"?",
    "Error while clearing chat history" : "Error al borrar el historial del chat",
    "Be careful, these actions cannot be undone." : "Ten cuidado, estas acciones no se pueden deshacer.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Una vez que se abandona una conversación, para volver a unirse a una conversación cerrada, se necesita una invitación. Una conversación abierta se puede volver a unir en cualquier momento.",
    "Permanently delete this conversation." : "Eliminar permanentemente esta conversación.",
    "Delete chat messages" : "Eliminar mensajes del chat",
    "Permanently delete all the messages in this conversation." : "Eliminar permanentemente todos los mensajes en esta conversación.",
    "_%n hour_::_%n hours_" : ["%n hora","%n horas","%n horas"],
    "_%n day_::_%n days_" : ["%n day","%n days","%n days"],
    "_%n week_::_%n weeks_" : ["%n week","%n weeks","%n weeks"],
    "Custom expiration time" : "Hora de vencimiento personalizada",
    "Message expiration disabled" : "Vencimiento del mensaje deshabilitado",
    "Message expiration set: {duration}" : "Vencimiento del mensaje establecido: {duration}",
    "Error when trying to set message expiration" : "Error al intentar establecer el vencimiento del mensaje",
    "Message expiration" : "Vencimiento del mensaje",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Los mensajes de chat pueden vencer después de cierto tiempo. Nota: Los archivos compartidos en el chat no se eliminarán para el propietario, pero ya no se compartirán en la conversación.",
    "Guest access" : "Acceso de invitado",
    "Allow guests to join this conversation via link" : "Permitir que los invitados se unan a esta conversación a través de un enlace",
    "Password protection" : "Protección con contraseña",
    "Set a password" : "Establecer una contraseña",
    "Enter new password" : "Ingresa una nueva contraseña",
    "Save password" : "Guardar contraseña",
    "Resend invitations" : "Volver a enviar invitaciones",
    "Error occurred when opening or limiting the conversation" : "Error al abrir o limitar la conversación",
    "Open conversation to registered users, showing it in search results" : "Abrir la conversación a usuarios registrados, mostrándola en los resultados de búsqueda",
    "Start time has been updated" : "La hora de inicio se ha actualizado",
    "Error occurred while updating start time" : "Error al actualizar la hora de inicio",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "Al habilitar el vestíbulo, los no moderadores se eliminarán de la llamada en curso.",
    "Enable lobby, restricting the conversation to moderators" : "Habilitar el vestíbulo, restringiendo la conversación a los moderadores",
    "Meeting start time" : "Hora de inicio de la reunión",
    "Start time (optional)" : "Hora de inicio (opcional)",
    "Error occurred when locking the conversation" : "Error al bloquear la conversación",
    "Error occurred when unlocking the conversation" : "Error al desbloquear la conversación",
    "Lock conversation" : "Bloquear conversación",
    "This will also terminate the ongoing call." : "Esto también terminará la llamada en curso.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Bloquear la conversación para evitar que alguien publique mensajes o inicie llamadas",
    "Edit" : "Editar",
    "More information" : "More information",
    "Delete" : "Borrar",
    "Add new bridged channel to current conversation" : "Agregar nuevo canal vinculado a la conversación actual",
    "unknown state" : "estado desconocido",
    "running" : "ejecutándose",
    "not running, check Matterbridge log" : "no se está ejecutando, revisa el registro de Matterbridge",
    "not running" : "no se está ejecutando",
    "Bridge saved" : "Puente guardado",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Puedes vincular canales de varios sistemas de mensajería instantánea con Matterbridge.",
    "More info on Matterbridge" : "Más información sobre Matterbridge",
    "Enable bridge" : "Habilitar puente",
    "Show Matterbridge log" : "Mostrar registro de Matterbridge",
    "Log content" : "Contenido de bitácoras",
    "Notifications" : "Notificaciones",
    "Notify about calls in this conversation" : "Notificar sobre llamadas en esta conversación",
    "Important conversation" : "Conversación importante",
    "SIP dial-in is now possible without PIN requirement" : "Ahora es posible el acceso telefónico SIP sin requerimiento de PIN",
    "SIP dial-in is now enabled" : "El acceso telefónico SIP ahora está habilitado",
    "SIP dial-in is now disabled" : "El acceso telefónico SIP ahora está deshabilitado",
    "Error occurred when enabling SIP dial-in" : "Se produjo un error al habilitar el acceso telefónico SIP",
    "Error occurred when disabling SIP dial-in" : "Se produjo un error al deshabilitar el acceso telefónico SIP",
    "Phone and SIP dial-in" : "Marcar y acceso telefónico SIP",
    "Enable phone and SIP dial-in" : "Habilitar marcar y acceso telefónico SIP",
    "Allow to dial-in without a PIN" : "Permitir marcar y acceder sin PIN",
    "In {conversation}" : "En {conversation}",
    "Join" : "Unirse",
    "Error while creating the conversation" : "Error al crear la conversación",
    "Unread mentions" : "Menciones no leídas",
    "Create conversation" : "Crear conversación",
    "Log in" : "Ingresar",
    "Mark as read" : "Marcar como leído",
    "Mark as unread" : "Marcar como no leído",
    "Remove from favorites" : "Eliminar de favoritos",
    "Add to favorites" : "Agregar a tus favoritos",
    "You need to promote a new moderator before you can leave the conversation." : "Necesitas promover un nuevo moderador antes de abandonar la conversación.",
    "Conversation actions" : "Acciones de la conversación",
    "Home" : "Inicio",
    "Unread" : "No leído",
    "Alphabetically" : "Alfabéticamente",
    "No matches found" : "No se encontraron coincidencias",
    "No conversations found" : "No se encontraron conversaciones",
    "An error occurred while performing the search" : "Se produjo un error al realizar la búsqueda",
    "Conversation list" : "Lista de conversaciones",
    "Unread messages" : "Mensajes no leídos",
    "Clear filters" : "Borrar filtros",
    "Threads" : "Hilos",
    "Clear filter" : "Borrar filtro",
    "App settings" : "Configuraciones de la aplicación",
    "Users" : "Usuarios",
    "Groups" : "Grupos",
    "Other sources" : "Otras fuentes",
    "Open conversations" : "Conversaciones abiertas",
    "No search results" : "No hay resultados de búsqueda",
    "Users and groups" : "Usuarios y grupos",
    "The meeting will start soon" : "La reunión comenzará pronto",
    "This meeting is scheduled for {startTime}" : "Esta reunión está programada para {startTime}",
    "You are currently waiting in the lobby" : "Actualmente estás esperando en el vestíbulo",
    "Select microphone" : "Seleccionar micrófono",
    "No microphone available" : "No hay micrófono disponible",
    "Select camera" : "Seleccione la cámara",
    "No camera available" : "No hay cámara disponible",
    "Test" : "Prueba",
    "Devices" : "Dispositivos",
    "Backgrounds" : "Fondos",
    "No audio" : "Sin audio",
    "No camera" : "No hay cámara",
    "Calls are not supported in your browser" : "Las llamadas no son compatibles en tu navegador",
    "Access to microphone is only possible with HTTPS" : "El acceso al micrófono solo es posible con HTTPS",
    "Access to microphone was denied" : "Se denegó el acceso al micrófono",
    "Error while accessing microphone" : "Error al acceder al micrófono",
    "Access to camera is only possible with HTTPS" : "El acceso a la cámara sólo es posible con HTTPS",
    "The call is being recorded." : "La llamada está siendo grabada.",
    "Select virtual office background" : "Seleccionar fondo de oficina virtual",
    "Select virtual home background" : "Seleccionar fondo de hogar virtual",
    "Select virtual abstract background" : "Seleccionar fondo abstracto virtual",
    "Select virtual beach background" : "Seleccionar fondo de playa virtual",
    "Select virtual park background" : "Seleccionar fondo de parque virtual",
    "Select virtual theater background" : "Seleccionar fondo de teatro virtual",
    "Select virtual library background" : "Seleccionar fondo de biblioteca virtual",
    "Select virtual space station background" : "Seleccionar fondo de estación espacial virtual",
    "Error while uploading the file" : "Error al cargar el archivo",
    "Select a file" : "Seleccionar un archivo",
    "Invalid path selected" : "Ruta seleccionada no válida.",
    "Select virtual background from file {fileName}" : "Seleccionar fondo virtual del archivo {fileName}",
    "Blur" : "Desenfoque",
    "Upload" : "Cargar",
    "Files" : "Archivos",
    "The message has expired or has been deleted" : "El mensaje ha caducado o ha sido eliminado",
    "Cancel quote" : "Cancelar cotización",
    "24 hours" : "24 horas",
    "7 days" : "7 días",
    "Add a reaction to this message" : "Agregar una reacción a este mensaje",
    "Reply" : "Responder",
    "More actions" : "Más acciones",
    "Reply privately" : "Responder de forma privada",
    "Edit message" : "Editar mensaje",
    "Copy message link" : "Copiar enlace del mensaje",
    "Go to file" : "Ir al archivo",
    "Forward message" : "Reenviar mensaje",
    "Translate" : "Traducir",
    "Close reactions menu" : "Cerrar menú de reacciones",
    "React with {emoji}" : "Reaccionar con {emoji}",
    "React with another emoji" : "Reaccionar con otro emoji",
    "Choose a conversation to forward the selected message." : "Elige una conversación para reenviar el mensaje seleccionado.",
    "Error while forwarding message" : "Error al reenviar el mensaje",
    "The message has been forwarded to {selectedConversationName}" : "El mensaje ha sido reenviado a {selectedConversationName}",
    "Dismiss" : "Descartar",
    "Go to conversation" : "Ir a la conversación",
    "Detect language" : "Detectar idioma",
    "The message could not be translated" : "No se pudo traducir el mensaje",
    "Translation copied to clipboard" : "Traducción copiada al portapapeles",
    "Translation could not be copied" : "No se pudo copiar la traducción",
    "Translate message" : "Traducir mensaje",
    "Source language to translate from" : "Idioma de origen para traducir",
    "Translate from" : "Traducir desde",
    "Target language to translate into" : "Idioma de destino para la traducción",
    "Translate to" : "Traducir a",
    "Translating" : "Traduciendo",
    "Copy translated text" : "Copiar texto traducido",
    "Send now" : "Enviar ahora",
    "Message read by everyone who shares their reading status" : "Mensaje leído por todos los que comparten su estado de lectura",
    "Message sent" : "Mensaje enviado",
    "Deleting message" : "Borrando mensaje",
    "Message deleted successfully" : "Mensaje eliminado correctamente",
    "Message could not be deleted because it is too old" : "No se pudo eliminar el mensaje porque es demasiado antiguo",
    "Only normal chat messages can be deleted" : "Solo los mensajes de chat normales se pueden eliminar",
    "An error occurred while deleting the message" : "Se produjo un error al eliminar el mensaje",
    "Your browser does not support playing audio files" : "Tu navegador no admite la reproducción de archivos de audio",
    "Contact" : "Contacto",
    "{stack} in {board}" : "{stack} en {board}",
    "Deck Card" : "Tarjeta de mazo",
    "Remove {fileName}" : "Eliminar {fileName}",
    "Open this location in OpenStreetMap" : "Abrir esta ubicación en OpenStreetMap",
    "Sending message" : "Enviando mensaje",
    "Failed to send the message. Click to try again" : "No se pudo enviar el mensaje. Haz clic para intentar nuevamente",
    "Not enough free space to upload file" : "No hay suficiente espacio libre para subir el archivo",
    "You cannot send messages to this conversation at the moment" : "No puedes enviar mensajes a esta conversación en este momento",
    "You voted" : "Votaste",
    "_%n vote_::_%n votes_" : ["%n voto","%n votos","%n votos"],
    "Open poll" : "Encuesta abierta",
    "See results" : "Ver resultados",
    "No permission to post reactions in this conversation" : "No tienes permiso para publicar reacciones en esta conversación",
    "Add more reactions" : "Agregar más reacciones",
    "No messages" : "Sin mensajes",
    "All messages have expired or have been deleted." : "Todos los mensajes han caducado o han sido eliminados.",
    "Unpin" : "Desanclar",
    "Cancel search" : "Cancelar búsqueda",
    "Create a new group conversation" : "Crear una nueva conversación grupal",
    "Add participants" : "Agregar participantes",
    "Conversation visibility" : "Visibilidad de la conversación",
    "Allow guests to join via link" : "Permitir que los invitados se unan mediante enlace",
    "Enter password" : "Introducir contraseña",
    "This conversation has been locked" : "Esta conversación ha sido bloqueada",
    "No permission to post messages in this conversation" : "No tienes permiso para enviar mensajes en esta conversación",
    "Joining conversation …" : "Unirse a la conversación ...",
    "Send message" : "Enviar mensaje",
    "Send without notification" : "Enviar sin notificación",
    "File to share" : "Archivo para compartir",
    "Add emoji" : "Añadir emoji",
    "Send later" : "Enviar más tarde",
    "Cancel editing" : "Cancelar edición",
    "Share from {nextcloud}" : "Compartir desde {nextcloud}",
    "Share from Files" : "Compartir desde Archivos",
    "Share files to the conversation" : "Compartir archivos en la conversación",
    "Upload from device" : "Subir desde el dispositivo",
    "Create new poll" : "Crear nueva encuesta",
    "Smart picker" : "Selector inteligente",
    "Record voice message" : "Grabar mensaje de voz",
    "End recording and send" : "Finalizar grabación y enviar",
    "Dismiss recording" : "Descartar grabación",
    "Access to the microphone was denied" : "Se ha denegado el acceso al micrófono",
    "Microphone either not available or disabled in settings" : "El micrófono no está disponible o está desactivado en la configuración",
    "Error while recording audio" : "Error al grabar audio",
    "New file" : "Nuevo archivo",
    "Blank" : "En blanco",
    "Error while creating file" : "Error al crear el archivo",
    "Create and share a new file" : "Crear y compartir un nuevo archivo",
    "Name of the new file" : "Nombre del nuevo archivo",
    "Create file" : "Crear archivo",
    "Someone is typing …" : "Alguien está escribiendo …",
    "{user1} is typing …" : "{user1} está escribiendo …",
    "{user1} and {user2} are typing …" : "{user1} y {user2} están escribiendo …",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} y {user3} están escribiendo …",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} y %n otro están escribiendo …","{user1}, {user2}, {user3} y %n otros están escribiendo …","{user1}, {user2}, {user3} y %n otros están escribiendo …"],
    "Add more files" : "Agregar más archivos",
    "Send" : "Enviar",
    "In this conversation <strong>{user}</strong> can:" : "En esta conversación <strong>{user}</strong> puede:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Editar permisos predeterminados para los participantes en <strong>{conversationName}</strong>",
    "Start a call" : "Iniciar una llamada",
    "Skip the lobby" : "Saltar el vestíbulo",
    "Can post messages and reactions" : "Puede publicar mensajes y reacciones",
    "Enable the microphone" : "Habilitar el micrófono",
    "Enable the camera" : "Habilitar la cámara",
    "Share the screen" : "Compartir pantalla",
    "Update permissions" : "Actualizar permisos",
    "Updating permissions" : "Actualizando permisos",
    "Create poll" : "Crear encuesta",
    "Question" : "Pregunta",
    "Ask a question" : "Hacer una pregunta",
    "Answers" : "Respuestas",
    "Answer {option}" : "Responder {option}",
    "Delete poll option" : "Eliminar opción de encuesta",
    "Add answer" : "Agregar respuesta",
    "Settings" : "Configuraciones ",
    "Anonymous poll" : "Encuesta anónima",
    "Multiple answers" : "Respuestas múltiples",
    "You voted for this option" : "Has votado por esta opción",
    "End poll" : "Finalizar encuesta",
    "Change your vote" : "Cambiar tu voto",
    "Results" : "Resultados",
    "Voted participants" : "Participantes que votaron",
    "Send a message to \"{roomName}\"" : "Enviar un mensaje a \"{roomName}\"",
    "Hide list of participants" : "Ocultar lista de participantes",
    "Show list of participants" : "Mostrar lista de participantes",
    "Assistance requested in {roomName}" : "Asistencia solicitada en {roomName}",
    "The message was sent to \"{roomName}\"" : "El mensaje se envió a \"{roomName}\"",
    "Dismiss request for assistance" : "Descartar solicitud de asistencia",
    "Send message to room" : "Enviar mensaje a la sala",
    "Back to main room" : "Volver a la sala principal",
    "Back to your room" : "Volver a tu sala",
    "Message all rooms" : "Enviar mensaje a todas las salas",
    "Start session" : "Iniciar sesión",
    "Start a call before you start a breakout room session" : "Iniciar una llamada antes de comenzar la sesión de salas de grupos",
    "Stop session" : "Detener sesión",
    "The message was sent to all breakout rooms" : "El mensaje se envió a todas las salas separadas",
    "Send a message to all breakout rooms" : "Enviar un mensaje a todas las salas separadas",
    "Breakout rooms are not started" : "Las salas de grupos no han sido iniciadas",
    "Disable lobby" : "Deshabilitar vestíbulo",
    "Settings for participant \"{user}\"" : "Configuración para el participante \"{user}\"",
    "Participant \"{user}\"" : "Participante \"{user}\"",
    "moderator" : "moderador",
    "bot" : "bot",
    "guest" : "invitado/a",
    "Raised their hand" : "Levantó la mano",
    "Joined with video" : "Se unió con video",
    "Joined via phone" : "Se unió a través del teléfono",
    "Joined with audio" : "Se unió con audio",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "El texto debe tener una longitud menor o igual a {maxLength} caracteres. Tu texto actual tiene {charactersCount} caracteres.",
    "Remove group and members" : "Eliminar grupo y miembros",
    "Remove participant" : "Eliminar participante",
    "Notification was sent to {displayName}" : "Se envió una notificación a {displayName}",
    "Could not send notification to {displayName}" : "No se pudo enviar la notificación a {displayName}",
    "Permissions granted to {displayName}" : "Permisos otorgados a {displayName}",
    "Could not modify permissions for {displayName}" : "No se pudieron modificar los permisos para {displayName}",
    "Permissions removed for {displayName}" : "Permisos eliminados para {displayName}",
    "Permissions set to default for {displayName}" : "Permisos restablecidos a los valores predeterminados para {displayName}",
    "Dial-in PIN" : "PIN para marcar desde teléfono",
    "Demote from moderator" : "Degradar de moderador",
    "Promote to moderator" : "Promover a moderador",
    "Resend invitation" : "Reenviar invitación",
    "Send call notification" : "Enviar notificación de llamada",
    "Reset custom permissions" : "Restablecer permisos personalizados",
    "Grant all permissions" : "Otorgar todos los permisos",
    "Remove all permissions" : "Eliminar todos los permisos",
    "Permissions modified for {displayName}" : "Permisos modificados para {displayName}",
    "Add users or groups" : "Agregar usuarios o grupos",
    "Add users" : "Agregar usuarios",
    "Add groups" : "Agregar grupos",
    "Add other sources" : "Agregar otras fuentes",
    "Add emails" : "Agregar correos electrónicos",
    "Integrations" : "Integraciones",
    "Add federated users" : "Agregar usuarios federados",
    "Searching …" : "Buscando...",
    "Search for more users" : "Buscar más usuarios",
    "Search or add participants" : "Buscar o agregar participantes",
    "Invitation was sent to {actorId}" : "La invitación fue enviada a {actorId}",
    "An error occurred while adding the participants" : "Se produjo un error al agregar los participantes",
    "Participants" : "Participantes",
    "Participants ({count})" : "Participantes ({count})",
    "Open chat" : "Abrir chat",
    "You have new unread messages in the chat." : "Tienes nuevos mensajes no leídos en el chat.",
    "You have been mentioned in the chat." : "Has sido mencionado en el chat.",
    "Chat" : "Chat",
    "Details" : "Detalles",
    "Shared items" : "Elementos compartidos",
    "No results found" : "No se encontraron resultados",
    "Load more results" : "Cargar más resultados",
    "Projects" : "Proyectos",
    "No shared items" : "No hay elementos compartidos",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Enlace a una conversación",
    "Search conversations or users" : "Buscar conversaciones o usuarios",
    "Select conversation" : "Seleccionar conversación",
    "Display name: {name}" : "Nombre de visualización: {name}",
    "Edit display name" : "Editar nombre para mostrar",
    "Save name" : "Guardar nombre",
    "Error while saving sounds setting" : "Error al guardar la configuración de sonidos",
    "Play sounds when participants join or leave a call" : "Reproducir sonidos cuando los participantes se unan o salgan de una llamada",
    "Notification settings" : "Configuración de notificaciones",
    "Default language" : "Idioma predeterminado",
    "Select location for attachments" : "Seleccionar ubicación para archivos adjuntos",
    "Error while setting attachment folder" : "Error al configurar la carpeta de archivos adjuntos",
    "Error while setting read status privacy" : "Error al configurar la privacidad del estado de lectura",
    "Error while setting typing status privacy" : "Error al configurar la privacidad del estado de escritura",
    "Privacy" : "Privacidad",
    "Attachments folder" : "Carpeta de archivos adjuntos",
    "Toggle full screen" : "Alternar pantalla completa",
    "Search" : "Buscar",
    "Focus the chat input" : "Enfocar el área de chat",
    "Unfocus the chat input to use shortcuts" : "Desenfocar el área de chat para usar atajos",
    "Shortcuts while in a call" : "Atajos mientras estás en una llamada",
    "Camera on and off" : "Encender y apagar la cámara",
    "Microphone on and off" : "Encender y apagar el micrófono",
    "Raise or lower hand" : "Levantar o bajar la mano",
    "Push to talk or push to mute" : "Pulsar para hablar o pulsar para silenciar",
    "Start call silently" : "Iniciar llamada en silencio",
    "Start call" : "Iniciar llamada",
    "You will be able to join the call only after a moderator starts it." : "Solo podrás unirte a la llamada después de que un moderador la inicie.",
    "End call for everyone" : "Finalizar llamada para todos",
    "Starting the recording" : "Iniciando la grabación",
    "Recording" : "Grabación",
    "Cancel recording start" : "Cancelar inicio de grabación",
    "Stop recording" : "Detener grabación",
    "Send a reaction" : "Enviar una reacción",
    "React with {reaction}" : "Reaccionar con {reaction}",
    "_%n participant in call_::_%n participants in call_" : ["%n participante en llamada","%n participantes en llamada","%n participantes en llamada"],
    "You are not allowed to enable screensharing" : "No tienes permiso para activar el intercambio de pantallas",
    "No screensharing" : "Sin intercambio de pantallas",
    "Screensharing options" : "Opciones de compartir pantalla",
    "Enable screensharing" : "Habilitar compartir pantalla",
    "Bad sent video and screen quality." : "Mala calidad de video y pantalla enviados.",
    "Bad sent screen quality." : "Mala calidad de pantalla enviada.",
    "Bad sent video quality." : "Mala calidad de video enviada.",
    "Bad sent audio, video and screen quality." : "Mala calidad de audio, video y pantalla enviados.",
    "Bad sent audio and screen quality." : "Mala calidad de audio y pantalla enviados.",
    "Bad sent audio and video quality." : "Mala calidad de audio y video enviados.",
    "Bad sent audio quality." : "Mala calidad de audio enviada.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Tu conexión a internet o tu computadora están ocupados, y es posible que otros participantes no puedan ver tu pantalla. Para mejorar la situación, intenta desactivar el desenfoque de fondo o tu video mientras compartes pantalla.",
    "Disable background blur" : "Deshabilitar desenfoque de fondo",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Tu conexión a internet o tu computadora están ocupados, y es posible que otros participantes no puedan ver tu pantalla. Para mejorar la situación, intenta desactivar tu video mientras compartes pantalla.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Tu conexión a internet o tu computadora están ocupados, y es posible que otros participantes no puedan ver tu pantalla.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Tu conexión a internet o tu computadora están ocupados, y es posible que otros participantes no puedan verte.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Tu conexión a internet o tu computadora están ocupados, y es posible que otros participantes no puedan entenderte y verte. Para mejorar la situación, intenta desactivar el desenfoque de fondo o tu video mientras compartes pantalla.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Tu conexión a internet o tu computadora están ocupados, y es posible que otros participantes no puedan entenderte y verte. Para mejorar la situación, intenta desactivar tu video mientras compartes pantalla.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Tu conexión a internet o tu computadora están ocupados, y es posible que otros participantes no puedan entenderte y ver tu pantalla. Para mejorar la situación, intenta desactivar tu compartición de pantalla.",
    "Disable screenshare" : "Desactivar compartición de pantalla",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Tu conexión a internet o tu computadora están ocupados, y es posible que otros participantes no puedan entenderte y verte. Para mejorar la situación, intenta desactivar el desenfoque de fondo o tu video.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Tu conexión a internet o tu computadora están ocupados, y es posible que otros participantes no puedan entenderte y verte. Para mejorar la situación, intenta desactivar tu video.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Tu conexión a internet o tu computadora están ocupados, y es posible que otros participantes no puedan entenderte.",
    "Screen sharing is not supported by your browser." : "El intercambio de pantalla no es compatible con tu navegador.",
    "Screen sharing requires the page to be loaded through HTTPS." : "El intercambio de pantalla requiere que la página se cargue a través de HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
    "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
    "Show your screen" : "Mostrar tu pantalla",
    "Stop screensharing" : "Dejar de compartir la pantalla",
    "Mute others" : "Silenciar a otros",
    "Start recording" : "Iniciar grabación",
    "Set up breakout rooms" : "Configurar salas de grupos",
    "Remove participant {name}" : "Eliminar participante {name}",
    "Keep" : "Mantén",
    "Select a region" : "Selecciona una región",
    "Search …" : "Buscar...",
    "Message without mention" : "Mensaje sin mencionar",
    "Mention myself" : "Mencionarme a mí mismo",
    "The conversation does not exist" : "La conversación no existe",
    "Join a conversation or start a new one!" : "Únete a una conversación o inicia una nueva",
    "Duplicate session" : "Sesión duplicada",
    "Join a conversation or start a new one" : "Únete a la conversación o incia una nueva",
    "Nextcloud URL" : "URL de Nextcloud",
    "Nextcloud user" : "Usuario de Nextcloud",
    "User password" : "Contraseña de usuario",
    "Talk conversation" : "Conversación de Talk",
    "Skip TLS verification" : "Omitir verificación TLS",
    "Matrix server URL" : "URL del servidor de Matrix",
    "User" : "Usuario",
    "Matrix channel" : "Canal de Matrix",
    "Mattermost server URL" : "URL del servidor de Mattermost",
    "Mattermost user" : "Usuario de Mattermost",
    "Team name" : "Nombre del equipo",
    "Channel name" : "Nombre del canal",
    "Rocket.Chat server URL" : "URL del servidor de Rocket.Chat",
    "User name or email address" : "Nombre de usuario o dirección de correo electrónico",
    "Rocket.Chat channel" : "Canal de Rocket.Chat",
    "Zulip server URL" : "URL del servidor de Zulip",
    "Bot user name" : "Nombre de usuario del bot",
    "Bot API key" : "Clave de API del bot",
    "Zulip channel" : "Canal de Zulip",
    "API token" : "Ficha del API",
    "Slack channel" : "Canal de Slack",
    "Server ID or name" : "ID o nombre del servidor",
    "Channel" : "Canal",
    "Login" : "Iniciar sesión",
    "Chat ID" : "ID de chat",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "URL del servidor de IRC (por ejemplo, chat.freenode.net:6667)",
    "Nickname" : "Apodo",
    "Connection password" : "Contraseña de conexión",
    "IRC channel" : "Canal de IRC",
    "Channel password" : "Contraseña del canal",
    "NickServ nickname" : "Apodo de NickServ",
    "NickServ password" : "Contraseña de NickServ",
    "Use TLS" : "Usar TLS",
    "Use SASL" : "Usar SASL",
    "Tenant ID" : "ID de inquilino",
    "Client ID" : "ID del cliente",
    "Team ID" : "ID de equipo",
    "Thread ID" : "ID de hilo",
    "XMPP/Jabber server URL" : "URL del servidor XMPP/Jabber",
    "MUC server URL" : "URL del servidor MUC",
    "Jabber ID" : "ID de Jabber",
    "Media" : "Multimedia",
    "Polls" : "Encuestas",
    "Deck cards" : "Tarjetas de mazo",
    "Voice messages" : "Mensajes de voz",
    "Locations" : "Ubicaciones",
    "Call recordings" : "Grabaciones de llamadas",
    "Audio" : "Audio",
    "Show all media" : "Mostrar todos los archivos adjuntos",
    "Show all files" : "Mostrar todos los archivos",
    "Show all polls" : "Mostrar todas las encuestas",
    "Show all deck cards" : "Mostrar todas las tarjetas de mazo",
    "Show all voice messages" : "Mostrar todos los mensajes de voz",
    "Show all locations" : "Mostrar todas las ubicaciones",
    "Show all call recordings" : "Mostrar todas las grabaciones de llamadas",
    "Show all audio" : "Mostrar todo el audio",
    "Show all other" : "Mostrar todo lo demás",
    "Group" : "Grupo",
    "You: {lastMessage}" : "Tú: {lastMessage}",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Estás intentando unirte a una conversación mientras tienes una sesión activa en otra ventana o dispositivo. Actualmente, esto no es compatible con Nextcloud Talk. ¿Qué quieres hacer?",
    "Leave this page" : "Salir de esta página",
    "Join here" : "Unirse aquí",
    "An error occurred while posting deck card to conversation" : "Se produjo un error al publicar la tarjeta de mazo en la conversación",
    "Post to a conversation" : "Publicar en una conversación",
    "Post to conversation" : "Publicar en la conversación",
    "The recording failed. Please contact your administrator." : "La grabación falló. Por favor, contacta a tu administrador.",
    "An error occurred while posting location to conversation" : "Se produjo un error al publicar la ubicación en la conversación",
    "Share to a conversation" : "Compartir en una conversación",
    "Share to conversation" : "Compartir en la conversación",
    "Error while clearing conversation history" : "Error al borrar el historial de conversación",
    "Error occurred while allowing guests" : "Error al permitir invitados",
    "Error occurred while disallowing guests" : "Error al denegar invitados",
    "Error occurred when restricting the conversation to moderator" : "Error al restringir la conversación a los moderadores",
    "Error occurred when opening the conversation to everyone" : "Error al abrir la conversación a todos",
    "Conversation password has been saved" : "La contraseña de la conversación se ha guardado",
    "Conversation password has been removed" : "La contraseña de la conversación se ha eliminado",
    "Error occurred while saving conversation password" : "Error al guardar la contraseña de la conversación",
    "Call recording is starting." : "La grabación de la llamada está comenzando.",
    "Call recording stopped while starting." : "La grabación de la llamada se detuvo al iniciar.",
    "Call recording stopped. You will be notified once the recording is available." : "La grabación de la llamada se detuvo. Se te notificará una vez que la grabación esté disponible.",
    "Conversation picture set" : "Imagen de la conversación establecida",
    "Conversation picture deleted" : "Imagen de la conversación eliminada",
    "Could not delete the conversation picture" : "No se pudo eliminar la imagen de la conversación",
    "Could not post message: {errorMessage}" : "No se pudo enviar el mensaje: {errorMessage}",
    "An error occurred while fetching the participants" : "Se produjo un error al obtener los participantes",
    "Could not send invitation to {actorId}" : "No se pudo enviar la invitación a {actorId}",
    "Invitations sent" : "Invitaciones enviadas",
    "Error occurred when sending invitations" : "Error al enviar las invitaciones",
    "An error occurred while creating breakout rooms" : "Se produjo un error al crear salas de grupos",
    "An error occurred while re-ordering the attendees" : "Se produjo un error al reordenar los asistentes",
    "An error occurred while deleting breakout rooms" : "Se produjo un error al eliminar las salas de grupos",
    "An error occurred while starting breakout rooms" : "Se produjo un error al iniciar las salas de grupos",
    "An error occurred while stopping breakout rooms" : "Se produjo un error al detener las salas de grupos",
    "An error occurred while sending a message to the breakout rooms" : "Se produjo un error al enviar un mensaje a las salas de grupos",
    "An error occurred while requesting assistance" : "Se produjo un error al solicitar asistencia",
    "An error occurred while resetting the request for assistance" : "Se produjo un error al restablecer la solicitud de asistencia",
    "An error occurred while joining breakout room" : "Se produjo un error al unirse a la sala de grupos",
    "{guest} (guest)" : "{guest} (invitado)",
    "An error occurred while submitting your vote" : "Se produjo un error al enviar tu voto",
    "An error occurred while ending the poll" : "Se produjo un error al finalizar la encuesta",
    "Failed to add reaction" : "Error al agregar una reacción",
    "Failed to remove reaction" : "Error al eliminar una reacción",
    "Error while uploading file \"{fileName}\"" : "Error al cargar el archivo \"{fileName}\"",
    "Not enough free space to upload file \"{fileName}\"" : "No hay suficiente espacio libre para cargar el archivo \"{fileName}\"",
    "You are not allowed to share files" : "No tienes permiso para compartir archivos",
    "Error while sharing file" : "Error al compartir el archivo",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "El navegador que estás utilizando no es completamente compatible con Nextcloud Talk. Utiliza la última versión de Mozilla Firefox, Microsoft Edge, Google Chrome, Opera o Apple Safari.",
    "Message link copied to clipboard" : "Enlace del mensaje copiado al portapapeles",
    "Conversation link copied to clipboard" : "Enlace de la conversación copiado al portapapeles",
    "The link could not be copied" : "No se pudo copiar el enlace",
    "Sending signaling message has failed" : "La entrega del mensaje de señalización ha fallado",
    "Lost connection to signaling server. Trying to reconnect." : "Se perdió la conexión con el servidor de señalización. Intentando reconectar.",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "El servidor de señalización configurado necesita ser actualizado para ser compatible con esta versión de Talk. Por favor, contacta a tu administrador.",
    "Please reload the page." : "Por favor vuelve a cargar la página.",
    "Do not disturb" : "No molestar",
    "Away" : "Ausente",
    "Microphone {number}" : "Micrófono {number}",
    "Camera {number}" : "Cámara {number}",
    "Speaker {number}" : "Altavoz {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Parece que estás hablando estando silenciado/a, por favor, activa tu micrófono para que los demás puedan escucharte",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "No se pudo establecer una conexión con al menos un participante. Es posible que se necesite un servidor TURN para tu escenario. Por favor, pide a tu administrador que lo configure siguiendo {linkstart}esta documentación{linkend}.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Esto está tardando más de lo esperado. ¿Se han concedido (o rechazado) ya los permisos de medios? Si es así, por favor, reinicia tu navegador, ya que el audio y el video pueden estar fallando",
    "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
    "Please move your setup to HTTPS" : "Por favor cambia tu configuración a HTTPS",
    "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
    "WebRTC is not supported in your browser" : "WebRTC no está soportado en tu navegador",
    "Please use a different browser like Firefox or Chrome" : "Por favor usa un navegador diferente como Firefox o Chrome",
    "Error while accessing microphone & camera" : "Se pressentó un error al acceder al micrófono & cámara",
    "%s Talk on your mobile devices" : "%s Talk en tus dispositivos móviles",
    "Join conversations at any time, anywhere, on any device." : "Únete a conversaciones en cualquier momento y lugar, desde cualquier dispositivo.",
    "Android app" : "Aplicación Android",
    "iOS app" : "Aplicación iOS",
    "__language_name__" : "__language_name__",
    "Tasks" : "Tareas",
    "Reports" : "Informes",
    "Open poll • You voted already" : "Encuesta abierta • Ya has votado",
    "Open poll • Click to vote" : "Encuesta abierta • Haz clic para votar",
    "Poll • Ended" : "Encuesta • Finalizada",
    "Talk recording from {time} ({conversation})" : "Grabación de Talk desde {time} ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Resultados de la encuesta • %n voto","Resultados de la encuesta • %n votos","Resultados de la encuesta • %n votos"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["Encuesta abierta • %n voto","Encuesta abierta • %n votos","Encuesta abierta • %n votos"],
    "Submit vote" : "Enviar voto",
    "Your privacy setting has been saved" : "Tu configuración de privacidad ha sido guardada",
    "Failed to save sounds setting" : "Error al guardar la configuración de sonidos",
    "Sounds setting saved" : "Configuración de sonidos guardada",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Te uniste a la conversación en otra ventana o dispositivo. Actualmente, Nextcloud Talk no admite esto, por lo que esta sesión se cerró."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
