OC.L10N.register(
    "spreed",
    {
    "a conversation" : "דיון",
    "(Duration %s)" : "(משך %s)",
    "You attended a call with {user1}" : "הצטרפת לשיחה עם {user1}",
    "_%n guest_::_%n guests_" : ["אורח/ת 1","%n אורחים","%n אורחים","%n אורחים"],
    "You attended a call with {user1} and {user2}" : "השתתפת בשיחה עם {user1} ועם {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "השתתפת בשיחה עם {user1}, {user2} ועם {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "השתתפת בשיחה עם {user1}, {user2}, {user3} ועם {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "השתתפת בשיחה עם {user1}, {user2}, {user3}, {user4} ועם {user5}",
    "_%n other_::_%n others_" : ["מישהו נוסף","%n נוספים","%n נוספים"],
    "{actor} invited you to {call}" : "הוזמנת אל {call} על ידי {actor}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "הוזמנת ל<strong>דיון</strong> או שקיבלת <strong>שיחה</strong>",
    "Other activities" : "פעילויות אחרות",
    "Talk" : "שיחה",
    "Guest" : "אורח/ת",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- ניתן מעתה להשתמש ב־Microsoft Edge וב־Safari כדי להשתת, בשיחות שמע ווידאו",
    "{actor} created the conversation" : "הדיון נוצר על ידי {actor}",
    "You created the conversation" : "יצרת את הדיון",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "השם של הדיון השתנה מ־„%1$s” ל־„%2$s” על ידי {actor}",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "שינית את שם הדיון מהשם „%1$s” לשם „%2$s”",
    "You started a call" : "התחלת שיחה",
    "{actor} started a call" : "שיחה החלה על ידי {actor}",
    "{actor} joined the call" : "{actor} מעכשיו בשיחה",
    "You joined the call" : "הצטרפת לשיחה",
    "{actor} left the call" : "{actor} לא בשיחה עוד",
    "You left the call" : "עזבת את השיחה",
    "{actor} unlocked the conversation" : "הדיון שוחרר על ידי {actor}",
    "You unlocked the conversation" : "שחררת את הדיון",
    "{actor} locked the conversation" : "הדיון ננעל על ידי {actor}",
    "You locked the conversation" : "נעלת את הדיון",
    "The conversation is now open to everyone" : "הדיון מעתה פתוח לכול",
    "{actor} opened the conversation to everyone" : "הדיון נפתח לכול על ידי {actor}",
    "You opened the conversation to everyone" : "פתחת את הדיון לכול",
    "{actor} restricted the conversation to moderators" : "הדיון הוגבל למפקחים על ידי {actor}",
    "You restricted the conversation to moderators" : "הגבלת את הדיון למפקחים",
    "{actor} allowed guests" : "אורחים הורשו על ידי {actor}",
    "You allowed guests" : "הרשית אורחים",
    "An administrator allowed guests" : "ההנהלה איפשרה אורחים",
    "{actor} disallowed guests" : "אורחים נאסרו על ידי {actor}",
    "You disallowed guests" : "אסרת אורחים",
    "An administrator disallowed guests" : "ההנהלה אסרה על אורחים",
    "{actor} set a password" : "הוגדרה ססמה על ידי {actor}",
    "You set a password" : "הגדרת ססמה",
    "An administrator set a password" : "ההנהלה הגדירה ססמה",
    "{actor} removed the password" : "הססמה הוסרה על ידי {actor}",
    "You removed the password" : "הסרת את הססמה",
    "An administrator removed the password" : "הססמה הוסרה על ידי ההנהלה",
    "{actor} added {user}" : "ההוספה של {user} בוצעה על ידי {actor}",
    "You joined the conversation" : "הצטרפת לדיון",
    "{actor} joined the conversation" : "הצטרפות של {actor} לדיון",
    "You added {user}" : "הוספת את {user}",
    "{actor} added you" : "נוספת על ידי {actor}",
    "An administrator added you" : "נוספת על ידי ההנהלה",
    "An administrator added {user}" : "ההנהלה הוסיפה את {user}",
    "You left the conversation" : "עזבת את הדיון",
    "You removed group {group}" : "הסרת את הקבוצה {group}",
    "An administrator removed group {group}" : "ההנהלה הסירה את הקבוצה {group}",
    "You shared a file which is no longer available" : "שיתפת קובץ שאינו זמין עוד",
    "You updated the Matterbridge configuration" : "עדכנת את הגדרות ה־Matterbridge",
    "You stopped Matterbridge" : "עצרת את Matterbridge",
    "{actor} deleted a message" : "הודעה נמחקה על ידי {actor}",
    "You deleted a message" : "מחקת הודעה",
    "Message deleted by author" : "ההודעה נמחקה על ידי מי שפרסם אותה",
    "Deleted user" : "משתמש מחוק",
    "Administration" : "ניהול",
    "System" : "מערכת",
    "Talk conversations" : "דיוני שיח",
    "File not found" : "קובץ לא נמצא",
    "File is too big" : "הקובץ גדול מדי",
    "Invalid file provided" : "הקובץ שסופק שגוי",
    "Invalid image" : "תמונה לא חוקית",
    "Unknown filetype" : "סוג קובץ לא מוכר",
    "Say hi to your friends and colleagues!" : "על הדרך לראות מה עם חבריך לעבודה!",
    "No unread mentions" : "אין אזכורים שלא נקראו",
    "Call in progress" : "מתנהלת שיחה",
    "Conversation invitation" : "הזמנה לדיון",
    "Description" : "תיאור",
    "Meeting ID" : "מזהה פגישה",
    "Meeting" : "מפגש",
    "Password request: %s" : "בקשת ססמה: %s",
    "Private conversation" : "דיון פרטי",
    "Deleted user (%s)" : "משתמש שנמחק (%s)",
    "Dismiss notification" : "התעלמות מהתראה",
    "Accept" : "אשר",
    "Decline" : "דחייה",
    "New message" : "הודעה חדשה",
    "Notification" : "הוֹדָעָה",
    "{user} sent you a private message" : "התקבלה הודעה פרטית מאת {user}",
    "{user} invited you to a group conversation: {call}" : "הוזמנת על ידי {user} לדיון קבוצתי: {call}",
    "Join call" : "הצטרפות לשיחה",
    "Answer call" : "לענות לשיחה",
    "Call back" : "להתקשר בחזרה",
    "You missed a call from {user}" : "החמצת שיחה עם {user}",
    "A group call has started in {call}" : "החלה שיחה קבוצתית תחת {call}",
    "Open settings" : "פתיחת הגדרות",
    "error" : "שגיאה",
    "Default" : "בררת מחדל",
    "Presentation" : "מצגת",
    "Conversations" : "דיונים",
    "{user}" : "{user}",
    "Messages" : "הודעות",
    "Messages in other conversations" : "הודעות בדיונים אחרים",
    "Avatar image is not square" : "התמונה המייצגת אינה מרובעת",
    "Other" : "אחר",
    "The email address is invalid." : "כתובת הדוא״ל שגויה.",
    "Andorra" : "אנדורה",
    "United Arab Emirates" : "איחוד האמירויות הערביות",
    "Afghanistan" : "אפגניסטן",
    "Antigua and Barbuda" : "אנטיגואה וברבודה",
    "Anguilla" : "אנגווילה",
    "Albania" : "אלבניה",
    "Armenia" : "ארמניה",
    "Angola" : "אנגולה",
    "Antarctica" : "אנטארקטיקה",
    "Argentina" : "ארגנטינה",
    "American Samoa" : "סמואה האמריקנית",
    "Austria" : "אוסטריה",
    "Australia" : "אוסטרליה",
    "Aruba" : "ארובה",
    "Åland Islands" : "איי אולנד",
    "Azerbaijan" : "אזרבייג׳ן",
    "Bosnia and Herzegovina" : "בוסניה והרצגובינה",
    "Barbados" : "ברבדוס",
    "Bangladesh" : "בנגלדש",
    "Belgium" : "בלגיה",
    "Burkina Faso" : "בורקינה פאסו",
    "Bulgaria" : "בולגריה",
    "Bahrain" : "בחריין",
    "Burundi" : "בורונדי",
    "Benin" : "בנין",
    "Saint Barthélemy" : "סן ברתלמי",
    "Bermuda" : "ברמודה",
    "Brunei Darussalam" : "ברוניי משכן השלום",
    "Bonaire, Sint Eustatius and Saba" : "בונייר, סנט אוסטתיוס וסאבא",
    "Brazil" : "ברזיל",
    "Bahamas" : "איי בהאמה",
    "Bhutan" : "בהוטן",
    "Bouvet Island" : "האי בּוּבֶה",
    "Botswana" : "בוטסואנה",
    "Belarus" : "בלרוס",
    "Belize" : "בליז",
    "Canada" : "קנדה",
    "Cocos (Keeling) Islands" : "איי קוקוס קילינג",
    "Central African Republic" : "הרפובליקה המרכז-אפריקאית",
    "Congo" : "קונגו",
    "Switzerland" : "שווייץ",
    "Côte d'Ivoire" : "קוט דיוואר (חוף השנהב)",
    "Cook Islands" : "איי קוק",
    "Chile" : "צ׳ילה",
    "Cameroon" : "קמרון",
    "China" : "סין",
    "Colombia" : "קולומביה",
    "Costa Rica" : "קוסטה ריקה",
    "Cuba" : "קובה",
    "Cabo Verde" : "כף ורדה",
    "Curaçao" : "קוראסאו",
    "Christmas Island" : "אי חג המולד",
    "Cyprus" : "קפריסין",
    "Czechia" : "צ׳כיה",
    "Germany" : "גרמניה",
    "Djibouti" : "ג׳יבוטי",
    "Denmark" : "דנמרק",
    "Dominica" : "דומיניקה",
    "Dominican Republic" : "הרפובליקה הדומיניקנית",
    "Algeria" : "אלג׳יריה",
    "Ecuador" : "אקוודור",
    "Estonia" : "אסטוניה",
    "Egypt" : "מצרים",
    "Western Sahara" : "סהרה המערבית",
    "Eritrea" : "אריתריאה",
    "Spain" : "ספרד",
    "Ethiopia" : "אתיופיה",
    "Finland" : "פינלנד",
    "Fiji" : "פיג׳י",
    "Falkland Islands (Malvinas)" : "איי פוקלנד (מלווינאס)",
    "Faroe Islands" : "איי פארו",
    "France" : "צרפת",
    "Gabon" : "גבון",
    "United Kingdom of Great Britain and Northern Ireland" : "הממלכה המאוחדת של בריטניה הגדולה וצפון אירלנד",
    "Grenada" : "גרנדה",
    "Georgia" : "גאורגיה",
    "French Guiana" : "גיאנה הצרפתית",
    "Guernsey" : "גרנזי",
    "Ghana" : "גאנה",
    "Gibraltar" : "גיברלטר",
    "Greenland" : "גרינלנד",
    "Gambia" : "גמביה",
    "Guinea" : "גינאה",
    "Guadeloupe" : "גוואדלופ",
    "Equatorial Guinea" : "גינאה המשוונית",
    "Greece" : "יוון",
    "South Georgia and the South Sandwich Islands" : "איי ג׳ורג׳יה הדרומית ואיי סנדוויץ׳ הדרומיים",
    "Guatemala" : "גואטמלה",
    "Guam" : "גואם",
    "Guinea-Bissau" : "גינאה ביסאו",
    "Guyana" : "גיאנה",
    "Hong Kong" : "הונג קונג",
    "Heard Island and McDonald Islands" : "האי הרד ואיי מקדונלד",
    "Honduras" : "הונדורס",
    "Croatia" : "קרואטיה",
    "Haiti" : "האיטי",
    "Hungary" : "הונגריה",
    "Indonesia" : "אינדונזיה",
    "Ireland" : "אירלנד",
    "Israel" : "ישראל",
    "Isle of Man" : "האי מאן",
    "India" : "הודו",
    "British Indian Ocean Territory" : "הטריטוריה הבריטית באוקיינוס ההודי",
    "Iraq" : "עיראק",
    "Iceland" : "איסלנד",
    "Italy" : "איטליה",
    "Jersey" : "ג׳רזי",
    "Jamaica" : "ג׳מייקה",
    "Jordan" : "ירדן",
    "Japan" : "יפן",
    "Kenya" : "קניה",
    "Kyrgyzstan" : "קירגיסטן",
    "Cambodia" : "קמבודיה",
    "Kiribati" : "קיריבטי",
    "Comoros" : "קומורוס",
    "Saint Kitts and Nevis" : "סנט קיטס ונוויס",
    "Korea, Republic of" : "קוריאה, הרפובליקה של",
    "Kuwait" : "כווית",
    "Cayman Islands" : "איי קיימן",
    "Kazakhstan" : "קזחסטן",
    "Lao People's Democratic Republic" : "הרפובליקה הדמוקרטית העממית של אנשי הלאו",
    "Lebanon" : "לבנון",
    "Saint Lucia" : "סנט לוסיה",
    "Liechtenstein" : "ליכטנשטיין",
    "Sri Lanka" : "סרי לנקה",
    "Liberia" : "ליבריה",
    "Lesotho" : "לסוטו",
    "Lithuania" : "ליטא",
    "Luxembourg" : "לוקסמבורג",
    "Latvia" : "לטביה",
    "Libya" : "לוב",
    "Morocco" : "מרוקו",
    "Monaco" : "מונקו",
    "Moldova, Republic of" : "מודלובה, הרפובליקה של",
    "Montenegro" : "מונטנגרו",
    "Saint Martin (French part)" : "סן מרטן (העבר הצרפתי)",
    "Madagascar" : "מדגסקר",
    "Marshall Islands" : "איי מרשל",
    "North Macedonia" : "מקדוניה הצפונית",
    "Mali" : "מאלי",
    "Myanmar" : "מיאנמר",
    "Mongolia" : "מונגוליה",
    "Macao" : "מקאו",
    "Northern Mariana Islands" : "איי מריאנה הצפוניים",
    "Martinique" : "מרטיניק",
    "Mauritania" : "מאוריטניה",
    "Montserrat" : "מונטסראט",
    "Malta" : "מלטא",
    "Mauritius" : "מאוריציוס",
    "Maldives" : "האיים המלדיביים",
    "Malawi" : "מלאווי",
    "Mexico" : "מקסיקו",
    "Malaysia" : "מלזיה",
    "Mozambique" : "מוזמביק",
    "Namibia" : "נמיביה",
    "New Caledonia" : "קלדוניה החדשה",
    "Niger" : "ניז׳ר",
    "Norfolk Island" : "האי נורפוק",
    "Nigeria" : "ניגריה",
    "Nicaragua" : "ניקרגואה",
    "Netherlands" : "הולנד",
    "Norway" : "נורווגיה",
    "Nepal" : "נפאל",
    "Nauru" : "נאורו",
    "Niue" : "ניואה",
    "New Zealand" : "ניו זילנד",
    "Oman" : "עומאן",
    "Panama" : "פנמה",
    "Peru" : "פרו",
    "French Polynesia" : "פולינזיה הצרפתית",
    "Papua New Guinea" : "פפואה גינאה החדשה",
    "Philippines" : "הפיליפינים",
    "Pakistan" : "פקיסטן",
    "Poland" : "פולין",
    "Saint Pierre and Miquelon" : "סן-פייר ומיקלון",
    "Pitcairn" : "פיטקרן",
    "Puerto Rico" : "פוארטו ריקו",
    "Palestine, State of" : "הרשות הפלסטינית",
    "Portugal" : "פורטוגל",
    "Palau" : "פלאו",
    "Paraguay" : "פרגוואי",
    "Qatar" : "קטאר",
    "Réunion" : "ראוניון",
    "Romania" : "רומניה",
    "Serbia" : "סרביה",
    "Russian Federation" : "הפדרציה הרוסית",
    "Rwanda" : "רואנדה",
    "Saudi Arabia" : "ערב הסעודית",
    "Solomon Islands" : "איי שלמה",
    "Seychelles" : "איי סיישל",
    "Sudan" : "סודאן",
    "Sweden" : "שוודיה",
    "Singapore" : "סינגפור",
    "Saint Helena, Ascension and Tristan da Cunha" : "סנט הלנה, אסנשן וטריסטן דה קונה",
    "Slovenia" : "סלובניה",
    "Svalbard and Jan Mayen" : "סבאלברד ויאן מאיין",
    "Slovakia" : "סלובקיה",
    "Sierra Leone" : "סיירה לאון",
    "San Marino" : "סן מרינו",
    "Senegal" : "סנגל",
    "Somalia" : "סומליה",
    "Suriname" : "סורינאם",
    "South Sudan" : "דרום סודאן",
    "Sao Tome and Principe" : "סאו טומה ופרינסיפה",
    "El Salvador" : "אל סלוודור",
    "Sint Maarten (Dutch part)" : "סנט מארטן (העבר ההולנדי)",
    "Syrian Arab Republic" : "הרפובליקה הערבית הסורית",
    "Eswatini" : "אסוואטיני",
    "Turks and Caicos Islands" : "איי טרקס וקייקוס",
    "Chad" : "צ׳אד",
    "French Southern Territories" : "הארצות הדרומיות והאנטארקטיות של צרפת",
    "Togo" : "טוגו",
    "Thailand" : "תאילנד",
    "Tajikistan" : "טג׳יקיסטן",
    "Tokelau" : "טוקלאו",
    "Timor-Leste" : "מזרח טימור",
    "Turkmenistan" : "טורקמניסטן",
    "Tunisia" : "תוניסיה",
    "Tonga" : "טונגאית",
    "Turkey" : "טורקיה",
    "Trinidad and Tobago" : "טרינידד וטובגו",
    "Tuvalu" : "טובאלו",
    "Taiwan, Province of China" : "טאיוואן (מחוז סיני)",
    "Tanzania, United Republic of" : "טנזניה, הרפובליקה המאוחדת של",
    "Ukraine" : "אוקראינה",
    "Uganda" : "אוגנדה",
    "United States Minor Outlying Islands" : "האיים המרוחקים הקטנים של ארה״ב",
    "United States of America" : "ארצות הברית",
    "Uruguay" : "אורוגוואי",
    "Uzbekistan" : "אוזבקיסטן",
    "Holy See" : "הכס הקדוש",
    "Saint Vincent and the Grenadines" : "סנט וינסנט והגרנדינים",
    "Viet Nam" : "וייטנאם",
    "Vanuatu" : "ונואטו",
    "Wallis and Futuna" : "ואליס ופוטונה",
    "Samoa" : "סמואה",
    "Yemen" : "תימן",
    "Mayotte" : "מָיוֹט",
    "South Africa" : "דרום אפריקה",
    "Zambia" : "זמביה",
    "Zimbabwe" : "זימבבואה",
    "Federation" : "איגוד",
    "Invalid date, date format must be YYYY-MM-DD" : "תאריך לא חוקי, תבנית התאריך חייבת להיות YYYY-MM-DD",
    "Conversation not found" : "הדיון לא נמצא",
    "Leave call" : "יציאה מהשיחה",
    "Navigating away from the page will leave the call in {conversation}" : "ניווט מחוץ לעמוד תנתק את השיחה שב־{conversation}",
    "Stay in call" : "להישאר בשיחה",
    "Discuss this file" : "לדון על הקובץ הזה",
    "Share this file with others to discuss it" : "שיתוף הקובץ הזה לדיונם של אחרים",
    "Share this file" : "שיתוף הקובץ הזה",
    "Join conversation" : "הצטרפות לדיון",
    "The password is wrong. Try again." : "הססמה שגויה. נא לנסות שוב.",
    "Password" : "ססמה",
    "Submit" : "שליחה",
    "Error requesting the password." : "בקשת הססמה נכשלה.",
    "Request password" : "בקשת ססמה",
    "This conversation has ended" : "הדיון הסתיים",
    "Everyone" : "כולם",
    "Users and moderators" : "משתמשים ומפקחים",
    "Moderators only" : "מפקחים בלבד",
    "Save changes" : "שמירת שינויים",
    "Saving …" : "מתבצעת שמירה…",
    "Saved!" : "נשמר!",
    "Limit to groups" : "הגבלה לקבוצות",
    "Limit starting a call" : "הגבלת התחלת שיחה",
    "Limit starting calls" : "הגבלת התחלת שיחות",
    "Enabled" : "מופעל",
    "Disabled" : "מושבת",
    "State" : "מצב",
    "Name" : "שם",
    "Beta" : "בטא",
    "Permissions" : "הרשאות",
    "All messages" : "כל ההודעות",
    "Off" : "כבוי",
    "General settings" : "הגדרות כלליות",
    "Enable encryption" : "אפשר הצפנה",
    "Pending" : "בהמתנה",
    "Error" : "שגיאה",
    "Blocked" : "נחסם",
    "Active" : "פעיל",
    "Expired" : "פג",
    "Never" : "מעולם לא",
    "Language" : "שפה",
    "Country" : "מדינה",
    "Status" : "מצב",
    "Created at" : "נוצר ב־",
    "Installed version: {version}" : "גרסה מותקנת: {version}",
    "Downloading …" : "מתבצעת הורדה…",
    "Failed to execute Matterbridge binary." : "הפעלת הבינרי של Matterbridge נכשלה.",
    "Matterbridge integration" : "שילוב עם Matterbridge",
    "Enable Matterbridge integration" : "הפעלת שילוב עם Matterbridge",
    "Validate SSL certificate" : "אימות אישור SSL",
    "Delete this server" : "מחיקת השרת הזה",
    "Test this server" : "בדיקת השרת הזה",
    "Shared secret" : "סוד משותף",
    "STUN server URL" : "כתובת שרת STUN",
    "STUN servers" : "שרתי STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "שרת STUN משמש לאיתור כתובת ה־IP הציבורית של המשתמשים מאחורי נתב.",
    "TURN server URL" : "כתובת שרת TURN",
    "TURN server protocols" : "פרוטוקולים לשרתים מסוג TURN",
    "TURN servers" : "שרתי TURN",
    "OK" : "אישור",
    "Checking …" : "מתבצעת בדיקה…",
    "Confirm" : "אימות",
    "Reset" : "איפוס",
    "Cancel" : "ביטול",
    "Back" : "חזרה",
    "Loading …" : "בטעינה…",
    "From" : "מאת",
    "To" : "אל",
    "Calendar" : "לוח שנה",
    "Attendees" : "משתתפים",
    "Save" : "שמירה",
    "Search participants" : "חיפוש משתתפים",
    "No results" : "אין תוצאות",
    "Done" : "הסתיים",
    "Speaker view" : "תצוגת דובר",
    "Grid view" : "תצוגת טבלה",
    "Reload" : "טעינה מחדש",
    "Waiting for others to join the call …" : "בהמתנה לאחרים להצטרף לשיחה…",
    "You can invite others in the participant tab of the sidebar" : "ניתן להזמין אחרים בלשונית המשתתפים בסרגל הצד",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "ניתן להזמין אחרים דרך לשונית המשתפים בסרגל הצד או לשתף את הקישור הזה כדי להזמין אחרים!",
    "Share this link to invite others!" : "יש לשתף את הקישור הזה כדי להזמין אחרים!",
    "Copy link" : "העתקת קישור",
    "Mute audio" : "השתקת שמע",
    "None" : "אין",
    "Disable video" : "השבתת וידאו",
    "Enable video" : "הפעלת וידאו",
    "You" : "אני",
    "Show screen" : "הצגת מסך",
    "Collapse" : "קיווץ",
    "Expand" : "הרחבה",
    "Drop your files to upload" : "יש לגרור לכאן קבצים כדי להעלות",
    "Favorite" : "סימון כמועדף",
    "Date:" : "בתאריך:",
    "Note:" : "הערה:",
    "Hide details" : "הסתרת פרטים",
    "Show details" : "הצגת פרטים",
    "Disable" : "השבתה",
    "Choose" : "בחר",
    "Restricted" : "מוגבלת",
    "Conversation settings" : "הגדרות דיון",
    "Personal" : "אישי",
    "Leave conversation" : "יציאה מהדיון",
    "Delete conversation" : "מחיקת דיון",
    "_%n hour_::_%n hours_" : ["שעה","שעתיים","%n שעות"],
    "_%n day_::_%n days_" : ["יום","יומיים","%n ימים"],
    "Password protection" : "הגנה בססמה",
    "Set a password" : "הגדרת ססמה",
    "Change password" : "שינוי ססמה",
    "Start time (optional)" : "מועד התחלה (רשות)",
    "Edit" : "עריכה",
    "More information" : "מידע נוסף",
    "Delete" : "מחיקה",
    "unknown state" : "מצב לא ידוע",
    "Bridge saved" : "הגישור נשמר",
    "Log content" : "תוכן הרישום",
    "Notifications" : "התראות",
    "Important conversation" : "דיון חשוב",
    "In {conversation}" : "בתוך {conversation}",
    "Join" : "הצטרף",
    "Error while creating the conversation" : "שגיאה ביצירת הדיון",
    "Create conversation" : "יצירת דיון",
    "Enter your name" : "נא למלא את שמך",
    "Log in" : "כניסה",
    "Mark as read" : "סימון כנקרא",
    "Mark as unread" : "סימון כלא נקרא",
    "Remove from favorites" : "הסרה מהמועדפים",
    "Add to favorites" : "הוספה למועדפים",
    "Home" : "בית",
    "Unread" : "לא נקרא",
    "Alphabetically" : "בסדר האלף-בית",
    "No matches found" : "לא נמצאו התאמות",
    "An error occurred while performing the search" : "אירעה שגיאה בעת ביצוע החיפוש",
    "Unread messages" : "הודעות שלא נקראו",
    "Threads" : "שרשורים",
    "Clear filter" : "מחיקת מסנן",
    "Users" : "משתמשים",
    "Groups" : "קבוצות",
    "Other sources" : "מקורות אחרים",
    "You are currently waiting in the lobby" : "הנך בהמתנה בלובי",
    "Test" : "בדיקה",
    "Devices" : "מכשירים",
    "No audio" : "אין שמע",
    "Calls are not supported in your browser" : "אין תמיכה בשיחות בדפדפן שלך",
    "Access to microphone was denied" : "הגישה למיקרופון נדחתה",
    "Invalid path selected" : "הנתיב שנבחר שגוי",
    "Upload" : "העלאה",
    "Files" : "קבצים",
    "24 hours" : "24 שעות",
    "Reply" : "תגובה",
    "More actions" : "פעולות נוספות",
    "Go to file" : "מעבר לקובץ",
    "Translate" : "תרגום",
    "React with {emoji}" : "הגיבו עם {emoji}",
    "Dismiss" : "התעלמות",
    "Message sent" : "הודעה נשלחה",
    "Deleting message" : "ההודעה נמחקה",
    "Contact" : "איש/אשת קשר",
    "_%n reply_::_%n replies_" : ["תגובה אחת","%n תגובות","%n תגובות"],
    "No messages" : "אין הודעות",
    "Create a new group conversation" : "יצירת דיון קבוצתי חדש",
    "Add participants" : "הוספת משתתפים",
    "Send message" : "שליחת הודעה",
    "File to share" : "קובץ לשיתוף",
    "Add emoji" : "הוספת אמוג׳י",
    "Share from Files" : "שיתוף מקבצים",
    "Share files to the conversation" : "שיתוף קבצים לדיון",
    "Create new poll" : "יצירת סקר חדש",
    "New file" : "קובץ חדש",
    "Add more files" : "הוספת קבצים נוספים",
    "Send" : "שליחה",
    "Create poll" : "יצירת סקר",
    "Settings" : "הגדרות",
    "Anonymous poll" : "סקר אלמוני",
    "moderator" : "מפקח/ת",
    "guest" : "אורח",
    "Remove group and members" : "הסרת קבוצה וחברים",
    "Remove participant" : "הסרת משתתף",
    "Demote from moderator" : "הורדה מדרגת פיקוח",
    "Promote to moderator" : "קידום לדרגת פיקוח",
    "Remove" : "הסרה",
    "Add users or groups" : "הוספת משתמשים או קבוצות",
    "Add groups" : "הוספת קבוצות",
    "Add other sources" : "הוספת מקורות אחרים",
    "Add emails" : "הוספת כתובות דוא״ל",
    "Integrations" : "שילובים",
    "Searching …" : "מתבצע חיפוש…",
    "Participants" : "משתתפים",
    "Chat" : "צ׳אט",
    "Details" : "פרטים",
    "No results found" : "לא נמצאו תוצאות",
    "Load more results" : "לטעון עוד תוצאות",
    "Projects" : "מיזמים",
    "Link to a conversation" : "קישור לדיון",
    "Select conversation" : "בחירת דיון",
    "Notification settings" : "הגדרות התראה",
    "Default language" : "שפת בררת מחדל",
    "Select location for attachments" : "בחירת מיקום לקבצים מצורפים",
    "Privacy" : "פרטיות",
    "Attachments folder" : "תיקיית הקבצים המצורפים",
    "Search" : "חיפוש",
    "Shortcuts while in a call" : "קיצורי דרך בזמן שיחה",
    "Start call" : "התחלת שיחה",
    "React with {reaction}" : "הגיבו עם {reaction}",
    "Screensharing options" : "אפשרויות שיתוף מסך",
    "Enable screensharing" : "הפעלת שיתוף מסך",
    "Screensharing requires the page to be loaded through HTTPS." : "לטובת שיתוף מסך יש לטעון את העמוד דרך HTTPS.",
    "An error occurred while starting screensharing." : "אירעה שגיאה בעת התחלת שיתוף המסך.",
    "Show your screen" : "הצגת המסך שלך",
    "Stop screensharing" : "הפסקת שיתוף המסך",
    "Mute others" : "השתקה של אחרים",
    "Keep" : "שימור",
    "Select a region" : "נא לבחור איזור",
    "Message without mention" : "הודעה ללא אזכור",
    "Mention myself" : "אזכור עצמי",
    "The conversation does not exist" : "הדיון לא קיים",
    "Join a conversation or start a new one!" : "הצטרפות לדיון או ליצור אחד חדש!",
    "Duplicate session" : "שכפול הפעלה",
    "Join a conversation or start a new one" : "ניתן להצטרף לדיון או להתחיל באחד חדש.",
    "Nextcloud URL" : "כתובת Nextcloud",
    "Nextcloud user" : "משתמש Nextcloud",
    "User password" : "ססמת משתמש",
    "Matrix server URL" : "כתובת שרת Matrix",
    "User" : "משתמש",
    "Matrix channel" : "ערוץ Matrix",
    "Mattermost server URL" : "כתובת שרת Mattermost",
    "Mattermost user" : "משתמש Mattermost",
    "Team name" : "שם צוות",
    "Channel name" : "שם ערוץ",
    "Rocket.Chat server URL" : "כתובת שרת Rocket.Chat",
    "Rocket.Chat channel" : "ערוץ Rocket.Chat",
    "Zulip server URL" : "כתובת שרת Zulip",
    "Bot user name" : "שם המשתמש של הבוט",
    "Bot API key" : "מפתח ה־API של הבוט",
    "Zulip channel" : "ערוץ Zulip",
    "API token" : "אסימון API",
    "Slack channel" : "ערוץ Slack",
    "Server ID or name" : "מזהה או שם שרת",
    "Channel" : "ערוץ",
    "Login" : "התחבר",
    "Chat ID" : "מזהה צ׳אט",
    "Nickname" : "כינוי",
    "Connection password" : "ססמת התחברות",
    "IRC channel" : "ערוץ IRC",
    "Client ID" : "מזהה לקו",
    "Team ID" : "מזהה הקבוצה",
    "Thread ID" : "מזהה שרשור",
    "MUC server URL" : "כתובת שרת MUC",
    "Jabber ID" : "מזהה Jabber",
    "Media" : "מדיה",
    "Polls" : "סקרים",
    "Locations" : "מיקומים",
    "Audio" : "שמע",
    "Group" : "קבוצה",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "An error occurred while fetching the participants" : "אירעה שגיאה במהלך קבלת המשתתפים",
    "Error while sharing file" : "שגיאה בשיתוף הקובץ",
    "Please reload the page." : "יש להעלות מחדש דף זה.",
    "Do not disturb" : "לא להפריע",
    "Away" : "לא פה",
    "Speaker {number}" : "רמקול {number}",
    "Access to microphone & camera is only possible with HTTPS" : "גישה למיקרופון ולמצלמה אפשרית רק עם HTTPS",
    "Please move your setup to HTTPS" : "נא להעביר את התצורה שלך ל־HTTPS",
    "Access to microphone & camera was denied" : "הגישה למיקרופון ולמצלמה נדחתה",
    "WebRTC is not supported in your browser" : "בדפדפן שלך אין תמיכה ב־WebRTC",
    "Please use a different browser like Firefox or Chrome" : "נא להשתמש בדפדפן אחר כגון Firefox או Chrome",
    "Error while accessing microphone & camera" : "אירעה שגיאה בעת גישה למיקרופון ולמצלמה",
    "Android app" : "יישומון ל־Android",
    "iOS app" : "יישומון ל־iOS",
    "__language_name__" : "עברית",
    "Tasks" : "משימות",
    "Notes" : "פתקים"
},
"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
