.drafts[data-v-279f66a6] .dialog__content{min-height:200px}.drafts__wrapper[data-v-279f66a6]{gap:var(--default-grid-baseline);grid-template-columns:1fr 1fr;display:grid}.drafts__empty[data-v-279f66a6]{margin:0!important}.poll-editor__wrapper[data-v-6abfc044]{align-items:flex-end;gap:var(--default-grid-baseline);display:flex}.poll-editor__caption[data-v-6abfc044]{margin:calc(var(--default-grid-baseline)*2)0 var(--default-grid-baseline);color:var(--color-primary-element);font-weight:700}.poll-editor__option[data-v-6abfc044]{align-items:flex-end;gap:var(--default-grid-baseline);width:100%;margin-bottom:calc(var(--default-grid-baseline)*2);display:flex}.poll-editor__settings[data-v-6abfc044]{flex-direction:column;gap:4px;margin-bottom:8px;display:flex}.poll-editor__back-button[data-v-6abfc044]{top:var(--default-grid-baseline);z-index:1;inset-inline-start:var(--default-grid-baseline);position:absolute!important}.internal-warning[data-v-680baaf2]{margin:var(--default-grid-baseline)!important}.talk-tab__wrapper[data-v-3e07a5ca]{height:100%;padding:var(--default-grid-baseline)0;flex-direction:column;justify-content:flex-end;display:flex}.talk-tab__call-button[data-v-3e07a5ca]{margin:0 auto calc(var(--default-grid-baseline)*2)}.talk-tab__chat-view[data-v-3e07a5ca]{overflow:hidden}
/*# sourceMappingURL=files-sidebar-tab-chunk.chunk.css.map*/