OC.L10N.register(
    "spreed",
    {
    "a conversation" : "keskustelu",
    "(Duration %s)" : "(Kesto %s)",
    "You attended a call with {user1}" : "Osallistuit puheluun käyttäjän {user1} kanssa",
    "_%n guest_::_%n guests_" : ["%n vieras","%n vierasta"],
    "You attended a call with {user1} and {user2}" : "Osallistuit puheluun käyttäjien {user1} ja {user2} kanssa",
    "You attended a call with {user1}, {user2} and {user3}" : "Osallistuit puheluun käyttäjien {user1}, {user2} ja {user3} kanssa",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Osallistuit puheluun käyttäjien {user1}, {user2}, {user3} ja {user4} kanssa",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Osallistuit puheluun käyttäjien {user1}, {user2}, {user3}, {user4} ja {user5} kanssa",
    "_%n other_::_%n others_" : ["%n muu","%n muuta"],
    "{actor} invited you to {call}" : "{actor} kutsui sinut puheluun {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Sinut kutsuttiin <strong>keskusteluun</strong> tai olit <strong>puhelussa</strong>",
    "Other activities" : "Muut tapahtumat",
    "Talk" : "Talk",
    "Guest" : "Vieras",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Tervetuloa, tämä on Nextcloud Talk!\nTässä keskustelussa sinulle kerrotaan, mitä uusia ominaisuuksia Nextcloud Talk sisältää.",
    "## New in Talk %s" : "## Uutta Talkin versiossa %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Voit käyttää Microsoft Edgeä ja Safaria ääni- ja videopuheluihin osallistumiseen",
    "- Raise your hand in a call with the R key" : "- Nosta kätesi puhelussa R-näppäimellä",
    "- In the sidebar you can now find an overview of the latest shared items" : "- Löydät sivupalkista yleiskatsauksen viimeksi jaettuihin kohteisiin",
    "- Set a reminder on a chat message to be notified later again" : "- Aseta keskustelussa olevaan viestiin muistutus, jotta saat siitä ilmoituksen myöhemmin",
    "Talk updates ✅" : "Talk-päivitykset ✅",
    "{actor} created the conversation" : "{actor} loi keskustelun",
    "You created the conversation" : "Sinä loit keskustelun",
    "System created the conversation" : "Järjestelmä loi keskustelun",
    "An administrator created the conversation" : "Ylläpitäjä loi keskustelun",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} muutti keskustelun \"%1$s\" uudeksi nimeksi \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Sinä muutit keskustelun \"%1$s\" uudeksi nimeksi \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Ylläpitäjä muutti keskustelun \"%1$s\" uudeksi nimeksi \"%2$s\"",
    "{actor} set the description" : "{actor} asetti kuvauksen",
    "You set the description" : "Sinä asetit kuvauksen",
    "An administrator set the description" : "Ylläpitäjä asetti kuvauksen",
    "{actor} removed the description" : "{actor} poisti kuvauksen",
    "You removed the description" : "Sinä poistit kuvauksen",
    "An administrator removed the description" : "Ylläpitäjä poisti kuvauksen",
    "You started a call" : "Sinä aloitit puhelun",
    "{actor} started a call" : "{actor} aloitti puhelun",
    "{actor} joined the call" : "{actor} liittyi puheluun",
    "You joined the call" : "Sinä liityit puheluun",
    "{actor} left the call" : "{actor} poistui puhelusta",
    "You left the call" : "Sinä poistuit puhelusta",
    "{actor} unlocked the conversation" : "{actor} poisti keskustelun lukituksen",
    "You unlocked the conversation" : "Poistit keskustelun lukituksen",
    "An administrator unlocked the conversation" : "Ylläpitäjä poisti keskustelun lukituksen",
    "{actor} locked the conversation" : "{actor} lukitsi keskustelun",
    "You locked the conversation" : "Sinä lukitsit keskustelun",
    "An administrator locked the conversation" : "Ylläpitäjä lukitsi keskustelun",
    "{actor} limited the conversation to the current participants" : "{actor} rajoitti keskustelun nykyisiin osallistujiin",
    "You limited the conversation to the current participants" : "Rajoitit keskustelun nykyisiin osallistujiin",
    "An administrator limited the conversation to the current participants" : "Ylläpitäjä rajoitti keskustelun nykyisiin osallistujiin",
    "{actor} opened the conversation to registered users" : "{actor} avasi keskustelun rekisteröityneille käyttäjille",
    "You opened the conversation to registered users" : "Avasit keskustelun rekisteröityneille käyttäjille",
    "An administrator opened the conversation to registered users" : "Ylläpitäjä avasi keskustelun rekisteröityneille käyttäjille",
    "The conversation is now open to everyone" : "Keskustelu on nyt avoin kaikille",
    "{actor} opened the conversation to everyone" : "{actor} avasi keskustelun kaikille",
    "You opened the conversation to everyone" : "Avasit uuden keskustelun kaikille",
    "{actor} restricted the conversation to moderators" : "{actor} rajoitti keskustelun moderaattoreille",
    "You restricted the conversation to moderators" : "Rajoitit keskustelun moderaattoreille",
    "{actor} started breakout rooms" : "{actor} käynnisti pienryhmätilat",
    "You started breakout rooms" : "Käynnistit pienryhmätilat",
    "{actor} stopped breakout rooms" : "{actor} pysäytti pienryhmätilat",
    "You stopped breakout rooms" : "Pysäytit pienryhmätilat",
    "{actor} allowed guests" : "{actor} salli vieraat",
    "You allowed guests" : "Sinä sallit vieraat",
    "An administrator allowed guests" : "Ylläpitäjä salli vieraat",
    "{actor} disallowed guests" : "{actor} esti vieraat",
    "You disallowed guests" : "Sinä estit vieraat",
    "An administrator disallowed guests" : "Ylläpitäjä ei sallinut vieraita",
    "{actor} set a password" : "{actor} asetti salasanan",
    "You set a password" : "Sinä asetit salasanan",
    "An administrator set a password" : "Ylläpitäjä asetti salasanan",
    "{actor} removed the password" : "{actor} poisti salasanan",
    "You removed the password" : "Sinä poistit salasanan",
    "An administrator removed the password" : "Ylläpitäjä poisti salasanan",
    "{actor} added {user}" : "{actor} lisäsi käyttäjän {user}",
    "You joined the conversation" : "Liityit keskusteluun",
    "{actor} joined the conversation" : "{actor} liittyi keskusteluun",
    "You added {user}" : "Sinä lisäsit käyttäjän {user}",
    "{actor} added you" : "{actor} lisäsi sinut",
    "An administrator added you" : "Ylläpitäjä lisäsi sinut",
    "An administrator added {user}" : "Ylläpitäjä lisäsi käyttäjän {user}",
    "You left the conversation" : "Poistuit keskustelusta",
    "{actor} left the conversation" : "{actor} poistui keskustelusta",
    "{actor} removed {user}" : "{actor} poisti käyttäjän {user}",
    "You removed {user}" : "Sinä poistit käyttäjän {user}",
    "{actor} removed you" : "{actor} poisti sinut",
    "An administrator removed you" : "Ylläpitäjä lisäsi sinut",
    "An administrator removed {user}" : "Ylläpitäjä poisti käyttäjän {user}",
    "{actor} invited {federated_user}" : "{actor} kutsui käyttäjän {federated_user}",
    "You invited {federated_user}" : "Kutsuit käyttäjän {federated_user}",
    "You accepted the invitation" : "Hyväksyit kutsun",
    "{actor} invited you" : "{actor} kutsui sinut",
    "An administrator invited you" : "Ylläpitäjä kutsui sinut",
    "An administrator invited {federated_user}" : "Ylläpitäjä kutsui käyttäjän {federated_user}",
    "{federated_user} accepted the invitation" : "{federated_user} hyväksyi kutsun",
    "{actor} removed {federated_user}" : "{actor} poisti käyttäjän {federated_user}",
    "You removed {federated_user}" : "Poistit käyttäjän {federated_user}",
    "An administrator removed {federated_user}" : "Ylläpitäjä poisti käyttäjän {federated_user}",
    "{federated_user} declined the invitation" : "{federated_user} kieltäytyi kutsusta",
    "{actor} added group {group}" : "{actor} lisäsi ryhmän {group}",
    "You added group {group}" : "Lisäsit ryhmän {group}",
    "An administrator added group {group}" : "Ylläpitäjä lisäsi ryhmän {group}",
    "{actor} removed group {group}" : "{actor} poisti ryhmän {group}",
    "You removed group {group}" : "Poistit ryhmän {group}",
    "An administrator removed group {group}" : "Ylläpitäjä poisti ryhmän {group}",
    "{actor} added team {circle}" : "{actor} lisäsi tiimin {circle}",
    "You added team {circle}" : "Lisäsit tiimin {circle}",
    "An administrator added team {circle}" : "Ylläpitäjä lisäsi tiimin {circle}",
    "{actor} removed team {circle}" : "{actor} poisti tiimin {circle}",
    "You removed team {circle}" : "Poistit tiimin {circle}",
    "An administrator removed team {circle}" : "Ylläpitäjä poisti tiimin {circle}",
    "{actor} added {phone}" : "{actor} lisäsi puhelimen {phone}",
    "You added {phone}" : "Lisäsit puhelimen {phone}",
    "An administrator added {phone}" : "Ylläpitäjä lisäsi puhelimen {phone}",
    "{actor} removed {phone}" : "{actor} poisti puhelimen {phone}",
    "You removed {phone}" : "Poistit puhelimen {phone}",
    "An administrator removed {phone}" : "Ylläpitäjä poisti puhelimen {phone}",
    "{actor} promoted {user} to moderator" : "{actor} nosti käyttäjän {user} moderaattoriksi",
    "You promoted {user} to moderator" : "Sinä nostit käyttäjän {user} moderaattoriksi",
    "{actor} promoted you to moderator" : "{actor} nosti sinut moderaattoriksi",
    "An administrator promoted you to moderator" : "Ylläpitäjä nosti sinut moderaattoriksi",
    "An administrator promoted {user} to moderator" : "Ylläpitäjä nosti käyttäjän {user} moderaattoriksi",
    "{actor} demoted {user} from moderator" : "{actor} poisti moderaattorin oikeudet käyttäjältä {user}",
    "You demoted {user} from moderator" : "Sinä poistit moderaattorin oikeudet käyttäjältä {user}",
    "{actor} demoted you from moderator" : "{actor} poisti sinulta moderaattorin oikeudet",
    "{actor} shared a file which is no longer available" : "{actor} jakoi kanssasi tiedoston, joka ei ole enää saatavilla",
    "You shared a file which is no longer available" : "Jaoit tiedoston, joka ei ole enää saatavilla",
    "{actor} updated the Matterbridge configuration" : "{actor} päivitti Matterbridge-kokoonpanon",
    "You updated the Matterbridge configuration" : "Päivitit Matterbridge-kokoonpanon",
    "{actor} removed the Matterbridge configuration" : "{actor} poisti Matterbridge-kokoonpanon",
    "You removed the Matterbridge configuration" : "Poistit Matterbridge-kokoonpanon",
    "{actor} started Matterbridge" : "{actor} käynnisti Matterbridgen",
    "You started Matterbridge" : "Käynnistit Matterbridgen",
    "{actor} stopped Matterbridge" : "{actor} pysäytti Matterbridgen",
    "You stopped Matterbridge" : "Pysäytit Matterbridgen",
    "{actor} deleted a message" : "{actor} poisti viestin",
    "You deleted a message" : "Sinä poistit viestin",
    "{actor} edited a message" : "{actor} muokkasi viestiä",
    "You edited a message" : "Sinä muokkasit viestiä",
    "{actor} deleted a reaction" : "{actor} poisti reaktion",
    "You deleted a reaction" : "Poistit reaktion",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["Asetit viestin vanhenemisen %n viikkoon","Asetit viestin vanhenemisen %n viikkoon"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["Asetit viestin vanhenemisen %n päivään","Asetit viestin vanhenemisen %n päivään"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["Asetit viestin vanhenemisen %n tuntiin","Asetit viestin vanhenemisen %n tuntiin"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["Asetit viestin vanhenemisen %n minuuttiin","Asetit viestin vanhenemisen %n minuuttiin"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} asetti viestin vanhenemisen %n viikkoon","{actor} asetti viesti vanhenemisen %n viikkoon"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} asetti viesti vanhenemisen %n päivään","{actor} asetti viesti vanhenemisen %n päivään"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} asetti viesti vanhenemisen %n tuntiin","{actor} asetti viesti vanhenemisen %n tuntiin"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} asetti viesti vanhenemisen %n minuuttiin","{actor} asetti viesti vanhenemisen %n minuuttiin"],
    "{actor} disabled message expiration" : "{actor} poisti käytöstä viestien vanhenemisen",
    "You disabled message expiration" : "Poistit käytöstä viestien vanhenemisen",
    "{actor} cleared the history of the conversation" : "{actor} tyhjensi keskusteluhistorian",
    "You cleared the history of the conversation" : "Sinä tyhjensit keskusteluhistorian",
    "{actor} set the conversation picture" : "{actor} asetti keskustelun kuvan",
    "You set the conversation picture" : "Asetit keskustelun kuvan",
    "{actor} removed the conversation picture" : "{actor} poisti keskustelun kuvan",
    "You removed the conversation picture" : "Poistit keskustelun kuvan",
    "{actor} ended the poll {poll}" : "{actor} lopetti kyselyn {poll}",
    "You ended the poll {poll}" : "Lopetit kyselyn {poll}",
    "{actor} started the video recording" : "{actor} aloitti videotallennuksen",
    "You started the video recording" : "Aloitit videotallennuksen",
    "{actor} stopped the video recording" : "{actor} lopetti videotallennuksen",
    "You stopped the video recording" : "Lopetit videotallennuksen",
    "{actor} started the audio recording" : "{actor} aloitti äänitallennuksen",
    "You started the audio recording" : "Aloitit äänitallennuksen",
    "{actor} stopped the audio recording" : "{actor} lopetti äänitallennuksen",
    "You stopped the audio recording" : "Lopetit äänitallennuksen",
    "The recording failed" : "Tallenne epäonnistui",
    "Someone voted on the poll {poll}" : "Joku äänesti kyselyssä {poll}",
    "Message deleted by author" : "Viestin lähettäjä poisti viestin",
    "Deleted user" : "Poistettu käyttäjä",
    "Unknown number" : "Tuntematon numero",
    "Administration" : "Ylläpito",
    "System" : "Järjestelmä",
    "%s (guest)" : "%s (vieras)",
    "Message of {user} in {conversation}" : "Käyttäjän {user} viesti keskustelussa {conversation}",
    "Message of {user}" : "Käyttäjän {user} viesti",
    "Message of a deleted user in {conversation}" : "Poistetun käyttäjän viesti keskustelussa {conversation}",
    "Talk conversations" : "Talk-keskustelut",
    "An error occurred. Please contact your administrator." : "Tapahtui virhe. Ole yhteydessä ylläpitäjään.",
    "Storage quota exceeded" : "Tallennustilan kiintiö täynnä",
    "File not found" : "Tiedostoa ei löytynyt",
    "File is not shared, or shared but not with the user" : "Tiedosto ei ole jaettu, tai jaettu mutta ei kyseisen käyttäjän kanssa",
    "Poll" : "Kysely",
    "No image file provided" : "Kuvatiedostoa ei määritetty",
    "File is too big" : "Tiedosto on liian suuri",
    "Invalid file provided" : "Virheellinen tiedosto määritetty",
    "Invalid image" : "Virheellinen kuva",
    "Unknown filetype" : "Tuntematon tiedostotyyppi",
    "Talk mentions" : "Talk-maininnat",
    "Say hi to your friends and colleagues!" : "Sano hei ystävillesi ja työkavereillesi!",
    "No unread mentions" : "Ei lukemattomia mainintoja",
    "Call in progress" : "Puhelu meneillään",
    "You were mentioned" : "Sinut mainittiin",
    "Write to conversation" : "Kirjoita keskusteluun",
    "Conversation invitation" : "Keskustelukutsu",
    "Description" : "Kuvaus",
    "You can also dial-in via phone with the following details" : "Voit myös yhdistää puhelimella seuraavin tiedoin",
    "Dial-in information" : "Puhelintiedot",
    "Meeting ID" : "Tapaamisen tunniste",
    "Your PIN" : "PIN-koodisi",
    "Meeting" : "Kokous",
    "Password request: %s" : "Salasanapyyntö: %s",
    "Private conversation" : "Yksityinen keskustelu",
    "Deleted user (%s)" : "Poistettiin käyttäjä (%s)",
    "Share to chat" : "Jaa keskusteluun",
    "Dismiss notification" : "Hylkää ilmoitus",
    "Call recording now available" : "Puhelutallenne on nyt saatavilla",
    "The recording for the call in {call} was uploaded to {file}." : "Puhelun {call} tallenne on nyt saatavilla tiedostona {file}.",
    "Transcript now available" : "Transkriptio on nyt saatavilla",
    "The transcript for the call in {call} was uploaded to {file}." : "Puhelun {call} transkriptio on nyt tiedostossa {file}.",
    "Failed to transcript call recording" : "Puhelutallenteen transkriptio epäonnistui",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} kutsui sinut huoneeseen {roomName} palvelimella {remoteServer}",
    "Accept" : "Hyväksy",
    "Decline" : "Kieltäydy",
    "{user1} invited you to a federated conversation" : "{user1} kutsui sinut federoituun keskusteluun",
    "New message" : "Uusi viesti",
    "Reminder" : "Muistutus",
    "Notification" : "Ilmoitus",
    "{user} in {call}" : "{user} puhelussa {call}",
    "{guest} (guest) in {call}" : "{guest} (vieras) puhelussa {call}",
    "Guest in {call}" : "Vieras puhelussa {call}",
    "{user} sent you a private message" : "{user} lähetti sinulle yksityisviestin",
    "{user} sent a message in conversation {call}" : "{user} lähetti viestin keskusteluun {call}",
    "A deleted user sent a message in conversation {call}" : "Poistettu käyttäjä lähetti viestin keskusteluun {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (vieras) lähetti viestin keskusteluun {call}",
    "A guest sent a message in conversation {call}" : "Vieras lähetti viestin keskusteluun {call}",
    "{user} replied to your private message" : "{user} vastasi yksityisviestiisi",
    "{user} replied to your message in conversation {call}" : "{user} vastasi viestiisi keskustelussa {call}",
    "A guest replied to your message in conversation {call}" : "Vieras vastasi viestiisi keskustelussa {call}",
    "{user} reacted with {reaction} to your private message" : "{user} vastasi reaktiolla {reaction} yksityisviestiisi",
    "{user} mentioned you in a private conversation" : "{user} mainitsi sinut yksityiskeskustelussa",
    "{user} mentioned group {group} in conversation {call}" : "{user} mainitsi ryhmän {group} keskustelussa {call}",
    "{user} mentioned everyone in conversation {call}" : "{user} mainitsi kaikki keskustelussa {call}",
    "{user} mentioned you in conversation {call}" : "{user} mainitsi sinut keskustelussa {call}",
    "A deleted user mentioned you in conversation {call}" : "Poistettu käyttäjä mainitsi sinut keskustelussa {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (vieras) mainitsi sinut keskustelussa {call}",
    "A guest mentioned you in conversation {call}" : "Vieras mainitsi sinut keskustelussa {call}",
    "View message" : "Näytä viesti",
    "Dismiss reminder" : "Hylkää muistutus",
    "View chat" : "Näytä keskustelu",
    "{user} invited you to a group conversation: {call}" : "{user} kutsui sinut ryhmäkeskusteluun: {call}",
    "Join call" : "Liity puheluun",
    "Answer call" : "Vastaa puheluun",
    "{user} would like to talk with you" : "{user} haluaa puhua kanssasi",
    "Call back" : "Soita takaisin",
    "You missed a call from {user}" : "Sinulta jäi vastaamatta puhelu käyttäjältä {user}",
    "A group call has started in {call}" : "Ryhmäpuhelu on alkanut puhelussa {call}",
    "{email} is requesting the password to access {file}" : "{email} pyytää salasanaa saadakseen pääsyn tiedostoon {file}",
    "{email} tried to request the password to access {file}" : "{email} yritti pyytää salasanaa päästäkseen tiedostoon {file}",
    "Someone is requesting the password to access {file}" : "Joku pyytää salasanaa päästäkseen tiedostoon {file}",
    "Open settings" : "Avaa asetukset",
    "error" : "virhe",
    "The certificate of {host} expires in {days} days" : "Palvelimen {host} varmenne vanhenee {days} päivän kuluttua",
    "The certificate of {host} expired" : "Palvelimen {host} varmenne vanheni",
    "Open Talk" : "Avaa Talk",
    "Default" : "Oletus",
    "Presentation" : "Esitys",
    "Conversations" : "Keskustelut",
    "Messages in current conversation" : "Viestit nykyisessä keskustelussa",
    "{user}" : "{user}",
    "Messages" : "Viestit",
    "{user} in {conversation}" : "{user} keskustelussa {conversation}",
    "Messages in other conversations" : "Viestit muissa keskusteluissa",
    "Invalid emoji character" : "Virheellinen emojimerkki",
    "Invalid background color" : "Virheellinen taustaväri",
    "Avatar image is not square" : "Avatar-kuva ei ole neliö",
    "Room {number}" : "Huone {number}",
    "Other" : "Muu",
    "Something unexpected happened." : "Jotain odottamatonta tapahtui.",
    "The URL is invalid." : "URL-osoite on virheellinen.",
    "An HTTPS URL is required." : "URL-osoitteen on oltava HTTPS-muodossa.",
    "The email address is invalid." : "Sähköpostiosoite on virheellinen.",
    "The language is invalid." : "Kieli on virheellinen.",
    "The country is invalid." : "Maa on virheellinen.",
    "Something unexpected happened. Please try again later." : "Jotain odottamatonta tapahtui. Yritä myöhemmin uudelleen.",
    "There is no such account registered." : "Kyseistä tiliä ei ole rekisteröity.",
    "Note to self" : "Muistutus itselle",
    "A place for your private notes, thoughts and ideas" : "Paikka henkilökohtaisille muistutuksille, ajatuksille ja ideoille",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Yhdistyneet arabiemiirikunnat",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antigua ja Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Etelämanner",
    "Argentina" : "Argentiina",
    "American Samoa" : "Amerikan Samoa",
    "Austria" : "Itävalta",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Ahvenanmaa",
    "Azerbaijan" : "Azerbaidžan",
    "Bosnia and Herzegovina" : "Bosnia ja Hertsegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgia",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermuda",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius ja Saba",
    "Brazil" : "Brasilia",
    "Bahamas" : "Bahamasaaret",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Bouvet'nsaari",
    "Botswana" : "Botswana",
    "Belarus" : "Valko-Venäjä",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Kookossaaret",
    "Central African Republic" : "Keski-Afrikan tasavalta",
    "Congo" : "Kongo",
    "Switzerland" : "Sveitsi",
    "Côte d'Ivoire" : "Norsunluurannikko",
    "Cook Islands" : "Cookinsaaret",
    "Chile" : "Chile",
    "Cameroon" : "Kamerun",
    "China" : "Kiina",
    "Colombia" : "Kolumbia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Kuuba",
    "Cabo Verde" : "Kap Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Joulusaari",
    "Cyprus" : "Kypros",
    "Czechia" : "Tšekki",
    "Germany" : "Saksa",
    "Djibouti" : "Djibouti",
    "Denmark" : "Tanska",
    "Dominican Republic" : "Dominikaaninen tasavalta",
    "Algeria" : "Algeria",
    "Ecuador" : "Ecuador",
    "Estonia" : "Viro",
    "Egypt" : "Egypti",
    "Eritrea" : "Eritrea",
    "Spain" : "Espanja",
    "Ethiopia" : "Etiopia",
    "Finland" : "Suomi",
    "Fiji" : "Fidži",
    "Faroe Islands" : "Färsaaret",
    "France" : "Ranska",
    "Gabon" : "Gabon",
    "Grenada" : "Grenada",
    "Georgia" : "Georgia",
    "French Guiana" : "Ranskan Guayana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Grönlanti",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Päiväntasaajan Guinea",
    "Greece" : "Kreikka",
    "South Georgia and the South Sandwich Islands" : "Etelä-Georgia ja Eteläiset Sandwichsaaret",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Heard ja McDonaldinsaaret",
    "Honduras" : "Honduras",
    "Croatia" : "Kroatia",
    "Haiti" : "Haiti",
    "Hungary" : "Unkari",
    "Indonesia" : "Indonesia",
    "Ireland" : "Irlanti",
    "Israel" : "Israel",
    "Isle of Man" : "Mansaari",
    "India" : "Intia",
    "British Indian Ocean Territory" : "Brittiläinen Intian valtameren alue",
    "Iraq" : "Irak",
    "Iceland" : "Islanti",
    "Italy" : "Italia",
    "Jamaica" : "Jamaika",
    "Jordan" : "Jordan",
    "Japan" : "Japani",
    "Kenya" : "Kenia",
    "Kyrgyzstan" : "Kirgisia",
    "Cambodia" : "Kambodža",
    "Kiribati" : "Kiribati",
    "Saint Kitts and Nevis" : "Saint Kitts ja Nevis",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Caymansaaret",
    "Kazakhstan" : "Kazakhstan",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Liettua",
    "Luxembourg" : "Luxemburg",
    "Latvia" : "Latvia",
    "Libya" : "Libya",
    "Morocco" : "Marokko",
    "Monaco" : "Monaco",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Marshallinsaaret",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Pohjois-Mariaanit",
    "Mauritania" : "Mauritania",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Malediivit",
    "Malawi" : "Malawi",
    "Mexico" : "Meksiko",
    "Malaysia" : "Malesia",
    "Mozambique" : "Mosambik",
    "Namibia" : "Namibia",
    "New Caledonia" : "Uusi-Kaledonia",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolkinsaari",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Alankomaat",
    "Norway" : "Norja",
    "Nepal" : "Nepali",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Uusi-Seelanti",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Ranskan Polynesia",
    "Papua New Guinea" : "Papua-Uusi-Guinea",
    "Philippines" : "Filippiinit",
    "Pakistan" : "Pakistan",
    "Poland" : "Puola",
    "Saint Pierre and Miquelon" : "Saint Pierre ja Miquelon",
    "Pitcairn" : "Pitcairnsaaret",
    "Puerto Rico" : "Puerto Rico",
    "Portugal" : "Portugali",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Réunion" : "Réunion",
    "Romania" : "Romania",
    "Serbia" : "Serbia",
    "Russian Federation" : "Venäjä",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Saudi-Arabia",
    "Solomon Islands" : "Salomonsaaret",
    "Seychelles" : "Seychellit",
    "Sudan" : "Sudan",
    "Sweden" : "Ruotsi",
    "Singapore" : "Singapore",
    "Saint Helena, Ascension and Tristan da Cunha" : "Saint Helena, Ascension ja Tristan da Cunha",
    "Slovenia" : "Slovenia",
    "Svalbard and Jan Mayen" : "Huippuvuoret ja Jan Mayen",
    "Slovakia" : "Slovakia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Suriname",
    "South Sudan" : "Etelä-Sudan",
    "Sao Tome and Principe" : "São Tomé ja Príncipe",
    "El Salvador" : "El Salvador",
    "Turks and Caicos Islands" : "Turks- ja Caicossaaret",
    "Chad" : "Tšad",
    "Togo" : "Togo",
    "Thailand" : "Thaimaa",
    "Tajikistan" : "Tadžikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Itä-Timor",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisia",
    "Tonga" : "Tonga",
    "Turkey" : "Turkki",
    "Trinidad and Tobago" : "Trinidad ja Tobago",
    "Tuvalu" : "Tuvalu",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Yhdysvaltojen pienet syrjäiset saaret",
    "United States of America" : "Yhdysvallat",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistan",
    "Saint Vincent and the Grenadines" : "Saint Vincent ja Grenadiinit",
    "Viet Nam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis ja Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Jemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Etelä-Afrikka",
    "Zambia" : "Sambia",
    "Zimbabwe" : "Zimbabwe",
    "Federation" : "Federaatio",
    "Error: Cannot connect to server" : "Virhe: Ei voi yhdistää palvelimeen",
    "Error: Server did not respond with proper JSON" : "Virhe: Palvelin ei vastannut kelvollisella JSON:illa",
    "Error: Certificate expired" : "Virhe: varmenne vanhentunut",
    "Could not get version" : "Versiota ei saatu",
    "Error: Server responded with: {error}" : "Virhe: palvelin vastasi: {error}",
    "Error: Unknown error occurred" : "Virhe: Tuntematon virhe",
    "SIP configuration" : "SIP-määritys",
    "Invalid date, date format must be YYYY-MM-DD" : "Virheellinen päiväys, päiväyksen muoto tulee olla YYYY-MM-DD",
    "Conversation not found" : "Keskustelua ei löydy",
    "Chat, video & audio-conferencing using WebRTC" : "Keskustelu ja video- sekä äänineuvottelut WebRTC:tä käyttäen",
    "Leave call" : "Poistu puhelusta",
    "Navigating away from the page will leave the call in {conversation}" : "Sivulta poistuminen päättää puhelun keskustelussa {conversation}",
    "Stay in call" : "Pysy puhelussa",
    "Discuss this file" : "Keskustele tästä tiedostosta",
    "Share this file with others to discuss it" : "Jaa tämä tiedosto muiden kanssa keskustellaksesi siitä",
    "Share this file" : "Jaa tämä tiedosto",
    "Join conversation" : "Liity keskusteluun",
    "This conversation is password-protected." : "Tämä keskustelu on suojattu salasanalla.",
    "The password is wrong. Try again." : "Salasana on väärin. Yritä uudelleen.",
    "Password" : "Salasana",
    "Submit" : "Lähetä",
    "Error requesting the password." : "Virhe pyytäessä salasanaa.",
    "Request password" : "Pyydä salasana",
    "This conversation has ended" : "Tämä keskustelu on päättynyt",
    "Error occurred when joining the conversation" : "Keskusteluun liittyessä tapahtui virhe",
    "Close Talk sidebar" : "Sulje Talkin sivupalkki",
    "Open Talk sidebar" : "Avaa Talkin sivupalkki",
    "Everyone" : "Kaikki",
    "Users and moderators" : "Käyttäjät ja moderaattorit",
    "Moderators only" : "Vain moderaattorit",
    "Disable calls" : "Poista puhelut käytöstä",
    "Save changes" : "Tallenna muutokset",
    "Saving …" : "Tallennetaan…",
    "Saved!" : "Tallennettu!",
    "Limit to groups" : "Rajoita ryhmiin",
    "Guests can still join public conversations." : "Vieraat voivat silti liittyä julkisiin keskusteluihin.",
    "Limit using Talk" : "Rajoita Talkin käyttöä",
    "Limit creating a public and group conversation" : "Rajoita julkisten ja ryhmäkeskustelujen luomista",
    "Limit creating conversations" : "Rajoita keskustelujen luomista",
    "Limit starting a call" : "Rajoita puhelun aloittamista",
    "Limit starting calls" : "Rajoita puhelujen aloittamista",
    "Description is not provided" : "Kuvausta ei ole annettu",
    "Enabled" : "Käytössä",
    "Disabled" : "Pois käytöstä",
    "Bots settings" : "Bottien asetukset",
    "State" : "Tila",
    "Name" : "Nimi",
    "Last error" : "Viimeisin virhe",
    "Total errors count" : "Virheitä yhteensä",
    "Find more bots" : "Etsi lisää botteja",
    "Beta" : "Beta",
    "Permissions" : "Oikeudet",
    "Select groups …" : "Valitse ryhmät…",
    "All messages" : "Kaikki viestit",
    "@-mentions only" : "Vain @-maininnat",
    "Off" : "Pois",
    "General settings" : "Yleiset asetukset",
    "Default notification settings" : "Ilmoitusten oletusasetukset",
    "Default group notification" : "Ryhmän oletusilmoitus",
    "Integration into other apps" : "Integraatio muihin sovelluksiin",
    "Allow conversations on files" : "Salli keskustelut tiedostoista",
    "Allow conversations on public shares for files" : "Salli keskustelut tiedostojen julkisissa jaoissa",
    "Enable encryption" : "Käytä salausta",
    "Pending" : "Odottaa",
    "Error" : "Virhe",
    "Blocked" : "Estetty",
    "Active" : "Aktiivinen",
    "Expired" : "Vanhentunut",
    "Never" : "Ei koskaan",
    "The account could not be deleted. Please try again later." : "Tätä tiliä ei voitu poistaa. Yritä myöhemmin uudelleen.",
    "URL of this Nextcloud instance" : "Tämän Nextcloud-instanssin URL-osoite",
    "Email of the user" : "Käyttäjän sähköpostiosoite",
    "Language" : "Kieli",
    "Country" : "Maa",
    "Status" : "Tila",
    "Created at" : "Luotu",
    "Expires at" : "Vanhenee",
    "Yes" : "Kyllä",
    "No" : "Ei",
    "_%n user_::_%n users_" : ["%n käyttäjä","%n käyttäjää"],
    "Installed version: {version}" : "Asennettu versio: {version}",
    "Matterbridge binary was not found or couldn't be executed." : "Matterbridge-binääriä ei löytynyt tai sitä ei voitu suorittaa.",
    "Downloading …" : "Ladataan…",
    "Install Talk Matterbridge" : "Asenna Talk Matterbridge",
    "Failed to execute Matterbridge binary." : "Matterbridge-binäärin suorittaminen epäonnistui.",
    "Matterbridge integration" : "Matterbridge-integraatio",
    "Enable Matterbridge integration" : "Käytä Matterbridge-integraatiota",
    "Status: Checking connection" : "Tila: Tarkistetaan yhteyttä",
    "OK: Running version: {version}" : "OK: Suoritetaan versiota: {version}",
    "Validate SSL certificate" : "Vahvista SSL-varmenne",
    "Delete this server" : "Poista tämä palvelin",
    "Test this server" : "Testaa tämä palvelin",
    "Shared secret" : "Jaettu salaisuus",
    "SIP configuration saved!" : "SIP-määritykset tallennettu!",
    "Phone number (Country)" : "Puhelinnumero (maa)",
    "STUN server URL" : "STUN-palvelimen osoite",
    "The server address is invalid" : "Palvelimen osoite on virheellinen",
    "STUN settings saved" : "STUN-asetukset tallennettu",
    "STUN servers" : "STUN-palvelimet",
    "Add a new STUN server" : "Lisää uusi STUN-palvelin",
    "{option1} and {option2}" : "{option1} ja {option2}",
    "{option} only" : "vain {option}",
    "TURN server schemes" : "TURN-palvelimen skeemat",
    "TURN server URL" : "TURN-palvelimen osoite",
    "TURN server secret" : "TURN-palvelimen salaisuus",
    "TURN server protocols" : "TURN-palvelimen protokollat",
    "TURN settings saved" : "TURN-asetukset tallennettu",
    "TURN servers" : "TURN-palvelin",
    "Add a new TURN server" : "Lisää uusi TURN-palvelin",
    "Failed" : "Epäonnistui",
    "OK" : "OK",
    "Checking …" : "Tarkistetaan…",
    "Federated user" : "Federoitu käyttäjä",
    "Assign participants to rooms" : "Määritä osallistujat huoneisiin",
    "Configure breakout rooms" : "Määritä pienryhmätilat",
    "Number of breakout rooms" : "Pienryhmätilojen määrä",
    "Automatically assign participants" : "Määritä osallistujat automaattisesti",
    "Manually assign participants" : "Määritä osallistujat manuaalisesti",
    "Allow participants to choose" : "Salli osallistujien valinta",
    "Create rooms" : "Luo pienryhmätilat",
    "Confirm" : "Vahvista",
    "Create breakout rooms" : "Luo pienryhmätilat",
    "Reset" : "Palauta",
    "Delete breakout rooms" : "Poista pienryhmätilat",
    "Room {roomNumber}" : "Huone {roomNumber}",
    "Current breakout rooms and settings will be lost" : "Nykyisen pienryhmätilat ja asetukset katoavat",
    "Cancel" : "Peruuta",
    "Unassigned participants" : "Osallistujat joita ei ole määritetty",
    "Back" : "Takaisin",
    "Add participant \"{user}\"" : "Lisää osallistuja \"{user}\"",
    "Now" : "Nyt",
    "Loading …" : "Ladataan…",
    "From" : "Lähettäjä",
    "To" : "Vastaanottaja",
    "Calendar" : "Kalenteri",
    "Attendees" : "Osallistujat",
    "Save" : "Tallenna",
    "Search participants" : "Etsi osallistujia",
    "No results" : "Ei tuloksia",
    "Done" : "Valmis",
    "Raise hand" : "Nosta käsi",
    "Raise hand (R)" : "Nosta käsi (R)",
    "Lower hand" : "Laske käsi",
    "Lower hand (R)" : "Laske käsi (R)",
    "Exit full screen (F)" : "Poistu koko näytön tilasta (F)",
    "Full screen (F)" : "Koko näyttö (F)",
    "Speaker view" : "Puhujan näkymä",
    "Grid view" : "Ruudukkonäkymä",
    "This conversation is read-only" : "Keskustelu on \"vain luku\"-tilassa",
    "Reload" : "Päivitä",
    "{nickName} raised their hand." : "{nickName} nosti kätensä.",
    "A participant raised their hand." : "Osallistuja nosti kätensä.",
    "Previous page of videos" : "Videoiden edellinen sivu",
    "Next page of videos" : "Videoiden seuraava sivu",
    "Connecting …" : "Yhdistetään…",
    "Calling …" : "Soitetaan…",
    "Waiting for {user} to join the call" : "Odotetaan käyttäjän {user} liittyvän puheluun",
    "Waiting for others to join the call …" : "Odotetaan muiden liittymistä puheluun...",
    "You can invite others in the participant tab of the sidebar" : "Voit kutsua muita sivupalkissa olevan Osallistujat-välilehden kautta",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Voit kutsua muita sivupalkissa olevan Osallistujat-välilehden kautta tai jakamalla tämän linkin!",
    "Share this link to invite others!" : "Jaa tämä linkki kutsuaksesi muita!",
    "Copy link" : "Kopioi linkki",
    "You are not allowed to enable audio" : "Sinulla ei ole oikeutta jakaa ääntä",
    "No audio. Click to select device" : "Ei ääntä. Napsauta valitaksesi laitteen",
    "Mute audio" : "Mykistä ääni",
    "Mute audio (M)" : "Mykistä äänet (M)",
    "Unmute audio" : "Palauta äänet",
    "Unmute audio (M)" : "Palauta äänet (M)",
    "None" : "Ei mitään",
    "Check devices" : "Tarkista laitteet",
    "Access to camera was denied" : "Pääsy kameraan estettiin",
    "Error while accessing camera: It is likely in use by another program" : "Virhe yrittäessä käyttää kameraa: se on luultavasti toisen ohjelman käytössä",
    "Error while accessing camera" : "Virhe käyttäessä kameraa",
    "You have been muted by a moderator" : "Moderaattori on mykistänyt sinut",
    "Hide presenter video" : "Piilota esittäjän video",
    "You are not allowed to enable video" : "Sinulla ei ole oikeutta ottaa videota käyttöön",
    "No video. Click to select device" : "Ei videota. Napsauta valitaksesi laitteen",
    "Disable video" : "Poista video käytöstä",
    "Disable video (V)" : "Poista video käytöstä (V)",
    "Enable video" : "Käytä videota",
    "Enable video (V)" : "Ota video käyttöön (v)",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Ota video käyttöön (V) - Yhteys keskeytyy hetkeksi, kun otat videon käyttöön ensimmäisen kerran",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Ota video käyttöön. Yhteys keskeytyy hetkeksi, kun otat videon käyttöön ensimmäisen kerran",
    "Show presenter" : "Näytä esittäjä",
    "You" : "Sinä",
    "Mute" : "Mykistä",
    "Muted" : "Mykistetty",
    "Show screen" : "Näytä näyttö",
    "Stop following" : "Lopeta seuraaminen",
    "Connection could not be established …" : "Yhteyttä ei voitu muodostaa…",
    "Connection was lost and could not be re-established …" : "Yhteys katkesi eikä sitä voitu muodostaa uudelleen…",
    "Connection could not be established. Trying again …" : "Yhteyttä ei voitu muodostaa. Yritetään uudelleen…",
    "Connection lost. Trying to reconnect …" : "Yhteys katkesi. Yritetään muodostaa yhteys uudelleen…",
    "Connection problems …" : "Ongelmia yhteydessä…",
    "Collapse" : "Kutista näkymää",
    "Expand" : "Laajenna",
    "You need to be logged in to upload files" : "Sinun tulee olla kirjautunut sisään, jotta voit lähettää tiedostoja",
    "Drop your files to upload" : "Pudota tiedostot lähettääksesi ne",
    "Conversation messages" : "Keskustelun viestit",
    "Scroll to bottom" : "Vieritä alas",
    "Post message" : "Lähetä viesti",
    "Federated conversation" : "Federoitu keskustelu",
    "Public conversation" : "Julkinen keskustelu",
    "Favorite" : "Suosikki",
    "Manage bans" : "Hallitse estoja",
    "No banned users" : "Ei estettyjä käyttäjiä",
    "Date:" : "Päivämäärä:",
    "Note:" : "Huomioi:",
    "Hide details" : "Piilota tiedot",
    "Show details" : "Näytä lisätiedot",
    "Error while updating conversation name" : "Virhe keskustelun nimeä päivittäessä",
    "Error while updating conversation description" : "Virhe keskustelun kuvausta päivittäessä",
    "Enter a name for this conversation" : "Anna nimi tälle keskustelulle",
    "Edit conversation name" : "Muokkaa keskustelun nimeä",
    "Edit conversation description" : "Muokkaa keskustelun kuvausta",
    "Enter a description for this conversation" : "Anna kuvaus tälle keskustelulle",
    "Picture" : "Kuva",
    "Disable" : "Poista käytöstä",
    "Enable" : "Käytä",
    "Breakout rooms" : "Pienryhmätilat",
    "Manage breakout rooms" : "Hallitse pienryhmätiloja",
    "Set up breakout rooms for this conversation" : "Määritä tämän keskustelun pienryhmätilat",
    "Please select a valid PNG or JPG file" : "Valitse kelvollinen PNG- tai JPG-tiedosto",
    "Choose your conversation picture" : "Valitse keskustelukuva",
    "Choose" : "Valitse",
    "Error setting conversation picture" : "Virhe keskustelukuvaa asettaessa",
    "Could not set the conversation picture: {error}" : "Keskustelun kuvaa ei voitu asettaa: {error}",
    "Error cropping conversation picture" : "Virhe keskustelukuvaa rajattaessa",
    "Error removing conversation picture" : "Virhe keskustelukuvaa poistaessa",
    "Set emoji as conversation picture" : "Aseta emoji keskustelukuvaksi",
    "Set background color for conversation picture" : "Aseta taustaväri keskustelukuvalle",
    "Upload conversation picture" : "Lähetä keskustelukuva",
    "Choose conversation picture from files" : "Valitse keskustelukuva tiedostoista",
    "Remove conversation picture" : "Aseta keskustelukuva",
    "The file must be a PNG or JPG" : "Tiedoston tulee olla PNG tai JPG",
    "Set picture" : "Aseta kuva",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Muokkaa tähän keskusteluun osallistuvien oletusoikeuksia. Nämä asetukset eivät vaikuta moderaattoreihin.",
    "All permissions" : "Kaikki oikeudet",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Osallistujilla on oikeus aloittaa puhelu, liittyä puheluun, ottaa ääni ja video käyttöön sekä jakaa näytön sisältö.",
    "Restricted" : "Rajoitettu",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Osallistujat voivat liittyä puheluihin, mutta eivät voi ottaa ääntä tai videota käyttöön tai jakaa näyttönsä sisältöä, ennen kuin moderaattori on antanut siihen luvan.",
    "Advanced permissions" : "Edistyneet oikeudet",
    "Edit permissions" : "Muokkaa oikeuksia",
    "Conversation settings" : "Keskustelun asetukset",
    "Basic Info" : "Perustiedot",
    "Personal" : "Henkilökohtainen",
    "Moderation" : "Moderaatio",
    "Breakout Rooms" : "Pienryhmätilat",
    "Matterbridge" : "Matterbridge",
    "Bots" : "Botit",
    "Danger zone" : "Vaaravyöhyke",
    "Leave conversation" : "Poistu keskustelusta",
    "Delete conversation" : "Poista keskustelu",
    "Do you really want to delete \"{displayName}\"?" : "Poistetaanko \"{displayName}\"?",
    "Error while deleting conversation" : "Virhe keskustelua poistaessa",
    "Delete all chat messages" : "Poista kaikki keskustelun viestit",
    "Error while clearing chat history" : "Virhe keskusteluhistoriaa siivotessa",
    "Be careful, these actions cannot be undone." : "Ole varovainen, näitä toimintoja ei voi perua.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Kun olet kerran poistunut suljetusta keskustelusta, tarvitset kutsun liittyäksesi uudelleen siihen. Avoimeen keskusteluun on mahdollista liittyä milloin hyvänsä.",
    "Permanently delete this conversation." : "Poista tämä keskustelu pysyvästi.",
    "Delete chat messages" : "Poista keskustelun viestit",
    "Permanently delete all the messages in this conversation." : "Poista pysyvästi kaikki tämän keskustelun viestit.",
    "_%n hour_::_%n hours_" : ["%n tunti","%n tuntia"],
    "_%n day_::_%n days_" : ["%n päivä","%n päivää"],
    "_%n week_::_%n weeks_" : ["%n viikko","%n viikkoa"],
    "Custom expiration time" : "Mukautettu vanhenemisaika",
    "Message expiration disabled" : "Viestien vanheneminen poistettu käytöstä",
    "Message expiration set: {duration}" : "Viestien vanhenemiseksi asetettu: {duration}",
    "Error when trying to set message expiration" : "Virhe yrittäessä asettaa viestin vanhenemista",
    "Message expiration" : "Viestin vanheneminen",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Keskusteluviestit on mahdollista vanhentaa tietyn ajan jälkeen. Huomio: Keskustelussa jaetut tiedostot eivät poistu omistajalta, mutta ne eivät ole enää jaettu keskustelussa.",
    "Set message expiration" : "Aseta viestin vanheneminen",
    "Current message expiration" : "Nykyinen viestin vanheneminen",
    "Guest access" : "Vieraspääsy",
    "Allow guests to join this conversation via link" : "Salli vieraiden liittyä tähän keskusteluun linkin kautta",
    "Password protection" : "Salasanasuojaus",
    "Set a password" : "Aseta salasana",
    "Change password" : "Vaihda salasana",
    "Enter new password" : "Kirjoita uusi salasana",
    "Save password" : "Tallenna salasana",
    "Guests are allowed to join this conversation via link" : "Vieraat voivat liittyä tähän keskusteluun linkin kautta",
    "Guests are not allowed to join this conversation" : "Vierailla ei ole oikeutta liittyä tähän keskusteluun",
    "Resend invitations" : "Lähetä kutsut uudelleen",
    "This conversation is open to registered users" : "Avaa keskustelu on avoinna rekisteröityneille käyttäjille",
    "Open conversation to registered users, showing it in search results" : "Avaa keskustelu rekisteröityneille käyttäjille, näytetään hakutuloksissa",
    "Open conversation" : "Avaa keskustelu",
    "Start time: {date}" : "Aloitusaika: {date}",
    "Start time has been updated" : "Aloitusaika on päivitetty",
    "Error occurred while updating start time" : "Virhe aloitusaikaa päivittäessä",
    "Meeting start time" : "Tapaamisen alotusaika",
    "Start time (optional)" : "Aloitusaika (valinnainen)",
    "Error occurred when locking the conversation" : "Keskustelun lukitsemisessa tapahtui virhe",
    "Lock conversation" : "Lukitse keskustelu",
    "This will also terminate the ongoing call." : "Tämä lopettaa meneillään olevan puhelun ̣",
    "Edit" : "Muokkaa",
    "More information" : "Lisää tietoa",
    "Delete" : "Poista",
    "Add new bridged channel to current conversation" : "Lisää uusi sillattu kanava nykyiseen keskusteluun",
    "unknown state" : "tuntematon tila",
    "running" : "käynnissä",
    "not running, check Matterbridge log" : "ei käynnistä, tarkista Matterbridge-loki",
    "not running" : "ei käynnissä",
    "Bridge saved" : "Silta tallennettu",
    "More info on Matterbridge" : "Lisätietoa Matterbridgestä",
    "Enable bridge" : "Ota silta käyttöön",
    "Show Matterbridge log" : "Näytä Matterbridge-loki",
    "Log content" : "Lokin sisältö",
    "Notifications" : "Ilmoitukset",
    "Notify about calls in this conversation" : "llmoita puheluista tässä keskustelussa",
    "Important conversation" : "Tärkeä keskustelu",
    "SIP dial-in is now possible without PIN requirement" : "SIP-sisäänsoitto on nyt mahdollista ilman PIN-koodin vaatimusta",
    "SIP dial-in is now enabled" : "SIP-sisäänsoitto on nyt käytössä",
    "SIP dial-in is now disabled" : "SIP-sisäänsoitto on nyt pois käytöstä",
    "Phone and SIP dial-in" : "Puhelin- ja SIP-sisäänsoitto",
    "Enable phone and SIP dial-in" : "Käytä puhelimella ja SIP:illä sisäänsoittoa",
    "Allow to dial-in without a PIN" : "Salli sisäänsoitto ilman PIN-koodia",
    "Join" : "Liity",
    "Error while creating the conversation" : "Virhe keskustelua luotaessa",
    "Create a new conversation" : "Luo uusi keskustelu",
    "Join open conversations" : "Liity avoimiin keskusteluihin",
    "Call a phone number" : "Soita puhelinnumeroon",
    "Schedule meetings" : "Sovi tapaamisia",
    "You don't have any upcoming meetings" : "Sinulla ei ole tulevia tapaamisia",
    "Open calendar" : "Avaa kalenteri",
    "Unread mentions" : "Lukemattomat maininnat",
    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "Viestit, joissa sinut on mainittu, näkyvät tässä. Voit mainita henkilöitä kirjoittamalla @ -merkin ja sitten heidän nimensä",
    "Message reminders" : "Viestimuistutukset",
    "Set a reminder on a message to be notified" : "Aseta muistutus viestiin, jotta saat siitä ilmoituksen",
    "Create conversation" : "Luo keskustelu",
    "Enter your name" : "Kirjoita nimesi",
    "Log in" : "Kirjaudu sisään",
    "Creating the conversation …" : "Luodaan keskustelu…",
    "Mark as read" : "Merkitse luetuksi",
    "Mark as unread" : "Merkitse lukemattomaksi",
    "Remove from favorites" : "Poista suosikeista",
    "Add to favorites" : "Lisää suosikkeihin",
    "Conversation actions" : "Keskustelun toiminnot",
    "Pending invitations" : "Odottavat kutsut",
    "From {user} at {remoteServer}" : "Käyttäjältä {user} palvelimelta {remoteServer}",
    "Decline invitation" : "Kieltäydy kutsusta",
    "Accept invitation" : "Hyväksy kutsu",
    "No pending invitations" : "Ei odottavia kutsuja",
    "Home" : "Koti",
    "Unread" : "Lukematon",
    "Alphabetically" : "Aakkosjärjestys",
    "No followed threads" : "Ei seurattuja keskusteluketjuja",
    "No matches found" : "Ei tuloksia",
    "No conversations found" : "Keskusteluja ei löytynyt",
    "Subscribe to an existing thread or start your own." : "Seuraa olemassa olevaa keskusteluketjua tai aloita omasi.",
    "You have no unread mentions." : "Sinulla ei ole lukemattomia mainintoja.",
    "You have no unread messages." : "Sinulla ei ole lukemattomia viestejä.",
    "An error occurred while performing the search" : "Hakua suorittaessa tapahtui virhe",
    "Conversation list" : "Keskustelulista",
    "Filter conversations by" : "Suodata keskusteluja",
    "Unread messages" : "Lukemattomat viestit",
    "Meeting conversations" : "Kokouskeskustelut",
    "Clear filters" : "Tyhjennä suodattimet",
    "New personal note" : "Uusi henkilökohtainen muistiinpano",
    "Back to conversations" : "Palaa keskusteluihin",
    "Threads" : "Keskusteluketjut",
    "Clear filter" : "Tyhjennä suodatin",
    "App settings" : "Sovelluksen asetukset",
    "Users" : "Käyttäjät",
    "Groups" : "Ryhmät",
    "Teams" : "Tiimit",
    "Federated users" : "Federoidut käyttäjät",
    "New private conversation" : "Uusi yksityinen keskustelu",
    "Other sources" : "Muut lähteet",
    "Open conversations" : "Avaa keskustelut",
    "No search results" : "Ei hakutuloksia",
    "Users, groups and teams" : "Käyttäjät, ryhmät ja tiimit",
    "Users and groups" : "Käyttäjät ja ryhmät",
    "Users and teams" : "Käyttäjät ja tiimit",
    "Groups and teams" : "Ryhmät ja tiimit",
    "New group conversation" : "Uusi ryhmäkeskustelu",
    "The meeting will start soon" : "Tämä kokous alkaa pian",
    "This meeting is scheduled for {startTime}" : "Kokous on ajoitettu alkavaksi {startTime}",
    "You are currently waiting in the lobby" : "Odotat parhaillaan aulassa",
    "Select microphone" : "Valitse mikrofoni",
    "No microphone available" : "Ei mikrofonia saatavilla",
    "Select camera" : "Valitse kamera",
    "No camera available" : "Ei kameraa saatavilla",
    "Select a device" : "Valitse laite",
    "Playing …" : "Toistetaan…",
    "Test speakers" : "Testaa kaiuttimia",
    "Test" : "Kokeile",
    "Devices" : "Laitteet",
    "Backgrounds" : "Taustakuvat",
    "No audio" : "Ei ääntä",
    "No camera" : "Ei kameraa",
    "Calls are not supported in your browser" : "Selaimesi ei tue puheluja",
    "Access to microphone is only possible with HTTPS" : "Mikrofonin käyttäminen on mahdollista vain HTTPS-yhteydellä",
    "Access to microphone was denied" : "Pääsy mikrofoniin estettiin",
    "Error while accessing microphone" : "Virhe yrittäessä käyttää mikrofonia",
    "Access to camera is only possible with HTTPS" : "Kameran käyttäminen on mahdollista vain HTTPS-yhteydellä",
    "The call is being recorded." : "Tämä puhelu tallennetaan.",
    "Apply settings" : "Toteuta asetukset",
    "Select virtual office background" : "Valitse virtuaalinen toimistotaustakuva",
    "Select virtual home background" : "Valitse virtuaalinen kotitaustakuva",
    "Select virtual abstract background" : "Valitse virtuaalinen abstraktitaustakuva",
    "Select virtual beach background" : "Valitse virtuaalinen rantataustakuva",
    "Select virtual park background" : "Valitse virtuaalinen puistotaustakuva",
    "Select virtual theater background" : "Valitse virtuaalinen teatteritaustakuva",
    "Select virtual library background" : "Valitse virtuaalinen kirjastotaustakuva",
    "Select virtual space station background" : "Valitse virtuaalinen avaruusasemataustakuva",
    "Error while uploading the file" : "Virhe tiedostoa lähettäessä",
    "Select a file" : "Valitse tiedosto",
    "Invalid path selected" : "Valittu virheellinen polku",
    "Select virtual background from file {fileName}" : "Valitse virtuaalinen taustakuva tiedostosta {fileName}",
    "Blur" : "Sumennus",
    "Upload" : "Lähetä",
    "Files" : "Tiedostot",
    "(edited)" : "(muokattu)",
    "The message has expired or has been deleted" : "Tämä viesti on vanhentunut tai se on poistettu",
    "Cancel quote" : "Peruuta lainaus",
    "24 hours" : "24 tuntia",
    "7 days" : "7 päivää",
    "Clear reminder – {timeLocale}" : "Tyhjennä muistutus – {timeLocale}",
    "Message text copied to clipboard" : "Viestin teksti kopioitu leikepöydälle",
    "Message text could not be copied" : "Viestin tekstiä ei voitu kopioida",
    "Add a reaction to this message" : "Lisää reaktio tähän viestiin",
    "Reply" : "Vastaa",
    "More actions" : "Lisää toimintoja",
    "Set reminder" : "Aseta muistutus",
    "Reply privately" : "Vastaa yksityisesti",
    "Edit message" : "Muokkaa viestiä",
    "Copy message link" : "Kopioi viestin linkki",
    "Go to file" : "Siirry tiedostoon",
    "Forward message" : "Lähetä edelleen",
    "Translate" : "Käännä",
    "Set custom reminder" : "Aseta mukautettu muistutus",
    "Close reactions menu" : "Sulje reaktiovalikko",
    "React with {emoji}" : "Reagoi emojilla {emoji}",
    "React with another emoji" : "Reagoi toisella emojilla",
    "Choose a conversation to forward the selected message." : "Valitse keskustelu, johon valittu viesti edelleenlähetetään.",
    "Error while forwarding message" : "Virhe edelleenlähettäessä viestiä",
    "The message has been forwarded to {selectedConversationName}" : "Viesti on lähetetty edelleen keskusteluun {selectedConversationName}",
    "Dismiss" : "Hylkää",
    "Go to conversation" : "Mene keskusteluun",
    "Detect language" : "Havaitse kieli",
    "The message could not be translated" : "Viestiä ei voitu kääntää",
    "Translation copied to clipboard" : "Käännös kopioitu leikepöydälle",
    "Translation could not be copied" : "Käännöstä ei voitu kopioida",
    "Translate message" : "Käännä viesti",
    "Source language to translate from" : "Lähdekieli, josta käännetään",
    "Translate from" : "Lähdekieli",
    "Target language to translate into" : "Kohdekieli, jolle käännetään",
    "Translate to" : "Kohdekieli",
    "Translating" : "Käännetään",
    "Copy translated text" : "Kopioi käännetty teksti",
    "Send now" : "Lähetä nyt",
    "Message read by everyone who shares their reading status" : "Viesti luettu kaikkien niiden kanssa, jotka jakavat lukutilapäivityksensä",
    "Message sent" : "Viesti lähetetty",
    "Deleting message" : "Poistetaan viestiä",
    "Message deleted successfully" : "Viesti poistettu onnistuneesti",
    "Message could not be deleted because it is too old" : "Viestiä ei voitu poistaa, koska se on liian vanha",
    "Only normal chat messages can be deleted" : "Vain normaaleja keskustelun viestejä on mahdollista poistaa",
    "An error occurred while deleting the message" : "Virhe viestiä poistaessa",
    "Your browser does not support playing audio files" : "Selaimesi ei tue äänitiedostojen toistamista",
    "Contact" : "Yhteystieto",
    "Remove {fileName}" : "Poista {fileName}",
    "Open this location in OpenStreetMap" : "Avaa tämä sijainti OpenStreetMapissa",
    "Sending message" : "Lähetetään viestiä",
    "Failed to send the message. Click to try again" : "Viestin lähettäminen epäonnistui. Paina yrittääksesi uudelleen",
    "Not enough free space to upload file" : "Ei riittävästi vapaata tilaa tiedoston lähettämiseksi",
    "You cannot send messages to this conversation at the moment" : "Et voi lähettää viestejä tähän keskusteluun tällä hetkellä",
    "You voted" : "Äänestit",
    "_%n vote_::_%n votes_" : ["%n ääni","%n ääntä"],
    "See results" : "Näytä tulokset",
    "Reactions" : "Reaktiot",
    "No permission to post reactions in this conversation" : "Ei oikeutta lähettää reaktioita tähän keskusteluun",
    "Show all reactions" : "Näytä kaikki reaktiot",
    "Add more reactions" : "Lisää enemmän reaktioita",
    "Show or collapse system messages" : "Näytä tai piilota järjestelmäviestit",
    "No messages" : "Ei viestejä",
    "All messages have expired or have been deleted." : "Kaikki viestit ovat vanhentuneet tai ne on poistettu.",
    "Unpin" : "Poista kiinnitys",
    "Cancel search" : "Peruuta haku",
    "Add a phone number" : "Lisää puhelinnumero",
    "All set, the conversation \"{conversationName}\" was created." : "Kaikki valmista, keskustelu \"{conversationName}\" luotu.",
    "Create a new group conversation" : "Luo uusi ryhmäkeskustelu",
    "Add participants" : "Lisää osallistujat",
    "Conversation visibility" : "Keskustelun näkyvyys",
    "Allow guests to join via link" : "Salli vieraiden liittyä linkin kautta",
    "Enter password" : "Anna salasana",
    "This conversation has been locked" : "Tämä keskustelu on lukittu",
    "No permission to post messages in this conversation" : "Ei oikeutta lähettää viestejä tässä keskustelussa",
    "Joining conversation …" : "Liitytään keskusteluun…",
    "Send message" : "Lähetä viesti",
    "Send without notification" : "Lähetä ilman ilmoitusta",
    "File to share" : "Jaettava tiedosto",
    "Add emoji" : "Lisää emoji",
    "Send later" : "Lähetä myöhemmin",
    "Cancel editing" : "Peruuta muokkaus",
    "Share from {nextcloud}" : "Jaa lähteestä {nextcloud}",
    "Share from Files" : "Jaa tiedostoista",
    "Share files to the conversation" : "Jaa tiedostoja keskusteluun",
    "Upload from device" : "Lähetä laitteelta",
    "Create new poll" : "Luo uusi kysely",
    "Smart picker" : "Älykäs valitsin",
    "Record voice message" : "Äänitä ääniviesti",
    "End recording and send" : "Lopeta äänitys ja lähetä",
    "Dismiss recording" : "Hylkää äänitallenne",
    "Access to the microphone was denied" : "Pääsy mikrofoniin estettiin",
    "Microphone either not available or disabled in settings" : "Mikrofoni ei ole käytettävissä tai se on poistettu käytöstä asetuksista",
    "Error while recording audio" : "Virhe äänittäessä",
    "New file" : "Uusi tiedosto",
    "Blank" : "Tyhjä",
    "Error while creating file" : "Virhe tiedostoa luotaessa",
    "Create and share a new file" : "Luo ja jaa uusi tiedosto",
    "Name of the new file" : "Uuden tiedoston nimi",
    "Create file" : "Luo tiedosto",
    "Someone is typing …" : "Joku kirjoittaa…",
    "{user1} is typing …" : "{user1} kirjoittaa…",
    "{user1} and {user2} are typing …" : "{user1} ja {user2} kirjoittavat…",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} ja {user3} kirjoittavat…",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} ja %n muu kirjoittavat…","{user1}, {user2}, {user3} ja %n muuta kirjoittavat…"],
    "Add more files" : "Lisää enemmän tiedostoja",
    "Send" : "Lähetä",
    "In this conversation <strong>{user}</strong> can:" : "Tässä keskustelussa käyttäjä <strong>{user}</strong> voi:",
    "Start a call" : "Aloita puhelu",
    "Skip the lobby" : "Ohita aula",
    "Can post messages and reactions" : "Voi lähettää viestejä ja reaktioita",
    "Enable the microphone" : "Ota mikrofoni käyttöön",
    "Enable the camera" : "Ota kamera käyttöön",
    "Share the screen" : "Jaa näyttö",
    "Update permissions" : "Päivitä oikeudet",
    "Updating permissions" : "Päivitetään oikeudet",
    "Create poll" : "Luo kysely",
    "Question" : "Kysymys",
    "Ask a question" : "Esitä kysymys",
    "Answers" : "Vastaukset",
    "Answer {option}" : "Vastaus {option}",
    "Add answer" : "Lisää vastaus",
    "Settings" : "Asetukset",
    "Anonymous poll" : "Anonyymi kysely",
    "Multiple answers" : "Useita vastauksia",
    "You voted for this option" : "Äänestit tätä vaihtoehtoa",
    "End poll" : "Lopeta kysely",
    "Change your vote" : "Muuta antamaasi ääntä",
    "Results" : "Tulokset",
    "Send a message to \"{roomName}\"" : "Lähetä viesti huoneeseen \"{roomName}\"",
    "Hide list of participants" : "Piilota osallistujaluettelo",
    "Show list of participants" : "Näytä osallistujaluettelo",
    "Assistance requested in {roomName}" : "Apua pyydetty pienryhmätilassa {roomName}",
    "The message was sent to \"{roomName}\"" : "Viesti lähetettiin huoneeseen \"{roomName}\"",
    "Send message to room" : "Lähetä viesti huoneeseen",
    "Back to main room" : "Takaisin päähuoneeseen",
    "Back to your room" : "Takaisin omaan huoneeseen",
    "Message all rooms" : "Viesti kaikkiin huoneisiin",
    "Start session" : "Aloita istunto",
    "Stop session" : "Pysäytä istunto",
    "The message was sent to all breakout rooms" : "Viesti lähetettiin kaikkiin pienryhmätiloihin.",
    "Send a message to all breakout rooms" : "Lähetä viesti kaikkiin pienryhmätiloihin",
    "Disable lobby" : "Poista aula käytöstä",
    "Settings for participant \"{user}\"" : "Osallistujen \"{user}\" asetukset",
    "Participant \"{user}\"" : "Osallistuja \"{user}\"",
    "moderator" : "moderaattori",
    "guest" : "vieras",
    "Ringing …" : "Soitetaan…",
    "Call rejected" : "Puhelu hylätty",
    "Raised their hand" : "Nosti kätensä",
    "Joined with video" : "Liittyi videon kera",
    "Joined via phone" : "Liittyi puhelimen kautta",
    "Joined with audio" : "Liittyi äänen kera",
    "Remove group and members" : "Poista ryhmä ja jäsenet",
    "Remove team and members" : "Poista tiimi ja jäsenet",
    "Remove participant" : "Poista osallistuja",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "Haluatko varmasti poistaa ryhmän  \"{displayName}\" ja sen jäsenet tästä kesksutelusta?",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "Haluatko varmasti poistaa tiimin \"{displayName}\" ja sen jäsenet tästä kesksutelusta?",
    "Notification was sent to {displayName}" : "Ilmoitus lähetettiin käyttäjälle {displayName}",
    "Phone number copied to clipboard" : "Puhelinnumero kopioitu leikepöydälle",
    "Phone number could not be copied" : "Puhelinnumeroa ei voitu kopioida",
    "Dial-in PIN" : "Sisäänsoiton PIN-koodi",
    "Demote from moderator" : "Alenna moderaattorista",
    "Promote to moderator" : "Ylennä moderaattoriksi",
    "Resend invitation" : "Lähetä kutsu uudelleen",
    "Send call notification" : "Lähetä puheluilmoitus",
    "Put phone number on hold" : "Aseta puhelinnumero pitoon",
    "Mute phone number" : "Mykistä puhelinnumero",
    "Copy phone number" : "Kopioi puhelinnumero",
    "Grant all permissions" : "Myönnä kaikki oikeudet",
    "Remove all permissions" : "Poista kaikki oikeudet",
    "Remove" : "Poista",
    "Add users, groups or teams" : "Lisää käyttäjiä, ryhmiä tai tiimejä",
    "Add users or groups" : "Lisää käyttäjiä tai ryhmiä",
    "Add users or teams" : "Lisää käyttäjiä tai tiimejä",
    "Add users" : "Lisää käyttäjiä",
    "Add groups or teams" : "Lisää ryhmiä tai tiimejä",
    "Add groups" : "Lisää ryhmiä",
    "Add teams" : "Lisää tiimejä",
    "Add other sources" : "Lisää muita lähteitä",
    "Add emails" : "Lisää sähköpostiosoitteita",
    "Integrations" : "Integraatiot",
    "Add federated users" : "Lisää federoituja käyttäjiä",
    "Searching …" : "Haetaan…",
    "Search for more users" : "Etsi lisää käyttäjiä",
    "Search or add participants" : "Etsi tai lisää osallistujia",
    "Invitation was sent to {actorId}" : "Kutsu lähetettiin käyttäjälle {actorId}",
    "An error occurred while adding the participants" : "Virhe osallistujia lisätessä",
    "Participants" : "Osallistujat",
    "Participants ({count})" : "Osallistujat ({count})",
    "Open chat" : "Avaa keskustelu",
    "You have new unread messages in the chat." : "Keskustelussa on uusia lukemattomia viestejä.",
    "You have been mentioned in the chat." : "Sinut on mainittu keskustelussa.",
    "Chat" : "Keskustelu",
    "Details" : "Tiedot",
    "Shared items" : "Jaetut tietueet",
    "No results found" : "Ei tuloksia",
    "Load more results" : "Lataa lisää tuloksia",
    "Projects" : "Projektit",
    "No shared items" : "Ei jaettuja kohteita",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Linkki keskusteluun",
    "No open conversations found" : "Avoimia keskusteluja ei löytynyt",
    "Search conversations or users" : "Hae keskusteluja tai käyttäjiä",
    "Select conversation" : "Valitse keskustelu",
    "Number length is not valid" : "Numeron pituus on virheellinen",
    "Number is not valid" : "Numero ei ole kelvollinen",
    "Phone numbers" : "Puhelinnumerot",
    "Display name: {name}" : "Näyttönimi: {name}",
    "Edit display name" : "Muokkaa näyttönimeä",
    "Save name" : "Tallenna nimi",
    "Error while saving sounds setting" : "Virhe ääniasetuksia tallentaessa",
    "Compact conversations list" : "Tiivis keskustelunäkymä",
    "Chat appearance" : "Keskustelun ulkoasu",
    "Play sounds when participants join or leave a call" : "Toista ääni kun osallistuja liittyy tai poistuu puhelusta",
    "Currently not available on iPhone and iPad due to technical restrictions by the manufacturer" : "Ei saatavilla tällä hetkellä iPhonelle tai iPadille valmistajan asettamien teknisten rajoitusten vuoksi",
    "Notification settings" : "Ilmoitusasetukset",
    "Sounds for chat and call notifications" : "Ääniasetukset keskustelu- ja puheluilmoituksille",
    "Default language" : "Oletuskieli",
    "Select location for attachments" : "Valitse sijainti liitteille",
    "Error while setting attachment folder" : "Virhe asettaessa liitekansiota",
    "Turn camera and microphone off by default" : "Kamera ja mikrofoni oletuksena pois päältä",
    "Blur camera background by default" : "Kameran taustan sumennus oletuksena",
    "Skip device preview before joining a call" : "Ohita laiteasetusten esikatselu ennen puheluun liittymistä",
    "Appearance & Sounds" : "Ulkoasu & äänet",
    "Privacy" : "Yksityisyys",
    "Send read receipts" : "Lähetä \"luettu\" -kuittaukset",
    "When off, all read statuses will be hidden" : "Kun pois päältä, kaikki viestien \"luettu\" -kuittaukset piilotetaan",
    "Share typing status" : "Jaa \"kirjoittaa\" -ilmoitukset",
    "When off, all typing indicators will be hidden" : "Kun pois päältä, kaikki \"kirjoittaa\" -ilmoitukset piilotetaan",
    "Attachments folder" : "Liitteiden kansio",
    "Toggle full screen" : "Koko näyttö päälle/pois",
    "Return to Home screen" : "Palaa kotinäkymään",
    "Search" : "Etsi",
    "Shortcuts while in a chat" : "Pikanäppäimet keskustelussa",
    "Focus the chat input" : "Kohdista keskustelun syötteeseen",
    "Unfocus the chat input to use shortcuts" : "Poista kohdistus keskustelusta käyttääksesi pikanäppäimiä",
    "Edit your last message" : "Muokkaa viimeistä viestiäsi",
    "Shortcuts while in a call" : "Pikanäppäimet puhelun aikana",
    "Camera on and off" : "Kamera päälle tai pois päältä",
    "Microphone on and off" : "Mikrofoni päälle tai pois päältä",
    "Raise or lower hand" : "Nosta tai laske käsi",
    "Push to talk or push to mute" : "Paina puhuaksesi tai mykistääksesi",
    "Zoom-in / zoom-out a screen share" : "Lähennä tai loitonna näytönjakoa",
    "Start call silently" : "Aloita puhelu hiljennettynä",
    "Start call" : "Aloita puhelu",
    "End call" : "Lopeta puhelu",
    "End call for everyone" : "Päätä puhelu kaikkien osalta",
    "The call has been running for one hour." : "Tämä puhelu on kestänyt yhden tunnin.",
    "Stop recording" : "Lopeta tallennus",
    "Send a reaction" : "Lähetä reaktio",
    "React with {reaction}" : "Reagoi käyttäen {reaction}",
    "_%n participant in call_::_%n participants in call_" : ["%n osallistuja puhelussa","%n osallistujaa puhelussa"],
    "You are not allowed to enable screensharing" : "Sinulla ei ole oikeutta ottaa näytönjakamista käyttöön",
    "No screensharing" : "Ei näytönjakamista",
    "Screensharing options" : "Näytönjakamisen valinnat",
    "Enable screensharing" : "Ota käyttöön näytönjakaminen",
    "Bad sent video and screen quality." : "Heikko lähetetyn videon ja näytön laatu.",
    "Bad sent screen quality." : "Heikko lähetetyn näytön laatu.",
    "Bad sent video quality." : "Heikko lähetetyn videon laatu.",
    "Bad sent audio, video and screen quality." : "Heikko lähetetyn äänen, videon ja näytön laatu.",
    "Bad sent audio and screen quality." : "Heikko lähetetyn äänen ja näytön laatu.",
    "Bad sent audio and video quality." : "Heikko lähetetyn äänen ja videon laatu.",
    "Bad sent audio quality." : "Heikko lähetetyn äänen laatu.",
    "Disable background blur" : "Poista taustan sumennus käytöstä",
    "Disable screenshare" : "Poista käytöstä näytönjakaminen",
    "Screen sharing is not supported by your browser." : "Selaimesi ei tue näytönjakoa.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Näytön jakaminen vaatii sivun lataamista HTTPS-protokollalla.",
    "Screensharing requires the page to be loaded through HTTPS." : "Näytön jakaminen vaatii sivun lataamista HTTPS-protokollalla.",
    "An error occurred while starting screensharing." : "Virhe aloitettaessa näytön jakamista.",
    "Show your screen" : "Näytä oma näyttösi",
    "Stop screensharing" : "Lopeta näytön jakaminen",
    "Mute others" : "Mykistä muut",
    "Start recording" : "Käynnistä tallennus",
    "Set up breakout rooms" : "Määritä pienryhmätilat",
    "Open Calendar" : "Avaa kalenteri",
    "Remove participant {name}" : "Poista osallistuja {name}",
    "Open dialpad" : "Avaa numeronäppäimistö",
    "Select a region" : "Valitse alue",
    "Search …" : "Hae…",
    "Message without mention" : "Viesti ilman mainintaa",
    "Mention myself" : "Mainitse itsesi",
    "Mention everyone" : "Mainitse kaikki",
    "Select a conversation" : "Valitse keskustelu",
    "The conversation does not exist" : "Tätä keskustelua ei ole olemassa",
    "Join a conversation or start a new one!" : "Liity keskusteluun tai aloita uusi keskustelu!",
    "Join a conversation or start a new one" : "Liity keskusteluun tai aloita uusi",
    "Nextcloud URL" : "Nextcloudin URL-osoite",
    "Nextcloud user" : "Nextcloud-käyttäjä",
    "User password" : "Käyttäjän salasana",
    "Talk conversation" : "Talk-keskustelu",
    "Skip TLS verification" : "Ohita TLS-vahvistus",
    "Matrix server URL" : "Matrix-palvelimen URL-osoite",
    "User" : "Käyttäjä",
    "Matrix channel" : "Matrix-kanava",
    "Mattermost server URL" : "Mattermost-palvelimen URL-osoite",
    "Mattermost user" : "Mattermost-käyttäjä",
    "Team name" : "Tiimin nimi",
    "Channel name" : "Kanavan nimi",
    "Rocket.Chat server URL" : "Rocket.Chat-palvelimen URL-osoite",
    "User name or email address" : "Käyttäjänimi tai sähköpostiosoite",
    "Rocket.Chat channel" : "Rocket.Chat-kanava",
    "Zulip server URL" : "Zulip-palvelimen URL-osoite",
    "Bot user name" : "Botin käyttäjätunnus",
    "Bot API key" : "Botin rajapinta-avain",
    "API token" : "API-poletti",
    "Slack channel" : "Slack-kanava",
    "Channel" : "Kanava",
    "Login" : "Kirjaudu",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "IRC-palvelimen URL-osoite (e.g. chat.freenode.net:6667)",
    "Nickname" : "Nimimerkki",
    "Connection password" : "Yhteyden salasana",
    "IRC channel" : "IRC-kanava",
    "Channel password" : "Kanavan salasana",
    "NickServ nickname" : "NickServ-nimimerkki",
    "NickServ password" : "NickServ-salasana",
    "Use TLS" : "Käytä TLS:ää",
    "Use SASL" : "Käytä SASL:ia",
    "Client ID" : "Asiakkaan tunniste",
    "XMPP/Jabber server URL" : "XMPP-/Jabber-palvelimen URL-osoite",
    "MUC server URL" : "MUC-palvelimen URL-osoite",
    "Media" : "Media",
    "Polls" : "Kyselyt",
    "Voice messages" : "Ääniviestit",
    "Locations" : "Sijainnit",
    "Call recordings" : "Puhelutallenteet",
    "Audio" : "Ääni",
    "Show all media" : "Näytä kaikki media",
    "Show all files" : "Näytä kaikki tiedostot",
    "Show all polls" : "Näytä kaikki kyselyt",
    "Show all voice messages" : "Näytä kaikki ääniviestit",
    "Show all locations" : "Näytä kaikki sijainnit",
    "Show all call recordings" : "Näytä kaikki puhelutallenteet",
    "Show all audio" : "Näytä kaikki ääni",
    "Show all other" : "Näytä kaikki muu",
    "Group" : "Ryhmä",
    "Team" : "Tiimi",
    "You reconnected to the call" : "Yhdistit uudelleen puheluun",
    "{actor} reconnected to the call" : "{actor} yhdisti uudelleen puheluun",
    "You added {user0} and {user1}" : "Lisäsit käyttäjät {user0} ja {user1}",
    "{user0} and {user1} joined the call" : "{user0} ja {user1} liittyivät puheluun",
    "You: {lastMessage}" : "Sinä: {lastMessage}",
    "(edited by you)" : "(muokattu toimestasi)",
    "(edited by a deleted user)" : "(muokattu poistetun käyttäjän toimesta)",
    "Leave this page" : "Poistu tältä sivulta",
    "Join here" : "Liity tähän",
    "Post to a conversation" : "Lähetä keskusteluun",
    "Post to conversation" : "Lähetä keskusteluun",
    "The recording failed. Please contact your administrator." : "Tallennus epäonnistui. Ole yhteydessä ylläpitoon.",
    "Share to a conversation" : "Jaa keskusteluun",
    "Share to conversation" : "Jaa keskusteluun",
    "Search in conversation: {conversation}" : "Etsi keskustelusta: {conversation}",
    "Error while clearing conversation history" : "Virhe keskusteluhistoriaa siivotessa",
    "Error occurred while allowing guests" : "Virhe vieraita salliessa",
    "Conversation password has been saved" : "Keskustelun salasana on tallennettu",
    "Conversation password has been removed" : "Keskustelun salasana on poistettu",
    "Error occurred while saving conversation password" : "Virhe tallentaessa keskustelun salasanaa",
    "Call recording is starting." : "Puhelun tallennus käynnistyy.",
    "Call recording stopped. You will be notified once the recording is available." : "Puhelun tallennus lopetettiin. Saat ilmoituksen, kun tallenne on saatavilla.",
    "Conversation picture set" : "Keskustelun kuva asetettu",
    "Conversation picture deleted" : "Keskustelun kuva poistettu",
    "Could not delete the conversation picture" : "Keskustelun kuvaa ei voitu poistaa",
    "Could not post message: {errorMessage}" : "Ei voitu lähettää viestiä: {errorMessage}",
    "An error occurred while fetching the participants" : "Virhe osallistujia noudettaessa",
    "Invitations sent" : "Kutsut lähetetty",
    "Error occurred when sending invitations" : "Kutsujen lähetyksessä tapahtui virhe",
    "An error occurred while creating breakout rooms" : "Pienryhmätiloja luotaessa tapahtui virhe",
    "{guest} (guest)" : "{guest} (vieras)",
    "Failed to add reaction" : "Reaktion lisääminen epäonnistui",
    "Failed to remove reaction" : "Reaktion poistaminen epäonnistui",
    "Error while uploading file \"{fileName}\"" : "Virhe lähettäessä tiedostoa \"{fileName}\"",
    "Not enough free space to upload file \"{fileName}\"" : "Ei riittävästi tallennustilaa tiedoston \"{fileName}\" lähettämiseksi",
    "You are not allowed to share files" : "Sinulla ei ole oikeutta jakaa tiedostoja",
    "Error while sharing file" : "Virhe tiedostoa jakaessa",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Nextcloud Talk ei tue täysin käyttämääsi selainta. Käytä uusinta versiota Mozilla Firefoxista, Microsoft Edgestä, Google Chromesta, Operasta tai Apple Safarista.",
    "Later today – {timeLocale}" : "Myöhemmin tänään – {timeLocale}",
    "Tomorrow – {timeLocale}" : "Huomenna – {timeLocale}",
    "This weekend – {timeLocale}" : "Tämä viikonloppu – {timeLocale}",
    "Next week – {timeLocale}" : "Ensi viikko – {timeLocale}",
    "Message link copied to clipboard" : "Viestin linkki kopioitu leikepöydälle",
    "Conversation link copied to clipboard" : "Keskustelulinkki kopioitu leikepöydälle",
    "The link could not be copied" : "Linkkiä ei voitu kopioida",
    "Please reload the page." : "Päivitä sivu.",
    "Do not disturb" : "Älä häiritse",
    "Away" : "Poissa",
    "Microphone {number}" : "Mikrofoni {number}",
    "Camera {number}" : "Kamera {number}",
    "Speaker {number}" : "Kaiutin {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Vaikuttaa siltä, että puhut vaikka sinut on mykistetty. Poista mykistys, jotta muut kuulevat sinut",
    "Access to microphone & camera is only possible with HTTPS" : "Kameran ja mikrofonin käyttäminen on mahdollista vain käytettäessä HTTPS-protokollaa",
    "Please move your setup to HTTPS" : "Siirrä asetuksesi HTTPS:n taakse",
    "Access to microphone & camera was denied" : "Yhteys mikrofoniin ja kameraan estettiin",
    "WebRTC is not supported in your browser" : "WebRTC ei ole tuettuna selaimessasi",
    "Please use a different browser like Firefox or Chrome" : "Käytä jotain toista selainta, kuten Firefoxia tai Chromea",
    "Error while accessing microphone & camera" : "Virhe yhdistettäessä mikrofoniin ja kameraan",
    "%s Talk on your mobile devices" : "%s Keskustele mobiililaitteillasi",
    "Join conversations at any time, anywhere, on any device." : "Liity keskusteluihin milloin tahansa, mistä tahansa ja miltä tahansa laitteelta.",
    "Android app" : "Android-sovellus",
    "iOS app" : "iOS-sovellus",
    "__language_name__" : "suomi",
    "Call summary (%s)" : "Puhelun yhteenveto (%s)",
    "Tasks" : "Tehtävät",
    "Notes" : "Muistiinpanot",
    "Reports" : "Raportit",
    "Call summary" : "Puhelun yhteenveto",
    "Call summary - {title}" : "Puhelun yhteenveto - {title}",
    "Talk conversation for event" : "Tapahtuman Talk-keskustelu",
    "Schedule a meeting from your calendar. A Talk conversation needs to be set as location to show up here" : "Sovi tapaaminen kalenterissasi. Talk-keskustelu pitää asettaa sijainniksi, jotta se näkyy tässä",
    "Set reminder for later today" : "Aseta muistutus myöhemmälle ajankohdalle tälle päivälle",
    "Set reminder for tomorrow" : "Aseta muistutus huomiselle",
    "Set reminder for this weekend" : "Aseta muistutus tälle viikonlopulle",
    "Set reminder for next week" : "Aseta muistutus seuraavalle viikolle",
    "Talk recording from {time} ({conversation})" : "Äänitallenne {time} ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Kyselyn tulokset • %n ääni","Kyselyn tulokset • %n ääntä"],
    "Submit vote" : "Lähetä ääni",
    "Your privacy setting has been saved" : "Yksityisyysasetuksesi on tallennettu",
    "Failed to save sounds setting" : "Ääniasetusten tallentaminen epäonnistui",
    "Sounds setting saved" : "Ääniasetukset tallennettu",
    "Always shown if recording consent is required" : "Näytetään aina, jos tarvitaan suostumus äänitykseen",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Liityit keskusteluun toisessa ikkunassa tai toisella laitteella. Tämä ei ole tällä hetkellä tuettua Nextcloud Talkissa, joten tämä istunto suljettiin."
},
"nplurals=2; plural=(n != 1);");
