header.app-sidebar-header.hidden-by-call>div:not(.talk-sidebar-callview){display:none!important}#call-container[data-v-319663c6]{max-height:56.25%;padding-bottom:56.25%;position:relative;overflow:hidden}.call-loading[data-v-319663c6]{background-color:#000000b3;max-height:56.25%;padding-bottom:56.25%}
/*# sourceMappingURL=files-sidebar-call-chunk.chunk.css.map*/