OC.L10N.register(
    "spreed",
    {
    "Talk" : "Prat",
    "Guest" : "Gjest",
    "Administration" : "Administrasjon",
    "System" : "System",
    "File not found" : "Fann ikkje fila",
    "File is too big" : "Fila er for stor",
    "Invalid file provided" : "Ugyldig fil",
    "Invalid image" : "Ugyldig bilete",
    "Unknown filetype" : "Ukjend filtype",
    "Say hi to your friends and colleagues!" : "Sei hei til dine venner og kollegar!",
    "Description" : "Skildring",
    "Open settings" : "Opne instillingar",
    "Default" : "Standard",
    "Messages" : "Meldingar",
    "Other" : "Anna",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Argentina" : "Argentina",
    "Austria" : "Austerrike",
    "Australia" : "Australia",
    "Belgium" : "Belgia",
    "Bulgaria" : "Bulgaria",
    "Bahamas" : "Bahamas",
    "Chile" : "Chile",
    "Germany" : "Tyskland",
    "Denmark" : "Danmark",
    "Estonia" : "Estland",
    "Egypt" : "Egypt",
    "Finland" : "Finland",
    "France" : "Frankrike",
    "Georgia" : "Georgia",
    "Greece" : "Hellas",
    "Indonesia" : "Indonesia",
    "Ireland" : "Irland",
    "Israel" : "Israel",
    "India" : "India",
    "Iceland" : "Island",
    "Jordan" : "Jordan",
    "Japan" : "Japan",
    "Kenya" : "Kenya",
    "Kuwait" : "Kuwait",
    "Lebanon" : "Libanon",
    "Lithuania" : "Litauen",
    "Latvia" : "Latvia",
    "Libya" : "Libya",
    "Mexico" : "Mexico",
    "Nigeria" : "Nigeria",
    "Netherlands" : "Nederland",
    "Norway" : "Noreg",
    "The password is wrong. Try again." : "Passordet er gale. Prøv igjen.",
    "Password" : "Passord",
    "Everyone" : "Alle",
    "Disabled" : "Deaktivert",
    "Name" : "Namn",
    "Enable encryption" : "Aktiver kryptering",
    "Pending" : "Under vegs",
    "Error" : "Feil",
    "Language" : "Språk",
    "Country" : "Land",
    "Status" : "Status",
    "Created at" : "Skapt den",
    "OK" : "OK",
    "Cancel" : "Avbryt",
    "Back" : "Tilbake",
    "Calendar" : "Kalendar",
    "Attendees" : "Deltakarar",
    "Save" : "Lagre",
    "Grid view" : "Rutenett visning",
    "Copy link" : "Kopier lenkje",
    "None" : "Ingen",
    "Favorite" : "Favoritt",
    "Disable" : "Slå av",
    "Enable" : "SLå på",
    "Choose" : "Vel",
    "Personal" : "Personleg",
    "Leave conversation" : "Forlat samtalen",
    "Delete conversation" : "Slett samtale",
    "Password protection" : "Password protection",
    "Set a password" : "Lag eit passord",
    "Edit" : "Endra",
    "More information" : "Meir informasjon",
    "Delete" : "Slett",
    "Notifications" : "Varsel",
    "Important conversation" : "Viktig samtale",
    "Log in" : "Logg inn",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Home" : "Heim",
    "Unread messages" : "Meldingar er ikkje lest",
    "Users" : "Brukarare",
    "Groups" : "Grupper",
    "Upload" : "Last opp",
    "Files" : "Filer",
    "Reply" : "Svare",
    "Reply privately" : "Svar privat",
    "Dismiss" : "Forkast",
    "Message sent" : "Melding sendt",
    "Contact" : "Kontakt",
    "Add participants" : "Legg til deltakarar",
    "Send message" : "Send melding",
    "Record voice message" : "Ta opp lyd melding ",
    "Send" : "Send",
    "Settings" : "Instillingar",
    "Remove group and members" : "Eksterne gruppe og medlemmar",
    "Remove participant" : "Eksterne deltakarar",
    "Demote from moderator" : "Nedrykk frå moderator",
    "Promote to moderator" : "Fremje til moderator",
    "Add users or groups" : "Add users or groups",
    "Participants" : "Deltakarar",
    "Open chat" : "Start lynmelding",
    "Chat" : "Lynmelding",
    "Details" : "Detaljar",
    "Notification settings" : "Varsel innstillingar",
    "Privacy" : "Personvern",
    "Search" : "Search",
    "Join a conversation or start a new one" : "Delta i ein samtale eller start ein ny ein",
    "User" : "Bruker",
    "Login" : "Login",
    "Nickname" : "Kallenamn",
    "Client ID" : "Klient-ID",
    "Group" : "Gruppe",
    "Please reload the page." : "Ver venleg og last sida på nytt.",
    "Away" : "Borte",
    "__language_name__" : "Nynorsk",
    "Tasks" : "Oppgåver"
},
"nplurals=2; plural=(n != 1);");
