(()=>{"use strict";var r={},t={};function e(s){var o=t[s];if(void 0!==o)return o.exports;var u=t[s]={exports:{}};return r[s](u,u.exports,e),u.exports}e.rv=()=>"1.7.11",e.ruid="bundler=rspack@1.7.11"})();
//# sourceMappingURL=talk-icons.js.map?v=6b6472444da4ee5b