OC.L10N.register(
    "spreed",
    {
    "a conversation" : "una conversacion",
    "(Duration %s)" : "(Durada %s)",
    "You attended a call with {user1}" : "Avètz assistit a una sonada amb {user1}",
    "_%n guest_::_%n guests_" : ["%n convidat","%n convidats"],
    "You attended a call with {user1} and {user2}" : "Avètz assistit a una sonada amb {user1} e {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Avètz assistit a una sonada amb {user1}, {user2} e {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Avètz assistit a una sonada amb {user1}, {user2},  {user3} e {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Avètz assistit a una sonada amb {user1}, {user2}, {user3}, {user4} e {user5}",
    "_%n other_::_%n others_" : ["%n autre","%n autres"],
    "{actor} invited you to {call}" : "{actor} vos a convidat a {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Sètz convidat a una <strong>conversacion</strong> o avètz agut una <strong>sonada</strong>",
    "Other activities" : "Autras activitats",
    "Talk" : "Talk",
    "Guest" : "Convidat",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## La benvenguda a Nextcloud Talk!\nDins aquesta conversacion seràs avisats de la foncionalitats novèlas disponiblas dins Nextcloud Talk.",
    "## New in Talk %s" : "## Nòu dins Talk %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge e Safari pòdon ara utilizar la conversacion àudio e vidèo",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Podètz ara notificar totes los participants en publicant « @all » al chat",
    "- You can now mention guests in the chat" : "- Podètz ara mencionar los convidats al chat",
    "- Join the same conversation and call from multiple devices" : "- Participar a la meteissa conversacion e sonada de mantun aparelh estant",
    "- Send voice messages, share your location or contact details" : "- Enviar de messatges vocals, partejar vòstra posicion e detalhs de contactes",
    "Talk updates ✅" : "Mesas a jorn Talk ✅",
    "Reaction deleted by author" : "Reaccion suprimida per son autor",
    "{actor} created the conversation" : "{actor} a creat la conversacion",
    "You created the conversation" : "Avètz creat la conversacion",
    "System created the conversation" : "Lo sistèma creèt la conversacion",
    "An administrator created the conversation" : "Un administrator a creat la conversacion",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} a renomenat la conversacion de « %1$s » a « %2$s »",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Avètz renomenat la conversacion de « %1$s » a « %2$s »",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Un administrator a renomenat la conversacion de « %1$s » a « %2$s »",
    "{actor} set the description" : "{actor} escriguèt la descripcion",
    "You set the description" : "Avètz escricha la descripcion",
    "An administrator set the description" : "Un administrator escriguèt la descripcion",
    "{actor} removed the description" : "{actor} a tirat la descripcion",
    "You removed the description" : "Avètz tirat la descripcion",
    "An administrator removed the description" : "Un administrator a tirat la descripcion",
    "You started a call" : "Avètz començat una sonada",
    "{actor} started a call" : "{actor} a començat una sonada",
    "{actor} joined the call" : "{actor} a rejonh la sonada",
    "You joined the call" : "Avètz rejonch la sonada",
    "{actor} left the call" : "{actor} a quitat la sonada",
    "You left the call" : "Avètz quitat la sonada",
    "{actor} unlocked the conversation" : "{actor} a desverrolhat la conversacion",
    "You unlocked the conversation" : "Avètz desverrolhat la conversacion",
    "An administrator unlocked the conversation" : "Un administrator a desverrolhat la conversacion",
    "{actor} locked the conversation" : "{actor} a clavat la conversacion",
    "You locked the conversation" : "Avètz clavat la conversacion",
    "An administrator locked the conversation" : "Un administrator a clavat la conversacion",
    "{actor} limited the conversation to the current participants" : "{actor} a limitat la conversacion als participants actuals",
    "You limited the conversation to the current participants" : "Avètz limitat la conversacion als participants actuals",
    "An administrator limited the conversation to the current participants" : "Un administrator a limitat la conversacion als participants actuals",
    "{actor} opened the conversation to registered users" : "{actor} dobriguèt la conversacion als utilizaires enregistrats",
    "You opened the conversation to registered users" : "Dobriretz la conversacion als utilizaires enregistrats",
    "An administrator opened the conversation to registered users" : "Un administrator dobriguèt la conversacion als utilizaires enregistrats",
    "The conversation is now open to everyone" : "La conversacion es ara dubèrta a tot lo monde",
    "{actor} opened the conversation to everyone" : "{actor} a dubèrta la conversacion a tot lo monde",
    "You opened the conversation to everyone" : "Avètz dobèrta la conversacion a tot lo monde",
    "{actor} restricted the conversation to moderators" : "{actor} a restrench la conversacion als moderators",
    "You restricted the conversation to moderators" : "Avètz restrench la conversacion als moderators",
    "{actor} allowed guests" : "{actor} autorizèt los convidats",
    "You allowed guests" : "Avètz autorizat los convidats",
    "An administrator allowed guests" : "Un administrator autorizèt los convidats",
    "{actor} disallowed guests" : "{actor} interdiguèt los convidats",
    "You disallowed guests" : "Avètz interdich los convidats",
    "An administrator disallowed guests" : "Un administrator desactivèt los convidats",
    "{actor} set a password" : "{actor} a definit un senhal",
    "You set a password" : "Avètz definit un senhal",
    "An administrator set a password" : "Un administrator a definit un senhal",
    "{actor} removed the password" : "{actor} a tirat lo senhal",
    "You removed the password" : "Avètz tirat lo senhal",
    "An administrator removed the password" : "Un administrator a tirat lo senhal",
    "{actor} added {user}" : "{actor} a apondut {user}",
    "You joined the conversation" : "Rejonhètz la conversacion",
    "{actor} joined the conversation" : "{actor} dintra dins la conversacion",
    "You added {user}" : "Avètz apondut {user}",
    "{actor} added you" : "{actor} vos a apondut",
    "An administrator added you" : "Un administrator vos a apondut",
    "An administrator added {user}" : "Un administrator a apondut {user}",
    "You left the conversation" : "Avètz quitat la conversacion",
    "{actor} left the conversation" : "{actor} a quitat la conversacion",
    "{actor} removed {user}" : "{actor} a levat {user}",
    "You removed {user}" : "Avètz levat {user}",
    "{actor} removed you" : "{actor} vos a levat",
    "An administrator removed you" : "Un administrator vos a levat",
    "An administrator removed {user}" : "Un administrator a tirat {user}",
    "{actor} invited {federated_user}" : "{actor} a invitat {federated_user}",
    "You invited {federated_user}" : "As invitat {federated_user}",
    "An administrator invited {federated_user}" : "Un administrator a invitat {federated_user}",
    "{federated_user} accepted the invitation" : "{federated_user} a acceptat l’invitacion",
    "{actor} removed {federated_user}" : "{actor} a tirat {federated_user}",
    "You removed {federated_user}" : "Avètz tirat {federated_user}",
    "An administrator removed {federated_user}" : "Un administrator a tirat {federated_user}",
    "{federated_user} declined the invitation" : "{federated_user} a refusat l’invitacion",
    "{actor} added group {group}" : "{actor} apondèt lo grop {group}",
    "You added group {group}" : "Avètz apondut lo grop {group}",
    "An administrator added group {group}" : "Un administrator apondèt lo grop {group}",
    "{actor} removed group {group}" : "{actor} levèt lo grop {group}",
    "You removed group {group}" : "Avètz levat lo grop {group}",
    "An administrator removed group {group}" : "Un administrator tirèt lo grop {group}",
    "{actor} added {phone}" : "{actor} a apondut {phone}",
    "You added {phone}" : "Avètz apondut {phone}",
    "{actor} promoted {user} to moderator" : "{actor} faguèt passar {user} moderator",
    "You promoted {user} to moderator" : "Avètz fach passar {user} moderator",
    "{actor} promoted you to moderator" : "{actor} vos faguèt passar moderator",
    "An administrator promoted you to moderator" : "Un administrator vos faguèt passar moderator",
    "An administrator promoted {user} to moderator" : "Un administrator faguèt passar {user} moderator",
    "{actor} demoted {user} from moderator" : "{actor} retrogradèt {user} de l’estat de moderator",
    "You demoted {user} from moderator" : "Avètz retrogradat {user} de l’estat de moderator",
    "{actor} demoted you from moderator" : "{actor} vos retrogradèt de l’estat de moderator",
    "An administrator demoted you from moderator" : "Un administrator vos retrogradèt de l’estat de moderator",
    "An administrator demoted {user} from moderator" : "Un administrator retrogradèt {user} de l’estat de moderator",
    "{actor} shared a file which is no longer available" : "{actor} partegèt un fichièr qu’es pas pus disponible",
    "You shared a file which is no longer available" : "Partegèretz un fichièr qu'es pas pus disponible",
    "The shared location is malformed" : "L’emplaçament partejat es mal format",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} configurèt Matterbridge per sincronizar aquesta conversacion amb d’autras discussions",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Avètz configurat Matterbridge per sincronizar aquesta conversacion amb d’autras discussions",
    "{actor} updated the Matterbridge configuration" : "{actor} actualizèt la configuracion Matterbridge",
    "You updated the Matterbridge configuration" : "Avètz actualizada la configuracion Matterbridge",
    "{actor} removed the Matterbridge configuration" : "{actor} suprimissèt la configuracion Matterbridge",
    "You removed the Matterbridge configuration" : "Avètz suprimida la configuracion Matterbdrige",
    "{actor} started Matterbridge" : "{actor} a lançat Matterbridge",
    "You started Matterbridge" : "Avètz lançat Matterbridge",
    "{actor} stopped Matterbridge" : "{actor} arrestèt Matterbridge",
    "You stopped Matterbridge" : "Avètz arrestat Matterbridge",
    "{actor} deleted a message" : "{actor} a suprimit un messatge",
    "You deleted a message" : "Avètz suprimit un messatge",
    "{actor} deleted a reaction" : "{actor} a suprimit una reaccion",
    "You deleted a reaction" : "Avètz suprimit una reaccion",
    "You disabled message expiration" : "Avètz desactivat l’expiracion dels messatges",
    "{actor} cleared the history of the conversation" : "{actor} escafèt l'istoric de la conversacion",
    "You cleared the history of the conversation" : "Avètz escafat l'istoric de la conversacion",
    "You started the audio recording" : "Avètz lançat l'enregistrament àudio",
    "You stopped the audio recording" : "Avètz arrestat l'enregistrament àudio",
    "The recording failed" : "L'enregistrament a pas foncionat",
    "Someone voted on the poll {poll}" : "Qualqu’un a votat dins lo sondatge {poll}",
    "Message deleted by author" : "Messatge suprimit per son autor",
    "Message deleted by {actor}" : "Messatge suprimit per {actor}",
    "Message deleted by you" : "Messatge suprimit per vos",
    "Deleted user" : "Utilizaire suprimit",
    "Unknown number" : "Numèro desconegut",
    "Administration" : "Administracion",
    "%s (guest)" : "%s (convidat)",
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} acabèt la sonada amb %n convidat (Durada {duration})","{actor} acabèt la sonada amb %n convidats (Durada {duration})"],
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} acabèt la sonada amb {user1} (Durada {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} acabèt la sonada amb {user1} e {user2} (Durada {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} acabèt la sonada amb {user1}, {user2} e {user3} (Durada {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} acabèt la sonada amb {user1}, {user2}, {user3} e {user4} (Durada {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} acabèt la sonada amb {user1}, {user2}, {user3}, {user4} {user5} (Durada {duration})",
    "Message of {user} in {conversation}" : "Messatge de {user} dins {conversation}",
    "Message of {user}" : "Messatge de {user}",
    "Message of a deleted user in {conversation}" : "Messatge d'un utilizaire suprimit dins {conversation}",
    "Talk conversations" : "Conversacions Talk",
    "Talk to %s" : "Parlar a %s",
    "File not found" : "Fichièr pas trobat",
    "File is not shared, or shared but not with the user" : "Fichièr pas partejat, o partejat mas pas a l’utilizaire",
    "No account available to delete." : "Cap de compte pas disponible per la supression.",
    "Poll" : "Sondatge",
    "No image file provided" : "Cap de fichièr imatge provesit",
    "File is too big" : "Fichièr tròp pesuc",
    "Invalid file provided" : "Fichièr provesit invalid",
    "Invalid image" : "Imatge invalid",
    "Unknown filetype" : "filetype desconegut",
    "Talk mentions" : "Mencions Talk",
    "Say hi to your friends and colleagues!" : "Saludatz vòstres amics e collègas !",
    "No unread mentions" : "Cap de mencion pas legida",
    "Call in progress" : "Sonada en cors",
    "You were mentioned" : "Qualqu’un vos a mencionat",
    "Write to conversation" : "Escriure dins la conversacion",
    "Conversation invitation" : "Convit de conversacion",
    "Description" : "Descripcion",
    "Dial-in information" : "Entresenhas de sonada",
    "Meeting ID" : "Identificant reünion",
    "Your PIN" : "Vòstre còdi",
    "Meeting" : "Reünion",
    "Password request: %s" : "Senhal requerit : %s",
    "Private conversation" : "Conversacion privada",
    "Deleted user (%s)" : "Utilizaire suprimit (%s)",
    "Dismiss notification" : "Ignorar la notificacion",
    "Call recording now available" : "L'enregistrament de sonada es ara disponible",
    "Accept" : "Acceptar",
    "Decline" : "Declinar",
    "Reminder" : "Recòrd",
    "Notification" : "Notificacion",
    "{user} reacted with {reaction}" : "{user} a reagit amb {reaction}",
    "{user} reacted with {reaction} in {call}" : "{user} a reagit amb {reaction} dins {call}",
    "{user} in {call}" : "{user} dins {call}",
    "Deleted user in {call}" : "Utilizaire suprimit dins {call}",
    "{guest} (guest) in {call}" : "{guest} (convidat) dins {call}",
    "Guest in {call}" : "Convidat dins {call}",
    "{user} sent you a private message" : "{user} vos a enviat un messatge privat",
    "{user} sent a message in conversation {call}" : "{user} a enviat un messatge dins la conversacion {call}",
    "A deleted user sent a message in conversation {call}" : "Un utilizaire suprimit vos envièt un messatge dins la conversacion {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (convidat) mandèt un messatge dins la conversacion {call}",
    "A guest sent a message in conversation {call}" : "Un convidat a enviat un messatge dins la conversacion {call}",
    "{user} replied to your private message" : "{user} a respondut a vòstre messatge privat",
    "{user} replied to your message in conversation {call}" : "{user} a respondut a vòstre messatge dins la conversacion {call}",
    "A deleted user replied to your message in conversation {call}" : "Un utilizaire suprimit a respondut a vòstre messatge dins la conversacion {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (convidat) respondèt a vòstre messatge dins la conversacion {call}",
    "A guest replied to your message in conversation {call}" : "Un convidat respondèt a vòstre messatge dins la conversacion {call}",
    "{user} reacted with {reaction} to your private message" : "{user} a reagit amb {reaction} a vòstre messatge privat",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} a reagit amb {reaction} a vòstre messatge dins la conversacion {call}",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "Un utilizaire suprimit a reagit amb {reaction} a vòstre messatge dins la conversacion {call}",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (convidat) a reagit amb {reaction} a vòstre messatge dins la conversacion {call}",
    "A guest reacted with {reaction} to your message in conversation {call}" : "Un convidat a reagit amb {reaction} a vòstre messatge dins la conversacion {call}",
    "{user} mentioned you in a private conversation" : "{user} vos mencionèt dins una conversacion privada",
    "{user} mentioned you in conversation {call}" : "{user} vos a mencionat dins la conversacion {call}",
    "A deleted user mentioned you in conversation {call}" : "Un utilizaire suprimit vos a mencionat dins la conversacion {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (convidat) vos a mencionat dins la conversacion {call}",
    "A guest mentioned you in conversation {call}" : "Un convidat vos a mencionat dins la conversacion {call}",
    "View message" : "Veire lo messatge",
    "View chat" : "Veire lo chat",
    "{user} invited you to a group conversation: {call}" : "{user} vos a convidat a un conversacion de grop : {call}",
    "Join call" : "Rejónher la sonada",
    "Answer call" : "Respondre a l’apèl",
    "{user} would like to talk with you" : "{user} volriá vos parlar",
    "Call back" : "Tornar",
    "You missed a call from {user}" : "Avètz mancat una sonada de {user}",
    "A group call has started in {call}" : "Una sonada de grop a començat dins {call}",
    "You missed a group call in {call}" : "Avètz mancat una sonada de grop dins {call}",
    "{email} is requesting the password to access {file}" : "{email} demanda l’accès al fichièr {file}",
    "{email} tried to request the password to access {file}" : "{email} ensagèt de demandar lo senhal per accedir a {file}",
    "Someone is requesting the password to access {file}" : "Qualqu’un demanda lo senhal per accedir a {file}",
    "Someone tried to request the password to access {file}" : "Qualqu’un ensagèt de demandar lo senhal per accedir a {file}",
    "Open settings" : "Dobrir los paramètres",
    "The hosted signaling server is now configured and will be used." : "Lo servidor de senhalament albergat es ara configurat e serà utilizat.",
    "pending" : "pendent",
    "active" : "actiu",
    "expired" : "expirat",
    "blocked" : "blocat",
    "error" : "error",
    "Contact via Talk" : "Contactar via Talk",
    "Open Talk" : "Dobrir la conversacion",
    "Default" : "Defaut",
    "Presentation" : "Presentacion",
    "Conversations" : "Discussions",
    "Messages in current conversation" : "Messatge de la conversacion actuala",
    "{user}" : "{user}",
    "Messages" : "Messatges",
    "{user} in {conversation}" : "{user} dins {conversation}",
    "Messages in other conversations" : "Messatges dins autras conversacions",
    "Invalid emoji character" : "Caractèr d'emoji invalid",
    "Invalid background color" : "Color de rèireplan invalida",
    "Room {number}" : "Sala {number}",
    "Other" : "Autre",
    "Something unexpected happened." : "Quicòm d’inesperat s’es produch.",
    "The URL is invalid." : "L’URL es invalida.",
    "An HTTPS URL is required." : "Una URL HTTPS es requerida.",
    "The email address is invalid." : "L’adreça email es invalida.",
    "The language is invalid." : "La lenga es invalida.",
    "The country is invalid." : "Lo país es invalid.",
    "Too many requests are send from your servers address. Please try again later." : "Tròp de requèstas enviadas de vòstras adreça de servidor. Ensajatz mai tard.",
    "Something unexpected happened. Please try again later." : "Quicòm d’inesperat s’es produch. Volgatz ensajar mai tard.",
    "There is no such account registered." : "Cal de tal compte pas enregistrat.",
    "Too many requests are sent from your servers address. Please try again later." : "Tròp de requèstas enviadas de vòstras adreça de servidor. Ensajatz mai tard.",
    "Andorra" : "Andòrra",
    "United Arab Emirates" : "Emirats Arabis Units",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antigua e Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angòla",
    "Antarctica" : "Antarctica",
    "Argentina" : "Argentina",
    "American Samoa" : "Amèrica, nord",
    "Austria" : "Austria",
    "Australia" : "Austràlia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Illas Åland",
    "Azerbaijan" : "Azerbaitjan",
    "Bosnia and Herzegovina" : "Bòsnia e Ercegovina",
    "Barbados" : "Barbada",
    "Bangladesh" : "Bangladèsh",
    "Belgium" : "Bèlgica",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Barein",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Sant Bartomieu",
    "Bermuda" : "Bermudas",
    "Brunei Darussalam" : "Sultanat de Brunei",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Botan",
    "Bouvet Island" : "Illa Bouvet",
    "Botswana" : "Botswana",
    "Belarus" : "Bielorusia",
    "Belize" : "Belize",
    "Canada" : "Canadà",
    "Cocos (Keeling) Islands" : "Illas Cocos (Keeling)",
    "Central African Republic" : "Centrafrica",
    "Congo" : "Congò",
    "Switzerland" : "Soïssa",
    "Côte d'Ivoire" : "Còsta d'Evòri",
    "Cook Islands" : "Illas Cook",
    "Chile" : "Chile",
    "Cameroon" : "Cameron",
    "China" : "China",
    "Colombia" : "Colombia",
    "Costa Rica" : "Còsta Rica",
    "Cuba" : "Cubà",
    "Cabo Verde" : "Cap Verd",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Illa Cristmas",
    "Cyprus" : "Chipre",
    "Czechia" : "Republica Chèca",
    "Germany" : "Alemanha",
    "Djibouti" : "Jiboti",
    "Denmark" : "Danemarc",
    "Dominica" : "Dominica",
    "Dominican Republic" : "Republica Dominicana",
    "Algeria" : "Algeria",
    "Ecuador" : "Eqüator",
    "Estonia" : "Estònia",
    "Egypt" : "Egipte",
    "Western Sahara" : "Sahara occidental",
    "Eritrea" : "Eritrèa",
    "Spain" : "Espanha",
    "Ethiopia" : "Etiopia",
    "Finland" : "Finlandia",
    "Fiji" : "Fiji",
    "Falkland Islands (Malvinas)" : "Illas Maldivas",
    "Micronesia, Federated States of" : "Micronesia, Estats Federats de",
    "Faroe Islands" : "Illas Feròe",
    "France" : "França",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Reialme Unit de Grand Bretanha e d’Irlanda del Nòrd",
    "Grenada" : "Granada",
    "Georgia" : "Georgia",
    "French Guiana" : "Guiana francesa",
    "Guernsey" : "Alemanya",
    "Ghana" : "Gana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Groenland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinèa",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Guinèa Eqüatoriala",
    "Greece" : "Grèça",
    "South Georgia and the South Sandwich Islands" : "Georgia del Sud e las illas Sandwich del Sud",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinèa-Bissau",
    "Guyana" : "Guianà",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Illas de Heard e McDonald",
    "Honduras" : "Hondures",
    "Croatia" : "Croacia",
    "Haiti" : "Aïtí",
    "Hungary" : "Ongria",
    "Indonesia" : "Indonesia",
    "Ireland" : "Irlanda",
    "Israel" : "Israel",
    "Isle of Man" : "Illa de Man",
    "India" : "Índia",
    "British Indian Ocean Territory" : "Territòris britanics de l'ocean indian",
    "Iraq" : "Iraq",
    "Iran, Islamic Republic of" : "Iran",
    "Iceland" : "Islàndia",
    "Italy" : "Italia",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamaïca",
    "Jordan" : "Jordan",
    "Japan" : "Japon",
    "Kenya" : "Kenia",
    "Kyrgyzstan" : "Kirghizstan",
    "Cambodia" : "Cambòtja",
    "Kiribati" : "Kiribati",
    "Comoros" : "Comòras",
    "Saint Kitts and Nevis" : "Sant Kitts e Nevis",
    "Korea, Democratic People's Republic of" : "Corèa, Republica Populara Democratica de",
    "Korea, Republic of" : "Corea",
    "Kuwait" : "Koweit",
    "Cayman Islands" : "Illas Caiman",
    "Kazakhstan" : "Cazacstan",
    "Lao People's Democratic Republic" : "Laòs",
    "Lebanon" : "Lebanon",
    "Saint Lucia" : "St. Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Libèria",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Lituània",
    "Luxembourg" : "Luxemborg",
    "Latvia" : "Letònia",
    "Libya" : "Libia",
    "Morocco" : "Marròc",
    "Monaco" : "Monegue",
    "Moldova, Republic of" : "Moldàvia",
    "Montenegro" : "Montenegro",
    "Saint Martin (French part)" : "Sant Martin (francés)",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Illas Marshall",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Kanu",
    "Northern Mariana Islands" : "Illas Marianas del Nòrd",
    "Martinique" : "Martinica",
    "Mauritania" : "Mauritània",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Maurici",
    "Maldives" : "Maldivas",
    "Malawi" : "Malawi",
    "Mexico" : "Mexic",
    "Malaysia" : "Malàisia",
    "Mozambique" : "Moçambic",
    "Namibia" : "Namibia",
    "New Caledonia" : "Nòva Caledònia",
    "Niger" : "Nigèr",
    "Norfolk Island" : "Norfòlk, Illa",
    "Nigeria" : "Nigèria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Holanda",
    "Norway" : "Norvègia",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Novèla Zelanda",
    "Oman" : "Oman",
    "Panama" : "Panamà",
    "Peru" : "Peru",
    "French Polynesia" : "Polinesia francesa",
    "Papua New Guinea" : "Papoa-Nòva Guinèa",
    "Philippines" : "Filipinas",
    "Pakistan" : "Paquistan",
    "Poland" : "Polonha",
    "Saint Pierre and Miquelon" : "Sant Pèire e Miquelon",
    "Pitcairn" : "Illas Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Palestine, State of" : "Estat de Palestina",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguai",
    "Qatar" : "Qatar",
    "Réunion" : "La Reünion",
    "Romania" : "Romania",
    "Serbia" : "Serbia",
    "Russian Federation" : "Federacion russa",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Arabia Saudita",
    "Solomon Islands" : "Illas Salomon",
    "Seychelles" : "Seichèlas",
    "Sudan" : "Sodan",
    "Sweden" : "Suècia",
    "Singapore" : "Singapor",
    "Slovenia" : "Eslovenia",
    "Svalbard and Jan Mayen" : "Svalbard e illa Jan Mayen",
    "Slovakia" : "Eslòvac",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "Sant Marin",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Surinam",
    "South Sudan" : "Sodan del Sud",
    "Sao Tome and Principe" : "São Tomé e Príncipe",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "Sant Martin (part neerlandesa)",
    "Syrian Arab Republic" : "Siria",
    "Turks and Caicos Islands" : "Illas Turcas e Caïcas",
    "Chad" : "Chad",
    "French Southern Territories" : "Tèrras australas francesas",
    "Togo" : "Tògo",
    "Thailand" : "Tailandia",
    "Tajikistan" : "Tatgiquistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turcmenistan",
    "Tunisia" : "Tunisia",
    "Tonga" : "Tònga",
    "Turkey" : "Turquia",
    "Trinidad and Tobago" : "Trinitat e Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "Taiwan, Província de China",
    "Tanzania, United Republic of" : "Tanzania",
    "Ukraine" : "Ucraïna",
    "Uganda" : "Oganda",
    "United States Minor Outlying Islands" : "Illas menoras aluenhadas dels Estats Units d'America",
    "United States of America" : "Estats Units d'America",
    "Uruguay" : "Uruguai",
    "Uzbekistan" : "Ozbequistan",
    "Holy See" : "Santa Ses",
    "Saint Vincent and the Grenadines" : "Sant Vincenç e las Grenadinas",
    "Venezuela, Bolivarian Republic of" : "República Bolivariana de Venezuela",
    "Virgin Islands, British" : "Illas Verges Britanicas",
    "Virgin Islands, U.S." : "Virgin Islands, U.S.",
    "Viet Nam" : "Vinyes",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis e Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Iemèn",
    "Mayotte" : "Maiòta",
    "South Africa" : "Sudafrica",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Error: Cannot connect to server" : "Error : connexion impossibla al servidor",
    "Error: Server did not respond with proper JSON" : "Error: lo servidor a pas respondut amb un JSON corrèct",
    "Could not get version" : "Obtencion impossibla de la version",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Error  : execucion de la version {version}, lo servidor requerís una actualizacion per èsser compatible amb aquesta version de Talk",
    "Error: Server responded with: {error}" : "Error : lo servidor a respondut : {error}",
    "Error: Unknown error occurred" : "Error : una error desconeguda s'es produsida",
    "SIP configuration" : "Configuracion SIP",
    "Invalid date, date format must be YYYY-MM-DD" : "Invalida data, lo format de data deu èsser YYYY-MM-DD",
    "Conversation not found" : "Conversacion pas trobada",
    "Chat, video & audio-conferencing using WebRTC" : "Messatjariá, conferéncias vidèo e àudio amb WebRTC",
    "Leave call" : "Quitar la sonada",
    "Stay in call" : "Demorar en linha",
    "Discuss this file" : "Discutir d’aqueste fichièr",
    "Share this file with others to discuss it" : "Partejar aqueste fichièr amb d’autres per ne discutir",
    "Share this file" : "Partejar aqueste fichièr",
    "Join conversation" : "Rejónher la conversacion",
    "The password is wrong. Try again." : "Lo senhal es incorrècte. Ensajatz tornamai.",
    "Password" : "Senhal",
    "Submit" : "Transmetre",
    "Error requesting the password." : "Error en demandant lo senhal.",
    "Request password" : "Demandar senhal",
    "This conversation has ended" : "La conversacion es acabada",
    "Close Talk sidebar" : "Tampar la barra laterala de Talk",
    "Open Talk sidebar" : "Dobrir la barra laterala de Talk",
    "Everyone" : "Tot lo monde",
    "Users and moderators" : "Utilizaires e moderators",
    "Moderators only" : "Moderators solament",
    "Save changes" : "Salvar los cambiaments",
    "Saving …" : "Enregistrament…",
    "Saved!" : "Enregistrat",
    "Limit to groups" : "Limitar als grops",
    "Guests can still join public conversations." : "Los convidats pòdon encara rejónher las conversacions publicas.",
    "Limit using Talk" : "Limits d’utilizacion de Talk",
    "Limit creating a public and group conversation" : "Limitar la creacion de grops e publicas de conversacions",
    "Limit creating conversations" : "Limitar la creacion de conversacions",
    "Limit starting a call" : "Limitar l’aviada de sonada",
    "Enabled" : "Activada",
    "Disabled" : "Desactivat",
    "Name" : "Nom",
    "Beta" : "Bèta",
    "Permissions" : "Autorizacions",
    "All messages" : "Totes los messatges",
    "@-mentions only" : "@-mencions sonque",
    "Off" : "Atudat",
    "General settings" : "Paramètres generals",
    "Default notification settings" : "Paramètres de notificacion per defaut",
    "Default group notification" : "Notificacion de grop per defaut",
    "Integration into other apps" : "Integracion dins d’autras aplicacions",
    "Allow conversations on files" : "Permetre las conversacions suls fichièrs",
    "Allow conversations on public shares for files" : "Permetre las conversacions suls partiment de fichièrs",
    "Enable encryption" : "Activar lo chiframent",
    "Pending" : "En espèra",
    "Error" : "Error",
    "Blocked" : "Blocat",
    "Active" : "Activa",
    "Expired" : "Expirat",
    "Never" : "Jamai",
    "URL of this Nextcloud instance" : "URL d’aquesta instància Nextcloud",
    "Email of the user" : "Email de l’utilizaire",
    "Language" : "Lenga",
    "Country" : "País",
    "Status" : "Estatut",
    "Created at" : "Creat lo",
    "Expires at" : "Expira lo",
    "Limits" : "Limits",
    "Yes" : "Òc",
    "No" : "Non",
    "_%n user_::_%n users_" : ["%n utilizaire","%n utilizaires"],
    "Installed version: {version}" : "Version installada : {version}",
    "Downloading …" : "Telecargament…",
    "Install Talk Matterbridge" : "Installar Talk Matterbridge",
    "Matterbridge integration" : "Integracion Matterbridge",
    "Enable Matterbridge integration" : "Activar l’integracion Matterbridge",
    "Status: Checking connection" : "Estat : verificacion de la connexion",
    "OK: Running version: {version}" : "OK : execucion de la version : {version}",
    "Validate SSL certificate" : "Validar lo certificat SSL",
    "Delete this server" : "Suprimir aqueste servidor",
    "Test this server" : "Ensajar aqueste servidor",
    "Shared secret" : "Secret partejat",
    "Recording consent" : "Consentiment d’enregistrament",
    "Enable SIP configuration" : "Activar la configuracion SIP",
    "Phone number (Country)" : "Numèro de telefòn (País)",
    "STUN server URL" : "URL servidor STUN",
    "The server address is invalid" : "L'adreça del servidor es invalida",
    "STUN servers" : "Servidors STUN",
    "{schema} scheme must be used with a domain" : "l’esquèma {schema} deu èsser utilizat amb un domeni",
    "{option1} and {option2}" : "{option1} e {option2}",
    "{option} only" : "{option} sonque",
    "TURN server schemes" : "Esquèmas servidor TURN",
    "TURN server URL" : "URL servidor TURN",
    "TURN server secret" : "Secrèt servidor TURN",
    "TURN server protocols" : "Protocòls servidor TURN",
    "TURN servers" : "Servidor TURN",
    "Failed" : "Fracàs",
    "OK" : "D’acòrdi",
    "Checking …" : "Verificacion…",
    "Web server setup checks" : "Verificacions de configuracion del servidor Web",
    "Confirm" : "Confirmar",
    "Reset" : "Reïnicializar",
    "Cancel" : "Anullar",
    "Back" : "Retorn",
    "Add participant \"{user}\"" : "Apondre participant « {user} »",
    "Loading …" : "Cargament…",
    "From" : "De",
    "Calendar" : "Calendièr",
    "Attendees" : "Convidats",
    "Save" : "Salvar",
    "Search participants" : "Cercar participants",
    "No results" : "Pas cap de resultat",
    "Raise hand" : "Levar la man",
    "Raise hand (R)" : "Levar la man (R)",
    "Lower hand" : "Baissar la man",
    "Lower hand (R)" : "Baissar la man (R)",
    "Exit full screen (F)" : "Sortir de l'ecran complèt (F)",
    "Full screen (F)" : "Ecran complèt (F)",
    "Speaker view" : "Vista parlaire",
    "Grid view" : "Vista en grasilha",
    "This conversation is read-only" : "Aquesta conversacion es en lectura sola",
    "Reload" : "Recargar",
    "{nickName} raised their hand." : "{nickName} a levat la man.",
    "A participant raised their hand." : "Un participant a levat la man.",
    "Previous page of videos" : "Pagina de vidèos precedenta",
    "Next page of videos" : "Pagina de vidèos seguenta",
    "Connecting …" : "Connexion…",
    "Calling …" : "Sonada...",
    "Waiting for {user} to join the call" : "En espèra de {user} dins la sonada",
    "Waiting for others to join the call …" : "En espèra que d’autres arriben…",
    "You can invite others in the participant tab of the sidebar" : "Podètz convidar d’autre monde amb l’onglet dels participants de la barra laterala",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Podètz convidar d’autre monde amb l’onglet dels participants de la barra laterala o partejar aqueste ligam per los convidar !",
    "Share this link to invite others!" : "Partejatz aqueste ligam per convidar mai de monde !",
    "Copy link" : "Copiar lo ligam",
    "You are not allowed to enable audio" : "Avètz pas l'autorizacion per activar l’àudio",
    "No audio. Click to select device" : "Cap d'àudio. Clicatz per seleccionar un periferic",
    "Mute audio" : "Copar lo son",
    "Mute audio (M)" : "Copar lo son (M)",
    "Unmute audio" : "Restablir lo son",
    "Unmute audio (M)" : "Restablir lo son (M)",
    "None" : "Pas cap",
    "Access to camera was denied" : "L’accès a la camèra es estat refusat",
    "Error while accessing camera: It is likely in use by another program" : "Error d’accès a la camèra : poiriá arribar qu’un autre programa l’utilize",
    "Error while accessing camera" : "Error pendent l’accès a la camèra",
    "You have been muted by a moderator" : "Un moderator vos a amudit",
    "You are not allowed to enable video" : "Avètz pas l'autorizacion per activar la vidèo",
    "No video. Click to select device" : "Cap de vièoa. Clicatz per seleccionar un periferic",
    "Disable video" : "Desactivar la vidèo",
    "Disable video (V)" : "Desactivar la vidèo (V)",
    "Enable video" : "Activar la vidèo",
    "Enable video (V)" : "Activar la vidèo (V)",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Activar la vidèo (V) - La connexion serà interrompuda brèvament pendent l’activacion de la vidèo pel primièr còp",
    "Show presenter" : "Mostrar lo presentator",
    "You" : "Vos",
    "Mute" : "Mut",
    "Show screen" : "Far veire l’ecran",
    "Stop following" : "Quitar de seguir",
    "Connection could not be established …" : "Establiment impossible de la connexion…",
    "Connection was lost and could not be re-established …" : "Connexion perduda e restabliment impossibla…",
    "Connection could not be established. Trying again …" : "Establiment impossible… Novèl ensag…",
    "Connection lost. Trying to reconnect …" : "Connexion perduda. Ensag de reconnexion…",
    "Connection problems …" : "Problèmas de connexion…",
    "Collapse" : "Replegar",
    "You need to be logged in to upload files" : "Devètz èsser autentificat per enviar de fichièrs",
    "Drop your files to upload" : "Depausatz los fichièrs d’enviar",
    "Conversation messages" : "Messatges de conversacion",
    "Scroll to bottom" : "Defilar enbàs",
    "Post message" : "Publicar messatge",
    "Favorite" : "Favorit",
    "Date:" : "Data :",
    "Hide details" : "Amagar detalhs",
    "Show details" : "Mostrar detalhs",
    "Error while updating conversation description" : "Error pendent l’actualizacion de la descripcion de la conversacion",
    "Edit conversation name" : "Modificar lo nom de la conversacion",
    "Edit conversation description" : "Editar la descripcion de la conversacion",
    "Enter a description for this conversation" : "Picatz una descripcion per aquesta conversacion",
    "Picture" : "Imatge",
    "Disable" : "Desactivar",
    "Enable" : "Activar",
    "Choose your conversation picture" : "Causissètz un imatge de conversacion",
    "Choose" : "Causir",
    "Set picture" : "Definir l'imatge",
    "Default permissions modified for {conversationName}" : "Permissions per defaut modificadas per {conversationName}",
    "Could not modify default permissions for {conversationName}" : "Las permissions per defaut se podiá pas modificar {conversationName}",
    "All permissions" : "Totas las permissions",
    "Restricted" : "Restrencha",
    "Advanced permissions" : "Permissions avançadas",
    "Edit permissions" : "Modificar las autorizacions",
    "Conversation settings" : "Paramètres de conversacion",
    "Personal" : "Personal",
    "Matterbridge" : "Matterbridge",
    "Danger zone" : "Zòna perilhosa",
    "Leave conversation" : "Quitar la conversacion",
    "Delete conversation" : "Suprimir la conversacion",
    "Do you really want to delete \"{displayName}\"?" : "Volètz vertadièrament suprimir « {displayName} » ?",
    "Error while deleting conversation" : "Error pendent la supression de la conversacion",
    "Delete all chat messages" : "Suprimir totes los messatges del chat",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Volètz vertadièrament suprimir totes los messatges dins « {displayName} » ?",
    "Error while clearing chat history" : "Error pendent l’escafament de l’istoric del chat",
    "Be careful, these actions cannot be undone." : "Fasètz atencion, aquelas accions pòdon pas èsser anulladas.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Un còp quitada, per tornar a un conversacion tampada, cal un convit. Una conversacion dubèrta es totjorn accessibla.",
    "Permanently delete this conversation." : "Suprimir permanent aquesta conversacion",
    "Delete chat messages" : "Suprimir los messatges del chat",
    "Permanently delete all the messages in this conversation." : "Suprimir per totjorn totes los messatges d’aquesta conversacion.",
    "_%n hour_::_%n hours_" : ["%n ora","%n oras"],
    "_%n day_::_%n days_" : ["%n jorn","%n jorns"],
    "_%n week_::_%n weeks_" : ["%n setmana","%n setmanas"],
    "Guest access" : "Accès convidat",
    "Password protection" : "Protegir via senhal",
    "Set a password" : "Definir lo senhal",
    "Enter new password" : "Picar un senhal novèl",
    "Save password" : "Enregistrar lo senhal",
    "Resend invitations" : "Tornar enviar las invitacions",
    "Error occurred when opening or limiting the conversation" : "Error en dobrissent o limitant la conversacion",
    "Open conversation" : "Dobrir la conversacion",
    "Start time has been updated" : "L'ora de debuta es estada actualizada",
    "Error occurred while updating start time" : "Error pendent la mesa a jorn de l’ora de debuta",
    "Meeting start time" : "Ora de debuta de la conferéncia",
    "Start time (optional)" : "Ora de debuta (opcional)",
    "Error occurred when locking the conversation" : "Error pendent lo verrolhatge de la conversacion",
    "Error occurred when unlocking the conversation" : "Error pendent lo desverrolhatge de la conversacion",
    "Lock conversation" : "Verrolhar la conversacion",
    "This will also terminate the ongoing call." : "Aquò acabarà tanben la sonada en cors.",
    "Edit" : "Modificar",
    "More information" : "Mai d’informacions",
    "Delete" : "Suprimir",
    "unknown state" : "estat desconegut",
    "running" : "en cors d'execucion",
    "not running" : "pas en execucion",
    "Bridge saved" : "Pont enregistrat",
    "More info on Matterbridge" : "Mai d’info sus Matterbridge",
    "Enable bridge" : "Activar lo pont",
    "Show Matterbridge log" : "Veire los jornals de Matterbridge",
    "Notifications" : "Notificacions",
    "Notify about calls in this conversation" : "Notificar las sonadas d’aquesta conversacion",
    "Recording Consent" : "Consentiment d'enregistrament",
    "Join" : "Rejónher",
    "Error while creating the conversation" : "Error pendent la creacion de la conversacion",
    "Create a new conversation" : "Crear una conversacion novèla",
    "Unread mentions" : "Mencions pas legidas",
    "Create conversation" : "Crear conversacion",
    "Enter your name" : "Picatz vòstre nom",
    "Log in" : "Connexion",
    "Creating the conversation …" : "Creacion de la conversacion...",
    "Mark as read" : "Marcar coma legit",
    "Mark as unread" : "Marcar coma pas legit",
    "Remove from favorites" : "Tirar dels favorits",
    "Add to favorites" : "Apondre als favorits",
    "Conversation actions" : "Accions de conversacion",
    "Alphabetically" : "Alfabeticament",
    "No matches found" : "Cap de correspondéncia pas trobada",
    "No conversations found" : "Cap de conversacion pas trobada",
    "You have no unread messages." : "Avètz un messatge pas legit.",
    "An error occurred while performing the search" : "Una error s'es producha en realizant la recèrca",
    "Conversation list" : "Lista de conversacion",
    "Unread messages" : "Messatges pas legits",
    "Clear filters" : "Escafar los filtres",
    "App settings" : "Paramètres d’aplicacion",
    "Users" : "Utilizaires",
    "Groups" : "Gropes",
    "Other sources" : "Autras fonts",
    "Open conversations" : "Dobrir las conversacions",
    "No search results" : "pas cap de resultats de recèrca",
    "Users and groups" : "Utilizaires e grops",
    "The meeting will start soon" : "La conferéncia començarà lèu",
    "This meeting is scheduled for {startTime}" : "La conferéncia es planificada per {startTime}",
    "You are currently waiting in the lobby" : "Sètz a esperar dins la sala d’espèra",
    "Select microphone" : "Causir microfòn",
    "No microphone available" : "Cap de microfòn pas disponible",
    "Select camera" : "Causir una camèra",
    "No camera available" : "Cap de camèra pas disponibla",
    "Devices" : "Periferics",
    "Backgrounds" : "Rèireplans",
    "No audio" : "Cap d’àudio",
    "No camera" : "Cap de camèra",
    "Calls are not supported in your browser" : "Vòstre navegador pren pas encarga las sonadas",
    "Access to microphone is only possible with HTTPS" : "L’accès al microfòn es sonque possibla amb HTTPS",
    "Access to microphone was denied" : "L’accès al microfòn es estat refusat",
    "Error while accessing microphone" : "Error pendent l’accès al microfòn",
    "Access to camera is only possible with HTTPS" : "L’accès a la camèra es sonque possibla amb HTTPS",
    "Invalid path selected" : "Camin seleccionat invalid",
    "Upload" : "Cargament",
    "Files" : "Fichièrs",
    "24 hours" : "24 oras",
    "7 days" : "7 jorns",
    "Add a reaction to this message" : "Apondre una reaccion a aqueste messatge",
    "Reply" : "Respondre",
    "More actions" : "Mai d’accions",
    "Reply privately" : "Respondre en privat",
    "Copy message link" : "Copiar ligam messatge",
    "Go to file" : "Anar al fichièr",
    "Forward message" : "Transferir lo messatge",
    "Translate" : "Tradurre",
    "Close reactions menu" : "Tampar lo menú de reaccions",
    "React with {emoji}" : "Reagir amb {emoji}",
    "React with another emoji" : "Reagir amb un autre emoji",
    "Choose a conversation to forward the selected message." : "Causir una conversacion destinària del messatge seleccionat.",
    "Error while forwarding message" : "Error en transferissent lo messatge",
    "The message has been forwarded to {selectedConversationName}" : "Lo messatge es estat transferit a {selectedConversationName}",
    "Dismiss" : "Regetar",
    "Go to conversation" : "Anar a la conversacion",
    "Translate message" : "Traduire lo messatge",
    "Translating" : "Traduccion",
    "Message read by everyone who shares their reading status" : "Messatge legit per tot lo monde que partejan lo estatut de lectura",
    "Message sent" : "Messatge mandat",
    "Deleting message" : "Supression del messatge",
    "Message deleted successfully" : "Messatge corrèctament suprimit",
    "Message could not be deleted because it is too old" : "Lo messatge a pas pogut èsser suprimit perque es tròp ancian",
    "Only normal chat messages can be deleted" : "Sonque los messatges de chat normal pòdon èsser suprimits",
    "An error occurred while deleting the message" : "Error pendent la supression del messatge",
    "Your browser does not support playing audio files" : "Vòstre navegador pren pas en carga la lectura dels fichièrs àudio",
    "Contact" : "Contacte",
    "{stack} in {board}" : "{stack} dins {board}",
    "Remove {fileName}" : "Suprimir {fileName}",
    "Open this location in OpenStreetMap" : "Dobrir aquesta posicion dins OpenStreetMap",
    "Sending message" : "Mandadís del messatge",
    "Failed to send the message. Click to try again" : "Mandadís del messatge impossible. Clicatz per tornar ensajar",
    "Not enough free space to upload file" : "Pas pro d’espaci liure per enviar lo fichièr",
    "You cannot send messages to this conversation at the moment" : "Podètz pas enviar de messatges a aquesta conversacion pel moment",
    "Open poll" : "Dobrir lo sondatge",
    "See results" : "Veire los resultats",
    "No messages" : "Cap de messatge",
    "Cancel search" : "Anullar la recèrca",
    "Add a phone number" : "Apondre un numèro de telefòn",
    "Create a new group conversation" : "Crear una conversacion de grop novèla",
    "Add participants" : "Apondre participants",
    "Conversation visibility" : "Visibilitat de la conversacion",
    "Allow guests to join via link" : "Permetre als convidats de rejónher via ligam",
    "Enter password" : "Picar lo senhal",
    "This conversation has been locked" : "Aquesta conversacion foguèt clavada",
    "Joining conversation …" : "Dintra dins la conversacion…",
    "Send message" : "Enviar un messatge",
    "File to share" : "Fichièr de partejar",
    "Add emoji" : "Apondre emoji",
    "Cancel editing" : "Anullar la modificacion",
    "Share from Files" : "Partejar a partir dels Fichièrs",
    "Share files to the conversation" : "Partejar de fichièrs dins la conversacion",
    "Record voice message" : "Enregistrar messatge vocal",
    "End recording and send" : "Acabar àudio e enviar",
    "Dismiss recording" : "Anullar l’enregistrament",
    "Access to the microphone was denied" : "L’accès al microfòn es estat refusat",
    "Microphone either not available or disabled in settings" : "Microfòn siá indisponible o desactivat dins los paramètres",
    "Error while recording audio" : "Error en enregistrant l’àudio",
    "New file" : "Fichièr novèl",
    "Create file" : "Crear un fichièr",
    "Someone is typing …" : "Qualqu’un pica...",
    "{user1} is typing …" : "{user1} pica…",
    "{user1} and {user2} are typing …" : "{user1} e {user2} pican…",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} e {user3} pican…",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} e %n autre pican…","{user1}, {user2}, {user3} e %n autres pican…"],
    "Add more files" : "Apondre mai de fichièrs",
    "Send" : "Mandar",
    "In this conversation <strong>{user}</strong> can:" : "Dins aquesta conversacion <strong>{user}</strong> pòt :",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Modificar las permissions per defaut dels participants dins <strong>{conversationName}</strong>",
    "Start a call" : "Començar una sonada",
    "Skip the lobby" : "Passar la sala d’espèra",
    "Enable the microphone" : "Activar lo microfòn",
    "Enable the camera" : "Activar la camèra",
    "Share the screen" : "Partejar l’ecran",
    "Update permissions" : "Actualizar las autorizacions",
    "Updating permissions" : "Actualizacion de las permissions",
    "Create poll" : "Crear un sondatge",
    "Question" : "Question",
    "Ask a question" : "Pausar una question",
    "Answers" : "Responsas",
    "Answer {option}" : "Responsa {option}",
    "Delete poll option" : "Suprimir l’opcion de sondatge",
    "Add answer" : "Apondre responsa",
    "Settings" : "Paramètres",
    "Multiple answers" : "Multi responsas",
    "End poll" : "Terminar lo sondatge",
    "Change your vote" : "Cambiar lo vòt",
    "Stop session" : "Arrestar la session",
    "Disable lobby" : "Desactivar la sala d’espèra",
    "Settings for participant \"{user}\"" : "Paramètres pel participant « {user} »",
    "Participant \"{user}\"" : "Participant « {user} »",
    "moderator" : "moderator",
    "bot" : "robòt",
    "guest" : "convidat",
    "Raised their hand" : "Levèt la man",
    "Joined with video" : "Rejonhèt amb vidèo",
    "Joined via phone" : "Rejonhèt via telefòn",
    "Joined with audio" : "Rejonhèt amb l’àudio",
    "Remove group and members" : "Levar de grops e membres",
    "Remove participant" : "Tirar participant",
    "Permissions granted to {displayName}" : "Autorizacions acordadas a {displayName}",
    "Permissions removed for {displayName}" : "Permissions suprimidas per {displayName}",
    "Permissions set to default for {displayName}" : "Permissions definidas a defaut per {displayName}",
    "Resend invitation" : "Renviar invitacion",
    "Reset custom permissions" : "Reïnicializar las permissions personalizadas",
    "Remove all permissions" : "Suprimir totas las permissions",
    "Remove" : "Suprimir",
    "Permissions modified for {displayName}" : "Permissions modificadas per {displayName}",
    "Add users or groups" : "Add users or groups",
    "Add users" : "Apondre utilizaires",
    "Add groups" : "Apondre grops",
    "Add other sources" : "Apondre d'autras fonts",
    "Add emails" : "Apondre emails",
    "Integrations" : "Integracions",
    "Add federated users" : "Apondre d’utilizaires federats",
    "Searching …" : "Recèrca…",
    "Search for more users" : "Cercar mai d’utilizaires",
    "Search or add participants" : "Cercar o apondre participants",
    "An error occurred while adding the participants" : "Una error s’es producha en ajustant los participants",
    "Participants" : "Participants",
    "Participants ({count})" : "Participants ({count})",
    "You have new unread messages in the chat." : "Avètz un messatge pas legit al chat.",
    "You have been mentioned in the chat." : "Qualqu’un vos a mencionat al chat.",
    "Chat" : "Messatjariá",
    "Details" : "Detalhs",
    "Shared items" : "Elements partejats",
    "Load more results" : "Cargar mai de resultats",
    "Projects" : "Projèctes",
    "{actor}: {lastMessage}" : "{actor} : {lastMessage}",
    "Link to a conversation" : "Ligam cap a la conversacion",
    "Search conversations or users" : "Cercar de conversacions o utilizaires",
    "Select conversation" : "Seleccionar una conversacion",
    "Number length is not valid" : "La longor del numèro de telefòn es invalida",
    "Region code is not valid" : "Lo còdi de region es invalida",
    "Number length is too short" : "La longor del numèro es tròp corta",
    "Number length is too long" : "La longor del numèro es tròp longa",
    "Number is not valid" : "Lo numèro es pas valid",
    "Phone numbers" : "Numèros de telefòn",
    "Display name: {name}" : "Nom d’afichatge : {name}",
    "Save name" : "Enregistrar lo nom",
    "Error while saving sounds setting" : "Error en enregistrant lo paramètre de son",
    "Play sounds when participants join or leave a call" : "Emetre sons quand los participants rejonhon o quitan una sonada",
    "Notification settings" : "Paramètres de notificacions",
    "Default language" : "Lenga per defaut",
    "Select location for attachments" : "Causir un emplaçament per las pèças juntas",
    "Error while setting attachment folder" : "Error pendent la definicion del dossièr de pèça junta",
    "Error while setting read status privacy" : "Error lor de definicion de la confidencialitat de l'estatut",
    "Privacy" : "Confidencialitat",
    "Attachments folder" : "Dossièr de pèças-juntas",
    "Toggle full screen" : "Alternar ecran complèt",
    "Search" : "Search",
    "Shortcuts while in a call" : "Acorchis pendent una sonada",
    "Camera on and off" : "Vidèo activada/desactivada",
    "Microphone on and off" : "Microfòn activat/desactivat",
    "Raise or lower hand" : "Levar o baissar la man",
    "Push to talk or push to mute" : "Tocar per parlar o tocar per copar lo son",
    "Start call silently" : "Començar la sonada en silenci",
    "Start call" : "Començar sonada",
    "End call" : "Acabar la sonada",
    "You will be able to join the call only after a moderator starts it." : "Poiretz sonque participar a la sonada un còp qu'un moderator l'aja començada.",
    "End call for everyone" : "Acabar la sonada per totes",
    "Starting the recording" : "L'enregistrament comença",
    "Recording" : "Enregistrament",
    "Stop recording" : "Arrestar l'enregistrament",
    "Send a reaction" : "Enviar una reaccion",
    "React with {reaction}" : "Reagir amb {reaction}",
    "You are not allowed to enable screensharing" : "Avètz pas l'autorizacion per activar lo partiment d’ecran",
    "No screensharing" : "Cap de partiment d’ecran",
    "Screensharing options" : "Opcion de partiment d’ecran",
    "Enable screensharing" : "Activar lo partiment d’ecran",
    "Bad sent video and screen quality." : "Marrida vidèo enviada e qualitat d’ecran.",
    "Bad sent screen quality." : "Marrida qualitat d’ecran enviada.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vejan pas vòstre ecran. Per melhorar la situacion ensajatz de desactivar lo rèireplan o la vidèo pendent un partiment d’ecran.",
    "Disable background blur" : "Desactivar lo rèireplan trebol",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vejan pas vòstre ecran. Per melhorar la situacion ensajatz de desactivar la vidèo pendent un partiment d’ecran.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vejan pas vòstre ecran.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos vejan pas.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos vejan pas. Per melhorar la situacion ensajatz de desactivar lo rèireplan o la vidèo pendent un partiment d’ecran.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos comprengan o vejan pas. Per melhorar la situacion ensajatz de desactivar la vidèo pendent un partiment d’ecran.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos comprengan o vejan pas vòstre ecran. Per melhorar la situacion ensajatz de desactivar lo partiment d’ecran.",
    "Disable screenshare" : "Desactivar lo partiment d’ecran",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos vejan pas. Per melhorar la situacion ensajatz de desactivar lo rèireplan o la vidèo.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos comprengan o vejan pas. Per melhorar la situacion ensajatz de desactivar la vidèo.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos comprengan o vejan pas.",
    "Screen sharing is not supported by your browser." : "Vòstre navegador pren pas en carga lo partiment d’ecran.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Lo partiment d’ecran requerís que la pagina siá cargada via HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "Lo partiment d’ecran requerís un cargament via HTTPS.",
    "An error occurred while starting screensharing." : "S’es producha una error en aviant lo partiment d’ecran.",
    "Show your screen" : "Partejar l’ecran",
    "Stop screensharing" : "Arrestar partiment d’ecran",
    "Mute others" : "Copar lo son dels autres",
    "Start recording" : "Lançar l'enregistrament",
    "Select a region" : "Seleccionatz una region",
    "Search …" : "Recercar...",
    "Message without mention" : "Messatge sens mencion",
    "Mention myself" : "Me mencionar",
    "The conversation does not exist" : "La conversacion existís pas",
    "Join a conversation or start a new one!" : "Rejonhètz una conversacion o creatz-ne una !",
    "Duplicate session" : "Duplicar la session",
    "Join a conversation or start a new one" : "Rejónher una conversacion o ne crear una",
    "Nextcloud URL" : "URL Nextcloud",
    "Nextcloud user" : "Utilizaire Nextcloud",
    "User password" : "Senhal utilizaire",
    "Talk conversation" : "Conversacion Talk",
    "Skip TLS verification" : "Passar la verificacion TLS",
    "Matrix server URL" : "URL servidor Matrix",
    "User" : "User",
    "Matrix channel" : "Cadena Matrix",
    "Mattermost server URL" : "URL servidor Mattermost",
    "Mattermost user" : "Utilizaire Mattermost",
    "Team name" : "Nom de la còla",
    "Channel name" : "Nom de la cadena",
    "Rocket.Chat server URL" : "URL del servidor Rocket.Chat",
    "User name or email address" : "Nom d’utilizaire o adreça email",
    "Rocket.Chat channel" : "Canal Rocket.Chat",
    "Zulip server URL" : "URL servidor Zulip",
    "Bot user name" : "Nom d’utilizaire robòt",
    "Bot API key" : "Clau d’API robòt",
    "Zulip channel" : "Canal Zulip",
    "API token" : "Geton API",
    "Slack channel" : "Canal Slack",
    "Server ID or name" : "ID o nom del servidor",
    "Channel" : "Cadena",
    "Login" : "Login",
    "Chat ID" : "ID del chat",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "URL servidor IRC (per exemple chat.freenode.net:6667)",
    "Nickname" : "Escais",
    "Connection password" : "Senhal de connexion",
    "IRC channel" : "Cadena IRC",
    "Channel password" : "Senhal de cadena",
    "NickServ nickname" : "Nom d’utilizaire NickServ",
    "NickServ password" : "Senhal NickServ",
    "Use TLS" : "Utilizar TLS",
    "Use SASL" : "Utilizar SASL",
    "Tenant ID" : "ID Tenant",
    "Client ID" : "ID client",
    "Team ID" : "ID Team",
    "Thread ID" : "ID fial",
    "XMPP/Jabber server URL" : "URL servidor XMPP/Jabber",
    "MUC server URL" : "URL servidor MUC",
    "Jabber ID" : "ID Jabber",
    "Media" : "Mèdia",
    "Polls" : "Sondatges",
    "Voice messages" : "Messatges àudio",
    "Locations" : "Emplaçaments",
    "Audio" : "Àudio",
    "Show all media" : "Veire totes los mèdia",
    "Show all files" : "Veire totes los fichièrs",
    "Show all polls" : "Mostrar totes los sondatges",
    "Show all voice messages" : "Veire totes los messatges àudio",
    "Show all locations" : "Veire totes los emplaçaments",
    "Show all call recordings" : "Mostrar los enregistraments de sonadas",
    "Show all audio" : "Veire totes los àudios",
    "Show all other" : "Veire tota la rèsta",
    "Group" : "Grop",
    "You: {lastMessage}" : "Vos : {lastMessage}",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Leave this page" : "Quitar aquesta pagina",
    "Join here" : "Rejónher aquí",
    "Post to a conversation" : "Publicar dins una conversacion",
    "Post to conversation" : "Publicar a la conversacion",
    "An error occurred while posting location to conversation" : "Error en publicant la localizacion dins la conversacion",
    "Share to a conversation" : "Partejar dins una conversacion",
    "Share to conversation" : "Partejar dins una conversacion",
    "Error while clearing conversation history" : "Error pendent escafament de l’istoric de la conversacion",
    "Error occurred while allowing guests" : "Error en autorizant los convidats",
    "Error occurred while disallowing guests" : "Error en autorizant pas mai los convidats",
    "Error occurred when restricting the conversation to moderator" : "Error pendent la restriccion de la conversacion al moderator",
    "Error occurred when opening the conversation to everyone" : "Error pendent la dubertura de la conversacion a tot lo monde",
    "Conversation password has been saved" : "Lo senhal de conversacion es estat enregistrat",
    "Conversation password has been removed" : "Lo senhal de conversacion es estat suprimit",
    "Error occurred while saving conversation password" : "Error pendent l'enregistrament del senhal de la conversacion",
    "Could not post message: {errorMessage}" : "Fracàs de la publicacion : {errorMessage}",
    "An error occurred while fetching the participants" : "Una error s’es producha en recuperant los participants",
    "Could not send invitation to {actorId}" : "Mandadís impossible del convit a {actorId}",
    "Invitations sent" : "Invitacions enviadas",
    "Error occurred when sending invitations" : "Error en enviant las invitacions",
    "{guest} (guest)" : "{guest} (convidat)",
    "Failed to add reaction" : "Apondon impossible de reaccion",
    "Failed to remove reaction" : "Supression impossibla de reaccion",
    "Error while uploading file \"{fileName}\"" : "Error en enviant lo fichièr « {fileName} »",
    "Not enough free space to upload file \"{fileName}\"" : "Pas pro d’espaci liure per enviar lo fichièr « {fileName} »",
    "You are not allowed to share files" : "Avètz pas lo drech de partejar de fichièrs",
    "Error while sharing file" : "Error pendent lo partiment del fichièr",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Lo navegador qu’utilizatz es pas complètament pres en cargar per Nextcloud Talk. Mercés d’utilizar la darrièra version de Mozilla Firefox, Microsoft Edge, Google Chrome o Apple Safari.",
    "Tomorrow – {timeLocale}" : "Deman – {timeLocale}",
    "Lost connection to signaling server. Trying to reconnect." : "Connexion perduda al servidor de senhalament. Ensag de reconnexion.",
    "Please reload the page." : "Volgatz recargar la pagina.",
    "Do not disturb" : "Me desrengar pas",
    "Away" : "Absent",
    "Microphone {number}" : "Microfòn {number}",
    "Camera {number}" : "Camèra {number}",
    "Speaker {number}" : "Naut-parlaire {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Sembla que parlatz mentre que lo son es copat, mercés de vos restablir lo son per que vos entendan los autres",
    "Access to microphone & camera is only possible with HTTPS" : "L’accès al microfòn e a la camèra es sonque possibla amb HTTPS",
    "Please move your setup to HTTPS" : "Mercés de passar vòstra configuracion al HTTPS",
    "Access to microphone & camera was denied" : "L’accès al microfòn e a la camèra es estat refusat",
    "WebRTC is not supported in your browser" : "Vòstre navegador pren pas en carga lo WebRTC",
    "Please use a different browser like Firefox or Chrome" : "Volgatz utilizar un navegador diferent coma Firefox o Chrome",
    "Error while accessing microphone & camera" : "Error pendent l’accès al microfòn e a la camèra",
    "%s Talk on your mobile devices" : "%sTalk on vòstres aparelhs mobiles",
    "Join conversations at any time, anywhere, on any device." : "Participatz a las conversacion quand volètz, d’ont volètz, sus tot aparelh.",
    "Android app" : "Aplicacion Android",
    "iOS app" : "Aplicacion iOS",
    "__language_name__" : "Occitan",
    "Tasks" : "Prètzfaches",
    "Open poll • You voted already" : "Sondatge・Avètz ja votat",
    "Open poll • Click to vote" : "Sondatge・Clicar per votar",
    "Poll • Ended" : "Sondatge・Terminat",
    "Talk recording from {time} ({conversation})" : "Enregistrament Talk a partir de {time} ({conversation})",
    "Submit vote" : "Enviar lo vòt",
    "Your privacy setting has been saved" : "Paramètre de confidencialitat enregistrat",
    "Failed to save sounds setting" : "Cargament impossible del paramètre de son",
    "Sounds setting saved" : "Paramètres de son enregistrats",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Avètz rejonch la conversacion dins una autra fenèstra o periferic. Aquò es actualament pas pres en cargar per Nextcloud Talk doncas aquesta session es estada tampada."
},
"nplurals=2; plural=(n > 1);");
