OC.L10N.register(
    "spreed",
    {
    "a conversation" : "elkarrizketa bat",
    "(Duration %s)" : "(Iraupena %s)",
    "You attended a call with {user1}" : "Dei batean parte hartu duzu {user1} erabiltzailearekin",
    "_%n guest_::_%n guests_" : ["%n gonbidatu","%n gonbidatu"],
    "You attended a call with {user1} and {user2}" : "Dei batean parte hartu duzu {user1} eta {user2} erabiltzaileekin",
    "You attended a call with {user1}, {user2} and {user3}" : "Dei batean parte hartu duzu {user1}, {user2} eta {user3} erabiltzaileekin",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Dei batean parte hartu duzu {user1}, {user2}, {user3} eta {user4} erabiltzaileekin",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Dei batean parte hartu duzu {user1}, {user2}, {user3}, {user4} eta {user5} erabiltzaileekin",
    "_%n other_::_%n others_" : ["beste %n ","beste %n "],
    "{actor} invited you to {call}" : "{actor} erabiltzaileak {call} deira gonbidatu zaitu",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "<strong> Elkarrizketa</strong> batera gonbidatu zaituzte edo <strong>dei</strong> bat jaso duzu",
    "Other activities" : "Beste jarduerak",
    "Talk" : "Hizketaldia",
    "Guest" : "Gonbidatua",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Ongi etorri Nextcloud Talk-era!\nElkarrizketa honetan ezaugarri berrien berri emango zaizu.",
    "## New in Talk %s" : "## Berria Talk%s-n",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Orain Microsoft Edge eta Safari erabili daitezke audio eta bideo deietan parte hartzeko",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Orain bi pertsonaren arteko elkarrizketak iraunkorrak dira eta ezin dira nahi gabe talde-elkarrizketa bihurtu. Horretaz gain, parte-hartzaile batek elkarrizketa uzten duenean, ez da lehen bezala elkarrizketa automatikoki ezabatzen. Bi parte-hartzaileek uzten dutenean soilik ezabatzen da elkarrizketa zerbitzaritik",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Orain jakinarazpen bat bidal diezaiekezu txateko parte-hartzaile guztiei \"@all\" bidaliz",
    "- With the \"arrow-up\" key you can repost your last message" : "- \"gora gezia\" erabiliz zure azken mezua berriz bidali dezakezu",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Orain Talk-ek komando berriak ditu, bidali \"/help\" txateko mezu bezala zure administratzaileak batere konfiguratu duen ikusteko",
    "- With projects you can create quick links between conversations, files and other items" : "- Proiektuekin esteka azkarrak sor ditzakezu elkarrizketa, fitxategi eta bestelako elementuetara",
    "- You can now mention guests in the chat" : "- Orain gonbidatuak aipatu ditzakezu txatean",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Orain elkarrizketek atondo bat eduki dezakete. Honek aukera ematen die moderatzaileei txat eta deira batu eta bilera prestatzeko, erabiltzaile eta gonbidatuek itxaron behar duten bitartean",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Orain mezuei erantzuna zuzenean eman diezaiekezu, besteei zure mezuari buruzko testuinguru gehiago emateko",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Orain elkarrizketa eta parte-hartzaileak bilatzean zure aurreko elkarrizketak ere iragaziko ditu, aurreko elkarrizketak bilatzea asko erraztuz",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Orain erabiltzaile talde pertsonalizatuak gehitu ditzakezu elkarrizketetara, zirkuluak aplikazioa instalatuta badago",
    "- Check out the new grid and call view" : "- Eman begiratua sareta berriari eta deien ikuspegiari",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Orain zure gailutik txatera zuzenean igo eta arrastatu ta jaregin ditzakezu fitxategiak",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Partekaturiko fitxategiak orain zuzenean irekitzen dira txatean ikuspegi aplikazioekin",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Txatak eta mezuak goiko barrako bilaketa bateratuan bila ditzakezu",
    "- Spice up your messages with emojis from the emoji picker" : "- Apaindu zure mezuak emotikono-hautatzailearen emotikonoekin",
    "- You can now change your camera and microphone while being in a call" : "- Orain kamera eta mikrofonoa aldatu ditzakezu dei batean zaudenean",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Eman zure elkarrizketei testuinguru bat deskribapenaren bitartez eta ireki saioa hasita duten erabiltzaileek aurkitu eta  bat egin dezaten",
    "- See a read status and send failed messages again" : "- Ikusi irakurritako egoera eta bidali berriro huts egindako mezuak",
    "- Raise your hand in a call with the R key" : "- Goratu eskua dei batean R teklarekin ",
    "- Join the same conversation and call from multiple devices" : "- Batu elkarrizketa berera eta deitu gailu anitzetik",
    "- Send voice messages, share your location or contact details" : "- Bidali ahots-mezuak, partekatu zure kokalekua edo kontaktu-xehetasunak",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Gehitu taldeak elkarrizketa batera eta talde berriaren kideak partehartzaile bezala gehituko dira automatikoki",
    "- A preview of your audio and video is shown before joining a call" : "- Zure audio eta bideoaren aurrebista erakutsiko da deira sartu baino lehen",
    "- You can now blur your background in the newly designed call view" : "- Orain zure atzeko planoa lausotu dezakezu diseinatu berri den deien ikuspegian",
    "- Moderators can now assign general and individual permissions to participants" : "- Moderatzaileek orain baimen orokorrak eta indibidualak esleitu ahal dizkiete parte-hartzaileei",
    "- You can now react to chat messages" : "- Txat-mezueri erreakzionatu diezaiokezu orain",
    "- In the sidebar you can now find an overview of the latest shared items" : "- Alboko barran orain partekatutako azken elementuen ikuspegi orokorra aurki dezakezu",
    "- Use a poll to collect the opinions of others or settle on a date" : "- Erabili galdetegi bat besteen iritziak batzeko edo data bat ezartzeko",
    "- Configure an expiration time for chat messages" : "- Konfiguratu txat-mezuen iraungitze-ordua",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Hasi deiak elkarrizketa handietan besteei jakinarazi gabe. Deia hasitakoan banakako deien jakinarazpenak bidal ditzakezu.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Bidali txat mezuak hartzaileei jakinarazi gabe premiazkoa ez bada",
    "- Emojis can now be autocompleted by typing a \":\"" : "- Emojiak automatikoki osa daitezke orain \":\" bat idatzita",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- Lotu hainbat elementu erabiliz hautatzaile adimendun berria \"/\" bat idatzita",
    "- Conversations can now have an avatar or emoji as icon" : "- Elkarrizketek avatar edo emoji bat izan dezakete ikono gisa",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- Atzeko plano birtualak ere eskuragarri daude orain bideo deietan, atzeko plano lausotuaz gain",
    "- Reactions are now available during calls" : "- Erreakzioak eskuragarri daude orain deietan zehar",
    "- Typing indicators show which users are currently typing a message" : "- Idazketa-adierazleek mezu bat idazten duten erabiltzaileek erakusten dute",
    "- Groups can now be mentioned in chats" : "- Taldeak txatetan aipa daitezke orain",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- Deien grabazioak automatikoki transkribatzen dira transkripzioen hornitzaile-aplikazio bat erregistratuta badago",
    "- Chat messages can be translated if a translation provider app is registered" : "- Txat-mezuak itzulpenen hornitzaile-aplikazio erabiliz itzul daitezke bat erregistratuta badago",
    "- **Markdown** can now be used in _chat_ messages" : "- **Markdown** orain _txat_ mezuetan erabil daiteke",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- Webhook-ak eskuragarri daude orain bot-ak ezartzeko. Ikusi dokumentazioa informazio gehiagorako https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "- Ezarri gogorarazpen bat txat-mezu batean, geroago berriro jakinarazteko",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- Erabili **Oharrak niretzat** elkarrizketa oharrak hartzeko eta zure gailuen artean informazioa partekatzeko",
    "- Captions allow to send a message with a file at the same time" : "- Epigrafeek fitxategi batekin mezu bat bidaltzeko aukera ematen dute aldi berean",
    "_All %n participant_::_All %n participants_" : ["Parte-hartzaile %n","%n parte-hartzaile guztiak"],
    "Talk updates ✅" : "Talk eguneraketak ✅",
    "Reaction deleted by author" : "Egileak erreakzioa ezabatu du",
    "{actor} created the conversation" : "{actor} erabiltzaileak elkarrizketa sortu du",
    "You created the conversation" : "Elkarrizketa zuk sortu duzu",
    "System created the conversation" : "Sistemak elkarrizketa sortu du",
    "An administrator created the conversation" : "Administratzaile batek elkarrizketa sortu du",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} erabiltzaileak elkarrizketa berrizendatu du: \"%1$s\" -> \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Zuk elkarrizketa berrizendatu duzu: \"%1$s\" -> \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Administratzaile batek elkarrizketaren izena aldatu du \"%1$s\" tik \"%2$s\"ra",
    "{actor} set the description" : "{actor} deskribapena ezarri du",
    "You set the description" : "Deskribapena ezarri duzu",
    "An administrator set the description" : "Administratzaile batek deskribapena ezarri du",
    "{actor} removed the description" : "{actor} erabiltzaileak deskribapena kendu du",
    "You removed the description" : "Deskribapena kendu duzu",
    "An administrator removed the description" : "Administratzaile batek deskribapena kendu du",
    "You started a silent call" : "Dei isil bat hasi duzu",
    "{actor} started a silent call" : "{actor}(e)k dei isil bat hasi du",
    "You started a call" : "Dei bat hasi duzu",
    "{actor} started a call" : "{actor} erabiltzaileak dei bat hasi du",
    "{actor} joined the call" : "{actor} deira batu da",
    "You joined the call" : "Deira batu zara",
    "{actor} left the call" : "{actor} erabiltzaileak deia utzi du",
    "You left the call" : "Deia utzi duzu",
    "{actor} unlocked the conversation" : "{actor} erabiltzaileak elkarrizketa desblokeatu du",
    "You unlocked the conversation" : "Elkarrizketa desblokeatu duzu",
    "An administrator unlocked the conversation" : "Administratzaile batek elkarrizketa desblokeatu du",
    "{actor} locked the conversation" : "{actor} erabiltzaileak elkarrizketa blokeatu du",
    "You locked the conversation" : "Elkarrizketa blokeatu duzu",
    "An administrator locked the conversation" : "Administratzaile batek elkarrizketa blokeatu du",
    "{actor} limited the conversation to the current participants" : "{actor} erabiltzaileak uneko parte-hartzaileen muga ezarri dio elkarrizketari",
    "You limited the conversation to the current participants" : "Uneko parte-hartzaileen muga ezarri diozu elkarrizketari",
    "An administrator limited the conversation to the current participants" : "Administratzaile batek uneko parte-hartzaileen muga ezarri dio elkarrizketari",
    "{actor} opened the conversation to registered users" : "{actor} erabiltzaileak elkarrizketa ireki du erregistraturiko erabiltzaileentzat",
    "You opened the conversation to registered users" : "Elkarrizketa ireki duzu erregistraturiko erabiltzaileentzat",
    "An administrator opened the conversation to registered users" : "Administratzaile batek elkarrizketa ireki du erregistraturiko erabiltzaileentzat",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} erabiltzaileak elkarrizketa ireki du erregistraturiko erabiltzaileentzat eta Gonbidatuak aplikazioaren bidez sorturiko erabiltzaileentzat",
    "You opened the conversation to registered users and users created with the Guests app" : "Elkarrizketa ireki duzu erregistraturiko erabiltzaileentzat eta Gonbidatuak aplikazioaren bidez sorturiko erabiltzaileentzat",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "Administratzaileak elkarrizketa ireki du erregistraturiko erabiltzaileentzat eta Gonbidatuak aplikazioaren bidez sorturiko erabiltzaileentzat",
    "The conversation is now open to everyone" : "Orain elkarrizketa irekia dago edozeinentzat",
    "{actor} opened the conversation to everyone" : "{actor} erabiltzaileak elkarrizketa ireki du edozeinentzat",
    "You opened the conversation to everyone" : "Elkarrizketa ireki duzu edozeinentzat",
    "{actor} restricted the conversation to moderators" : "{actor} erabiltzaileak elkarrizketa moderatzaileentzako murriztu du",
    "You restricted the conversation to moderators" : "Elkarrizketa moderatzaileentzako murriztu duzu",
    "{actor} started breakout rooms" : "{actor}-(e)k taldekako gelak hasi ditu",
    "You started breakout rooms" : "Taldekako gelak hasi dituzu",
    "{actor} stopped breakout rooms" : "{actor}-(e)k taldekako gelak geldiarazi ditu",
    "You stopped breakout rooms" : "Taldekako gelak geldiarazi dituzu",
    "{actor} allowed guests" : "{actor} erabiltzaileak gonbidatuak baimendu ditu",
    "You allowed guests" : "Gonbidatuak baimendu dituzu",
    "An administrator allowed guests" : "Administratzaile batek gonbidatuak baimendu ditu",
    "{actor} disallowed guests" : "{actor} erabiltzaileak gonbidatuei baimena kendu die",
    "You disallowed guests" : "Gonbidatuei baimena kendu diezu",
    "An administrator disallowed guests" : "Administratzaile batek gonbidatuak debekatu ditu",
    "{actor} set a password" : "{actor} erabiltzaileak pasahitz bat ezarri du",
    "You set a password" : "Pasahitz bat ezarri duzu",
    "An administrator set a password" : "Administratzaile batek pasahitza ezarri du",
    "{actor} removed the password" : "{actor} erabiltzaileak pasahitza kendu du",
    "You removed the password" : "Pasahitza kendu duzu",
    "An administrator removed the password" : "Administratzaile batek pasahitza kendu du",
    "{actor} added {user}" : "{actor} erabiltzaileak {user} gehitu du",
    "You joined the conversation" : "Elkarrizketara batu zara",
    "{actor} joined the conversation" : "{actor} elkarrizketara batu da",
    "You added {user}" : "{user} gehitu duzu",
    "{actor} added you" : "{actor} erabiltzaileak zu gehitu zaitu",
    "An administrator added you" : "Administratzaile batek gehitu egin zaitu",
    "An administrator added {user}" : "Administratzaile batek {user} gehitu du",
    "You left the conversation" : "Elkarrizketatik atera zara",
    "{actor} left the conversation" : "{actor} erabiltzaileak elkarrizketa utzi du",
    "{actor} removed {user}" : "{actor} erabiltzaileak {user} kendu du",
    "You removed {user}" : "{user} erabiltzailea kendu duzu",
    "{actor} removed you" : "{actor} erabiltzaileak kendu egin zaitu",
    "An administrator removed you" : "Administratzaile batek kanporatu egin zaitu",
    "An administrator removed {user}" : "Administratzaile batek {user} kanporatu du",
    "{actor} invited {federated_user}" : "{actor}erabiltzaileak {federated_user} gonbidatu du",
    "You invited {federated_user}" : "{federated_user} gonbidatu duzu",
    "You accepted the invitation" : "Gonbidapena onartu duzu",
    "{actor} invited you" : "{actor} erabiltzaileak gonbidatu zaitu",
    "An administrator invited you" : "Administratzaile batek gonbidatu zaitu",
    "An administrator invited {federated_user}" : "Administratzaile batek {federated_user} gonbidatu du",
    "{federated_user} accepted the invitation" : "{federated_user}-(e)k gonbidapena onartu du",
    "{actor} removed {federated_user}" : "{actor}-(e)k {federated_user} kendu du",
    "You removed {federated_user}" : "{federated_user} kendu duzu",
    "An administrator removed {federated_user}" : "Administratzaile batek {federated_user} kendu du",
    "{federated_user} declined the invitation" : "{federated_user} gonbidapena ukatu du",
    "{actor} added group {group}" : "{actor} erabiltzaileak {group} taldea gehitu du",
    "You added group {group}" : "{group} taldea gehitu duzu",
    "An administrator added group {group}" : "Administratzaile batek {group} taldea gehitu du",
    "{actor} removed group {group}" : "{actor} erabiltzaileak {group} taldea kendu du",
    "You removed group {group}" : "{group} taldea kendu duzu",
    "An administrator removed group {group}" : "Administratzaile batek {group} taldea kendu du",
    "{actor} added team {circle}" : "{actor} erabiltzaileak {circle} lantaldea gehitu du ",
    "You added team {circle}" : "{circle} lantaldea gehitu duzu",
    "An administrator added team {circle}" : "Administratzaile batek {circle} lantaldea gehitu du",
    "{actor} removed team {circle}" : "{actor} erabiltzaileak {circle} lantaldea kendu du",
    "You removed team {circle}" : "{circle} lantaldea kendu duzu",
    "An administrator removed team {circle}" : "Administratzaile batek {circle} lantaldea kendu du",
    "{actor} added {phone}" : "{actor} erabiltzaileak {phone} gehitu du",
    "You added {phone}" : "{phone} gehitu duzu",
    "An administrator added {phone}" : "Administratzaile batek {phone} gehitu du",
    "{actor} removed {phone}" : "{actor} erabiltzaileak {phone} kendu du",
    "You removed {phone}" : "{phone} kendu duzu",
    "An administrator removed {phone}" : "Administratzaile batek {phone} kendu du",
    "{actor} promoted {user} to moderator" : "{actor} erabiltzaileak {user} moderatzaile egin du",
    "You promoted {user} to moderator" : "{user} moderatzaile egin duzu",
    "{actor} promoted you to moderator" : "{actor} erabiltzaileak moderatzaile egin zaitu",
    "An administrator promoted you to moderator" : "Administratzaile batek moderatzaile egin zaitu",
    "An administrator promoted {user} to moderator" : "Administratzaile batek {user} moderatzaile egin du",
    "{actor} demoted {user} from moderator" : "{actor} erabiltzaileak moderatzaile rola kendu dio {user} erabiltzaileari",
    "You demoted {user} from moderator" : "{user} erabiltzaileari moderatzaile rola kendu diozu",
    "{actor} demoted you from moderator" : "{actor} erabiltzaileak moderatzaile rola kendu dizu",
    "An administrator demoted you from moderator" : "Administratzaile batek moderatzaile rola kendu dizu",
    "An administrator demoted {user} from moderator" : "Administratzaile batek {user} erabiltzaileari moderatzaile rola kendu dio",
    "{actor} shared a file which is no longer available" : "{actor} erabiltzaileak erabilgarri ez dagoen fitxategi bat partekatu du",
    "You shared a file which is no longer available" : "Eskuragarri ez dagoen fitxategi bat partekatu duzu",
    "File shares are currently not supported in federated conversations" : "Fitxategien partekatzeak une honetan ez dira onartzen federatutako elkarrizketetan",
    "The shared location is malformed" : "Partekatutako kokalekua gaizki osatuta dago",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} erabiltzaileak Matterbridge konfiguratu du elkarrizketa hau beste txat batzuekin sinkronizatzeko",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Matterbridge konfiguratu duzu elkarrizketa hau beste txat batzuekin sinkronizatzeko",
    "{actor} updated the Matterbridge configuration" : "{actor} erabiltzaileak Matterbridge konfigurazioa eguneratu du",
    "You updated the Matterbridge configuration" : "Matterbridge konfigurazioa eguneratu duzu",
    "{actor} removed the Matterbridge configuration" : "{actor} erabiltzaileak Matterbridge konfigurazioa kendu du",
    "You removed the Matterbridge configuration" : "Matterbridge konfigurazioa kendu duzu",
    "{actor} started Matterbridge" : "{actor} Matterbridge hasi du",
    "You started Matterbridge" : "Matterbridge hasi duzu",
    "{actor} stopped Matterbridge" : "{actor} erabiltzaileak Matterbridge gelditu du",
    "You stopped Matterbridge" : "Matterbridge gelditu duzu",
    "{actor} deleted a message" : "{actor}(e)k mezua ezabatu du",
    "You deleted a message" : "Mezu bat ezabatu duzu",
    "{actor} edited a message" : "{actor} erabiltzaileak mezu bat editatu du",
    "You edited a message" : "Mezu bat editatu duzu",
    "{actor} deleted a reaction" : "{actor}-(e)k erreakzio bat ezabatu du",
    "You deleted a reaction" : "Erreakzio bat ezabatu duzu",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["Mezuaren iraungitzea aste %nera aldatu duzu","Mezuaren iraungitzea %n astetara aldatu duzu"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["Mezuaren iraungitzea egun%nera aldatu duzu","Mezuaren iraungitzea %n egunetara aldatu duzu"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["Mezuaren iraungitzea ordu %nera aldatu duzu","Mezuaren iraungitzea %n ordutara aldatu duzu"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["Mezuaren iraungitzea %nminututara aldatu duzu","Mezuaren iraungitzea%nminututara aldatu duzu"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor}-(e)k mezuaren iraungitzea aste %nera aldatu du","{actor}-(e)k mezuaren iraungitzea %n astetara aldatu du"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor}-(e)k mezuaren iraungitzea ordu %nera  aldatu du","{actor}-(e)k mezuaren iraungitzea %n egunetara aldatu du"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor}-(e)k mezuaren iraungitzea ordu %nera aldatu du","{actor}-(e)k mezuaren iraungitzea %n ordutara aldatu du"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["actor}-(e)k mezuaren iraungitzea%nminututara aldatu du","actor}-(e)k mezuaren iraungitzea %nminututara aldatu du"],
    "{actor} disabled message expiration" : "{actor}-(e)k mezuaren iraungitzea desgaitu du",
    "You disabled message expiration" : "Mezuaren iraungitzea desgaitu duzu",
    "{actor} cleared the history of the conversation" : "{actor} elkarrizketaren historia ezabatu du",
    "You cleared the history of the conversation" : "Elkarrizketaren historia ezabatu duzu",
    "{actor} set the conversation picture" : "{actor}-(e)k ezarri du elkarrizketaren argazkia",
    "You set the conversation picture" : " Ezarri duzu elkarrizketaren argazkia",
    "{actor} removed the conversation picture" : "{actor}-(e)k elkarrizketaren argazkia kendu du",
    "You removed the conversation picture" : "Elkarrizketaren argazkia kendu duzu",
    "{actor} ended the poll {poll}" : "{actor}(e)k {poll} galdeketa bukatu du",
    "You ended the poll {poll}" : "{poll} galdeketa bukatu duzu",
    "{actor} started the video recording" : "{actor} bideoa grabatzen hasi da",
    "You started the video recording" : "Bideoa grabatzen hasi zara",
    "{actor} stopped the video recording" : "{actor}-(e)k bideoaren grabazioa gelditu du",
    "You stopped the video recording" : "bideoaren grabazioa gelditu duzu",
    "{actor} started the audio recording" : "{actor}-(e)k audio-grabazioa hasi du",
    "You started the audio recording" : "Audio-grabazioa hasi duzu",
    "{actor} stopped the audio recording" : "{actor}-(e)k audio-grabaketa gelditu du",
    "You stopped the audio recording" : "Audio-grabaketa gelditu duzu",
    "The recording failed" : "Grabaketak huts egin du",
    "Someone voted on the poll {poll}" : "Norbaitek {poll} galdeketan bozkatu du.",
    "Message deleted by author" : "Egileak mezua ezabatu du",
    "Message deleted by {actor}" : "{actor} erabiltzaileak mezua ezabatu du",
    "Message deleted by you" : "Mezua ezabatu duzu",
    "Deleted user" : "Ezabatutako erabiltzaileak",
    "Unknown number" : "Zenbaki ezezaguna",
    "Administration" : "Administrazioa",
    "System" : "Sistema",
    "%s (guest)" : "%s (gonbidatua)",
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} deia bukatu du %n gonbidatuarekin (Iraupena {duration})","{actor} deia bukatu du %n gonbidatuekin (Iraupena {duration})"],
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} deia bukatu du {user1} erabiltzailearekin (Iraupena {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} deia bukatu du {user1} eta {user2} erabiltzaileekin (Iraupena {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} deia bukatu du {user1}, {user2} eta {user3} erabiltzaileekin (Iraupena {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} deia bukatu du {user1}, {user2}, {user3} eta {user4} erabiltzaileekin (Iraupena {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} deia bukatu du {user1}, {user2}, {user3}, {user4} eta {user5} erabiltzaileekin (Iraupena {duration})",
    "Message of {user} in {conversation}" : "{user}-ren mezua {conversation}-n",
    "Message of {user}" : "{user} erabiltzailearen mezua",
    "Message of a deleted user in {conversation}" : "Ezabatutako erabiltzaile baten mezua {elkarrizketa} atalean",
    "Talk conversations" : "Talk elkarrizketak",
    "Talk to %s" : "Hitz egin %s erabiltzailearekin",
    "An error occurred. Please contact your administrator." : "Errore bat gertatu da. Jarri zure administratzailearekin harremanetan mesedez.",
    "Storage quota exceeded" : "Biltegiratze kuota gainditu da",
    "File not found" : "Ez da fitxategia aurkitu",
    "File is not shared, or shared but not with the user" : "Fitxategia ez dago partekatua, edo partekatu da baina ez erabiltzailearekin",
    "No account available to delete." : "Ez dago konturik eskuragarri ezabatzeko.",
    "Poll" : "Galdeketa",
    "No image file provided" : "Ez da irudi fitxategirik eman",
    "File is too big" : "Fitxategia handiegia da",
    "Invalid file provided" : "Baliogabeko fitxategia eman da",
    "Invalid image" : "Irudi baliogabea",
    "Unknown filetype" : "Fitxategi mota ezezaguna",
    "Talk mentions" : "Talk aipamenak",
    "More conversations" : "Elkarrizketa gehiago",
    "Say hi to your friends and colleagues!" : "Esan kaixo zure lagun eta lankideei!",
    "No unread mentions" : "Ez dago irakurri gabeko aipamenik",
    "Call in progress" : "Deia abian da",
    "You were mentioned" : "Aipatu egin zaituzte",
    "Write to conversation" : "Idatzi elkarrizketan",
    "Writes event information into a conversation of your choice" : "Gertaeraren informazioa idazten du zuk hautatutako elkarrizketan",
    "Conversation invitation" : "Gonbidapena elkarrizketara",
    "Description" : "Deskribapena",
    "You can also dial-in via phone with the following details" : "Markatzea telefono bidez ere egin dezakezu, honako xehetasunekin",
    "Dial-in information" : "Markatze informazioa",
    "Meeting ID" : "Bileraren IDa",
    "Your PIN" : "Zure PINa",
    "Meeting" : "Bilera",
    "Password request: %s" : "Pasahitz eskaera: %s",
    "Private conversation" : "Elkarrizketa pribatua",
    "Deleted user (%s)" : "Ezabatutako erabiltzailea (%s)",
    "Failed to upload call recording" : "Deien grabaketaren igotzeak huts egin du",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "Grabaketa-zerbitzariak huts egin du {call} deiaren grabazioa igotzean. Jarri harremanetan administrazioarekin.",
    "Share to chat" : "Partekatu txatarekin",
    "Dismiss notification" : "Baztertu jakinarazpena",
    "Call recording now available" : "Deien grabaketa ez dago erabilgarri",
    "The recording for the call in {call} was uploaded to {file}." : "{deia} deiaren grabazioa {file}-ra igo da.",
    "Transcript now available" : "Transkripzioa eskuragarri dago",
    "The transcript for the call in {call} was uploaded to {file}." : "{call} deiaren transkripzioa {file} fitxategira kargatu da.",
    "Failed to transcript call recording" : "Dei grabaketa transkribatzeak huts egin du",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "Zerbitzariak huts egin du {call}deiaren {file} fitxategiko grabaketa transkribatzean. Jarri harremanetan administratzailearekin.",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} erabiltzaileak {remoteServer} zerbitzariko {roomName} gelara gonbidatu zaitu",
    "Accept" : "Onartu",
    "Decline" : "Uko egin",
    "{user1} invited you to a federated conversation" : "{user1} erabiltzaileak elkarrizketa federatu batera gonbidatu zaitu",
    "New message" : "Mezu berria",
    "Reminder" : "Gogorarazpena",
    "Notification" : "Jakinarazpena",
    "{user} reacted with {reaction}" : "{user}(e)k {reaction} adierazi du",
    "{user} reacted with {reaction} in {call}" : "{user}(e)k {reaction} adierazi du {call} deian",
    "Deleted user reacted with {reaction} in {call}" : "Ezabatutako erabiltzaile batek {reaction} adierazi du {call} deian",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest} gonbidatuak {reaction} adierazi du {call} deian",
    "Guest reacted with {reaction} in {call}" : "Gonbidatu batek {reaction} adierazi du {call} deian",
    "{user} in {call}" : "{user} erabiltzailea {call} deian",
    "Deleted user in {call}" : "Erabiltzailea ezabatu da {call} deian",
    "{guest} (guest) in {call}" : "{guest} (guest) gonbidatua(k) {call} deian",
    "Guest in {call}" : "Gonbidatua {call} deian",
    "{user} sent you a private message" : "{user} erabiltzaileak mezu pribatu bat bidali dizu",
    "{user} sent a message in conversation {call}" : "{user} erabiltzaileak mezu bat bidali du {call} deian",
    "A deleted user sent a message in conversation {call}" : "Ezabatutako erabiltzaile batek mezu bat bidali du {call} deian",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (gonbidatua) erabiltzaileak mezu bat bidali du {call} deian",
    "A guest sent a message in conversation {call}" : "Gonbidatu batek mezu bat bidali du {call} deian",
    "{user} replied to your private message" : "{user} erabiltzaileak zure mezu pribatuari erantzun dio",
    "{user} replied to your message in conversation {call}" : "{user} erabiltzaileak zure mezuari erantzun dio {call} deian",
    "A deleted user replied to your message in conversation {call}" : "Ezabatutako erabiltzaile batek zure mezuari erantzun dio {call} deian",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (gonbidatua) erabiltzaileak zure mezu bati erantzun dio {call} deian",
    "A guest replied to your message in conversation {call}" : "Gonbidatu batek zure mezuari erantzun dio {call} deian",
    "{user} reacted with {reaction} to your private message" : "{user}-k {reaction} erabili du zure mezu pribatuari erreakzionatzeko",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user}-k {reaction} erabili du zure mezuari {call} elkarrizketan erreakzionatzeko",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "Ezabatutako erabiltzaile batek {reaction} erabili du zure mezuari {call} elkarrizketan erreakzionatzeko",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{gonbidatua} (gonbidatua) {reaction} erabili du zure mezuari {deia} elkarrizketan erreakzionatzeko",
    "A guest reacted with {reaction} to your message in conversation {call}" : "Gonbidatu batek {reaction} rabili du zure mezuari {call} elkarrizketan erreakzionatzeko",
    "{user} mentioned you in a private conversation" : "{user} erabiltzaileak elkarrizketa pribatu batean aipatu zaitu",
    "{user} mentioned group {group} in conversation {call}" : "{user}-(e)k taldea {group} aipatu du {call} elkarrizketan",
    "{user} mentioned everyone in conversation {call}" : "{user}-(e)k guztiak aipatu ditu {call} elkarrizketan",
    "{user} mentioned you in conversation {call}" : "{user} erabiltzaileak aipatu zaitu {call} deian",
    "A deleted user mentioned group {group} in conversation {call}" : "Ezabatutako erabiltzaile batek {group} taldea aipatu du {call} elkarrizketan",
    "A deleted user mentioned everyone in conversation {call}" : "Ezabatutako erabiltzaile batek  {call} elkarrizketan guztiak aipatu ditu",
    "A deleted user mentioned you in conversation {call}" : "Ezabatutako erabiltzaile batek aipatu zaitu {call} deian",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest} (gonbidatuak) {group} taldea aipatu du {call} elkarrizketan",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest} (gonbidatuak) {group} guztiak aipatu ditu {call} elkarrizketan",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (gonbidatua) erabiltzaileak aipatu zaitu {call} deian",
    "A guest mentioned group {group} in conversation {call}" : "Gonbidatu batek {group} taldea aipatu du {call} elkarrizketan",
    "A guest mentioned everyone in conversation {call}" : "Gonbidatu batek {call} elkarrizketan guztiak aipatu ditu ",
    "A guest mentioned you in conversation {call}" : "Gonbidatu batek aipatu zaitu {call} deian",
    "View message" : "Ikusi mezua",
    "Dismiss reminder" : "Baztertu gogorarazpena",
    "View chat" : "Ikusi txata",
    "{user} invited you to a group conversation: {call}" : "{user} erabiltzaileak talde-elkarrizketa batera gonbidatu zaitu: {call}",
    "Join call" : "Batu deira",
    "Answer call" : "Erantzun deia",
    "{user} would like to talk with you" : "{user} zurekin hitz egin nahi du",
    "Call back" : "Itzuli deia",
    "You missed a call from {user}" : "{user} erabiltzailearen dei bat galdu duzu",
    "A group call has started in {call}" : "Talde dei bat hasi da {call} elkarrizketan",
    "You missed a group call in {call}" : "Talde dei bat huts egin duzu {call} elkarrizketan",
    "{email} is requesting the password to access {file}" : "{email} pasahitza eskatzen ari da {file} fitxategira sarbidea izateko",
    "{email} tried to request the password to access {file}" : "{email} {file} fitxategira sarbidea izateko pasahitza eskatzen saiatu da",
    "Someone is requesting the password to access {file}" : "Norbait {file} fitxategira sarbidea izateko pasahitza eskatzen ari da",
    "Someone tried to request the password to access {file}" : "Norbait {file} fitxategira sarbidea izateko pasahitza eskatzen saiatu da",
    "Open settings" : "Ireki ezarpenak",
    "The hosted signaling server is now configured and will be used." : "Ostataturiko seinalizazio zerbitzaria konfiguratu da eta erabili egingo da.",
    "The hosted signaling server was removed and will not be used anymore." : "Ostataturiko seinalizazio zerbitzaria kendu egin da eta ez da gehiago erabiliko.",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "Ostataturiko seinalizazio zerbitzariaren kontua aldatu egin da \"{oldstatus}\" izatetik \"{newstatus}\" izatera.",
    "pending" : "zain",
    "active" : "aktibo",
    "expired" : "iraungita",
    "blocked" : "blokeatuta",
    "error" : "errorea",
    "Contact via Talk" : "Jarri harremanetan Talk bidez",
    "Open Talk" : "Ireki Talk",
    "Default" : "Lehenetsia",
    "Presentation" : "Aurkezpena",
    "Conversations" : "Elkarrizketak",
    "Messages in current conversation" : "Uneko elkarrizketako mezuak",
    "{user}" : "{user}",
    "Messages" : "Mezuak",
    "{user} in {conversation}" : "{user} erabiltzailea {conversation} elkarrizketan",
    "Messages in other conversations" : "Mezuak beste elkarrizketa batzuetan",
    "One-to-one rooms always need to show the other users avatar" : "Batetik baterako gelek beti erakutsi behar dute beste erabiltzaileen avatarra",
    "Invalid emoji character" : "Emoji karaktere baliogabea",
    "Invalid background color" : "Atzeko planoko kolore baliogabea",
    "Avatar image is not square" : "Abatarreko irudia ez da karratua",
    "Room {number}" : "{number} gela",
    "Other" : "Bestelakoa",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "Proba eskaerak huts egin du ezin delako atzitu probako zerbitzaria. Saiatu berriro beranduago.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Arazo bat dago instantzia honen autentifikazioarekin. Agian ez dago irisgarritasunik kanpoaldetik URLa egiaztatzeko.",
    "Something unexpected happened." : "Espero ez zen zerbait gertatu da.",
    "The URL is invalid." : "URLa baliogabea da.",
    "An HTTPS URL is required." : "HTTPS URL bat behar da.",
    "The email address is invalid." : "E-posta helbidea baliogabea da.",
    "The language is invalid." : "Hizkuntza baliogabea da.",
    "The country is invalid." : "Herrialdea baliogabea da.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Arazo bat dago proba eskaerarekin. Egiaztatu zure erregistroak informazio gehiagorako.",
    "Too many requests are send from your servers address. Please try again later." : "Eskaera gehiegi bidali dira zure zerbitzari helbidetik. Saiatu berriro beranduago.",
    "There is already a trial registered for this Nextcloud instance." : "Dagoeneko badago proba bat erregistratuta Nextcloud instantzia honetatik.",
    "Something unexpected happened. Please try again later." : "Espero ez zen zerbait gertatu da. Saiatu berriro beranduago.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "Proba eskatzeak huts egin du proba zerbitzariak oker jokatu duelako. Saiatu berriro beranduago.",
    "Trial requested but failed to get account information. Please check back later." : "Proba eskatu da, baina kontuaren informazioa eskuratzeak huts egin du. Egiaztatu berriro beranduago.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Arazo bat dago eskaera honen autentifikazioarekin. Agian ez dago irisgarritasunik kanpoaldetik URLa egiaztatzeko.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "Kontuaren informazioa eskuratzeak huts egin du proba zerbitzariak oker jokatu duelako. Egiaztatu berriro beranduago.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Arazo bat dago kontuaren informazioa eskuratzearekin. Egiaztatu zure erregistroak informazio gehiagorako.",
    "There is no such account registered." : "Kontu hori ez dago erregistratuta.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "Kontuaren informazioa eskuratzeak huts egin du proba zerbitzaria ez dagoelako eskuragarri. Egiaztatu berriro beranduago.",
    "Deleting the hosted signaling server account failed. Please check back later." : "Ostataturiko seinalizazio zerbitzaria ezabatzeak huts egin du. Saiatu berriro beranduago.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Kontua ezabatzeak huts egin du proba zerbitzariak oker jokatu duelako. Egiaztatu berriro beranduago.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Arazo bat dago kontua ezabatzearekin. Egiaztatu zure erregistroak informazio gehiagorako.",
    "Too many requests are sent from your servers address. Please try again later." : "Eskaera gehiegi bidali dira zure zerbitzari helbidetik. Saiatu berriro beranduago.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Kontua ezabatzeak huts egin du proba zerbitzaria ez dagoelako eskuragarri. Egiaztatu berriro beranduago.",
    "Note to self" : "Nire oharrak",
    "A place for your private notes, thoughts and ideas" : "Zure ohar, hausnarketa eta ideientzako leku pribatua",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Arabiar Emirerri Batuak",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antigua eta Barbuda",
    "Anguilla" : "Aingira",
    "Albania" : "Albaniera",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Antartika",
    "Argentina" : "Argentina",
    "American Samoa" : "Samoa Estatubatuarra",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Aland Uharteak",
    "Azerbaijan" : "Azerbaijan",
    "Bosnia and Herzegovina" : "Bosnia-Herzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgika",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei Darussalam" : "Brunei",
    "Bolivia, Plurinational State of" : "Boliviako Estatu Plurinazionala",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, San Eustakio eta Saba",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahamak",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Bouvet uhartea",
    "Botswana" : "Botswana",
    "Belarus" : "Bielorrusia",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Cocos (Keeling) uharteak",
    "Congo, the Democratic Republic of the" : "Kongoko Errepublika Demokratikoa",
    "Central African Republic" : "Afrika Erdiko Errepublika",
    "Congo" : "Kongo",
    "Switzerland" : "Suitza",
    "Côte d'Ivoire" : "Boli Kosta",
    "Cook Islands" : "Cook uharteak",
    "Chile" : "Txile",
    "Cameroon" : "Kamerun",
    "China" : "Txina",
    "Colombia" : "Kolombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Cabo Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Christmas uhartea",
    "Cyprus" : "Zipre",
    "Czechia" : "Txekia",
    "Germany" : "Alemania",
    "Djibouti" : "Djibuti",
    "Denmark" : "Danimarka",
    "Dominica" : "Dominika",
    "Dominican Republic" : "Dominikar Errepublika",
    "Algeria" : "Algeria",
    "Ecuador" : "Ekuador",
    "Estonia" : "Estonia",
    "Egypt" : "Egipto",
    "Western Sahara" : "Mendebaldeko Sahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Espainia",
    "Ethiopia" : "Etiopia",
    "Finland" : "Finlandia",
    "Fiji" : "Fiji",
    "Falkland Islands (Malvinas)" : "Falkland uharteak (Malvinak)",
    "Micronesia, Federated States of" : "Mikronesiako Estatu Federatuak",
    "Faroe Islands" : "Faroe uharteak",
    "France" : "Frantzia",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Britainia Handiko eta Ipar Irlandako Erresuma Batua",
    "Grenada" : "Grenada",
    "Georgia" : "Georgia",
    "French Guiana" : "Guyana Frantsesa",
    "Guernsey" : "Guernesey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Groenlandia",
    "Gambia" : "Gambia",
    "Guinea" : "Ginea",
    "Guadeloupe" : "Guadalupe",
    "Equatorial Guinea" : "Ekuatore Ginea",
    "Greece" : "Grezia",
    "South Georgia and the South Sandwich Islands" : "Hegoaldeko Georgia eta Hegoaldeko Sandwich uharteak",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Ginea Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Heard eta McDonald uharteak",
    "Honduras" : "Honduras",
    "Croatia" : "Kroazia",
    "Haiti" : "Haiti",
    "Hungary" : "Hungaria",
    "Indonesia" : "Indonesia",
    "Ireland" : "Irlanda",
    "Israel" : "Israel",
    "Isle of Man" : "Man uhartea",
    "India" : "India",
    "British Indian Ocean Territory" : "Indiako Ozeanoko Britainiar Lurraldea",
    "Iraq" : "Irak",
    "Iran, Islamic Republic of" : "Irango Islamiar Errepublika",
    "Iceland" : "Islandia",
    "Italy" : "Itali",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamaika",
    "Jordan" : "Jordania",
    "Japan" : "Japonia",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kirgizistan",
    "Cambodia" : "Kanbodia",
    "Kiribati" : "Kiribati",
    "Comoros" : "Komoreak",
    "Saint Kitts and Nevis" : "Saint Kitts eta Nevis",
    "Korea, Democratic People's Republic of" : "Koreako Herri Errepublika Demokratikoa",
    "Korea, Republic of" : "Koreako Errepublika",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Kaiman uharteak",
    "Kazakhstan" : "Kazakhstan",
    "Lao People's Democratic Republic" : "Laosko Herri Errepublika Demokratikoa",
    "Lebanon" : "Libano",
    "Saint Lucia" : "Santa Luzia",
    "Liechtenstein" : "Liechtestein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Lituania",
    "Luxembourg" : "Luxemburg",
    "Latvia" : "Letonia",
    "Libya" : "Libia",
    "Morocco" : "Maroko",
    "Monaco" : "Monako",
    "Moldova, Republic of" : "Moldaviako Errepublika",
    "Montenegro" : "Montenegro",
    "Saint Martin (French part)" : "San Martin (Frantziako eremua)",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Marshall uharteak",
    "North Macedonia" : "Ipar Mazedonia",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Mariana uharteak",
    "Martinique" : "Martinika",
    "Mauritania" : "Mauritania",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Maurizio",
    "Maldives" : "Maldivak",
    "Malawi" : "Malawi",
    "Mexico" : "Mexiko",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mozambike",
    "Namibia" : "Namibia",
    "New Caledonia" : "Kaledonia Berria",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolk uhartea",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nikaragua",
    "Netherlands" : "Herbehereak",
    "Norway" : "Norvegia",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Zeelanda berria",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Polinesia Frantsesa",
    "Papua New Guinea" : "Papua Ginea Berria",
    "Philippines" : "Filipinak",
    "Pakistan" : "Pakistan",
    "Poland" : "Polonia",
    "Saint Pierre and Miquelon" : "Saint-Pierre eta Mikelune",
    "Pitcairn" : "Pitcairn uharteak",
    "Puerto Rico" : "Puerto Rico",
    "Palestine, State of" : "Palestinako Estatua",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguai",
    "Qatar" : "Qatar",
    "Réunion" : "Réunion",
    "Romania" : "Errumania",
    "Serbia" : "Serbia",
    "Russian Federation" : "Errusiar Federakundea",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Saudi Arabia",
    "Solomon Islands" : "Salomon Uharteak",
    "Seychelles" : "Seychelleak",
    "Sudan" : "Sudan",
    "Sweden" : "Suedia",
    "Singapore" : "Singapur",
    "Saint Helena, Ascension and Tristan da Cunha" : "Santa Helena, Ascension eta Tristan da Cunha",
    "Slovenia" : "Eslovenia",
    "Svalbard and Jan Mayen" : "Svalbard eta Jan Mayen uharteak",
    "Slovakia" : "Eslovakia",
    "Sierra Leone" : "Sierra Leona",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Surinam",
    "South Sudan" : "Hego Sudan",
    "Sao Tome and Principe" : "Sao Tome eta Principe",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "Sint Maarten (Alemaniako eremua)",
    "Syrian Arab Republic" : "Siriako Arabiar Errepublika",
    "Eswatini" : "Eswatini",
    "Turks and Caicos Islands" : "Turk eta Caico uharteak",
    "Chad" : "Txad",
    "French Southern Territories" : "Hegoaldeko lurralde frantsesak",
    "Togo" : "Togo",
    "Thailand" : "Thailandia",
    "Tajikistan" : "Tajikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Ekialdeko Timor",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisia",
    "Tonga" : "Tonga",
    "Turkey" : "Turkia",
    "Trinidad and Tobago" : "Trinidad eta Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "Taiwan",
    "Tanzania, United Republic of" : "Tanzaniako Errepublika Batua",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Ameriketako Estatu Batuetako itsasoz haraindiko uharteak",
    "United States of America" : "Ameriketako Estatu Batuak",
    "Uruguay" : "Uruguai",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Vatikanoa",
    "Saint Vincent and the Grenadines" : "Saint Vincent eta Grenadinak",
    "Venezuela, Bolivarian Republic of" : "Venezuelako Bolibartar Errepublika",
    "Virgin Islands, British" : "Birjina Uharte Britaniarrak",
    "Virgin Islands, U.S." : "Birjina Uharte Estatubatuarrak",
    "Viet Nam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis eta Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Yemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Hegoafrika",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Background blur" : "Atzeko planoaren lausotzea",
    "Federation" : "Federazioa",
    "High-performance backend" : "Errendimendu handiko motorra",
    "Error: Cannot connect to server" : "Errorea: Ezin da zerbitzarira konektatu",
    "Error: Server did not respond with proper JSON" : "Errorea: zerbitzariak ez du JSON egokiarekin erantzun",
    "Error: Certificate expired" : "Errorea: Ziurtagiria iraungi da",
    "Could not get version" : "Ezin bertsioa lortu",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Errorea: exekutatzen ari den bertsioa: {version}; Zerbitzaria eguneratu egin behar da Talk-en bertsio honekin bateragarria izan dadin",
    "Error: Server responded with: {error}" : "Errorea: zerbitzariak {error} errorearekin erantzun du",
    "Error: Unknown error occurred" : "Errorea: errore ezezaguna gertatu da",
    "Recording backend" : "Atzealdeko grabaketa",
    "SIP configuration" : "SIP konfigurazioa",
    "Invalid date, date format must be YYYY-MM-DD" : "Data baliogabea, dataren formatuak UUUU-HH-EE izan behar du",
    "Conversation not found" : "Elkarrizketa ez da aurkitu",
    "Path is already shared with this conversation" : "Bidea dagoeneko partekatu da elkarrizketa honekin",
    "Chat, video & audio-conferencing using WebRTC" : "Txata, bideo-konferentziak eta audio-konferentziak WebRTC erabiliz",
    "Leave call" : "Utzi deia",
    "Navigating away from the page will leave the call in {conversation}" : "Orritik kanpora nabigatzeak {conversation}(e)ko deitik ateratzea eragingo du",
    "Stay in call" : "Mantendu deian",
    "Discuss this file" : "Eztabaidatu fitxategi hau",
    "Share this file with others to discuss it" : "Partekatu fitxategi hau besteekin eztabaidatzeko",
    "Share this file" : "Partekatu fitxategi hau",
    "Join conversation" : "Batu elkarrizketara",
    "This conversation is password-protected." : "Elkarrizketa hau pasahitz bidez babestua dago.",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "Saioa hasteko hainbat saiakera baliogabe jaso ditugu zure IPtik. Ondorioz, zure hurrengo saio hasiera 30 segundo atzeratuko da.",
    "The password is wrong. Try again." : "Pasahitza okerra da. Saiatu berriro.",
    "Password" : "Pasahitza",
    "Submit" : "Bidali",
    "Error requesting the password." : "Errorea pasahitza eskatzean.",
    "Request password" : "Eskatu pasahitza",
    "This conversation has ended" : "Elkarrizketa hau amaitu da",
    "Error occurred when joining the conversation" : "Errorea gertatu da elkarrizketara sartzean",
    "Close Talk sidebar" : "Itxi Talk alboko barra",
    "Open Talk sidebar" : "Ireki Talk alboko barra",
    "Everyone" : "Edonor",
    "Users and moderators" : "Erabiltzaileak eta moderatzaileak",
    "Moderators only" : "Moderatzaileak soilik",
    "Disable calls" : "Desgaitu deiak",
    "Save changes" : "Gorde aldaketak",
    "Saving …" : "Gordetzen …",
    "Saved!" : "Gordeta!",
    "Limit to groups" : "Mugatu taldeetara",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Gutxienez talde bat hautatuta badago, zerrendatutako taldeetako pertsonek soilik parte har dezakete elkarrizketetan.",
    "Guests can still join public conversations." : "Gonbidatuek elkarrizketa publikoekin bat egin dezakete hala ere.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Jada Talk erabili ezin duten erabiltzaileak parte-hartzaile bezala agertuko dira beren aurreko elkarrizketetan eta beren txateko mezuak ere gordeko dira.",
    "Limit using Talk" : "Mugatu Elkarrizketen erabilera",
    "Limit creating a public and group conversation" : "Mugatu elkarrizketa publikoak eta talde-elkarrizketak sortzea",
    "Limit creating conversations" : "Mugatu elkarrizketen sortzea",
    "Limit starting a call" : "Mugatu dei bat hastea",
    "Limit starting calls" : "Mugatu deiak hastea",
    "When a call has started, everyone with access to the conversation can join the call." : "Dei bat hastean, elkarrizketara sarbidea duen edonork bat egin dezake deiarekin.",
    "Description is not provided" : "Ez da deskribapenik eskaini",
    "Locked for moderators" : "Moderatzaileentzat blokeatuta",
    "Enabled" : "Gaituta",
    "Disabled" : "Desaktibatua",
    "Bots settings" : "Bots ezarpenak",
    "State" : "Egoera",
    "Name" : "Izena",
    "Last error" : "Azken errorea",
    "Total errors count" : "Errore zenbaki totala",
    "Find more bots" : "Bilatu bot gehiago",
    "Beta" : "Beta",
    "Enable Federation in Talk app" : "Gaitu federazioa Talk aplikazioan",
    "Permissions" : "Baimenak",
    "Allow users to be invited to federated conversations" : "Eman baimena zure erabiltzaileei elkarrizketa federatuetara joateko",
    "Allow users to invite federated users into conversation" : "Eman baimena zure erabiltzaileei beste erabiltzaile federatu batzuk elkarrizketara gonbidatzeko",
    "Only allow to federate with trusted servers" : "Fidagarritzat jotako zerbitzariekin bakarrik baimendu federazioa",
    "Select groups …" : "Hautatu taldeak ...",
    "All messages" : "Mezu guztiak",
    "@-mentions only" : "@ aipamenak soilik",
    "Off" : "Desaktibatu",
    "General settings" : "Ezarpen orokorrak",
    "Default notification settings" : "Jakinarazpenen ezarpen lehenetsiak",
    "Default group notification" : "Taldeen ezarpen lehenetsiak",
    "Default group notification for new groups" : "Taldeen ezarpen lehenetsiak talde berrientzat",
    "Integration into other apps" : "Beste aplikazioetan integrazioa",
    "Allow conversations on files" : "Baimendu elkarrizketak fitxategietan",
    "Allow conversations on public shares for files" : "Baimendu elkarrizketak fitxategien partekatze publikoetan",
    "Enable encryption" : "Gaitu zifratzea",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "Goiko botoian klik eginez inprimakiko informazioa Struktur AG-ren zerbitzarietara bidaltzen da. Informazio gehiago jaso dezakezu hemen {linkstart}spreed.eu{linkend}.",
    "Pending" : "Zain",
    "Error" : "Errorea",
    "Blocked" : "Blokeatuta",
    "Active" : "Aktiboa",
    "Expired" : "Iraungita",
    "Never" : "Inoiz ez",
    "The trial could not be requested. Please try again later." : "Ezin izan da proba eskaera egin. Saiatu berriro beranduago.",
    "The account could not be deleted. Please try again later." : "Ezin izan da kontua ezabatu. Saiatu berriro beranduago.",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Gure kide Struktur AG-ek eskaintzen duen zerbitzuaren baitan, ostataturiko seinalizazio zerbitzaria eska daiteke. Horretarako, beheko inprimakia betetzea besterik ez duzu eta zure Nextcloudak eskaera egingo du. Zerbitzaria konfiguratzen denean kredentzialak automatikoki beteko dira. Honek uneko seinalizazio zerbitzariaren ezarpenak gainidatziko ditu.",
    "URL of this Nextcloud instance" : "Nextcloud instantzia honen URLa",
    "Full name of the user requesting the trial" : "Proba eskatzen duen erabiltzailearen izen osoa",
    "Email of the user" : "Erabiltzailearen e-posta",
    "Language" : "Hizkuntza",
    "Country" : "Herrialdea",
    "Request signaling server trial" : "Eskatu seinalizazio zerbitzari proba",
    "You can see the current status of your hosted signaling server in the following table." : "Ondorengo taulan ikus dezakezu zure ostataturiko seinalizazio zerbitzariaren uneko egoera.",
    "Status" : "Egoera",
    "Created at" : "Sortua",
    "Expires at" : "Iraungitze data",
    "Limits" : "Mugak",
    "Yes" : "Bai",
    "No" : "Ez",
    "Delete the signaling server account" : "Ezabatu seinalizazio zerbitzariaren kontua",
    "_%n user_::_%n users_" : ["erabiltzaile %n ","%n erabiltzaile"],
    "Installed version: {version}" : "Instalaturiko bertsioa: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "Matterbridge instala dezakezu Nextcloud Talk beste zerbitzu batzuekin lotzeko, joan {linkstart1}GitHub orrira{linkend} xehetasun gehiagorako. Aplikazioak deskargatu eta instalatzeko denbora behar lezake. Denbora-muga gainditzen badu, saiatu eskuz instalatzen {linkstart2}appstoretik{linkend}.",
    "Matterbridge binary was not found or couldn't be executed." : "Matterbridge bitarra ez da aurkitu edo ezin izan da exekutatu.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Matterbridge bitarrerako bidea eskuz ere konfigura dezakezu konfigurazioaren bidez. Informazio gehiago lortzeko, begiratu {linkstart}Matterbridge integrazio dokumentazioa {linkend}.",
    "Downloading …" : "Deskargatzen...",
    "Install Talk Matterbridge" : "Instalatu Talk Matterbridge",
    "An error occurred while installing the Matterbridge app" : "Errore bat gertatu da Matterbridge aplikazioa instalatzean",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "Errore bat gertatu da Talk Matterbridge instalatzean. Instala ezazu eskuz",
    "Failed to execute Matterbridge binary." : "Matterbridge bitarra exekutatzeak huts egin du.",
    "Matterbridge integration" : "Matterbridge integrazioa",
    "Enable Matterbridge integration" : "Gaitu Matterbridge integrazioa",
    "Status: Checking connection" : "Egoera: konexioa egiaztatzen",
    "OK: Running version: {version}" : "OK: {version} bertsioa exekutatzen",
    "Recording backend URL" : "Atzealdeko URLa grabatzen",
    "Validate SSL certificate" : "Balioztatu SSL ziurtagiria",
    "Delete this server" : "Ezabatu zerbitzari hau",
    "Test this server" : "Probatu zerbitzari hau",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "\"upload_max_filesize\" edo \"post_max_size\" PHP ezarpenek {maxUpload} arteko fitxategiak igotzeko aukera emango dute soilik.",
    "Recording backend settings saved" : "Atzealdeko grabaketa ezarpena gordeta",
    "Add a new recording backend server" : "Gehitu atzealdeko zerbitzari grabaketa berri bat",
    "Shared secret" : "Partekatutako sekretua",
    "Recording consent" : "Grabatzeko baimena",
    "Recording transcription" : "Transkripzioa grabatzen",
    "SIP configuration saved!" : "SIP konfigurazioa gorde da!",
    "Restrict SIP configuration" : "Murriztu SIP konfigurazioa",
    "Enable SIP configuration" : "Gaitu SIP konfigurazioa",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Honako taldeetako erabiltzaileek bakarrik gaitu dezakete SIP, beraiek moderatzen dituzten elkarrizketetan",
    "Phone number (Country)" : "Telefono zenbakia (Herrialdea)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Informazio hau gonbidapen emailetan bidaltzen da eta parte-hartzaile guztiei bistaratzen zaie alboko barran.",
    "Error code" : "Errore kodea",
    "High-performance backend URL" : "Errendimendu handiko motorraren URLa",
    "High-performance backend settings saved" : "Errendimendu handiko atzealdekoaren ezarpenak gorde dira",
    "STUN server URL" : "STUN zerbitzariaren URLa",
    "The server address is invalid" : "Zerbitzariaren helbidea baliogabea da",
    "STUN settings saved" : "STUN ezarpenak gorde dira",
    "STUN servers" : "STUN zerbitzariak",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN zerbitzaria bideratzaile baten atzean dauden parte-hartzaileen IP helbideak zehazteko erabiltzen da.",
    "Add a new STUN server" : "Gehitu STUN zerbitzari berri bat",
    "{schema} scheme must be used with a domain" : "{schema} eskema domeinu batekin erabili behar da",
    "{option1} and {option2}" : "{option1} eta {option2}",
    "{option} only" : "{option} soilik",
    "OK: Successful ICE candidates returned by the TURN server" : "OK: baliozko ICE hautagaiak itzuli ditu TURN zerbitzariak",
    "Error: No working ICE candidates returned by the TURN server" : "Errorea: TURN zerbitzariak ez du baliozko ICE hautagairik itzuli",
    "Testing whether the TURN server returns ICE candidates" : "TURN zerbitzariak ICE hautagairik itzultzen duen aztertzen",
    "TURN server schemes" : "TURN zerbitzariaren eskemak",
    "TURN server URL" : "TURN zerbitzariaren URLa",
    "TURN server secret" : "TURN zerbitzariaren sekretua",
    "TURN server protocols" : "TURN zerbitzariaren protokoloak",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "TURN zerbitzariak suhesi baten atzeko partaideen trafikoa bideratzeko erabiltzen dira. Partaideek ezin badute beraien artean konektatu, TURN zerbitzari bat beharrezkoa da seguru aski. Ikusi {linkstart}dokumentazio hau{linkend} konfigurazio jarraibideak jasotzeko.",
    "TURN settings saved" : "TURN ezarpenak gorde dira",
    "TURN servers" : "TURN zerbitzariak",
    "Add a new TURN server" : "Gehitu TURN zerbitzari berri bat",
    "Failed" : "Huts egin du",
    "OK" : "Ados",
    "Checking …" : "Egiaztatzen ...",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "Huts egin du: WebAssembly desgaituta dago edo ez da onartzen arakatzaile honetan. Gaitu WebAssembly edo erabili hartarako laguntza duen arakatzaile bat egiaztapena egiteko.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "Huts egin du: \".wasm\" eta \".tflite\" fitxategiak ez ditu behar bezala itzuli web zerbitzariak. Egiaztatu Talk-en dokumentazioan \"Sistemaren eskakizunak\" atala.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "Ados: \".wasm\" eta \".tflite\" fitxategiak behar bezala itzuli ditu web zerbitzariak.",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "Badirudi PHP eta Apache konfigurazioa ez dela bateragarria. Mesedez, kontuan hartu PHP MPM_PREFORK moduluarekin soilik erabili daitekela and PHP-FPM MPM_EVENT moduluarekin erabili daitekela.",
    "Web server setup checks" : "Web zerbitzariaren konfigurazio egiaztapenak",
    "Federated user" : "Erabiltzaile federatua",
    "Assign participants to rooms" : "Esleitu parte-hartzaileak geletara",
    "Configure breakout rooms" : "Konfiguratu taldekako gelak",
    "Number of breakout rooms" : "Taldekako-gela kopurua",
    "Assignment method" : "Esleitzeko modua",
    "Automatically assign participants" : "Parte-hartzaileak automatikoki esleitu",
    "Manually assign participants" : "Parte-hartzaileak eskuz esleitu ",
    "Allow participants to choose" : "Baimendu parte-hartzaileek aukera dezaten",
    "Create rooms" : "Sortu gelak",
    "Confirm" : "Berretsi",
    "Create breakout rooms" : "Sortu taldekako gelak",
    "Reset" : "Berrezarri",
    "Delete breakout rooms" : "Ezabatu taldekako gelak",
    "Room {roomNumber}" : "{roomNumber} gela",
    "Current breakout rooms and settings will be lost" : "Uneko taldekako gelak eta ezarpenak galduko dira",
    "Cancel" : "Utzi",
    "Unassigned participants" : "Esleitu gabeko parte-hartzaileak",
    "Back" : "Atzera",
    "Assign" : "Esleitu",
    "Add participant \"{user}\"" : "Gehitu \"{user}\" parte-hartzailea",
    "Now" : "Orain",
    "Loading …" : "Kargatzen ...",
    "From" : "Nork",
    "To" : "Nori",
    "Calendar" : "Egutegia",
    "Attendees" : "Partaideak",
    "Save" : "Gorde",
    "Search participants" : "Bilatu parte-hartzaileak",
    "No results" : "Emaitzarik ez",
    "Done" : "Egina",
    "Raise hand" : "Jaso eskua",
    "Raise hand (R)" : "Jaso eskua (R)",
    "Lower hand" : "Jaitsi eskua",
    "Lower hand (R)" : "Jaitsi eskua (R)",
    "Exit full screen (F)" : "Irten pantaila osotik (F)",
    "Full screen (F)" : "Pantaila osoa (F)",
    "Speaker view" : "Hizlari ikuspegia",
    "Grid view" : "Sareta ikuspegia",
    "Recording consent is required" : "Grabatzeko baimena behar da",
    "This conversation is read-only" : "Elkarrizketa hau irakurtzeko soilik da",
    "Conversation not found or not joined" : "Elkarrizketa ez da aurkitu edo ez da sartu",
    "Connection failed" : "Konexioak huts egin du",
    "Reload" : "Birkargatu",
    "{nickName} raised their hand." : "{nickName} eskua jaso du.",
    "A participant raised their hand." : "Parte-hartzaile batek eskua jaso du",
    "Collapse stripe" : "Tolestu marra",
    "Expand stripe" : "Zabaldu marra",
    "Previous page of videos" : "Bideoen aurreko orria",
    "Next page of videos" : "Bideoen hurrengo orria",
    "Connecting …" : "Konektatzen ...",
    "Calling …" : "Deitzen ...",
    "Waiting for {user} to join the call" : "{user} deian sartzeko zain",
    "Waiting for others to join the call …" : "Besteak deira batzeko itxaroten...",
    "You can invite others in the participant tab of the sidebar" : "Besteak gonbidatu ditzakezu alboko barrako parte-hartzaileak fitxan",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Besteak gonbidatu ditzakezu alboko barrako parte-hartzaileak fitxan edo esteka hau partekatuz!",
    "Share this link to invite others!" : "Partekatu esteka hau besteak gonbidatzeko!",
    "Copy link" : "Kopiatu esteka",
    "You are not allowed to enable audio" : "Ez duzu baimenik audioa gaitzeko",
    "No audio. Click to select device" : "Audiorik ez. Egin klik gailua hautatzeko",
    "Mute audio" : "Mututu audioa",
    "Mute audio (M)" : "Isildu audioa (M)",
    "Unmute audio" : "Gaitu audioa",
    "Unmute audio (M)" : "Aktibatu audioa (M)",
    "None" : "Bat ere ez",
    "Access to camera was denied" : "Kamerara sarbidea ukatu da",
    "Error while accessing camera: It is likely in use by another program" : "Errorea kamera atzitzean: litekeena da beste programa bat hura erabiltzen aritzea",
    "Error while accessing camera" : "Errorea kamera atzitzean",
    "You have been muted by a moderator" : "Moderatzaile batek isilarazi zaitu",
    "Hide presenter video" : "Ezkutatu aurkezlearen bideoa",
    "You are not allowed to enable video" : "Ez duzu baimenik bideoa gaitzeko",
    "No video. Click to select device" : "Bideorik ez. Egin klik gailua hautatzeko",
    "Disable video" : "Desgaitu bideoa",
    "Disable video (V)" : "Desgaitu bideoa (V)",
    "Enable video" : "Gaitu bideoa",
    "Enable video (V)" : "Gaitu bideoa (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Gaitu bideoa - Zure konexioa momentu bat etengo da bideoa lehenengo aldiz gaitzean",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Gaitu bideoa (V) - Zure konexioa une labur batez etengo da bideoa lehen aldiz gaitzean",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Gaitu bideoa. Zure konexioa momentu bat etengo da bideoa lehenengo aldiz gaitzean",
    "Show presenter" : "Erakutsi aurkezlea",
    "You" : "Zu ",
    "Mute" : "Isilarazi",
    "Muted" : "Isilduta",
    "Show screen" : "Erakutsi pantaila",
    "Stop following" : "Utzi jarraitzeari",
    "Connection could not be established …" : "Ezin izan da konexioa ezarri ...",
    "Connection was lost and could not be re-established …" : "Konexioa galdu da eta ezin izan da berriro ezarri ...",
    "Connection could not be established. Trying again …" : "Konexioa ezin izan da ezarri. Berriro saiatzen ...",
    "Connection lost. Trying to reconnect …" : "Konexioa galdu da. Birkonektatzen saiatzen ...",
    "Connection problems …" : "Konexio arazoak ...",
    "Collapse" : "Tolestu",
    "Expand" : "Zabaldu",
    "You need to be logged in to upload files" : "Fitxategiak igo ahal izateko saioa hasi behar duzu",
    "Drop your files to upload" : "Jaregin zure fitxategiak igotzeko",
    "Conversation messages" : "Elkarrizketa mezuak",
    "Scroll to bottom" : "Korritu beherantz",
    "Post message" : "Argitaratu mezua",
    "Federated conversation" : "Elkarrizketa federatua",
    "Public conversation" : "Elkarrizketa publikoa",
    "Favorite" : "Gogokoa",
    "Banned users" : "Debekatutako erabiltzaileak",
    "Manage bans" : "Kudeatu debekuak",
    "No banned users" : "Ez dago debekatutako erabiltzailerik",
    "Banned by:" : "Honek debekatuta:",
    "Date:" : "Data:",
    "Note:" : "Oharra:",
    "Hide details" : "Ezkutatu xehetasunak",
    "Show details" : "Erakutsi xehetasunak",
    "Unban" : "Debekua kendu",
    "Error while updating conversation name" : "Errore bat gertatu da elkarrizketaren izena eguneratzean",
    "Error while updating conversation description" : "Errorea elkarrizketa deskribapena eguneratzen",
    "Enter a name for this conversation" : "Idatzi izen bat elkarrizketa honetarako",
    "Edit conversation name" : "Editatu elkarrizketaren izena",
    "Edit conversation description" : "Editatu elkarrizketaren deskribapena",
    "Enter a description for this conversation" : "Sartu deskribapen bat elkarrrizketa honentzat",
    "Picture" : "Irudia",
    "Disable" : "Desaktibatu",
    "Enable" : "Aktibatu",
    "Breakout rooms" : "Taldekako gelak",
    "Manage breakout rooms" : "Kudeatu taldekako gelak",
    "Set up breakout rooms for this conversation" : "Konfiguratu taldekako gelak elkarrizketa honetarako",
    "Please select a valid PNG or JPG file" : "Mesedez, hautatu baliozko PNG edo JPG fitxategi bat",
    "Choose your conversation picture" : "Aukeratu zure elkarrizketaren irudia",
    "Choose" : "Aukeratu",
    "Error setting conversation picture" : "Errorea elkarrizketaren irudia ezartzean",
    "Set emoji as conversation picture" : "Ezarri emojia elkarrizketa-irudi gisa",
    "Upload conversation picture" : "Igo elkarrizketaren irudia",
    "Choose conversation picture from files" : "Aukeratu elkarrizketaren irudia fitxategietatik",
    "Remove conversation picture" : "Kendu elkarrizketaren irudia",
    "The file must be a PNG or JPG" : "Fitxategiak PNG edo JPG izan behar du",
    "Set picture" : "Ezarri irudia",
    "Default permissions modified for {conversationName}" : "Lehenetsitako baimenak aldatu dira {conversationName}(r)entzat",
    "Could not modify default permissions for {conversationName}" : "Ezin izan dira {conversationName}(r)en baimenak aldatu",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Editatu elkarrizketa honen baimen lehenetsiak parte-hartzaileentzat. Ezarpen hauek ez dituzte moderatzaileen baimenak aldatzen.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Atal honetako baimenak aldatzen diren bakoitzean, parte-hartzaileei esleitutako baimen pertsonalizatuak galduko dira.",
    "All permissions" : "Baimen guztiak",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Parte-hartzaileek dei bat hasi, sartu, audioa eta bideoa gaitu eta pantaila partekatzeko baimenak dituzte.",
    "Restricted" : "Mugatua",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Parte-hartzaileek deietara sartzeko baimena dute, baina ezin dute audio edo bideoa gaitu edo pantaila partekatu moderatzaile batek baimen hauek eman arte.",
    "Advanced permissions" : "Baimen aurreratuak",
    "Edit permissions" : "Editatu baimenak",
    "Conversation settings" : "Elkarrizketaren ezarpenak",
    "Basic Info" : "Oinarrizko informazioa",
    "Personal" : "Pertsonala",
    "Moderation" : "Moderazioa",
    "Setup overview" : "Konfigurazioaren ikuspegi orokorra",
    "Breakout Rooms" : "Taldekako gelak",
    "Matterbridge" : "Matterbridge",
    "Bots" : "Bot-ak",
    "Danger zone" : "Arrisku eremua",
    "Archive conversation" : "Artxibatu elkarrizketa",
    "Leave conversation" : "Atera elkarrizketatik",
    "You need to promote a new moderator before you can leave the conversation" : "Moderatzaile berri bat sustatu behar duzu elkarrizketatik irten aurretik",
    "Delete conversation" : "Ezabatu elkarrizketa",
    "Do you really want to delete \"{displayName}\"?" : "Ziur zaude \"{displayName}\" ezabatu nahi duzula?",
    "Error while deleting conversation" : "Errorea elkarrizketa ezabatzen",
    "Delete all chat messages" : "Ezabatu txateko mezu guztiak",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Ziur zaude \"{displayName}\" elkarrizketako mezu guztiak ezabatu nahi dituzula?",
    "Error while clearing chat history" : "Errorea txataren historia garbitzen",
    "Be careful, these actions cannot be undone." : "Kontuz ibili, ekintza hauek ezin dira desegin.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Elkarrizketa uzten denean, elkarrizketa itxi batera berriro sartzeko, gonbidapen bat behar da. Elkarrizketa ireki batean edozein unetan sar daiteke berriro.",
    "Permanently delete this conversation." : "Betirako ezabatu elkarrizketa hau.",
    "Delete chat messages" : "Ezabatu txateko mezuak",
    "Permanently delete all the messages in this conversation." : "Ezabatu betirako elkarrizketa honen mezu guztiak.",
    "_%n hour_::_%n hours_" : ["%nordu","%n"],
    "_%n day_::_%n days_" : ["egun %n","%n egun"],
    "_%n week_::_%n weeks_" : ["aste %n","%n aste"],
    "Custom expiration time" : "Iraungitze denbora pertsonalizatua",
    "Message expiration disabled" : "Mezua iraungitzea desgaituta dago",
    "Message expiration set: {duration}" : "Mezuaren iraungitze ezarria: {duration}",
    "Error when trying to set message expiration" : "Errore bat gertatu da mezu-iraungipena ezartzen saiatzean",
    "Message expiration" : "Mezuen iraungitzea",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Txat-mezuak denbora jakin baten ondoren iraungi daitezke. Oharra: txatean partekatutako fitxategiak ez dira jabearentzat ezabatuko, baina ez dira gehiago elkarrizketan partekatuko.",
    "Set message expiration" : "Ezarri mezuaren iraungitzea",
    "Current message expiration" : "Uneko mezuaren iraungitzea",
    "Guest access" : "Gonbidatuen sarbidea",
    "Allow guests to join this conversation via link" : "Onartu gonbidatuei elkarrizketa honetan esteka bidez sartzea",
    "Password protection" : "Pasahitz bidezko babesa",
    "Set a password" : "Ezarri pasahitz bat",
    "Change password" : "Pasahitza aldatu",
    "Enter new password" : "Sartu pasahitz berria",
    "Save password" : "Gorde pasahitza",
    "Copy password" : "Kopiatu pasahitza",
    "Guests are allowed to join this conversation via link" : "Gonbidatuek baimena dute elkarrizketa honetan sartzeko esteka bidez",
    "Guests are not allowed to join this conversation" : "Gonbidatuek ezin dute elkarrizketa honetan sartu esteka bidez",
    "Resend invitations" : "Birbidali gonbidapenak",
    "This conversation is open to both registered users and users created with the Guests app" : "Elkarrizketa hau irekita dago bai erregistraturiko erabiltzaileentzat eta baita Gonbidatuak aplikazioaren bidez sorturiko erabiltzaileentzat ere",
    "You opened the conversation to both registered users and users created with the Guests app" : "Elkarrizketa ireki duzu bai erregistraturiko erabiltzaileentzat eta baita Gonbidatuak aplikazioaren bidez sorturiko erabiltzaileentzat ere",
    "Error occurred when opening or limiting the conversation" : "Errorea gertatu da elkarrizketa mugatu edo irekitzean",
    "Open conversation to registered users, showing it in search results" : "Ireki elkarrizketa erregistratutako erabiltzaileei, bilaketen emaitzetan erakutsiaz.",
    "Also open to users created with the Guests app" : "Irekita dago baita ere Gonbidatuak aplikazioak sorturiko erabiltzaileentzat",
    "Open conversation" : "Ireki elkarrizketa",
    "Invalid language" : "Hizkuntza baliogabea",
    "Start time: {date}" : "Hasiera-ordua: {date}",
    "Start time has been updated" : "Hasiera-data aldatu da",
    "Error occurred while updating start time" : "Errorea gertatu da hasiera ordua eguneratzean",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "Ataria gaitzean uneko deiko ez-moderatzaileak kanporatuko dira.",
    "Enable lobby, restricting the conversation to moderators" : "Gaitu ataria, elkarrizketa moderatzaileetara murriztuz",
    "Meeting start time" : "Bileraren hasiera-ordua",
    "Start time (optional)" : "Hasiera-ordua (hautazkoa)",
    "Import email participants" : "Inportatu e-postako partaideak",
    "Poll drafts" : "Galdeketa zirriborroak",
    "Browse poll drafts" : "Arakatu galdeketa-zirriborroak",
    "Error occurred when locking the conversation" : "Errorea gertatu da elkarrizketa blokeatzean",
    "Error occurred when unlocking the conversation" : "Errorea gertatu da elkarrizketa desblokeatzean",
    "Lock conversation" : "Blokeatu elkarrizketa",
    "This will also terminate the ongoing call." : "Honek hasita dagoen deia ere bukatuko du.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Blokeatu elkarrizketa edonork mezuak idatzi edo deiak egitea ekiditeko",
    "Edit" : "Editatu",
    "More information" : "Informazio gehiago",
    "Delete" : "Ezabatu",
    "Add new bridged channel to current conversation" : "Gehitu zubidun kanal berria uneko elkarrizketari",
    "unknown state" : "egoera ezezaguna",
    "running" : "Exekutatzen",
    "not running, check Matterbridge log" : "ez dabil, egiaztatu Matterbridge erregistroa",
    "not running" : "Ez da exekutatzen ari",
    "Bridge saved" : "Zubia ondo gorde da",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Berehalako mezularitza sistema ugaritako kanalen artean zubiak ezar ditzakezu Matterbridge erabiliz.",
    "More info on Matterbridge" : "Informazio gehiago Matterbridge-en",
    "Messaging systems" : "Mezularitza sistema",
    "Enable bridge" : "Gaitu zubia",
    "Show Matterbridge log" : "Erakutsi Matterbridge erregistroa",
    "Log content" : "Log edukia",
    "Allow participants to mention @all" : "Baimendu parte-hartzaileek @all aipatu dezaten",
    "Mention permissions" : "Aipatze-baimenak",
    "Notifications" : "Jakinarazpenak",
    "Notify about calls in this conversation" : "Jakinarazi elkarrizketa honen deiei buruz",
    "Important conversation" : "Elkarrizketa garrantzitsua",
    "Recording Consent" : "Grabatzeko baimena",
    "Require recording consent before joining call in this conversation" : "Eskatu grabatzeko baimena elkarrizketa honetako deian sartu aurretik",
    "Recording consent is required for all calls" : "Dei guztietan grabatzeko baimena behar da",
    "SIP dial-in is now possible without PIN requirement" : "SIP markatzea posible da orain PIN baldintzarik gabe",
    "SIP dial-in is now enabled" : "SIP markatzea gaituta dago",
    "SIP dial-in is now disabled" : "SIP markatzea desgaituta dago",
    "Error occurred when enabling SIP dial-in" : "Errorea gertatu da SIP markatzea gaitzean",
    "Error occurred when disabling SIP dial-in" : "Errorea gertatu da SIP markatzea desgaitzean",
    "Phone and SIP dial-in" : "Telefonoa eta SIP markatzea",
    "Enable phone and SIP dial-in" : "Gaitu telefonoa eta SIP markatzea",
    "Allow to dial-in without a PIN" : "Baimendu PINik gabe deitzeko",
    "Join" : "Batu",
    "Error while creating the conversation" : "Errorea elkarrizketa sortzean",
    "Create a new conversation" : "Sortu elkarrizketa berri bat",
    "Join open conversations" : "Sartu elkarrizketa irekietara",
    "Unread mentions" : "Irakurri gabeko aipamenak",
    "Create conversation" : "Sortu elkarrizketa",
    "Enter your name" : "Sartu zure izena",
    "Submit name and join" : "Bidali izena eta sartu",
    "Log in" : "Izena eman",
    "Import a file" : "Inportatu fitxategi bat",
    "Browse" : "Arakatu",
    "This might take a moment" : "Momentu bat beharko da",
    "Send invitations" : "Bidali gonbidapenak",
    "Mark as read" : "Markatu irakurri gisa",
    "Mark as unread" : "Markatu ez irakurri gisa",
    "Remove from favorites" : "Kendu gogokoetatik",
    "Add to favorites" : "Gehitu gogokoetara",
    "Unarchive conversation" : "Desartxibatu elkarrizketa",
    "You need to promote a new moderator before you can leave the conversation." : "Moderatzaile berri bat izendatu behar duzu elkarrizketa utzi ahal izateko.",
    "Conversation actions" : "Elkarrizketa ekintzak",
    "Notify about calls" : "Jakinarazi deiei buruz",
    "Pending invitations" : "Bidaltzeko gonbidapenak",
    "Decline invitation" : "Bazteztu gonbidapena",
    "Accept invitation" : "Onartu gonbidapena",
    "No pending invitations" : "Ez duzu gonbidapenik zain",
    "Home" : "Etxea",
    "Unread" : "Irakurri gabe",
    "Alphabetically" : "Alfabetikoki",
    "No matches found" : "Ez dira emaitzarik aurkitu",
    "No conversations found" : "Ez da elkarrizketarik aurkitu",
    "An error occurred while performing the search" : "Errore bat gertatu da bilaketa egitean",
    "Conversation list" : "Elkarrizketa zerrenda",
    "Unread messages" : "Irakurri gabeko mezuak",
    "Clear filters" : "Garbitu iragazkiak",
    "New personal note" : "Nota pertsonal berria",
    "Back to conversations" : "Itzuli elkarrizketetara",
    "Archived conversations" : "Artxibatutako elkarrizketak",
    "Clear filter" : "Garbitu iragazkia",
    "App settings" : "Aplikazioaren ezarpenak",
    "Users" : "Erabiltzaileak",
    "Groups" : "Taldeak",
    "Teams" : "Lantaldeak",
    "Federated users" : "Erabiltzaile federatuak",
    "New private conversation" : "Elkarrizketa pribatu berria",
    "Other sources" : "Beste iturburuak",
    "Open conversations" : "Ireki elkarrizketak",
    "No search results" : "Ez dago bilaketaren emaitzarik",
    "Users, groups and teams" : "Erabiltzaileak, taldeak eta lantaldeak",
    "Users and groups" : "Erabiltzaileak eta taldeak",
    "Users and teams" : "Erabiltzaileak eta lantaldeak",
    "Groups and teams" : "Taldeak eta lantaldeak",
    "New group conversation" : "Talde elkarrizketa berria",
    "The meeting will start soon" : "Bilera laster hasiko da",
    "This meeting is scheduled for {startTime}" : "Bilera hau {startTime}-rako programatuta dago",
    "You are currently waiting in the lobby" : "Une honetan atondoan itxaroten ari zara",
    "Select microphone" : "Hautatu mikrofonoa",
    "No microphone available" : "Ez dago mikrofonorik eskuragarri",
    "Select camera" : "Hautatu kamera",
    "No camera available" : "Ez dago kamerarik eskuragarri",
    "Select a device" : "Hautatu gailu bat",
    "Playing …" : "Erreproduzitzen ...",
    "Test speakers" : "Probatu bozgorailuak",
    "Test" : "Proba",
    "Devices" : "Gailuak",
    "Backgrounds" : "Atzeko planoak",
    "No audio" : "Audiorik ez",
    "No camera" : "Kamerarik ez",
    "Calls are not supported in your browser" : "Deiak ez dira onartzen zure nabigatzailean",
    "Access to microphone is only possible with HTTPS" : "Mikrofonoa atzitzeko modu bakarra HTTPS bidez da",
    "Access to microphone was denied" : "Mikrofonora sarbidea ukatua da",
    "Error while accessing microphone" : "Errorea kamera atzitzean",
    "Access to camera is only possible with HTTPS" : "Kamera atzitzeko modu bakarra HTTPS bidez da",
    "The call might be recorded." : "Baliteke deia grabatzea.",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "Baliteke grabazioan zure ahotsa, kamerako bideoa eta pantaila partekatzea. Zure baimena beharrezkoa da deian sartu aurretik.",
    "Apply settings" : "Aplikatu ezarpenak",
    "Select a file" : "Hautatu fitxategi bat",
    "Invalid path selected" : "Bide baliogabea hautatuta",
    "Blur" : "Lausotu",
    "Upload" : "Igo",
    "Files" : "Fitxategiak",
    "(editing)" : "(editatzen)",
    "(edited)" : "(editatuta)",
    "The message has expired or has been deleted" : "Mezua iraungi egin da edo ezabatu egin da",
    "Cancel quote" : "Utzi eskaintza",
    "24 hours" : "24 ordu",
    "7 days" : "7 egun",
    "Clear reminder – {timeLocale}" : "Garbitu gogorarazpena – {timeLocale}",
    "Edited by {actor}" : "{actor}-(e)k editatuta",
    "A reminder was successfully removed" : "Gogorarazpena ondo ezabatu da",
    "Error occurred when removing a reminder" : "Errorea gertatu da gogorarazpena ezabatzean",
    "A reminder was successfully set at {datetime}" : "Gogorarazpena ondo ezarri da {datetime}(e)rako",
    "Error occurred when creating a reminder" : "Errorea gertatu da gogorarazpena sortzean",
    "Add a reaction to this message" : "Gehitu erreakzioa mezu honi",
    "Reply" : "Erantzun",
    "More actions" : "Ekintza gehiago",
    "Set reminder" : "Ezarri gogorarazpena",
    "Reply privately" : "Erantzun pribatuki",
    "Edit message" : "Editatu mezua",
    "Copy message link" : "Kopiatu mezuaren esteka",
    "Go to file" : "Joan fitxategira",
    "Download file" : "Deskargatu fitxategia",
    "Forward message" : "Birbidali mezua",
    "Translate" : "Itzuli",
    "Set custom reminder" : "Ezarri gogorarazpen pertsonalizatua",
    "Close reactions menu" : "Itxi erreakzio menua",
    "React with {emoji}" : "Erreakzionatu {emoji}-(r)ekin",
    "React with another emoji" : "Erreakzionatu beste emoji batekin",
    "Choose a conversation to forward the selected message." : "Hautatu elkarrizketa bat hurrengo mezua birbidaltzeko.",
    "Error while forwarding message" : "Errorea mezua birbidaltzen",
    "The message has been forwarded to {selectedConversationName}" : "Mezua {selectedConversationName}(e)ra birbidali da",
    "Dismiss" : "Baztertu",
    "Go to conversation" : "Joan elkarrizketara",
    "Detect language" : "Detektatu hizkuntza",
    "The message could not be translated" : "Ezin izan da mezu hau itzuli",
    "Translation copied to clipboard" : "Itzulpena arbelera kopiatu da",
    "Translation could not be copied" : "Ezin izan da itzulpena kopiatu",
    "Translate message" : "Itzuli mezua",
    "Translate from" : "Itzuli honetatik",
    "Translate to" : "Itzuli honetara",
    "Translating" : "Itzultzen",
    "Copy translated text" : "Kopiatu itzulitako testua",
    "Send now" : "Bidali orain",
    "Message read by everyone who shares their reading status" : "Irakurtze-egoera partekatzen duten guztiek irakurri dute mezua",
    "Message sent" : "Mezua bidalita",
    "Sent without notification" : "Jakinarazpenik gabe bidalita",
    "Deleting message" : "Mezua ezabatzen",
    "Message deleted successfully" : "Mezua ondo ezabatu da",
    "Message could not be deleted because it is too old" : "Mezua ezin izan da ezabatu zaharregia delako",
    "Only normal chat messages can be deleted" : "Txat mezu normalak soilik ezabatu daitezke",
    "An error occurred while deleting the message" : "Errore bat gertatu da mezua ezabatzean",
    "Your browser does not support playing audio files" : "Zure nabigatzaileak ez du audio fitxategiak erreproduzitzeko euskarririk",
    "Contact" : "Kontaktua",
    "{stack} in {board}" : "{stack} {board}-(e)n",
    "Deck Card" : "Deck txartela",
    "Remove {fileName}" : "Kendu {fileName}",
    "Open this location in OpenStreetMap" : "Ireki kokaleku hau OpenStreetMap-en",
    "Sending message" : "Mezua bidaltzen",
    "Failed to send the message. Click to try again" : "Mezua bidaltzeak huts egin du. Egin klik berriro saiatzeko",
    "Not enough free space to upload file" : "Ez dago nahikoa leku librerik fitxategia igotzeko",
    "You cannot send messages to this conversation at the moment" : "Une honetan ezin duzu mezurik bidali elkarrizketa honetara",
    "_%n vote_::_%n votes_" : ["Boto %n","%n boto"],
    "Delete poll draft" : "Ezabatu galdeketaren zirriborroa",
    "Open poll" : "Galdeketa irekia",
    "See results" : "Ikusi emaitzak",
    "Reactions" : "Erreakzioak",
    "No permission to post reactions in this conversation" : "Ez dago baimenik elkarrizketa honetan erreakzioak argitaratzeko",
    "and {participant}" : "eta {participant}",
    "Show all reactions" : "Erakutsi erreakzio guztiak",
    "Add more reactions" : "Gehitu erreakzio gehiago",
    "No messages" : "Mezurik ez",
    "All messages have expired or have been deleted." : "Mezu guztiak iraungita daude edo ezabatuak izan dira.",
    "Unpin" : "Kendu aingura",
    "Cancel search" : "Utzi bilaketa",
    "Create a new group conversation" : "Sortu talde-elkarrizketa berria",
    "Add participants" : "Gehitu parte-hartzaileak",
    "Conversation visibility" : "Elkarrizketaren ikusgarritasuna",
    "Allow guests to join via link" : "Baimendu gonbidatuak esteka bidez batzea",
    "Enter password" : "Sartu pasahitza",
    "This conversation has been locked" : "Elkarrizketa hau blokeatu da",
    "No permission to post messages in this conversation" : "Ez duzu baimenik mezuak argitaratzeko elkarrizketa honetan",
    "Joining conversation …" : "Elkarrizketara batzen ...",
    "Send message silently" : "Bidali mezua modu isilean",
    "Send message" : "Bidali mezua",
    "Send without notification" : "Bidali jakinarazpenik gabe",
    "File to share" : "Partekatuko den fitxategia",
    "Add emoji" : "Gehitu emojia",
    "Send later" : "Bidali geroago",
    "Cancel editing" : "Utzi editatzeari",
    "Share from {nextcloud}" : "Partekatu {nextcloud} bidez",
    "Share from Files" : "Partekatu Fitxategiak-etik",
    "Share files to the conversation" : "Partekatu fitxategiak elkarrizketan",
    "Upload from device" : "Igo gailutik",
    "Create new poll" : "Sortu inkesta berria",
    "Smart picker" : "Hautatzaile adimenduna",
    "Record voice message" : "Grabatu ahots mezua",
    "End recording and send" : "Amaitu grabazioa eta bidali",
    "Dismiss recording" : "Baztertu grabazioa",
    "Access to the microphone was denied" : "Mikrofonoa atzitzeko baimena ukatu da",
    "Microphone either not available or disabled in settings" : "Mikrofonoa ezin da atzitu edo desgaituta dago ezarpenetan",
    "Error while recording audio" : "Errorea audioa grabatzean",
    "New file" : "Fitxategi berria",
    "Blank" : "Hutsik",
    "Error while creating file" : "Errorea fitxategia sortzen",
    "Create and share a new file" : "Sortu eta partekatu fitxategi berri bat",
    "Name of the new file" : "Fitxategiaren izen berria",
    "Create file" : "Sortu fitxategia",
    "Someone is typing …" : "Norbait idazten ari da ...",
    "{user1} is typing …" : "{user1} idazten ari da …",
    "{user1} and {user2} are typing …" : "{user1} eta {user2} idazten ari dira …",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} eta {user3} idazten ari dira …",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} eta beste %n idazten ari dira …","{user1}, {user2}, {user3} eta beste %n idazten ari dira …"],
    "Add more files" : "Gehitu fitxategi gehiago",
    "Send" : "Bidali",
    "In this conversation <strong>{user}</strong> can:" : "Elkarrizketa honetan <strong>{user}</strong> ekintza hauek egin ditzake:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Editatu lehenetsitako baimenak <strong>{conversationName}</strong> elkarrizketako parte-hartzaileentzat",
    "Start a call" : "Hasi dei bat",
    "Skip the lobby" : "Saltatu ataria",
    "Can post messages and reactions" : "Mezuak eta erreakzioak bidal daitezke",
    "Enable the microphone" : "Gaitu mikrofonoa",
    "Enable the camera" : "Gaitu kamera",
    "Share the screen" : "Partekatu pantaila",
    "Update permissions" : "Eguneratu baimenak",
    "Updating permissions" : "Baimenak eguneratzen",
    "No poll drafts" : "Ez dago galdeketa zirriborrorik",
    "Create poll" : "Sortu galdeketa",
    "Question" : "Galdera",
    "Ask a question" : "Egin galdera bat",
    "Answers" : "Erantzunak",
    "Answer {option}" : "Galdera (aukera)",
    "Delete poll option" : "Ezabatu galdeketaren aukera",
    "Add answer" : "Gehitu erantzuna",
    "Settings" : "Ezarpenak",
    "Anonymous poll" : "Galdeketa anonimoa",
    "Multiple answers" : "Erantzun anitz",
    "Save as draft" : "Gorde zirriborro bezala",
    "You voted for this option" : "Aukera hau bozkatu duzu",
    "End poll" : "Amaitu galdeketa",
    "Change your vote" : "Aldatu zure botoa",
    "Results" : "Emaitzak",
    "Voted participants" : "Botoa eman duten parte-hartzaileak",
    "Send a message to \"{roomName}\"" : "Bidali mezu bat \"{roomName}\"-(e)ra",
    "Hide list of participants" : "Ezkutatu parte-hartzaile zerrenda",
    "Show list of participants" : "Erakutsi parte-hartzaile zerrenda",
    "The message was sent to \"{roomName}\"" : "Mezua \"{roomName}\"-(e)ra bidali da",
    "Send message to room" : "Bidali mezua gelara",
    "Back to main room" : "Itzuli gela nagusira",
    "Back to your room" : "Itzuli zure gelara",
    "Message all rooms" : "Bidali mezua gela guztietara",
    "Start session" : "Hasi saioa",
    "Stop session" : "Gelditu saioa",
    "The message was sent to all breakout rooms" : "Mezua taldekako gela guztietara bidali da",
    "Send a message to all breakout rooms" : "Bidali mezu bat taldekako gela guztietara",
    "Disable lobby" : "Desgaitu ataria",
    "Settings for participant \"{user}\"" : "\"{user}\" parte-hartzailearen ezarpenak",
    "Participant \"{user}\"" : "\"{user}\" parte-hartzailea",
    "moderator" : "moderatzailea",
    "bot" : "bot",
    "guest" : "gonbidatua",
    "Ringing …" : "Komunikatzen ...",
    "Call rejected" : "Deia baztertu da",
    "{time} talking …" : "{time} hitz egiten ...",
    "{time} talking time" : "{time} hitzegite-denbora",
    "Raised their hand" : "Eskua jaso dute",
    "Joined with video" : "Bideoarekin batuta",
    "Joined via phone" : "Telefonoarekin batuta",
    "Joined with audio" : "Audioarekin batuta",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "Testuak {maxLength} karaktere baino txikiagoa edo berdina izan behar du. Uneko testuak {charactersCount} karaktere ditu.",
    "Remove group and members" : "Kendu taldea eta kideak",
    "Remove team and members" : "Kendu lantaldea eta kideak",
    "Remove participant" : "Kendu parte-hartzailea",
    "Notification was sent to {displayName}" : "{displayName}-(e)ri jakinarazpena bidali zaio",
    "Could not send notification to {displayName}" : "Ezin izan da jakinarazpena bidali {displayName}-ra",
    "Permissions granted to {displayName}" : "Baimenak emanda {displayName}(r)i",
    "Could not modify permissions for {displayName}" : "Ezin izan dira {displayName}(r)en baimenak aldatu",
    "Permissions removed for {displayName}" : "Baimenak kendu zaizkio {displayName}(r)i",
    "Permissions set to default for {displayName}" : "Baimenak lehenetsira ezarri dira {displayName}-rentzat",
    "Phone number could not be muted" : "Ezin izan da telefono zenbakia isilarazi",
    "Phone number could not be unmuted" : "Ezin izan da telefono zenbakia gaitu",
    "in the lobby" : "atarian",
    "Dial out phone" : "Telefonoa itzali",
    "Hang up phone" : "Telefonoa eskegi",
    "Move to conversation" : "Mugitu elkarrizketara",
    "Dial-in PIN" : "Markatzen PINa",
    "Demote from moderator" : "Kendu moderatzaile rola",
    "Promote to moderator" : "Egin moderatzaile",
    "Resend invitation" : "Birbidali gonbidapena",
    "Send call notification" : "Bidali dei jakinarazpena",
    "Unmute phone number" : "Telefono zenbakia gaitu",
    "Mute phone number" : "Mututu telefono zenbakia",
    "Copy phone number" : "Kopiatu telefono zenbakia",
    "Reset custom permissions" : "Berezarri baimen pertsonalizatuak",
    "Grant all permissions" : "Eman baimen guztiak",
    "Remove all permissions" : "Kendu baimen guztiak",
    "Remove" : "Kendu",
    "Permissions modified for {displayName}" : "Baimenak aldatu dira {displayName}(r)entzat",
    "Add users, groups or teams" : "Gehitu erabiltzaileak, taldeak edo lantaldeak",
    "Add users or groups" : "Add users or groups",
    "Add users or teams" : "Gehitu erabiltzaileak edo lantaldeak",
    "Add users" : "Gehitu erabiltzailea",
    "Add groups or teams" : "Gehitu taldeak edo lantaldeak",
    "Add groups" : "Gehitu taldeak",
    "Add teams" : "Gehitu lantaldeak",
    "Add other sources" : "Gehitu beste iturburuak",
    "Add emails" : "Gehitu helbide elektronikoa",
    "Integrations" : "Integrazioak",
    "Add federated users" : "Gehitu erabiltzaile federatuak",
    "Searching …" : "Bilatzen …",
    "Search for more users" : "Bilatu erabiltzaile gehiago",
    "Search or add participants" : "Bilatu edo gehitu parte-hartzaileak",
    "Invitation was sent to {actorId}" : "{actorId}-(e)ri gonbidapena bidali zaio",
    "An error occurred while adding the participants" : "Errore bat gertatu da parte-hartzaileak gehitzean",
    "Participants" : "Parte-hartzaileak",
    "Participants ({count})" : "Parte-hartzaileak ({count})",
    "Open chat" : "Ireki txata",
    "You have new unread messages in the chat." : "Irakurri gabeko mezu berriak dauzkazu txatean.",
    "You have been mentioned in the chat." : "Txatean aipatu egin zaituzte.",
    "Chat" : "Txata",
    "Details" : "Xehetasunak",
    "Shared items" : "Partekatutako elementuak",
    "Until" : "Arte",
    "No results found" : "Ez da emaitzarik aurkitu",
    "Load more results" : "Kargatu emaitza gehiago ",
    "Projects" : "Proiektuak",
    "No shared items" : "Ez dago partekatutako elementurik",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Esteka elkarrizketara",
    "Search conversations or users" : "Bilatu elkarrizketak edo erabiltzaileak",
    "Select conversation" : "Hautatu elkarrizketa",
    "Phone numbers" : "Telefono zenbakiak",
    "Display name: {name}" : "Pantaila-izena: {name}",
    "Edit display name" : "Editatu erakutsiko den izena",
    "Save name" : "Gorde izena",
    "Error while saving sounds setting" : "Errorea soinu ezarpenak gordetzean",
    "Play sounds when participants join or leave a call" : "Soinuak egin parte-hartzaileak deira etortzean edo joatean",
    "Notification settings" : "Jakinarazpen-ezarpenak",
    "Default language" : "Hizkuntza lehenetsia",
    "Select location for attachments" : "Hautatu kokalekua eranskinentzat",
    "Error while setting attachment folder" : "Errorea eranskinen karpeta ezartzean",
    "Error while setting read status privacy" : "Errorea irakurtze-egoera pribatutasun ezarpenak konfiguratzean",
    "Privacy" : "Pribatutasuna",
    "Attachments folder" : "Eranskinen karpeta",
    "Toggle full screen" : "Txandakatu pantaila osoa",
    "Search" : "Bilatu",
    "Focus the chat input" : "Fokuratu txat sarrera",
    "Unfocus the chat input to use shortcuts" : "Utzi txat sarrera fokuratzeari lasterbideak erabiltzeko",
    "Shortcuts while in a call" : "Lasterbideak deian zehar",
    "Camera on and off" : "Kamera gaitu eta desgaitu",
    "Microphone on and off" : "Mikrofonoa aktibatu eta desaktibatu",
    "Raise or lower hand" : "Jaso edo jaitsi eskua",
    "Push to talk or push to mute" : "Sakatu hitz egiteko edo mututzeko",
    "Start call silently" : "Hasi deia modu isilean",
    "Start call" : "Hasi deia",
    "End call" : "Amaitu deia",
    "You will be able to join the call only after a moderator starts it." : "Moderatzaile batek deia hasten duenean bakarrik batu ahalko zara.",
    "End call for everyone" : "Amaitu deia denontzat",
    "Starting the recording" : "Grabaketa hasten",
    "Recording" : "Grabatzea",
    "The call has been running for one hour." : "Deia ordubetez egon da martxan.",
    "Cancel recording start" : "Utzi grabaketaren hasiera",
    "Stop recording" : "Utzi grabaketa",
    "Send a reaction" : "Bidali erreakzioa",
    "React with {reaction}" : "Erreakzionatu {reaction}-(r)ekin",
    "All tasks done!" : "Zeregin guztiak eginda!",
    "You are not allowed to enable screensharing" : "Ez duzu baimenik pantaila partekatzea gaitzeko",
    "No screensharing" : "Pantaila partekatzerik ez",
    "Screensharing options" : "Pantaila partekatzeko aukerak",
    "Enable screensharing" : "Gaitu pantaila partekatzea",
    "Bad sent video and screen quality." : "Bidaltze bideo eta pantaila kalitate txarra.",
    "Bad sent screen quality." : "Bidaltze pantaila kalitate txarra.",
    "Bad sent video quality." : "Bidaltze bideo kalitate txarra.",
    "Bad sent audio, video and screen quality." : "Bidaltze audio, bideo eta pantaila kalitate txarra.",
    "Bad sent audio and screen quality." : "Bidaltze audio eta pantaila kalitate txarra.",
    "Bad sent audio and video quality." : "Bidaltze audio eta bideo kalitate txarra.",
    "Bad sent audio quality." : "Bidaltze audio kalitate txarra.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Zure internet konexioa edo ordenagailua lanpetuta daude eta baliteke beste partaideek zu ulertu edo ikusteko zailtasunak izatea. Egoera hobetzeko saiatu zure atzeko planoko lausotzea edo bideoa desgaitzen pantaila partekatzen ari zarenean.",
    "Disable background blur" : "Desgaitu atzeko planoko lausotzea",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Zure internet konexioa lanpetuta dago eta baliteke beste partaideek zu ez ikustea. Egoera hobetzeko saiatu zure bideoa desgaitzen pantaila partekatzen ari zarenean.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Zure internet konexioa edo ordenagailua lanpetuta daude eta baliteke beste partaideek zure pantaila ez ikustea.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Zure internet konexioa edo ordenagailua lanpetuta daude eta baliteke beste partaideek zu ez ikustea.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Zure internet konexioa edo ordenagailua lanpetuta daude eta baliteke beste partaideek zu ulertu edo ikusteko zailtasunak izatea. Egoera hobetzeko saiatu zure atzeko planoko lausotzea edo bideoa desgaitzen pantaila partekatzen ari zarenean.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Zure internet konexioa edo ordenagailua lanpetuta daude eta baliteke beste partaideek zu ulertu edo ikusteko zailtasunak izatea. Egoera hobetzeko saiatu zure bideoa desgaitzen pantaila partekatzen ari zarenean.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Zure internet konexioa edo ordenagailua lanpetuta daude eta baliteke beste partaideek zu ulertu edo zure pantaila ikusteko zailtasunak izatea. Egoera hobetzeko saiatu pantaila partekatu gabe aritzen.",
    "Disable screenshare" : "Utzi pantaila partekatzeari",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Zure internet konexioa edo ordenagailua lanpetuta daude eta baliteke beste partaideek zu ulertu edo ikusteko zailtasunak izatea. Egoera hobetzeko saiatu zure atzeko planoko lausotzea desgaitzen zure bideoan.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Zure internet konexioa edo ordenagailua lanpetuta daude eta baliteke beste partaideek zu ulertu edo ikusteko zailtasunak izatea. Egoera hobetzeko saiatu zure bideoa desgaitzen.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Zure internet konexioa edo ordenagailua lanpetuta daude eta baliteke beste partaideek zu ulertzeko zailtasunak izatea.",
    "Screen sharing is not supported by your browser." : "Zure nabigatzaileak ez du pantaila partekatzea onartzen.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Pantaila partekatu ahal izateko orria HTTPS bidez kargatu behar da.",
    "Screensharing requires the page to be loaded through HTTPS." : "Pantaila partekatu ahal izateko orria HTTPS bidez kargatu behar da.",
    "An error occurred while starting screensharing." : "Pantaila partekatzen hastean errore bat gertatu da.",
    "Show your screen" : "Erakutsi zure pantaila",
    "Stop screensharing" : "Utzi pantaila partekatzeari",
    "Mute others" : "Mututu besteak",
    "Start recording" : "Hasi grabatzen",
    "Set up breakout rooms" : "Konfiguratu taldekako gelak",
    "Open Calendar" : "Ireki egutegia",
    "Remove participant {name}" : "Kendu {name} parte-hartzailea",
    "Open dialpad" : "Ireki markatze-teklatua",
    "Select a region" : "Hautatu eskualde bat",
    "Search …" : "Bilatu …",
    "Message without mention" : "Aipamenik gabeko mezua",
    "Mention myself" : "Aipatu ni",
    "Mention everyone" : "Aipatu denak",
    "Select a conversation" : "Hautatu elkarrizketa bat",
    "Select a mode" : "Hautatu modu bat",
    "The conversation does not exist" : "Elkarrizketa ez da existitzen",
    "Join a conversation or start a new one!" : "Batu elkarrizketa batera edo hasi berri bat!",
    "Duplicate session" : "Bikoiztu saioa",
    "Join a conversation or start a new one" : "Batu elkarrizketa batera edo hasi berri bat",
    "Nextcloud URL" : "Nextcloud URLa",
    "Nextcloud user" : "Nextcloud erabiltzailea",
    "User password" : "Erabiltzaile pasahitza",
    "Talk conversation" : "Talk elkarrizketa",
    "Skip TLS verification" : "Ez egiaztatu TLS",
    "Matrix server URL" : "Matrix zerbitzariaren URLa",
    "User" : "Erabiltzailea",
    "Matrix channel" : "Matrix kanala",
    "Mattermost server URL" : "Mattermost zerbitzariaren URLa",
    "Mattermost user" : "Mattermost erabiltzailea",
    "Team name" : "Lantaldearen izena",
    "Channel name" : "Kanalaren izena",
    "Rocket.Chat server URL" : "Rocket.Chat zerbitzariraren URLa",
    "User name or email address" : "Erabiltzaile-izena edo e-posta helbidea",
    "Rocket.Chat channel" : "Rocket.Chat kanala",
    "Zulip server URL" : "Zulip zerbitzariaren URLa",
    "Bot user name" : "Bot-aren erabiltzaile izena",
    "Bot API key" : "Bot-aren API gakoa",
    "Zulip channel" : "Zulip kanala",
    "API token" : "API tokena",
    "Slack channel" : "Slack kanala",
    "Server ID or name" : "Zerbitzariaren IDa edo izena",
    "Channel" : "Kanala",
    "Login" : "Hasi saioa",
    "Chat ID" : "Txataren IDa",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "IRC zerbitzariaren URLa (adib. chat.freenode.net:6667)",
    "Nickname" : "Ezizena",
    "Connection password" : "Konexio pasahitza",
    "IRC channel" : "IRC kanala",
    "Channel password" : "Kanalaren pasahitza",
    "NickServ nickname" : "NickServ ezizena",
    "NickServ password" : "NickServ pasahitza",
    "Use TLS" : "Erabili TLS",
    "Use SASL" : "Erabili SASL",
    "Tenant ID" : "Tenant IDa",
    "Client ID" : "Bezeroaren IDa",
    "Team ID" : "Lantaldearen IDa",
    "Thread ID" : "Hariaren IDa",
    "XMPP/Jabber server URL" : "XMPP/Jabber zerbitzariaren URLa",
    "MUC server URL" : "MUC zerbitzariaren URLa",
    "Jabber ID" : "Jabber IDa",
    "Media" : "Media",
    "Polls" : "Bozketak",
    "Deck cards" : "Deck txartelak",
    "Voice messages" : "Ahots-mezuak",
    "Locations" : "Kokapenak",
    "Call recordings" : "Deien grabaketak",
    "Audio" : "Audioa",
    "Show all media" : "Erakutsi multimedia guztia",
    "Show all files" : "Erakustsi fitxategi guztiak",
    "Show all polls" : "Erakutsi galdeketa guztiak",
    "Show all deck cards" : "Erakutsi txartel sorta guztiak",
    "Show all voice messages" : "Erakutsi ahots-mezu guztiak",
    "Show all locations" : "Erakutsi kokaleku guztiak",
    "Show all audio" : "Erakutsi audio guztia",
    "Show all other" : "Erakutsi beste guztiak",
    "Group" : "Taldea",
    "Team" : "Lantaldea",
    "You reconnected to the call" : "Deira berriro konektatu zara",
    "You added {user0} and {user1}" : "{user0} eta {user1} gehitu dituzu",
    "An administrator added you and {user0}" : "Administratzaile batek zu eta {user0} gehitu zaituzte",
    "An administrator added {user0} and {user1}" : "Administratzaile batek {user0} eta {user1} gehitu ditu",
    "You removed {user0} and {user1}" : "{user0} eta {user1} kendu dituzu",
    "An administrator removed you and {user0}" : "Administratzaile batek zu eta {user0} kendu zaituzte",
    "An administrator removed {user0} and {user1}" : "Administratzaile batek {user0} eta {user1} kendu ditu",
    "You promoted {user0} and {user1} to moderators" : "{user0} eta {user1} moderatzaile bihurtu dituzu",
    "An administrator promoted you and {user0} to moderators" : "Administratzaile batek zu eta {user0} moderatzaile egin zaituzte",
    "An administrator promoted {user0} and {user1} to moderators" : "Administratzaile batek {user0} eta {user1} moderatzaile egin ditu",
    "You demoted {user0} and {user1} from moderators" : "{user0} eta {user1} moderatzaileetatik kendu dituzu",
    "An administrator demoted you and {user0} from moderators" : "Administratzaile batek zu eta {user0} moderatzaileetatik kendu zaituzte",
    "An administrator demoted {user0} and {user1} from moderators" : "Administratzaile batek {user0} eta {user1} moderatzaileetatik kendu ditu",
    "You: {lastMessage}" : "Zu: {lastMessage}",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "(edited by you)" : "(zuk editatuta)",
    "(edited by {moderator})" : "({moderator}-(e)k editatuta)",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Elkarrizketa batera batu nahi duzu aldi berean saioa aktibaturik beste leiho edo gailu batean. Nextcloud Talkek ez du hau onartzen une honetan. Zer egin nahi duzu?",
    "Leave this page" : "Orri hau utzi",
    "Join here" : "Hemen bat egin",
    "An error occurred while posting deck card to conversation" : "Errore bat gertatu da elkarrizketan deck txartela argitaratzean",
    "Post to a conversation" : "Argitaratu elkarrizketa batera",
    "Post to conversation" : "Argitaratu elkarrizketan",
    "The recording failed. Please contact your administrator." : "Utzi grabaketaren hasiera",
    "An error occurred while posting location to conversation" : "Errorea gertatu da elkarrizketara kokalekua bidaltzean",
    "Share to a conversation" : "Partekatu elkarrizketa batera",
    "Share to conversation" : "Partekatu elkarrizketara",
    "In conversation" : "Elkarrizketan",
    "Error while clearing conversation history" : "Errorea elkarrizketaren historia garbitzen",
    "Error occurred while allowing guests" : "Errorea gertatu da gonbidatuak baimentzean",
    "Error occurred while disallowing guests" : "Errorea gertatu da gonbidatuei baimena kentzean",
    "Error occurred when restricting the conversation to moderator" : "Errorea gertatu da elkarrizketari moderatzaile muga jartzean",
    "Error occurred when opening the conversation to everyone" : "Errorea gertatu da elkarrizketa edonorentzat irekitzean",
    "Conversation password has been saved" : "Elkarrizketaren pasahitza gorde da",
    "Conversation password has been removed" : "Elkarrizketaren pasahitza kendu da",
    "Error occurred while saving conversation password" : "Errore bat gertatu da elkarrizketaren pasahitza gordetzean",
    "Call recording is starting." : "Deiaren grabaketa hasten ari da.",
    "Conversation picture set" : "Elkarrizketa-irudia ezarrita",
    "Conversation picture deleted" : "Elkarrizketa-irudia ezabatuta",
    "Could not delete the conversation picture" : "Ezin izan da elkarrizketaren argazkia ezabatu",
    "Could not post message: {errorMessage}" : "Ezin izan da mezua argitaratu: {errorMessage}",
    "An error occurred while fetching the participants" : "Errore bat gertatu da parte-hartzaileak eskuratzean",
    "Could not send invitation to {actorId}" : "Ezin izan da gonbidapena {actorId}(r)i bidali",
    "Invitations sent" : "Gonbidapenak bidalita",
    "Error occurred when sending invitations" : "Errorea gonbidapenak bidaltzean",
    "{guest} (guest)" : "{guest} (gonbidatua)",
    "An error occurred while submitting your vote" : "Errore bat gertatu da botoa bidaltzean",
    "An error occurred while ending the poll" : "Errore bat gertatu da galdeketa bukatzean",
    "Failed to add reaction" : "Huts egin du erreakzioa gehitzean",
    "Failed to remove reaction" : "Huts egin du erreakzioa kentzean",
    "Error while uploading file \"{fileName}\"" : "Errorea \"{fileName}\" fitxategia igotzerakoan",
    "Not enough free space to upload file \"{fileName}\"" : "Ez dago nahikoa leku librerik \"{fileName}\" fitxategia igotzeko",
    "You are not allowed to share files" : "Ez duzu baimenik fitxategiak partekatzeko",
    "Error while sharing file" : "Errorea fitxategia partekatzean",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Nextcloud Talkek ez dauka erabateko euskarria erabiltzen ari zaren nabigatzailearentzat. Erabili Mozilla Firefox, Microsoft Edge, Google Chrome, Opera edo Apple Safari nabigatzaileen bertsio berriena.",
    "_In %n hour_::_In %n hours_" : ["ordu %n barru","%n ordu barru"],
    "_%n minute _::_%n minutes_" : ["Minutu %n","%n minutu"],
    "_In %n minute_::_In %n minutes_" : ["minutu %nean","%n minutu barru"],
    "Later today – {timeLocale}" : "Beranduago gaur – {timeLocale}",
    "Tomorrow – {timeLocale}" : "Bihar – {timeLocale}",
    "This weekend – {timeLocale}" : "Hurrengo asteburua – {timeLocale}",
    "Next week – {timeLocale}" : "Hurrengo astea – {timeLocale}",
    "Message link copied to clipboard" : "Mezuaren esteka arbelera kopiatu da",
    "Conversation link copied to clipboard" : "Elkarrizketaren esteka arbelera kopiatu da",
    "The link could not be copied" : "Ezin izan da esteka kopiatu",
    "Error while parsing a PROPFIND error" : "Errore bat gertatu da PROPFIND errore bat analizatzean",
    "Lost connection to signaling server. Trying to reconnect." : "Konexioa galdu da seinalizazio zerbitzariarekin. Berriro konektatzen saiatzen.",
    "Please reload the page." : "Mesedez birkargatu orria.",
    "Do not disturb" : "Ez molestatu",
    "Away" : "Kanpoan",
    "Microphone {number}" : "{number} mikrofonoa",
    "Camera {number}" : "{number} kamera",
    "Speaker {number}" : "{number} bozgorailua",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Audioa desaktibatuta duzula hitz egiten ari zarela dirudi, aktibatu audioa besteek entzun zaitzaten",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Ezin izan da konexioa ezarri partaide batekin gutxienez. Zure egoeran TURN zerbitzari bat beharrezkoa izan liteke. Eskatu zure administratzaileari horrelako bat konfiguratzeko {linkstart}this documentazio hau{linkend} erabiliz.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Hau uste baino denbora gehiago hartzen ari da. Multimedia baimenak emanda (edo ukatuta) daude jada? Hala bada, berrabiarazi zure nabigatzailea, audioa eta bideoa huts egiten ari baitira",
    "Access to microphone & camera is only possible with HTTPS" : "Kamera eta mikrofonoak atzitzeko modu bakarra HTTPS bidez da",
    "Please move your setup to HTTPS" : "Aldatu zure konfigurazioa HTTPSra",
    "Access to microphone & camera was denied" : "Kamera eta mikrofonora sarbidea ukatu da",
    "WebRTC is not supported in your browser" : "Zure nabigatzaileak ez du WebRTC onartzen",
    "Please use a different browser like Firefox or Chrome" : "Beste nabigatzaile bat erabil ezazu: Firefox edo Chrome.",
    "Error while accessing microphone & camera" : "Errorea mikrofonoa eta kamara atzitzean",
    "%s Talk on your mobile devices" : "%s Hitz egin zure gailu mugikorretan",
    "Join conversations at any time, anywhere, on any device." : "Batu elkarrizketetara edonoiz, edonondik, edozein gailutatik.",
    "Android app" : "Android aplikazioa",
    "iOS app" : "iOS aplikazioa",
    "__language_name__" : "Euskara",
    "Call summary (%s)" : "Deiaren laburpena (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "Deiaren laburpen bot-ak deiaren ondoren laburpen mezu bat argitaratzen du partaide guztiak zerrendatu eta zereginak zehazten dituena",
    "Tasks" : "Zereginak",
    "Notes" : "Oharrak",
    "Reports" : "Txostenak",
    "Decisions" : "Erabakiak",
    "Agenda" : "Agenda",
    "Call summary" : "Deiaren laburpena",
    "Call summary - {title}" : "Deiaren laburpena - {title}",
    "Next meeting" : "Hurrengo bilera",
    "Set reminder for later today" : "Ezarri gogorarazpena gaur beranduagorako",
    "Set reminder for tomorrow" : "Ezarri gogorarazpena biharko",
    "Set reminder for this weekend" : "Ezarri gogorarazpena asteburu honetarako",
    "Set reminder for next week" : "Ezarri gogorarazpena hurrengo asterako",
    "Generate summary" : "Sortu laburpena",
    "Open poll • You voted already" : "Galdeketa irekia • Botoa dagoeneko eman duzu",
    "Open poll • Click to vote" : "Galdeketa irekia・ Egin klik botoa emateko",
    "Poll • Ended" : "Galdeketa ・ Bukatuta",
    "Talk recording from {time} ({conversation})" : "Solasaldi grabazioa {time} -tik aurrera ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Galdeketaren emaitzak • %n  boto","Galdeketaren emaitzak • %nboto"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["Galdeketa irekia・Boto %n","Galdeketa irekia・%n boto"],
    "Submit vote" : "Bidali botoa",
    "Your privacy setting has been saved" : "Zure pribatutasun ezarpenak gorde dira",
    "Failed to save sounds setting" : "Soinu ezarpenak gordetzeak huts egin du",
    "Sounds setting saved" : "Soinu ezarpenak gordeta",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Elkarrizketara batu zara beste leiho edo gailu batean. Nextcloud Talkek ez du hau onartzen une honetan, beraz saioa itxi egin da."
},
"nplurals=2; plural=(n != 1);");
