.material-design-icon[data-v-45e1396f]{justify-content:center;place-self:center;align-items:center;display:flex}.color-picker[data-v-45e1396f]{padding:var(--border-radius-element);min-width:calc(4*var(--default-clickable-area) + 2*var(--border-radius-element));flex-direction:column;place-content:flex-end space-between;display:flex;overflow:hidden}.color-picker--clearable[data-v-45e1396f]{min-width:calc(5*var(--default-clickable-area) + 2*var(--border-radius-element))}.color-picker--advanced-fields[data-v-45e1396f]{min-width:264px}.color-picker__clear[data-v-45e1396f]{color:var(--color-main-text)}.color-picker__clear[data-v-45e1396f]:hover:not(:has(:checked)){color:var(--color-text-maxcontrast)}.color-picker__simple[data-v-45e1396f]{grid-template-columns:repeat(auto-fit,var(--default-clickable-area));grid-auto-rows:var(--default-clickable-area);display:grid}.color-picker__simple-color-circle[data-v-45e1396f]{width:calc(var(--default-clickable-area) - 10px);height:calc(var(--default-clickable-area) - 10px);min-height:calc(var(--default-clickable-area) - 10px);color:#fff;border:1px solid #00000040;border-radius:50%;justify-content:center;align-items:center;margin:auto;padding:0;font-size:16px;display:flex}.color-picker__simple-color-circle[data-v-45e1396f]:focus-within{outline:2px solid var(--color-main-text)}.color-picker__simple-color-circle[data-v-45e1396f]:hover{opacity:.6}.color-picker__simple-color-circle--active[data-v-45e1396f]{width:calc(var(--default-clickable-area) - 6px);height:calc(var(--default-clickable-area) - 6px);min-height:calc(var(--default-clickable-area) - 6px);transition:all .1s ease-in-out;opacity:1!important}.color-picker__advanced[data-v-45e1396f]{box-shadow:none!important}.color-picker__navigation[data-v-45e1396f]{gap:var(--default-grid-baseline);margin-top:calc(2*var(--default-grid-baseline));flex-direction:row;justify-content:space-between;display:flex}[data-v-45e1396f] .vc-chrome{width:unset;background-color:var(--color-main-background)}[data-v-45e1396f] .vc-chrome-color-wrap{width:30px;height:30px}[data-v-45e1396f] .vc-chrome-active-color{border-radius:17px}[data-v-45e1396f] .vc-chrome-body{background-color:var(--color-main-background);padding:14px 0 0}[data-v-45e1396f] .vc-chrome-body .vc-input__input{--input-border-radius:var(--border-radius-element);--input-border-width-offset:calc(var(--border-width-input-focused,2px) - var(--border-width-input,2px));width:100%;height:var(--default-clickable-area);padding-inline:calc(var(--border-radius-element) + var(--input-border-width-offset));padding-block:var(--input-border-width-offset);border:var(--border-width-input,2px)solid var(--color-border-maxcontrast);border-radius:var(--input-border-radius);font-size:var(--default-font-size);color:var(--color-main-text);box-shadow:none;margin:0}[data-v-45e1396f] .vc-chrome-body .vc-input__input:active:not([disabled]),[data-v-45e1396f] .vc-chrome-body .vc-input__input:hover:not([disabled]),[data-v-45e1396f] .vc-chrome-body .vc-input__input:focus:not([disabled]){--input-border-width-offset:0px;border-color:var(--color-main-text);border-width:var(--border-width-input-focused,2px);box-shadow:0 0 0 2px var(--color-main-background)!important}[data-v-45e1396f] .vc-chrome-body .vc-input__input:active:not([disabled])+.vc-input__label,[data-v-45e1396f] .vc-chrome-body .vc-input__input:hover:not([disabled])+.vc-input__label,[data-v-45e1396f] .vc-chrome-body .vc-input__input:focus:not([disabled])+.vc-input__label{color:var(--color-main-text)}[data-v-45e1396f] .vc-chrome-body .vc-input__label{inset-inline:var(--border-width-input-focused,2px);max-width:fit-content;margin-inline:calc(var(--border-radius-element) - var(--default-grid-baseline));padding-inline:var(--default-grid-baseline);font-family:var(--font-face);font-size:var(--font-size-small,13px);color:var(--color-text-maxcontrast);background-color:var(--color-main-background);pointer-events:none;margin-block:0;font-weight:500;line-height:1.5;position:absolute;inset-block-start:calc(-1.5*var(--font-size-small,13px)/2)}[data-v-45e1396f] .vc-chrome-toggle-btn{width:var(--default-clickable-area);height:var(--default-clickable-area);filter:var(--background-invert-if-dark);justify-content:center;align-items:center;margin-inline-start:6px;display:flex}[data-v-45e1396f] .vc-chrome-toggle-icon{width:24px;height:24px;margin:0}[data-v-45e1396f] .vc-chrome-toggle-icon-highlight{width:var(--default-clickable-area);height:var(--default-clickable-area);inset:0}[data-v-45e1396f] .vc-chrome-saturation-wrap{border-radius:3px}[data-v-45e1396f] .vc-chrome-saturation-circle{width:20px;height:20px}.slide-enter-from[data-v-45e1396f]{opacity:0;transform:translate(-50%)}.slide-enter-to[data-v-45e1396f],.slide-leave-from[data-v-45e1396f]{opacity:1;transform:translate(0)}.slide-leave-to[data-v-45e1396f]{opacity:0;transform:translate(-50%)}.slide-enter-active[data-v-45e1396f],.slide-leave-active[data-v-45e1396f]{transition:all 50ms ease-in-out}
/*# sourceMappingURL=node_modules_nextcloud_vue_dist_assets_NcColorPicker-CCanY5eB_css.chunk.css.map*/