OC.L10N.register(
    "spreed",
    {
    "a conversation" : "разговор",
    "(Duration %s)" : "(Продължителност %s)",
    "You attended a call with {user1}" : "Присъствахте на разговор с {user1}",
    "_%n guest_::_%n guests_" : ["%nгости ","%n гости"],
    "You attended a call with {user1} and {user2}" : "Присъствахте на разговор с {user1} и {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Присъствахте на разговор с {user1}, {user2} и {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Присъствахте на разговор с {user1}, {user2}, {user3} и {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Присъствахте на разговор с {user1}, {user2}, {user3}, {user4} и {user5}",
    "_%n other_::_%n others_" : ["%nдруги ","%n други"],
    "{actor} invited you to {call}" : "{actor} ви покани за {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Бяхте поканени на <strong>разговор</strong> или сте имали <strong>обаждане</strong>",
    "Other activities" : "Други активности",
    "Talk" : "Talk",
    "Guest" : "Гост",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge и Safari вече могат да се използват за участие в аудио и видео разговори",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Разговорите един към един вече са постоянни и повече не могат да бъдат превърнати в групови разговори случайно. Също така, когато един от участниците напусне разговора, разговорът вече не се изтрива автоматично. Само ако и двамата участници напуснат, разговорът се изтрива от сървъра",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Вече можете да уведомявате всички участници, като публикувате „@all“ в чата",
    "- With the \"arrow-up\" key you can repost your last message" : "- С клавиш \"стрелка нагоре\" можете да публикувате повторно последното си съобщение",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk вече може да има команди, изпращане \"/помощ\" като съобщение за чат, за да видите дали вашият администратор е конфигурирал някои",
    "- With projects you can create quick links between conversations, files and other items" : "- С проекти можете да създавате бързи връзки между разговори, файлове и други елементи",
    "- You can now mention guests in the chat" : "- Вече можете да споменавате гости в чата",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Разговорите вече могат да имат лоби. Това ще позволи на модераторите да се присъединят към чата и да се обаждат вече, за да подготвят срещата, докато потребителите и гостите трябва да изчакат",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Вече можете директно да отговаряте на съобщения, давайки на другите потребители повече контекст за какво е вашето съобщение",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "-Търсенето на разговори и участници вече също ще филтрира съществуващите ви разговори, което прави много по-лесно намирането на предишни разговори",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Вече можете да добавяте персонализирани потребителски групи към разговорите, когато приложението circles /кръгове/ е инсталирано",
    "- Check out the new grid and call view" : "- Проверете новата мрежа и изглед на обаждане",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Вече можете да качвате и да плъзгате и пускате файлове директно от вашето устройство в чата",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Споделените файлове вече се отварят директно в изгледа за чат с приложенията за преглед",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Вече можете да търсите чатове и съобщения в обединеното търсене в горната лента",
    "- Spice up your messages with emojis from the emoji picker" : "- Подправете съобщенията си с емоджита от инструмента за избор на емоджи",
    "- You can now change your camera and microphone while being in a call" : "- Вече можете да си сменяте камерата и микрофона, докато сте в разговор",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Дайте на разговорите си някакъв контекст с описание и го отворете, така че влезлите потребители да могат да го намерят и да се присъединят",
    "- See a read status and send failed messages again" : "- Вижте състоянието на четене и изпратете отново неуспешно изпратени съобщения",
    "- Raise your hand in a call with the R key" : "- Вдигнете ръката си при повикване с клавиша R",
    "- Join the same conversation and call from multiple devices" : "- Присъединете се към същия разговор и се обаждайте от множество устройства",
    "- Send voice messages, share your location or contact details" : "- Изпращайте гласови съобщения, споделяйте вашето местоположение или подробности за контакт",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Добавете групи към разговор и новите членове на групата автоматично ще бъдат добавени като участници",
    "- A preview of your audio and video is shown before joining a call" : "- Показване на визуализация на вашето аудио и видео, преди да се присъедините към разговор",
    "- You can now blur your background in the newly designed call view" : "- Вече можете да замъглите фона си в новият проект  на изглед за разговори",
    "- Moderators can now assign general and individual permissions to participants" : "- Модераторите вече могат да задават общи и индивидуални права на участниците",
    "- In the sidebar you can now find an overview of the latest shared items" : "- Вече можете да намерите общ преглед на най-новите споделени елементи в страничната лента",
    "- Use a poll to collect the opinions of others or settle on a date" : "- Използвайте анкета, за събиране на мнението на другите или за определяне на дата",
    "- Configure an expiration time for chat messages" : "- Конфигуриране на срок на валидност на съобщенията в чата",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Започвайте разговори, без да уведомявате другите участници в големи разговори. Можете да изпращате индивидуални известия за повиквания, след като повикването е започнало.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Изпращайте съобщения в чата, без да уведомявате получателите, в случай че не е спешно",
    "- Emojis can now be autocompleted by typing a \":\"" : "- Емотиконите вече могат да се попълват автоматично чрез въвеждането на символа \":\"",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- Свързване на различни елементи с помощта на новия интелигентен инструмент за избор чрез въвеждането на символа \"/\"",
    "- Unsent message drafts are now saved in your browser" : "-Неизпратените чернови вече се съхраняват в браузъра",
    "Talk updates ✅" : "Актуализации на Talk ✅",
    "Reaction deleted by author" : "Реакцията е изтрита от автор",
    "{actor} created the conversation" : "{actor} създаде разговора",
    "You created the conversation" : "Вие създадохте разговор",
    "An administrator created the conversation" : "Администратор създаде разговора",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} преименува разговора от „%1$s“ на „%2$s“",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Вие преименувахте разговора от „%1$s“ на „%2$s“",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Администратор преименува разговора от „%1$s“ на „%2$s“",
    "{actor} set the description" : "{actor} зададе описанието",
    "You set the description" : "Вие зададохте описанието",
    "An administrator set the description" : "Администратор зададе описанието",
    "{actor} removed the description" : "{actor} премахна описанието",
    "You removed the description" : "Премахнахте описанието",
    "An administrator removed the description" : "Администратор премахна описанието",
    "You started a call" : "Вие започнахте разговор",
    "{actor} started a call" : "{actor} започна обаждане",
    "{actor} joined the call" : "{actor} се присъедини към разговора",
    "You joined the call" : "Вие се присъединихте към разговора",
    "{actor} left the call" : "{actor} напусна разговора",
    "You left the call" : "Вие напуснахте разговора",
    "{actor} unlocked the conversation" : "{actor} отключи разговора",
    "You unlocked the conversation" : "Вие отключихте разговора",
    "An administrator unlocked the conversation" : "Администратор отключи разговора",
    "{actor} locked the conversation" : "{actor} заключи разговора",
    "You locked the conversation" : "Вие заключихте разговора",
    "An administrator locked the conversation" : "Администратор заключи разговора",
    "{actor} limited the conversation to the current participants" : "{actor} ограничи разговора до настоящите участници",
    "You limited the conversation to the current participants" : "Вие ограничихте разговора до настоящите участници",
    "An administrator limited the conversation to the current participants" : "Администратор ограничи разговора до настоящите участници",
    "{actor} opened the conversation to registered users" : "{actor} отвори разговора за регистрирани потребители",
    "You opened the conversation to registered users" : "Отворихте разговора за регистрирани потребители",
    "An administrator opened the conversation to registered users" : "Администратор отвори разговора за регистрирани потребители",
    "The conversation is now open to everyone" : "Разговорът вече е отворен за всички",
    "{actor} opened the conversation to everyone" : "{actor} отвори разговора за всички",
    "You opened the conversation to everyone" : "Вие отворихте разговора за всички",
    "{actor} restricted the conversation to moderators" : "{actor} ограничи разговора само за модератори",
    "You restricted the conversation to moderators" : "Вие ограничихте разговора само за модератори",
    "{actor} started breakout rooms" : "{actor} стартира стаите за отделно събрание",
    "You started breakout rooms" : "Вие стартирахте стаите за отделно събрание",
    "{actor} stopped breakout rooms" : "{actor} спря стаите за отделно събрание",
    "You stopped breakout rooms" : "Вие спряхте стаите за отделно събрание",
    "{actor} allowed guests" : "{actor} допусна гости ",
    "You allowed guests" : "Допуснахте гости",
    "An administrator allowed guests" : "Администратор допусна гости",
    "{actor} disallowed guests" : "{actor} забрани гости",
    "You disallowed guests" : "Вие забранихте гости",
    "An administrator disallowed guests" : "Администратор забрани гости",
    "{actor} set a password" : "{actor} зададе парола",
    "You set a password" : "Зададохте парола",
    "An administrator set a password" : "Администратор зададе парола",
    "{actor} removed the password" : "{actor} премахна парола",
    "You removed the password" : "Премахнахте парола",
    "An administrator removed the password" : "Администратор премахна парола",
    "{actor} added {user}" : "{actor} добави {user}",
    "You joined the conversation" : "Вие се присъединихте към разговора",
    "{actor} joined the conversation" : "{actor} се присъедини към разговора",
    "You added {user}" : "Добавихте {user}",
    "{actor} added you" : "{actor} ви добави",
    "An administrator added you" : "Администратор ви добави",
    "An administrator added {user}" : "Администратор добави {user}",
    "You left the conversation" : "Напуснахте разговора",
    "{actor} left the conversation" : "{actor} напусна разговора",
    "{actor} removed {user}" : "{actor} премахна {user}",
    "You removed {user}" : "Премахнахте {user}",
    "{actor} removed you" : "{actor} ви премахна",
    "An administrator removed you" : "Администратор ви премахна",
    "An administrator removed {user}" : "Администратор премахна {user}",
    "{federated_user} accepted the invitation" : "{federated_user} прие поканата",
    "{actor} removed {federated_user}" : "{actor} премахна {federated_user}",
    "You removed {federated_user}" : "Премахнахте {federated_user}",
    "An administrator removed {federated_user}" : "Администратор премахна {federated_user}",
    "{federated_user} declined the invitation" : "{federated_user} отказа поканата",
    "{actor} added group {group}" : "{actor} добави група {group}",
    "You added group {group}" : "Добавихте група {group}",
    "An administrator added group {group}" : "Администратор добави група {group}",
    "{actor} removed group {group}" : "{actor} премахна група {group}",
    "You removed group {group}" : "Премахнахте група {group}",
    "An administrator removed group {group}" : "Администратор премахна група {group}",
    "{actor} promoted {user} to moderator" : "{actor} повиши {user} до модератор",
    "You promoted {user} to moderator" : "Повишихте {user} до модератор",
    "{actor} promoted you to moderator" : "{actor} ви повиши до модератор",
    "An administrator promoted you to moderator" : "Администратор ви повиши до модератор",
    "An administrator promoted {user} to moderator" : "Администратор повиши {user} до модератор",
    "{actor} demoted {user} from moderator" : "{actor} понижи {user} от модератор",
    "You demoted {user} from moderator" : "Понижихте {user} от модератор",
    "{actor} demoted you from moderator" : "{actor} ви понижи от модератор",
    "An administrator demoted you from moderator" : "Администратор ви понижи от модератор",
    "An administrator demoted {user} from moderator" : "Администратор понижи {user} от модератор",
    "{actor} shared a file which is no longer available" : "{actor} сподели файл, който вече не е наличен",
    "You shared a file which is no longer available" : "Споделихте файл, който вече не е наличен",
    "The shared location is malformed" : "Споделеното местоположение е формирано неправилно ",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} настрои Matterbridge да синхронизира този разговор с други чатове",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Настроихте Matterbridge да синхронизира този разговор с други чатове",
    "{actor} updated the Matterbridge configuration" : "{actor} актуализира конфигурацията на Matterbridge",
    "You updated the Matterbridge configuration" : "Вие актуализирахте конфигурацията на Matterbridge",
    "{actor} removed the Matterbridge configuration" : "{actor} премахна конфигурацията на Matterbridge",
    "You removed the Matterbridge configuration" : "Премахнахте конфигурацията на Matterbridge",
    "{actor} started Matterbridge" : "{actor} стартира Matterbridge",
    "You started Matterbridge" : "Вие стартирахте Matterbridge",
    "{actor} stopped Matterbridge" : "{actor} спря Matterbridge",
    "You stopped Matterbridge" : "Спряхте Matterbridge",
    "{actor} deleted a message" : "{actor} изтри съобщение",
    "You deleted a message" : "Изтрихте съобщение",
    "{actor} deleted a reaction" : "{actor} изтри реакция",
    "You deleted a reaction" : "Изтрихте реакция",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["Зададохте изтичане на съобщението след %n седмици","Зададохте изтичане на съобщението на %n седмици"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["Зададохте изтичане на съобщението след %n дни","Зададохте изтичане на съобщението след %n дни"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["Зададохте изтичане на съобщението след %n часа","Зададохте изтичане на съобщението след %n часа"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["Зададохте изтичане на съобщението след %n минути","Зададохте изтичане на съобщението след %n минути"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} зададе изтичането на съобщението след %n седмици","{actor} зададе изтичането на съобщението след %n седмици"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} зададе изтичането на съобщението след %n дни","{actor} зададе изтичането на съобщението след %n дни"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} зададе изтичането на съобщението след %n часа","{actor} зададе изтичането на съобщението след %n дни"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} зададе изтичането на съобщението след %n минути","{actor} зададе изтичането на съобщението след %n минути"],
    "{actor} disabled message expiration" : "{actor} деактивира изтичането на съобщението",
    "You disabled message expiration" : "Деактивирахте изтичането на съобщението",
    "{actor} cleared the history of the conversation" : "{actor} изчисти историята на разговора",
    "You cleared the history of the conversation" : "Изчистихте историята на разговора",
    "{actor} set the conversation picture" : "{actor} зададе снимка на разговора",
    "You set the conversation picture" : "Вие зададохте снимка на разговора",
    "{actor} removed the conversation picture" : "{actor} премахна снимката на разговора",
    "You removed the conversation picture" : "Вие премахнахте снимката на разговора",
    "{actor} ended the poll {poll}" : "{actor} прекрати анкетата {poll}",
    "You ended the poll {poll}" : "Вие прекратихте анкетата {poll}",
    "{actor} started the video recording" : "{actor} стартира видеозапис",
    "You started the video recording" : "Вие стартирахте видеозапис",
    "{actor} stopped the video recording" : "{actor} спря видеозаписа",
    "You stopped the video recording" : "Вие спряхте видеозаписа",
    "{actor} started the audio recording" : "{actor} стартира аудиозапис",
    "You started the audio recording" : "Вие стартирахте аудиозапис",
    "{actor} stopped the audio recording" : "{actor} спря аудиозаписа",
    "You stopped the audio recording" : "Вие спряхте аудиозаписа",
    "The recording failed" : "Записването е неуспешно",
    "Someone voted on the poll {poll}" : "Някой гласува в анкетата {poll}",
    "Message deleted by author" : "Съобщението е изтрито от автора",
    "Message deleted by {actor}" : "Съобщението е изтрито от {actor}",
    "Message deleted by you" : "Съобщение, изтрито от вас",
    "Deleted user" : "Изтрит потребител",
    "Administration" : "Администрация",
    "System" : "Система",
    "%s (guest)" : "%s (гост)",
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} прекрати разговора с %n гости (продължителност {duration})","{actor} прекрати разговора с %n гости (Продължителност {duration})"],
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} прекрати разговора с {user1} (Продължителност {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} прекрати разговора с {user1} и {user2} (Продължителност {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} прекрати разговора с {user1}, {user2} и {user3} (Продължителност {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} прекрати разговора с {user1}, {user2}, {user3} и {user4} (Продължителност {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} прекрати разговора с {user1}, {user2}, {user3}, {user4} и {user5} (Продължителност {duration})",
    "Message of {user} in {conversation}" : "Съобщение на {user} в {conversation}",
    "Message of {user}" : "Съобщение на {user}",
    "Message of a deleted user in {conversation}" : "Съобщение на изтрит потребител в {conversation}",
    "Talk conversations" : "Talk разговори",
    "Talk to %s" : "Говорене с %s",
    "An error occurred. Please contact your administrator." : "Възникна грешка. Моля, свържете се с вашия администратор.",
    "File not found" : "Файлът не е намерен",
    "File is not shared, or shared but not with the user" : "Файлът не се споделя или се споделя, но не и с потребителя",
    "No account available to delete." : "Няма достъпен профил за изтриване.",
    "Poll" : "Анкета",
    "No image file provided" : "Не е предоставен файл с изображение",
    "File is too big" : "Файлът е твърде голям",
    "Invalid file provided" : "Предоставен е невалиден файл",
    "Invalid image" : "Невалидно изображение",
    "Unknown filetype" : "Неизвестен тип файл",
    "Talk mentions" : "Споменавания в Talk",
    "Say hi to your friends and colleagues!" : "Поздравете приятелите и колегите си!",
    "No unread mentions" : "Няма непрочетени споменавания",
    "Call in progress" : "В ход е обаждане",
    "You were mentioned" : "Вие бяхте споменати",
    "Write to conversation" : "Записване към разговор",
    "Writes event information into a conversation of your choice" : "Записва информация за събитието в разговор по ваш избор",
    "Conversation invitation" : "Покана за разговор",
    "Description" : "Описание",
    "You can also dial-in via phone with the following details" : "Можете също да наберете по телефона със следните подробности",
    "Dial-in information" : "Информация за набиране",
    "Meeting ID" : "Идентификатор на срещата",
    "Your PIN" : "Вашият ПИН",
    "Meeting" : "Среща",
    "Password request: %s" : "Заявка за парола %s",
    "Private conversation" : "Частен разговор",
    "Deleted user (%s)" : "Изтрит потребител (%s)",
    "Failed to upload call recording" : "Неуспешно качване на запис на обаждане/то/",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "Записващият сървър не успя да качи записа на обаждането {call}. Моля, свържете се с администрацията.",
    "Share to chat" : "Споделяне в чата",
    "Dismiss notification" : "Спри известията",
    "Call recording now available" : "Записването на обаждане е налично",
    "The recording for the call in {call} was uploaded to {file}." : "Записът на разговора в {call}, беше качен в {file}.",
    "Transcript now available" : "Вече е налична транскрипция",
    "The transcript for the call in {call} was uploaded to {file}." : "Транскрипцията на разговора в {call}, беше качена в {file}.",
    "Failed to transcript call recording" : "Неуспешнa транскрипция на записa на обаждането",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "Сървърът не успя да направи транскрипция на записа в {file} за повикването в {call}. Моля, свържете се с администрацията.",
    "Accept" : "Приемам",
    "Decline" : "Отхвърляне",
    "New message" : "Ново съобщение",
    "Reminder" : "Напомняне",
    "Notification" : "Известие",
    "{user} in {call}" : "{user} в {call}",
    "Deleted user in {call}" : "Изтрит потребител в {call}",
    "{guest} (guest) in {call}" : "{guest} (guest) в {call}",
    "Guest in {call}" : "Гост в {call}",
    "{user} sent you a private message" : "{user} ви изпрати лично съобщение",
    "{user} sent a message in conversation {call}" : "{user} изпрати съобщение в разговор {call}",
    "A deleted user sent a message in conversation {call}" : "Изтрит потребител изпрати съобщение в разговор {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (гост) изпрати съобщение в разговор {call}",
    "A guest sent a message in conversation {call}" : "Гост изпрати съобщение в разговор {call}",
    "{user} replied to your private message" : "{user} отговори на вашето лично съобщение",
    "{user} replied to your message in conversation {call}" : "{user} отговори на вашето съобщение в разговор {call}",
    "A deleted user replied to your message in conversation {call}" : "Изтрит потребител отговори на съобщението ви в разговор {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (гост) отговори на съобщението ви в разговор {call}",
    "A guest replied to your message in conversation {call}" : "Гост отговори на съобщението ви в разговор {call}",
    "{user} reacted with {reaction} to your private message" : "{user} реагира с {reaction} на вашето лично съобщение",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} реагира с {reaction} на вашето съобщение в разговор {call}",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "Изтрит потребител реагира с {reaction} на вашето съобщение в разговор {call}",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (гост) реагира с {reaction} на вашето съобщение в разговор {call}",
    "A guest reacted with {reaction} to your message in conversation {call}" : "Гост реагира с {reaction} на вашето съобщение в разговор {call}",
    "{user} mentioned you in a private conversation" : "{user} ви спомена в личен разговор",
    "{user} mentioned group {group} in conversation {call}" : "{user} спомена група {group} в разговор {call}",
    "{user} mentioned everyone in conversation {call}" : "{user} спомена всички в разговор {call}",
    "{user} mentioned you in conversation {call}" : "{user} ви спомена в разговор {call}",
    "A deleted user mentioned group {group} in conversation {call}" : "Изтрит потребител спомена група {group} в разговор {call}",
    "A deleted user mentioned everyone in conversation {call}" : "Изтрит потребител спомена всички в разговор {call}",
    "A deleted user mentioned you in conversation {call}" : "Изтрит потребител ви спомена в разговор {call}",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest} (гост) спомена група {group} в разговор {call}",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest} (гост) спомена всички в разговор {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (гост) ви спомена в разговор {call}",
    "A guest mentioned group {group} in conversation {call}" : "Гост спомена група {group} в разговор {call}",
    "A guest mentioned everyone in conversation {call}" : "Гост спомена всички в разговор {call}",
    "A guest mentioned you in conversation {call}" : "Гост ви спомена в разговор {call}",
    "View chat" : "Преглед на чата",
    "{user} invited you to a group conversation: {call}" : "{user} ви покани в групов разговор: {call}",
    "Join call" : "Присъединяване към обаждането",
    "Answer call" : "Отговаряне на обаждане",
    "{user} would like to talk with you" : "{user} би искал да говори с вас",
    "Call back" : "Върнете обаждането",
    "You missed a call from {user}" : "Пропуснахте обаждане от {user}",
    "A group call has started in {call}" : "Започна групово обаждане в {call}",
    "You missed a group call in {call}" : "Пропуснахте групово обаждане в {call}",
    "{email} is requesting the password to access {file}" : "{email} поиска паролата за достъп до {file}",
    "{email} tried to request the password to access {file}" : "{email} се опита да поиска паролата за достъп до {file}",
    "Someone is requesting the password to access {file}" : "Някой иска паролата за достъп до {file}",
    "Someone tried to request the password to access {file}" : "Някой се опита да поиска паролата за достъп до {file}",
    "Open settings" : "Отваряне на настройките",
    "The hosted signaling server is now configured and will be used." : "Хостваният сървър за сигнализация вече е конфигуриран и ще се използва.",
    "The hosted signaling server was removed and will not be used anymore." : "Хостваният сървър за сигнализиране е премахнат и няма да се използва повече.",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "Профил на хоствания сървър за сигнализация промени състоянието от „{oldstatus}“ на „{newstatus}“.",
    "error" : "грешка",
    "Contact via Talk" : "Свързване чрез Talk",
    "Open Talk" : "Отваряне на Talk",
    "Default" : "Стандартен",
    "Presentation" : "Презентация",
    "Conversations" : "Разговори",
    "{user}" : "{user}",
    "Messages" : "Съобщения",
    "{user} in {conversation}" : "{user} в {conversation}",
    "Messages in other conversations" : "Съобщения в други разговори",
    "One-to-one rooms always need to show the other users avatar" : "В индивидуалните стаи винаги трябва да се показва аватарът на другия потребител",
    "Avatar image is not square" : "Изображението на аватара не е квадратно",
    "Room {number}" : "Стая {number}",
    "Other" : "Други",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "Неуспешна заявка за изпробване, защото пробният сървър е недостъпен. Моля, опитайте отново по-късно.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Има проблем с удостоверяването на този екземпляр. Може би не е достъпен отвън, за да се провери URL адресът му.",
    "Something unexpected happened." : "Случи се нещо неочаквано.",
    "The URL is invalid." : "URL адресът е невалиден.",
    "An HTTPS URL is required." : "Нужно е HTTPS URL.",
    "The email address is invalid." : "Имейл адресът е невалиден.",
    "The language is invalid." : "Езикът е невалиден.",
    "The country is invalid." : "Държавата е невалидна.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Има проблем със заявката на процеса. Моля, проверете вашите регистрационни файлове/журнали/ за допълнителна информация.",
    "Too many requests are send from your servers address. Please try again later." : "От адреса на вашия сървър се изпращат твърде много заявки. Моля, опитайте отново по-късно.",
    "There is already a trial registered for this Nextcloud instance." : "Вече има регистрирано изпробване за този екземпляр на Nextcloud.",
    "Something unexpected happened. Please try again later." : "Случи се нещо неочаквано. Моля, опитайте отново по-късно.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "Неуспешна заявка за изпробване, защото пробният сървър се държеше неправилно. Моля, опитайте отново по-късно.",
    "Trial requested but failed to get account information. Please check back later." : "Беше заявено изпробване, но не се получи информация за профил. Моля, проверете отново по-късно.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Има проблем с удостоверяването на тази заявка. Може би не е достъпна отвън, за да се провери URL адресът и.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "Неуспешно извличане на информация за профил, защото пробният сървър се държеше неправилно. Моля, проверете отново по-късно.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Има проблем с извличането на информацията за профил. Моля, проверете вашите регистрационни файлове/журнали/ за допълнителна информация.",
    "There is no such account registered." : "Няма регистриран такъв профил.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "Неуспешно извличане на информация за профил, защото пробният сървър е недостъпен. Моля, проверете отново по-късно.",
    "Deleting the hosted signaling server account failed. Please check back later." : "Изтриването на профил на хоствания сървър за сигнализация не бе успешно. Моля, проверете отново по-късно.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Изтриването на профил не бе успешно, защото пробният сървър се държеше неправилно. Моля, проверете отново по-късно.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Има проблем с изтриването на профил. Моля, проверете вашите регистрационни файлове/журнали/ за допълнителна информация.",
    "Too many requests are sent from your servers address. Please try again later." : "От адреса на вашия сървър се изпращат твърде много заявки.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Изтриването на профил не беше успешно, защото пробният сървър е недостъпен. Моля, проверете отново по-късно.",
    "Andorra" : "Андора",
    "United Arab Emirates" : "Обединени арабски емирства",
    "Afghanistan" : "Афганистан",
    "Antigua and Barbuda" : "Антигуа и Барбуда",
    "Anguilla" : "Ангила",
    "Albania" : "Албания",
    "Armenia" : "Армения",
    "Angola" : "Ангола",
    "Antarctica" : "Антарктида",
    "Argentina" : "Аржентина",
    "American Samoa" : "Американска Самоа",
    "Austria" : "Австрия",
    "Australia" : "Австралия",
    "Aruba" : "Аруба",
    "Åland Islands" : "Оландски острови",
    "Azerbaijan" : "Азербайджан",
    "Bosnia and Herzegovina" : "Босна и Херцеговина",
    "Barbados" : "Барбадос",
    "Bangladesh" : "Бангладеш",
    "Belgium" : "Белгия",
    "Burkina Faso" : "Буркина Фасо",
    "Bulgaria" : "България",
    "Bahrain" : "Бахрейн",
    "Burundi" : "Бурунди",
    "Benin" : "Бенин",
    "Saint Barthélemy" : "Сен Бартелеми",
    "Bermuda" : "Бермуда",
    "Brunei Darussalam" : "Бруней",
    "Bolivia, Plurinational State of" : "Боливия",
    "Bonaire, Sint Eustatius and Saba" : "отвъдморски територии на Нидерландия",
    "Brazil" : "Бразилия",
    "Bahamas" : "Бахамски острови",
    "Bhutan" : "Бутан",
    "Bouvet Island" : "остров Буве",
    "Botswana" : "Ботсуана",
    "Belarus" : "Беларус",
    "Belize" : "Белийз",
    "Canada" : "Канада",
    "Cocos (Keeling) Islands" : "Кокосови строви (Кийлинг)",
    "Congo, the Democratic Republic of the" : "Конго",
    "Central African Republic" : "Централноафриканска република",
    "Congo" : "Конго",
    "Switzerland" : "Швейцария",
    "Côte d'Ivoire" : "Кот д’Ивоар",
    "Cook Islands" : "Oстрови Кук",
    "Chile" : "Чили",
    "Cameroon" : "Камерун",
    "China" : "Китай",
    "Colombia" : "Колумбия",
    "Costa Rica" : "Коста Рика",
    "Cuba" : "Куба",
    "Cabo Verde" : "Кабо Верде",
    "Curaçao" : "Кюрасао",
    "Christmas Island" : "остров Рождество",
    "Cyprus" : "Кипър",
    "Czechia" : "Чехия",
    "Germany" : "Германия",
    "Djibouti" : "Джибути",
    "Denmark" : "Дания",
    "Dominica" : "Доминика",
    "Dominican Republic" : "Доминиканска република",
    "Algeria" : "Алжир",
    "Ecuador" : "Еквадор",
    "Estonia" : "Естония",
    "Egypt" : "Египет",
    "Western Sahara" : "Западна Сахара",
    "Eritrea" : "Еритрея",
    "Spain" : "Испания",
    "Ethiopia" : "Етиопия",
    "Finland" : "Финландия",
    "Fiji" : "Фиджи",
    "Falkland Islands (Malvinas)" : "Фолкландски острови (Малдиви)",
    "Micronesia, Federated States of" : "Микронезия",
    "Faroe Islands" : "Фарьорски острови",
    "France" : "Франция",
    "Gabon" : "Габон",
    "United Kingdom of Great Britain and Northern Ireland" : "Обединено кралство",
    "Grenada" : "Гренада",
    "Georgia" : "Грузия",
    "French Guiana" : "Френска Гвиана",
    "Guernsey" : "Гърнзи",
    "Ghana" : "Гана",
    "Gibraltar" : "Гибралтар",
    "Greenland" : "Гренландия",
    "Gambia" : "Гамбия",
    "Guinea" : "Гвинея",
    "Guadeloupe" : "Гваделупа",
    "Equatorial Guinea" : "Екваториална Гвинея",
    "Greece" : "Гърция",
    "South Georgia and the South Sandwich Islands" : "Южна Джорджия и Южни Сандвичеви острови",
    "Guatemala" : "Гватемала",
    "Guam" : "Гуам",
    "Guinea-Bissau" : "Гвинея Бисау",
    "Guyana" : "Гвиaна",
    "Hong Kong" : "Хонконг",
    "Heard Island and McDonald Islands" : "Хърд и Макдоналд",
    "Honduras" : "Хондурас",
    "Croatia" : "Хърватия",
    "Haiti" : "Хаити",
    "Hungary" : "Унгария",
    "Indonesia" : "Индонезия",
    "Ireland" : "Ирландия",
    "Israel" : "Израел",
    "Isle of Man" : "Остров Ман",
    "India" : "Индия",
    "British Indian Ocean Territory" : "Британска индоокеанска територия",
    "Iraq" : "Ирак",
    "Iran, Islamic Republic of" : "Иран",
    "Iceland" : "Исландия",
    "Italy" : "Италия",
    "Jersey" : "Джърси",
    "Jamaica" : "Ямайка",
    "Jordan" : "Йордания",
    "Japan" : "Япония",
    "Kenya" : "Кения",
    "Kyrgyzstan" : "Киргизстан",
    "Cambodia" : "Камбоджа",
    "Kiribati" : "Кирибати",
    "Comoros" : "Коморски острови",
    "Saint Kitts and Nevis" : "Сейнт Китс и Невис",
    "Korea, Democratic People's Republic of" : "Северна Корея",
    "Korea, Republic of" : "Южна Корея",
    "Kuwait" : "Кувейт",
    "Cayman Islands" : "Кайманови острови",
    "Kazakhstan" : "Казахстан",
    "Lao People's Democratic Republic" : "Лаос",
    "Lebanon" : "Ливан",
    "Saint Lucia" : "Сейнт Лусия",
    "Liechtenstein" : "Лихтенщайн",
    "Sri Lanka" : "Шри Ланка",
    "Liberia" : "Либерия",
    "Lesotho" : "Лесото",
    "Lithuania" : "Литва",
    "Luxembourg" : "Люксембург",
    "Latvia" : "Латвия",
    "Libya" : "Либия",
    "Morocco" : "Мароко",
    "Monaco" : "Монако",
    "Moldova, Republic of" : "Молдова",
    "Montenegro" : "Черна гора",
    "Saint Martin (French part)" : "Сен Мартен",
    "Madagascar" : "Мадагаскар",
    "Marshall Islands" : "Маршалови острови",
    "North Macedonia" : "Северна Македония",
    "Mali" : "Мали",
    "Myanmar" : "Мианмар",
    "Mongolia" : "Монголия",
    "Macao" : "Макао",
    "Northern Mariana Islands" : "Северни Мариански острови",
    "Martinique" : "Мартиника",
    "Mauritania" : "Мавритания",
    "Montserrat" : "Монсерат",
    "Malta" : "Малта",
    "Mauritius" : "Мавриций",
    "Maldives" : "Малдиви",
    "Malawi" : "Малави",
    "Mexico" : "Мексико",
    "Malaysia" : "Малайзия",
    "Mozambique" : "Мозамбик",
    "Namibia" : "Намибия",
    "New Caledonia" : "Нова Каледония",
    "Niger" : "Нигер",
    "Norfolk Island" : "Oстров Норфолк",
    "Nigeria" : "Нигерия",
    "Nicaragua" : "Никарагуа",
    "Netherlands" : "Нидерландия",
    "Norway" : "Норвегия",
    "Nepal" : "Непал",
    "Nauru" : "Науру",
    "Niue" : "Ниуе",
    "New Zealand" : "Нова Зеландия",
    "Oman" : "Оман",
    "Panama" : "Панама",
    "Peru" : "Перу",
    "French Polynesia" : "Френска Полинезия",
    "Papua New Guinea" : "Папуа Нова Гвинея",
    "Philippines" : "Филипини",
    "Pakistan" : "Пакистан",
    "Poland" : "Полша",
    "Saint Pierre and Miquelon" : "Сен Пиер и Микелон",
    "Pitcairn" : "Oстрови Питкерн",
    "Puerto Rico" : "Пуерто Рико",
    "Palestine, State of" : "Палестина",
    "Portugal" : "Португалия",
    "Palau" : "Палау",
    "Paraguay" : "Парагвай",
    "Qatar" : "Катар",
    "Réunion" : "Реюнион",
    "Romania" : "Румъния",
    "Serbia" : "Сърбия",
    "Russian Federation" : "Русия",
    "Rwanda" : "Руанда",
    "Saudi Arabia" : "Саудитска Арабия",
    "Solomon Islands" : "Соломонови острови",
    "Seychelles" : "Сейшелски острови",
    "Sudan" : "Судан",
    "Sweden" : "Швеция",
    "Singapore" : "Сингапур",
    "Saint Helena, Ascension and Tristan da Cunha" : "Света Елена, Възнесение и Тристан да Куня",
    "Slovenia" : "Словения",
    "Svalbard and Jan Mayen" : "Свалбард и Ян Майен",
    "Slovakia" : "Словакия",
    "Sierra Leone" : "Сиера Леоне",
    "San Marino" : "Сан Марино",
    "Senegal" : "Сенегал",
    "Somalia" : "Сомалия",
    "Suriname" : "Суринам",
    "South Sudan" : "Южен Судан",
    "Sao Tome and Principe" : "Сао Томе и Принсипи",
    "El Salvador" : "Ел Салвадор",
    "Sint Maarten (Dutch part)" : "Сен Мартен",
    "Syrian Arab Republic" : "Сирия",
    "Eswatini" : "Есватини",
    "Turks and Caicos Islands" : "Търкс и Кайкос",
    "Chad" : "Чад",
    "French Southern Territories" : "Френски южни и антарктически територии",
    "Togo" : "Того",
    "Thailand" : "Тайланд",
    "Tajikistan" : "Таджикистан",
    "Tokelau" : "Токелау",
    "Timor-Leste" : "Източен Тимор",
    "Turkmenistan" : "Туркменистан",
    "Tunisia" : "Тунис",
    "Tonga" : "Тонга",
    "Turkey" : "Турция",
    "Trinidad and Tobago" : "Тринидад и Тобаго",
    "Tuvalu" : "Тувалу",
    "Taiwan, Province of China" : "Тайван, провинция Китай ",
    "Tanzania, United Republic of" : "Танзания",
    "Ukraine" : "Украйна",
    "Uganda" : "Уганда",
    "United States Minor Outlying Islands" : "Малки отдалечени острови на Съединените щати",
    "United States of America" : "Съединени щати",
    "Uruguay" : "Уругвай",
    "Uzbekistan" : "Узбекистан",
    "Holy See" : "Свети престол",
    "Saint Vincent and the Grenadines" : "Сейнт Винсънт и Гренадини",
    "Venezuela, Bolivarian Republic of" : "Венецуела",
    "Virgin Islands, British" : "Британски Вирджински острови",
    "Virgin Islands, U.S." : "Американски Вирджински острови",
    "Viet Nam" : "Виетнам",
    "Vanuatu" : "Вануату",
    "Wallis and Futuna" : "Уолис и Футуна",
    "Samoa" : "Самоа",
    "Yemen" : "Йемен",
    "Mayotte" : "Майот",
    "South Africa" : "Южна Африка",
    "Zambia" : "Замбия",
    "Zimbabwe" : "Зимбабве",
    "Federation" : "Федерация",
    "High-performance backend" : "Високопроизводителен сървър",
    "Error: Cannot connect to server" : "Грешка: Невъзможно свързване със сървъра",
    "Error: Server did not respond with proper JSON" : "Грешка: Сървърът не отговори с правилен JSON",
    "Could not get version" : "Не можа да се получи версията",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Грешка: Използвана версия: {version}; Сървърът трябва да бъде актуализиран, за да бъде съвместим с тази версия на приложението Talk",
    "Error: Server responded with: {error}" : "Грешка: Сървърът отговори с: {error}",
    "Error: Unknown error occurred" : "Грешка: Възникна неизвестна грешка",
    "Recording backend" : "Записващ сървър",
    "SIP configuration" : "SIP конфигурация",
    "Invalid date, date format must be YYYY-MM-DD" : "Невалидна дата, форматът е различен от ГГГГ-ММ-ДД",
    "Conversation not found" : "Разговорът не е намерен",
    "Chat, video & audio-conferencing using WebRTC" : "Чат, видео и аудио-конферентна връзка с помощта на WebRTC",
    "Leave call" : "Напускане на обаждането",
    "Navigating away from the page will leave the call in {conversation}" : "Навигирането извън страницата ще остави обаждането в {conversation}",
    "Stay in call" : "Оставене в обаждането",
    "Discuss this file" : "Обсъждане на този файл",
    "Share this file with others to discuss it" : "Споделете този файл с други, за да го обсъдите",
    "Share this file" : "Споделяне на този файл",
    "Join conversation" : "Присъединяване към разговора",
    "This conversation is password-protected." : "Този разговор е защитен с парола.",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "Открихме множество опити с невалидна парола от вашия IP. Следователно следващият ви опит се ограничава за 30 секунди.",
    "The password is wrong. Try again." : "Паролата е грешна. Опитайте отново.",
    "Password" : "Парола",
    "Submit" : "Изпращане",
    "Error requesting the password." : "Грешка при заявяване на паролата.",
    "Request password" : "Заявка за парола",
    "This conversation has ended" : "Този разговор е приключил",
    "Error occurred when joining the conversation" : "Възникна грешка при присъединяване към разговора",
    "Close Talk sidebar" : "Затваряне на страничната лента на Talk",
    "Open Talk sidebar" : "Отворяне на страничната лента на Talk",
    "Everyone" : "Всички",
    "Users and moderators" : "Потребители и модератори",
    "Moderators only" : "Само модератори",
    "Disable calls" : "Деактивиране на обажданията",
    "Save changes" : "Запиши промените",
    "Saving …" : "Записване …",
    "Saved!" : "Записано!",
    "Limit to groups" : "Ограничен достъп",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Когато е избрана поне една група, само хората от изброените групи могат да участват в разговорите.",
    "Guests can still join public conversations." : "Гостите все още могат да се присъединяват към публични разговори.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Потребителите, които вече не могат да използват Talk, ще продължат да бъдат броени като участници в предишните им разговори, а също и техните съобщения в чата ще бъдат запазени.",
    "Limit using Talk" : "Ограничаване на използването на Talk",
    "Limit creating a public and group conversation" : "Ограничете създаването на публичен и групов разговор",
    "Limit creating conversations" : "Ограничете създаването на разговори",
    "Limit starting a call" : "Ограничете започването на обаждане",
    "Limit starting calls" : "Ограничете започващите обаждания",
    "When a call has started, everyone with access to the conversation can join the call." : "Когато обаждането започне, всеки с достъп до разговора може да се присъедини към обаждането.",
    "Enabled" : "Включено",
    "Disabled" : "Изключено",
    "State" : "Състояние",
    "Name" : "Име",
    "Beta" : "Бета",
    "Permissions" : "Права",
    "All messages" : "Всички съобщения",
    "@-mentions only" : "@-само споменавания",
    "Off" : "Изключен",
    "General settings" : "Общи настройки",
    "Default notification settings" : "Настройки на известие по подразбиране",
    "Default group notification" : "Групово известие по подразбиране",
    "Default group notification for new groups" : "Групово известие за нови групи по подразбиране",
    "Integration into other apps" : "Интегриране в други приложения",
    "Allow conversations on files" : "Разрешаване на разговори за файлове",
    "Allow conversations on public shares for files" : "Разрешаване на разговори за публични споделяния на файлове",
    "Enable encryption" : "Активиране на криптирането",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "С натискане на горния бутон, информацията във формуляра се изпраща към сървърите на Struktur AG. Можете да намерите допълнителна информация на {linkstart}spreed.eu{linkend}.",
    "Pending" : "Чакащо",
    "Error" : "Грешка",
    "Blocked" : "Блокира",
    "Active" : "Активен",
    "Expired" : "Изтекъл",
    "Never" : "Никога",
    "The trial could not be requested. Please try again later." : "Не можа да се поиска изпробване. Моля, опитайте отново по-късно.",
    "The account could not be deleted. Please try again later." : "Профилът не можа да бъде изтрит. Моля, опитайте отново по-късно.",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Нашият партньор Struktur AG предоставя услуга, при която може да бъде заявен хостван сървър за сигнализация. За това трябва само да попълните формуляра по-долу и вашият Nextcloud ще го заяви След като сървърът е настроен за вас, вашите идентификационни данни ще бъдат попълнени автоматично. Това ще презапише съществуващите настройки на сървъра за сигнализация.",
    "URL of this Nextcloud instance" : "URL на този екземпляр на Nextcloud",
    "Full name of the user requesting the trial" : "Пълно име на потребителя, който иска изпробването",
    "Email of the user" : "Имейл на потребителя",
    "Language" : "Език",
    "Country" : "Държава",
    "Request signaling server trial" : "Заявка зс изпробване на сървъра за сигнализиране",
    "You can see the current status of your hosted signaling server in the following table." : "Можете да видите текущото състояние на вашия хостван сигнализиращ сървър в следващата таблица.",
    "Status" : "Състояние",
    "Created at" : "Създаден на",
    "Expires at" : "Изтича в",
    "Limits" : "Ограничения",
    "Yes" : "Да",
    "No" : "Не",
    "Delete the signaling server account" : "Изтриване на профил на сигналния сървър",
    "_%n user_::_%n users_" : ["%n потребители","%n потребители"],
    "Installed version: {version}" : "Инсталирана версия: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "Можете да инсталирате Matterbridge, за да свържете Nextcloud Talk с някои други услуги, посетете тяхната {linkstart1}страница на GitHub{linkend} за повече подробности. Изтеглянето и инсталирането на приложението може да отнеме известно време. В случай, че то изтече, моля, инсталирайте го ръчно от {linkstart2}Nextcloud App Store{linkend}.",
    "Matterbridge binary was not found or couldn't be executed." : "Двоичният файл Matterbridge не е намерен или не може да бъде изпълнен.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Можете също да зададете пътя към двоичния файл Matterbridge ръчно чрез конфигурацията. Проверете {linkstart}документацията за интеграция на Matterbridge{linkend} за повече информация.",
    "Downloading …" : "Изтегляне …",
    "Install Talk Matterbridge" : "Инсталиране на Talk Matterbridge",
    "An error occurred while installing the Matterbridge app" : "Възникна грешка при инсталирането на приложението Matterbridge",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "Възникна грешка при инсталирането на Talk Matterbridge. Моля, инсталирайте го ръчно",
    "Failed to execute Matterbridge binary." : "Неуспешно изпълнение на двоичен файл Matterbridge.",
    "Matterbridge integration" : "Интеграция на Matterbridge",
    "Enable Matterbridge integration" : "Активиране на интеграцията на Matterbridge",
    "Status: Checking connection" : "Състояние: Проверка на връзката",
    "OK: Running version: {version}" : "ОК: Работна версия: {version}",
    "Recording backend URL" : "URL адрес на записващ бекенд сървър",
    "Validate SSL certificate" : "Проверка на SSL сертификата",
    "Delete this server" : "Изтриване на този сървър",
    "Test this server" : "Тествайте този сървър",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "Настройките на PHP „upload_max_filesize“/качване_макс_размернафайл/  или „post_max_size“ /публикуване_макс_размер/ ще позволят само качване на файлове до {maxUpload}.",
    "Recording backend settings saved" : "Настройките на записващия бекенд сървър са запазени",
    "Add a new recording backend server" : "Добавяне на нов записващ бекенд сървър",
    "Shared secret" : "Споделена тайна",
    "SIP configuration saved!" : "SIP конфигурацията е запазена!",
    "Restrict SIP configuration" : "Ограничаване на SIP конфигурацията",
    "Enable SIP configuration" : "Активиране на SIP конфигурацията",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Само потребители от следните групи могат да активират SIP в разговорите, които модерират",
    "Phone number (Country)" : "Телефонен номер (държава)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Тази информация се изпраща в имейли с покани, също така се показва в страничната лента на всички участници.",
    "Error code" : "Код за грешка",
    "High-performance backend URL" : "URL адрес на високопроизводителен сървър",
    "High-performance backend settings saved" : "Настройките на бекенд сървъра с висока производителност са запазени",
    "STUN server URL" : "URL на STUN сървъра",
    "The server address is invalid" : "Адресът на сървъра е невалиден",
    "STUN settings saved" : "Настройките на STUN са запазени",
    "STUN servers" : "STUN сървъри",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Сървърът STUN се използва за определяне на публичния IP адрес на участниците зад рутер.",
    "Add a new STUN server" : "Добавяне на нов STUN сървър",
    "{schema} scheme must be used with a domain" : "Схемата {schema} трябва да се използва с домейн",
    "{option1} and {option2}" : "{option1} и {option2}",
    "{option} only" : "само {option}",
    "OK: Successful ICE candidates returned by the TURN server" : "OK: Успешни ICE кандидати, върнати от TURN сървъра",
    "Error: No working ICE candidates returned by the TURN server" : "Грешка: Няма работещи ICE кандидати, върнати от TURN сървъра",
    "Testing whether the TURN server returns ICE candidates" : "Тества се дали TURN сървърът връща ICE кандидати",
    "TURN server schemes" : "Сървърни схеми TURN",
    "TURN server URL" : "URL на TURN сървъра",
    "TURN server secret" : "Тайна на сървъра TURN",
    "TURN server protocols" : "Протоколи на TURN сървър",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "TURN сървър се използва за прокси трафик от участници зад защитна стена. Ако отделните участници не могат да се свържат с други, най-вероятно е нужен TURN сървър. Вижте {linkstart} тази документация {linkend} с инструкции за настройка.",
    "TURN settings saved" : "Настройките на TURN са запазени",
    "TURN servers" : "TURN сървъри",
    "Add a new TURN server" : "Добавяне на нов TURN сървър",
    "Failed" : "Неуспешно",
    "OK" : "Добре",
    "Checking …" : "Проверка ...",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "Неуспешно: WebAssembly е деактивиран или не се поддържа в този браузър. Моля, активирайте WebAssembly или използвайте браузър с поддръжка за него, за да направите проверката.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "Неуспех: файловете „wasm“ и „.tflite“ не са върнати правилно от уеб сървъра. Моля, проверете раздела „Системни изисквания“ в документацията на Talk.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "OK: файловете „wasm“ и „.tflite“ са върнати правилно от уеб сървъра.",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "Изглежда, че конфигурацията на PHP и Apache не е съвместима. Моля, обърнете внимание, че PHP може да се използва само с модул MPM_PREFORK, а PHP-FPM може да се използва само с модул MPM_EVENT.",
    "Web server setup checks" : "Проверки за настройка на уеб сървъра",
    "Files required for virtual background can be loaded" : "Могат да се заредят файлове необходими за виртуалния фон",
    "Assign participants to rooms" : "Зачисляване на участници към стаи",
    "Configure breakout rooms" : "Конфигуриране на стаи за отделно събрание",
    "Number of breakout rooms" : "Брой стаи за отделно събрание",
    "Assignment method" : "Метод на задаване",
    "Automatically assign participants" : "Автоматично зачисляване на участници",
    "Manually assign participants" : "Ръчно зачисляване на участниците",
    "Allow participants to choose" : "Позволяване на участниците да избират",
    "Create rooms" : "Създаване на стаи",
    "Confirm" : "Потвърдете",
    "Create breakout rooms" : "Създаване на стаи за отделно събрание",
    "Reset" : "Възстановяване",
    "Delete breakout rooms" : "Изтриване на стаи за отделно събрание",
    "Room {roomNumber}" : "Стая {roomNumber}",
    "Current breakout rooms and settings will be lost" : "Текущите стаи за отделно събрание и настройки ще бъдат изгубени",
    "Cancel" : "Отказ",
    "Unassigned participants" : "Незачислени участници",
    "Back" : "Назад",
    "Assign" : "Задаване на",
    "Add participant \"{user}\"" : "Добавяне на участник „{user}“",
    "Now" : "Сега",
    "Loading …" : "Зареждане …",
    "From" : "От",
    "To" : "До",
    "Calendar" : "Kалендар",
    "Attendees" : "Участници",
    "Save" : "Запазване",
    "Search participants" : "Търсене на участници",
    "No results" : "Няма резултати",
    "Done" : "Завършено",
    "Raise hand" : "Вдигане на ръка",
    "Raise hand (R)" : "Вдигане на ръка (R)",
    "Lower hand" : "Сваляне на ръка",
    "Lower hand (R)" : "Сваляне на ръка (R)",
    "Speaker view" : "Изглед на високоговорителя",
    "Grid view" : "Решетъчен изглед",
    "This conversation is read-only" : "Този разговор е само за четене",
    "Reload" : "Презареди",
    "{nickName} raised their hand." : "{nickName} вдигна ръка.",
    "A participant raised their hand." : "Един участник вдигна ръка.",
    "Collapse stripe" : "Свиване на лента",
    "Expand stripe" : "Разширяване на лента",
    "Previous page of videos" : "Предишна страница с видеоклипове",
    "Next page of videos" : "Следваща страница с видеоклипове",
    "Connecting …" : "Свързване ...",
    "Waiting for {user} to join the call" : "Изчаква се {user} да се присъедини към обаждането",
    "Waiting for others to join the call …" : "Изчаква се и други да се присъединят към обаждането ...",
    "You can invite others in the participant tab of the sidebar" : "Можете да поканите други от раздела за участници в страничната лента",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Можете да поканите други от раздела за участници на страничната лента или да споделите тази връзка, за да поканите други!",
    "Share this link to invite others!" : "Споделете тази връзка, за да поканите други!",
    "Copy link" : "Копирай връзката",
    "You are not allowed to enable audio" : "Нямате право да активирате аудио",
    "No audio. Click to select device" : "Няма аудио. Кликнете, за да изберете устройство",
    "Mute audio" : "Спиране на звука",
    "Mute audio (M)" : "Изключване на звука (M)",
    "Unmute audio" : "Включване на звука",
    "Unmute audio (M)" : "Включване на звука (M)",
    "None" : "Без",
    "Access to camera was denied" : "Беше отказан достъп до камера",
    "Error while accessing camera: It is likely in use by another program" : "Грешка при достъп до камера: възможно е тя се използва от друга програма",
    "Error while accessing camera" : "Грешка при достъп до камера",
    "You have been muted by a moderator" : "Бяхте заглушен от модератор",
    "You are not allowed to enable video" : "Нямате право да активирате видео",
    "No video. Click to select device" : "Няма видео. Кликнете, за да изберете устройство",
    "Disable video" : "Изключване на видеото",
    "Disable video (V)" : "Изключване на видеото (V)",
    "Enable video" : "Включи видео",
    "Enable video (V)" : "Включване на видеото (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Включване на видеото - Вашата връзка ще бъде прекъсната за кратко, когато включите видеото за първи път",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Включване на видеото (V) – Вашата връзка ще бъде прекъсната за кратко, когато включите видеото за първи път",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Включване на видеото. Вашата връзка ще бъде прекъсната за кратко, когато включите видеото за първи път",
    "You" : "Ти",
    "Mute" : "Заглушаване",
    "Muted" : "Заглушен",
    "Show screen" : "Показване на екрана",
    "Stop following" : "Спрете да следвате",
    "Connection could not be established …" : "Връзката не можа да бъде установена …",
    "Connection was lost and could not be re-established …" : "Връзката се изгуби и не можа да бъде възстановена ...",
    "Connection could not be established. Trying again …" : "Връзката не можа да бъде установена. Повторен опит …",
    "Connection lost. Trying to reconnect …" : "Връзката е загубена. Опит за повторно свързване …",
    "Connection problems …" : "Проблеми с връзката …",
    "Collapse" : "Сгъване",
    "Expand" : "Разгъване",
    "You need to be logged in to upload files" : "Трябва да сте влезли, за да качвате файлове",
    "Drop your files to upload" : "Пуснете вашите файлове, за да ги качите",
    "Conversation messages" : "Съобщения за разговор",
    "Scroll to bottom" : "Превъртане до долу",
    "Post message" : "Публикуване на съобщение",
    "Favorite" : "Любима",
    "Date:" : "Дата:",
    "Hide details" : "Скриване на подробностите",
    "Show details" : "Показване на подробности",
    "Error while updating conversation name" : "Грешка при актуализиране на името на разговора",
    "Error while updating conversation description" : "Грешка при актуализиране на описанието на разговора",
    "Enter a name for this conversation" : "Въведете име за този разговор",
    "Edit conversation name" : "Редактиране на името на разговора",
    "Edit conversation description" : "Редактиране на описанието на разговора",
    "Enter a description for this conversation" : "Въвеждане на описание за този разговор",
    "Picture" : "Снимка",
    "Disable" : "Изключване",
    "Enable" : "Включена",
    "Breakout rooms" : "Стаи за отделно събрание",
    "Manage breakout rooms" : "Управление на стаите за отделно събрание",
    "Set up breakout rooms for this conversation" : "Създаване на стаи за отделно събрание за този разговор",
    "Please select a valid PNG or JPG file" : "Моля, изберете валиден PNG или JPG файл",
    "Choose" : "Изберете",
    "The file must be a PNG or JPG" : "Файлът трябва да е във формат PNG или JPG",
    "Default permissions modified for {conversationName}" : "Права по подразбиране са променени за {conversationName}",
    "Could not modify default permissions for {conversationName}" : "Не можаха да се променят права по подразбиране за {conversationName}",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Редактиране на права по подразбиране за участниците в този разговор. Тези настройки не засягат модераторите.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Всеки път, когато се променят права в този раздел, потребителските права, които са били зададени преди това на отделните участници, ще бъдат загубени.",
    "All permissions" : "Всички права",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Участниците имат права да започнат разговор, да се присъединят към разговор, да активират аудио и видео и да споделят екран.",
    "Restricted" : "Ограничен",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Участниците могат да се присъединяват към разговори, но не могат да активират аудио или видео, нито да споделят екран, докато модераторът ръчно не им предостави права.",
    "Advanced permissions" : "Разширени права",
    "Edit permissions" : "Редактиране на права",
    "Conversation settings" : "Настройки за разговор",
    "Basic Info" : "Основна информация",
    "Personal" : "Личен",
    "Moderation" : "Модериране /Наблюдаване/",
    "Breakout Rooms" : "Стаи за Отделно събрание",
    "Matterbridge" : "Matterbridge",
    "Danger zone" : "Зона на опасност",
    "Leave conversation" : "Напускане на разговор",
    "You need to promote a new moderator before you can leave the conversation" : "Трябва да повишите нов модератор, преди да можете да напуснете разговора",
    "Delete conversation" : "Изтриване на разговора",
    "Do you really want to delete \"{displayName}\"?" : "Наистина ли искате да изтриете „{displayName}“?",
    "Error while deleting conversation" : "Грешка при изтриването на разговор",
    "Delete all chat messages" : "Изтриване на всички съобщенията в чата",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Наистина ли искате да изтриете всички съобщения в „{displayName}“?",
    "Error while clearing chat history" : "Грешка при изчистване на историята на чата",
    "Be careful, these actions cannot be undone." : "Бъдете внимателни, тези действия не могат да бъдат отменени.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Веднъж след като разговорът бъде напуснат, за да се присъедините отново към затворен разговор, е необходима покана. Към отворен разговор може да се присъедините по всяко време.",
    "Permanently delete this conversation." : "Изтриване на разговора за постоянно.",
    "Delete chat messages" : "Изтриване на съобщенията в чата",
    "Permanently delete all the messages in this conversation." : "Изтриване за постоянно на всички съобщения в този разговор.",
    "_%n hour_::_%n hours_" : ["%n часа","%n часа"],
    "_%n day_::_%n days_" : ["%n дни","%n дни"],
    "_%n week_::_%n weeks_" : ["%n седмици","%n седмици"],
    "Custom expiration time" : "Персонализиране на времето на изтичане",
    "Message expiration disabled" : "Изтичането на съобщение е деактивирано",
    "Message expiration set: {duration}" : "Зададено изтичане на съобщение: {duration}",
    "Error when trying to set message expiration" : "Грешка при опит за задаване на краен срок на съобщението",
    "Message expiration" : "Изтичане на съобщението",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Съобщенията в чата могат да изтекат след определено време. Забележка: Файловете, споделени в чата, няма да бъдат изтрити за собственика, но повече няма да бъдат споделяни в разговора.",
    "Guest access" : "Достъп за гост",
    "Allow guests to join this conversation via link" : "Разрешаване на гостите да се присъединят към този разговор чрез връзка",
    "Password protection" : "Password protection",
    "Set a password" : "Задаване на парола",
    "Change password" : "Промяна на парола",
    "Enter new password" : "Въвеждане на нова парола",
    "Save password" : "Запиши паролата",
    "Resend invitations" : "Повторно изпращане на покани",
    "Error occurred when opening or limiting the conversation" : "Възникна грешка при отваряне или ограничаване на разговора",
    "Open conversation to registered users, showing it in search results" : "Отваряне на разговора за регистрирани потребители, и показването му в резултатите от търсенето",
    "Start time has been updated" : "Началният час е актуализиран ",
    "Error occurred while updating start time" : "Възникна грешка при актуализиране на началния час",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "Активирането на лобито ще премахне немодераторите от текущия разговор.",
    "Enable lobby, restricting the conversation to moderators" : "Активиране на лобито и ограничаване на разговора за модераторите",
    "Meeting start time" : "Начален час на срещата",
    "Start time (optional)" : "Начален час (по избор)",
    "Error occurred when locking the conversation" : "Възникна грешка при заключване на разговора",
    "Error occurred when unlocking the conversation" : "Възникна грешка при отключване на разговора",
    "Lock conversation" : "Заключване на разговор",
    "This will also terminate the ongoing call." : "Това също ще прекрати текущото обаждане.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Заключване на разговора, за да се попречи на всеки да публикува съобщения или да започва обаждания",
    "Edit" : "Променяне",
    "More information" : "Повече информация",
    "Delete" : "Изтриване",
    "Add new bridged channel to current conversation" : "Добавяне на нов мостов канал към текущия разговор",
    "unknown state" : "неизвестно състояние",
    "running" : "в процес",
    "not running, check Matterbridge log" : "не работи, проверка на журнал на Matterbridge",
    "not running" : "не работи",
    "Bridge saved" : "Мостът е запазен",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Можете да свързвате канали от различни системи за незабавни съобщения с Matterbridge.",
    "More info on Matterbridge" : "Повече информация за Matterbridge",
    "Enable bridge" : "Активиране на мост",
    "Show Matterbridge log" : "Показване на журнал на Matterbridge",
    "Log content" : "Съдържание на журнал",
    "Notifications" : "Известия",
    "Notify about calls in this conversation" : "Уведомяване за обаждания в този разговор",
    "Important conversation" : "Важен разговор",
    "SIP dial-in is now possible without PIN requirement" : "Вече е възможно SIP набиране без изискване за PIN",
    "SIP dial-in is now enabled" : "SIP набирането  вече е активирано",
    "SIP dial-in is now disabled" : "SIP набирането вече е деактивирано",
    "Error occurred when enabling SIP dial-in" : "Възникна грешка при активиране на SIP набиране",
    "Error occurred when disabling SIP dial-in" : "Възникна грешка при деактивиране на SIP набиране",
    "Phone and SIP dial-in" : "Набиране по телефон и SIP",
    "Enable phone and SIP dial-in" : "Активиране на телефонно и SIP набиране",
    "Allow to dial-in without a PIN" : "Разрешаване на набиране без ПИН",
    "Join" : "Влез",
    "Error while creating the conversation" : "Грешка при създаването на разговора",
    "Unread mentions" : "Непрочетени споменавания",
    "Create conversation" : "Създаване на разговор",
    "Enter your name" : "Въведете вашето име",
    "Mark as read" : "Маркирай като прочетено",
    "Mark as unread" : "Маркирай като непрочетено",
    "Remove from favorites" : "Премахни от любимите",
    "Add to favorites" : "Добави към любимите",
    "You need to promote a new moderator before you can leave the conversation." : "Трябва да повишите нов модератор, преди да можете да напуснете разговора.",
    "Conversation actions" : "Действия при разговор",
    "Home" : "Начало",
    "Unread" : "Непрочетено",
    "Alphabetically" : "По азбучен ред",
    "No matches found" : "Няма намерени съвпадения",
    "No conversations found" : "Няма намерени разговори",
    "An error occurred while performing the search" : "Възникна грешка при извършване на търсенето",
    "Conversation list" : "Списък с разговори",
    "Unread messages" : "Непрочетени съобщения",
    "New personal note" : "Нова лична бележка",
    "Clear filter" : "Изчстиване на филтър",
    "App settings" : "Настройки на приложението",
    "Users" : "Потребители",
    "Groups" : "Групи",
    "Other sources" : "Други източници",
    "Open conversations" : "Отворени разговори",
    "No search results" : "Няма резултати от търсенето",
    "Users and groups" : "Потребители и групи",
    "The meeting will start soon" : "Срещата ще започне скоро",
    "This meeting is scheduled for {startTime}" : "Тази среща е насрочена за {startTime}",
    "You are currently waiting in the lobby" : "В момента изчаквате в лобито",
    "Select microphone" : "Избор на микрофон",
    "No microphone available" : "Няма наличен микрофон",
    "Select camera" : "Избор на камера",
    "No camera available" : "Няма налична камера",
    "Test" : "Тест",
    "Devices" : "Устройства",
    "Backgrounds" : "Фонове",
    "No audio" : "Без аудио",
    "No camera" : "Без камера",
    "Calls are not supported in your browser" : "Обажданията не се поддържат във вашия браузър",
    "Access to microphone is only possible with HTTPS" : "Достъп до микрофона е възможен само с HTTPS",
    "Access to microphone was denied" : "Беше отказан достъп до микрофон",
    "Error while accessing microphone" : "Грешка при достъп до микрофон",
    "Access to camera is only possible with HTTPS" : "Достъп до камера е възможен само с HTTPS",
    "The call is being recorded." : "Разговорът се записва.",
    "Select a file" : "Избор на файл",
    "Invalid path selected" : "Предоставен е невалиден път до файл.",
    "Blur" : "Замъгляване",
    "Upload" : "Качване",
    "Files" : "Файлове",
    "The message has expired or has been deleted" : "Съобщението е изтекло или е изтрито",
    "Cancel quote" : "Отказ на офертата",
    "24 hours" : "24 часа",
    "7 days" : "7 дни",
    "Clear reminder – {timeLocale}" : "Премахни напомнянето - {timeLocale}",
    "Add a reaction to this message" : "Добавяне на реакция към това съобщение",
    "Reply" : "Отговори",
    "More actions" : "Повече действия",
    "Reply privately" : "Отговаряне на лично ",
    "Edit message" : "Редактиране на съобщение",
    "Copy message link" : "Копиране на връзката към съобщението",
    "Go to file" : "Отидете до файла",
    "Forward message" : "Препращане на съобщение",
    "Translate" : "Превод",
    "Close reactions menu" : "Затваряне на менюто за действия",
    "React with {emoji}" : "Реагирайте с {emoji}",
    "React with another emoji" : "Реагирайте с друг емотикон",
    "Choose a conversation to forward the selected message." : "Изберете разговор, за да препратите избраното съобщение.",
    "Error while forwarding message" : "Грешка при препращане на съобщение",
    "The message has been forwarded to {selectedConversationName}" : "Съобщението е препратено до {selectedConversationName}",
    "Dismiss" : "Отхвърляне",
    "Go to conversation" : "Отиване на разговор",
    "Detect language" : "Разпознаване на език",
    "Send now" : "Изпратете сега",
    "Message read by everyone who shares their reading status" : "Съобщение, прочетено от всеки, който споделя статуса си на четене",
    "Message sent" : "Съобщението е изпратено",
    "Deleting message" : "Съобщението се изтрива",
    "Message deleted successfully" : "Съобщението е изтрито успешно",
    "Message could not be deleted because it is too old" : "Съобщението не можа да бъде изтрито, защото е твърде старо",
    "Only normal chat messages can be deleted" : "Само нормалните съобщения за чат могат да бъдат изтрити",
    "An error occurred while deleting the message" : "Възникна грешка при изтриването на съобщението",
    "Your browser does not support playing audio files" : "Вашият браузър не поддържа възпроизвеждане на аудио файлове",
    "Contact" : "Контакт",
    "{stack} in {board}" : "{stack} в {board}",
    "Deck Card" : "Deck карта",
    "Remove {fileName}" : "Премахване на {fileName}",
    "Open this location in OpenStreetMap" : "Отвяне на това местоположение в OpenStreetMap",
    "Sending message" : "Изпращане на съобщение",
    "Failed to send the message. Click to try again" : "Изпращането на съобщението не беше успешно. Кликнете, за да опитате отново",
    "Not enough free space to upload file" : "Няма достатъчно свободно място за качване на файл",
    "You cannot send messages to this conversation at the moment" : "В момента не можете да изпращате съобщения до този разговор",
    "You voted" : "Вие гласувахте",
    "_%n vote_::_%n votes_" : ["%nгласувания ","%n гласувания"],
    "See results" : "Вижте резултатите",
    "No permission to post reactions in this conversation" : "Няма зададено право за публикуване на реакции в този разговор",
    "Add more reactions" : "Добавяне на повече реакции",
    "No messages" : "Няма съобщения.",
    "All messages have expired or have been deleted." : "Всички съобщения са изтекли или са били изтрити.",
    "Unpin" : "Отмяна на закачване",
    "Cancel search" : "Отказване на търсенето",
    "Create a new group conversation" : "Създаване на нов групов разговор",
    "Add participants" : "Добавяне на участници",
    "Conversation visibility" : "Видимост на разговора",
    "Allow guests to join via link" : "Разрешете на гостите да се присъединят чрез връзка",
    "Enter password" : "Въвеждане на парола",
    "This conversation has been locked" : "Този разговор е заключен",
    "No permission to post messages in this conversation" : "Няма право за публикуване на съобщения в този разговор",
    "Joining conversation …" : "Присъединяване към разговора ...",
    "Send message" : "Изпрати съобщение",
    "Send without notification" : "Изпращане без известие",
    "File to share" : "Файл за споделяне",
    "Add emoji" : "Добавяне на емотикон",
    "Send later" : "Изпратете по-късно",
    "Cancel editing" : "Отказ на редактирането",
    "Absence period: {startDate} - {endDate}" : "Период на отсъствие:  {startDate} до {endDate}.",
    "Share from {nextcloud}" : "Споделяне от {nextcloud}",
    "Share from Files" : "Споделяне от файлове",
    "Share files to the conversation" : "Споделяне на файлове в разговора",
    "Upload from device" : "Качване от устройство",
    "Create new poll" : "Създаване на нова анкета",
    "Smart picker" : "Умно избиране",
    "Record voice message" : "Запис на гласово съобщение",
    "End recording and send" : "Край на записа и изпращане",
    "Dismiss recording" : "Отхвърляне на записа",
    "Access to the microphone was denied" : "Беше отказан достъп до микрофона",
    "Microphone either not available or disabled in settings" : "Микрофонът или не е наличен, или е деактивиран в настройките",
    "Error while recording audio" : "Грешка при запис на аудио",
    "New file" : "Нов файл",
    "Blank" : "Празен",
    "Error while creating file" : "Грешка при създаване на файл",
    "Create and share a new file" : "Създаване и споделяне на нов файл",
    "Name of the new file" : "Име на новия файл",
    "Create file" : "Създаване на файл",
    "Add more files" : "Добавяне на още файлове ",
    "Send" : "Изпрати",
    "In this conversation <strong>{user}</strong> can:" : "В този разговор <strong>{user}</strong> може:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Редактиране на права по подразбиране за участниците в <strong>{conversationName}</strong>",
    "Start a call" : "Започване на обаждане",
    "Skip the lobby" : "Пропускане на лобито",
    "Can post messages and reactions" : "Може да се публикуват съобщения и реакции",
    "Enable the microphone" : "Активиране на микрофона",
    "Enable the camera" : "Активиране на камера",
    "Share the screen" : "Споделяне на екрана",
    "Update permissions" : "Актуализиране на права",
    "Updating permissions" : "Актуализират се права",
    "There is no poll drafts yet saved for this conversation" : "Все още няма запаметени чернови на анкети за този разговор",
    "Create poll" : "Създаване на анкета",
    "Question" : "Въпрос",
    "Ask a question" : "Задаване на въпрос",
    "Answers" : "Отговори",
    "Answer {option}" : "Отговор {option}",
    "Delete poll option" : "Изтриване на опция за анкета",
    "Add answer" : "Добавяне на отговор",
    "Settings" : "Настройки",
    "Anonymous poll" : "Анонимна анкета",
    "Multiple answers" : "Множество отговори",
    "You voted for this option" : "Гласували сте за тази опция",
    "End poll" : "Край на анкетата",
    "Change your vote" : "Променете гласуването си",
    "Results" : "Резултати",
    "Voted participants" : "Гласували участници",
    "Send a message to \"{roomName}\"" : "Изпращане на съобщение до „{roomName}“",
    "Hide list of participants" : "Скриване на списъка с участници",
    "Show list of participants" : "Показване на списъка с участници",
    "Assistance requested in {roomName}" : "Поискано е съдействие в {roomName}",
    "The message was sent to \"{roomName}\"" : "Съобщението е изпратено до „{roomName}“",
    "Dismiss request for assistance" : "Отхвърляне на заявка за съдействие",
    "Send message to room" : "Изпращане на съобщение до стая",
    "Back to main room" : "Обратно към основната стая",
    "Back to your room" : "Обратно към вашата стая",
    "Message all rooms" : "Съобщение до всички стаи",
    "Start session" : "Начало на сесията",
    "Start a call before you start a breakout room session" : "Започване на обаждане, преди да стартирате сесия в стая за  отделно събрание",
    "Stop session" : "Спиране на сесия",
    "The message was sent to all breakout rooms" : "Съобщението е изпратено до всички стаи за отделно събрание",
    "Send a message to all breakout rooms" : "Изпращане на съобщение до всички стаи за отделно събрание",
    "Breakout rooms are not started" : "Стаите за отделно събрание не са стартирани",
    "Disable lobby" : "Деактивиране на лоби",
    "Settings for participant \"{user}\"" : "Настройки за участник „{user}“",
    "Participant \"{user}\"" : "Участник „{user}“",
    "moderator" : "модератор",
    "bot" : "бот",
    "guest" : "гост",
    "Raised their hand" : "Вдигнаха ръка",
    "Joined with video" : "Присъединен с видео",
    "Joined via phone" : "Присъединен по телефона",
    "Joined with audio" : "Присъединен с аудио",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "Текстът трябва да е по-малък или равен на {maxLength} знака. Текущият ви текст е дълъг {charactersCount} знака.",
    "Remove group and members" : "Премахване на групата и на членовете",
    "Remove participant" : "Премахване на участник",
    "Notification was sent to {displayName}" : "Беше изпратено известие до {displayName}",
    "Could not send notification to {displayName}" : "Не можа да се изпрати известие до {displayName}",
    "Permissions granted to {displayName}" : "Дадоха се права на {displayName}",
    "Could not modify permissions for {displayName}" : "Не можаха да се променят права за {displayName}",
    "Permissions removed for {displayName}" : "Премахнати са права за {displayName}",
    "Permissions set to default for {displayName}" : "Зададени са права по подразбиране за {displayName}",
    "Dial-in PIN" : "ПИН за набиране",
    "Demote from moderator" : "Понижаване от модератор",
    "Promote to moderator" : "Повишаване до модератор",
    "Resend invitation" : "Повторно изпращане на покана",
    "Send call notification" : "Изпращане на известие за обаждане",
    "Reset custom permissions" : "Възстановяване на персонализираните права",
    "Grant all permissions" : "Даване на всички права",
    "Remove all permissions" : "Премахване на всички права",
    "Remove" : "Премахване",
    "Permissions modified for {displayName}" : "Променени са права за {displayName}",
    "Add users or groups" : "Add users or groups",
    "Add users" : "Добавяне на потребители",
    "Add groups" : "Добавяне на групи",
    "Add other sources" : "Добавяне на други източници",
    "Add emails" : "Добавяне на имейли",
    "Integrations" : "Интеграции",
    "Add federated users" : "Добавяне на федерирани потребители",
    "Searching …" : "Търсене ...",
    "Search for more users" : "Търсене на повече потребители",
    "Search or add participants" : "Търсене или добавяне на участници",
    "Invitation was sent to {actorId}" : "Беше изпратена покана до {actorId}",
    "An error occurred while adding the participants" : "Възникна грешка при добавянето на участници",
    "Participants" : "Участници",
    "Participants ({count})" : "Участници ({count})",
    "Open chat" : "Отворяне на чата",
    "You have new unread messages in the chat." : "Имате нови непрочетени съобщения в чата.",
    "You have been mentioned in the chat." : "Споменаха ви в чата.",
    "Chat" : "Съобщения",
    "Details" : "Подробности",
    "Shared items" : "Споделени елементи",
    "No results found" : "Няма намерени резултати",
    "Load more results" : "Зареждане на още резултати",
    "Projects" : "Проекти",
    "No shared items" : "Няма споделени елементи",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Свързване към разговор",
    "Search conversations or users" : "Търсене на разговори или потребители",
    "Select conversation" : "Избор на разговор",
    "Save name" : "Запиши името",
    "Error while setting personal setting" : "Грешка при записване на личната настройка",
    "Error while saving sounds setting" : "Грешка при запазване на настройката за звуци",
    "Play sounds when participants join or leave a call" : "Възпроизвеждане на звуци, когато участниците се присъединят или напуснат разговор",
    "Notification settings" : "Настройки на известие",
    "Default language" : "Стандартен език",
    "Select location for attachments" : "Избор на местоположение за прикачени файлове",
    "Error while setting attachment folder" : "Грешка при настройка на папка за прикачени файлове",
    "Error while setting read status privacy" : "Грешка при задаване на поверителност на състоянието на четене",
    "Privacy" : "Поверителност",
    "Attachments folder" : "Папка с прикачени файлове",
    "Search" : "Търсене",
    "Focus the chat input" : "Фокусиране на въвеждането в чата",
    "Unfocus the chat input to use shortcuts" : "Прекратяване на фокусирането на въвеждането в чата, за да се използват преки пътища ",
    "Shortcuts while in a call" : "Преки пътища по време на обаждане",
    "Camera on and off" : "Включване и изключване на камера",
    "Microphone on and off" : "Включване и изключване на микрофон",
    "Raise or lower hand" : "Повдигане или сваляне на ръка",
    "Push to talk or push to mute" : "Натиснете за разговор или натиснете за заглушаване",
    "Start call silently" : "Започване на разговор безшумно",
    "Start call" : "Започване на обаждане",
    "You will be able to join the call only after a moderator starts it." : "Ще можете да се присъедините към разговора само след като го започне модератор.",
    "End call for everyone" : "Прекратяване на разговора за всички",
    "Starting the recording" : "Започване на записа",
    "Recording" : "Записване",
    "Cancel recording start" : "Отмяна на стартирането на записа",
    "Stop recording" : "Спиране на записването",
    "Send a reaction" : "Изпращане на реакция",
    "React with {reaction}" : "Реагирайте с {reaction}",
    "_%n participant in call_::_%n participants in call_" : ["%n участници в разговора","%n участници в разговора"],
    "You are not allowed to enable screensharing" : "Нямате право да активирате споделянето на екрана",
    "No screensharing" : "Без споделяне на екрана",
    "Screensharing options" : "Опции за споделяне на екрана",
    "Enable screensharing" : "Активиране на споделянето на екрана",
    "Bad sent video and screen quality." : "Лошо изпратено видео и качество на екрана.",
    "Bad sent screen quality." : "Лошо изпратено качество на екрана.",
    "Bad sent video quality." : "Лошо изпратено качество на видеото.",
    "Bad sent audio, video and screen quality." : "Лошо изпратено качество на звука, видеото и екрана.",
    "Bad sent audio and screen quality." : "Лошо изпратено качество на звука и на екрана.",
    "Bad sent audio and video quality." : "Лошо изпратено качество на звук и на видео. ",
    "Bad sent audio quality." : "Лошо изпратено качество на звука. ",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Интернет връзката или компютърът ви са заети и другите участници може и да не могат да видят екрана ви. За да подобрите ситуацията, опитайте се да деактивирате замъгляването на фона или на видеоклипа си, докато правите споделяне на екрана.",
    "Disable background blur" : "Деактивиране на замъгляването на фона",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Интернет връзката или компютърът ви са заети и другите участници може да не могат да видят екрана ви. За да подобрите ситуацията, опитайте се да деактивирате видеоклипа си, докато правите споделяне на екрана.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Интернет връзката или компютърът ви са заети и другите участници може да не могат да видят екрана ви.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Интернет връзката или компютърът ви са заети и другите участници може и да не могат да ви видят.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Интернет връзката или компютърът ви са заети и другите участници може и да не могат да ви разберат и видят. За да подобрите ситуацията, опитайте се да деактивирате замъгляването на фона или на видеоклипа си, докато правите споделяне на екрана.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Интернет връзката или компютърът ви са заети и другите участници може и да не могат да ви разберат и видят. За да подобрите ситуацията, опитайте се да деактивирате видеоклипа си, докато правите споделяне на екрана.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Интернет връзката или компютърът ви са заети и другите участници може и да не могат да ви разберат и да видят екрана ви. За да подобрите ситуацията, опитайте се да деактивирате споделянето на екрана.",
    "Disable screenshare" : "Деактивиране на споделянето на екрана",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Интернет връзката или компютърът ви са заети и другите участници може и да не могат да ви разберат и видят. За да подобрите ситуацията, опитайте се да деактивирате замъгляването на фона или вашето видео.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Интернет връзката или компютърът ви са заети и другите участници може и да не могат да ви разберат и видят. За да подобрите ситуацията, опитайте се да деактивирате вашето видео.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Интернет връзката или компютърът ви са заети и другите участници може и да не могат да ви разберат.",
    "Screen sharing is not supported by your browser." : "Споделянето на екрана не се поддържа от вашия браузър.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Споделянето на екрана изисква страницата да бъде заредена чрез HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "Споделянето на екрана изисква страницата да бъде заредена чрез HTTPS.",
    "An error occurred while starting screensharing." : "Възникна грешка при стартиране на споделянето на екрана.",
    "Show your screen" : "Покажете екрана си",
    "Stop screensharing" : "Спрете споделянето на екрана",
    "Mute others" : "Заглушаване на другите",
    "Start recording" : "Започване на запис",
    "Set up breakout rooms" : "Създаване на стаи за отделно събрание",
    "Remove participant {name}" : "Премахване на участник {name}",
    "Keep" : "Запази",
    "Select a region" : "Изберете регион",
    "Search …" : "Търсене …",
    "Message without mention" : "Съобщение без споменаване",
    "Mention myself" : "Споменх себе си",
    "The conversation does not exist" : "Разговорът не съществува",
    "Join a conversation or start a new one!" : "Присъединяване към разговор или започване на нов",
    "Duplicate session" : "Дублирана сесия",
    "Join a conversation or start a new one" : "Присъединяване към разговор или започване на нов",
    "Nextcloud URL" : "URL адрес на Nextcloud",
    "Nextcloud user" : "Потребител на Nextcloud",
    "User password" : "Потребителска парола",
    "Talk conversation" : "Talk разговор",
    "Skip TLS verification" : "Пропускане на TLS потвърждение",
    "Matrix server URL" : "URL адрес на матричен сървър",
    "User" : "Потребител",
    "Matrix channel" : "Матричен канал",
    "Mattermost server URL" : " URL адрес на сървъра на Mattermost",
    "Mattermost user" : "Потребител на Mattermost",
    "Team name" : "Име на екипа",
    "Channel name" : "Име на канала",
    "Rocket.Chat server URL" : "URL адрес на сървъра на Rocket.Chat",
    "User name or email address" : "Потребителско име или имейл адрес",
    "Rocket.Chat channel" : "Rocket.Chat канал",
    "Zulip server URL" : "URL адрес на сървъра на Zulip",
    "Bot user name" : "Потребителско име на бот",
    "Bot API key" : "API ключ за бот",
    "Zulip channel" : "Zulip канал",
    "API token" : "API токен",
    "Slack channel" : "Slack канал",
    "Server ID or name" : "Идентификатор или име на сървъра",
    "Channel" : "Канал",
    "Login" : "Вписване",
    "Chat ID" : "Идентификатор за чат",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "URL адрес на IRC сървър (напр. chat.freenode.net:6667)",
    "Nickname" : "Псевдоним",
    "Connection password" : "Парола за връзка",
    "IRC channel" : "IRC канал",
    "Channel password" : "Парола за канал ",
    "NickServ nickname" : "Псевдоним за NickServ",
    "NickServ password" : "Парола за NickServ",
    "Use TLS" : "Използвайте TLS",
    "Use SASL" : "Използвайте SASL",
    "Tenant ID" : "Идентификатор на клиент",
    "Client ID" : "Client ID",
    "Team ID" : "Идентификатор на екип",
    "Thread ID" : "Идентификатор на нишка",
    "XMPP/Jabber server URL" : "URL адрес на XMPP/Jabber сървър",
    "MUC server URL" : "URL адрес на MUC сървър",
    "Jabber ID" : "Идентификатор на Jabber",
    "Media" : "Медия",
    "Polls" : "Анкети",
    "Deck cards" : "Deck карти",
    "Voice messages" : "Гласови съобщения",
    "Locations" : "Местоположения",
    "Call recordings" : "Записи на обаждания",
    "Audio" : "Аудио",
    "Show all media" : "Показване на всички медии",
    "Show all files" : "Показване на всички файлове",
    "Show all polls" : "Показване на всички анкети",
    "Show all deck cards" : "Показване на всички deck карти",
    "Show all voice messages" : "Показване на всички гласови съобщения",
    "Show all locations" : "Показване на всички местоположения",
    "Show all call recordings" : "Показване на всички записи на обаждания",
    "Show all audio" : "Показване на всички аудиозаписи",
    "Show all other" : "Показване на всичко останало",
    "Group" : "Група",
    "Team" : "Екип",
    "You: {lastMessage}" : "Вие: {lastMessage}",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Опитвате се да се присъедините към разговор, докато имате активна сесия в друг прозорец или устройство. Това в момента не се поддържа от Nextcloud Talk. Какво искате да направите?",
    "Leave this page" : "Напускане на тази страница",
    "Join here" : "Присъединяване тук",
    "An error occurred while posting deck card to conversation" : "Възникна грешка при публикуване на deck карта в разговор",
    "Post to a conversation" : "Публикуване в разговор",
    "Post to conversation" : "Публикуване в разговорa",
    "The recording failed. Please contact your administrator." : "Записът е неуспешен. Моля, свържете се с вашия администратор.",
    "An error occurred while posting location to conversation" : "Възникна грешка при публикуване на местоположението в разговор",
    "Share to a conversation" : "Споделяне в разговор",
    "Share to conversation" : "Споделяне в разговора",
    "Error while clearing conversation history" : "Грешка при изчистване на историята на разговорите",
    "Error occurred while allowing guests" : "Възникна грешка при разрешаването на гостите",
    "Error occurred while disallowing guests" : "Възникна грешка при забраняването на гостите",
    "Error occurred when restricting the conversation to moderator" : "Възникна грешка при ограничаване на разговора до модератор",
    "Error occurred when opening the conversation to everyone" : "Възникна грешка при отваряне на разговора за всички",
    "Conversation password has been saved" : "Паролата за разговор е записана",
    "Conversation password has been removed" : "Паролата за разговор е премахната",
    "Error occurred while saving conversation password" : "Възникна грешка при запазване на паролата за разговор",
    "Call recording is starting." : "Записването на обаждането започва.",
    "Call recording stopped while starting." : "Записването на разговора спря при стартирането му.",
    "Call recording stopped. You will be notified once the recording is available." : "Записването на обаждането е спряно. Ще бъдете уведомени, когато записът е наличен.",
    "Conversation picture set" : "Набор от снимки на разговор",
    "Conversation picture deleted" : "Снимката на разговора е изтрита",
    "Could not delete the conversation picture" : "Не можа да се изтрие снимката на разговора",
    "Could not post message: {errorMessage}" : "Не можа да се публикува съобщение: {errorMessage}",
    "An error occurred while fetching the participants" : "Възникна грешка при извличане на участниците",
    "Could not send invitation to {actorId}" : "Не можа да се изпрати покана до {actorId}",
    "Invitations sent" : "Поканите са изпратени",
    "Error occurred when sending invitations" : "Възникна грешка при изпращането на покани",
    "An error occurred while creating breakout rooms" : "Възникна грешка при създаването на стаи за отделно събрание",
    "An error occurred while re-ordering the attendees" : "Възникна грешка при пренареждане на участниците",
    "An error occurred while deleting breakout rooms" : "Възникна грешка при изтриването на стаи за отделно събрание",
    "An error occurred while starting breakout rooms" : "Възникна грешка при стартирането на стаи за отделно събрание",
    "An error occurred while stopping breakout rooms" : "Възникна грешка при спирането на стаи за отделно събрание",
    "An error occurred while sending a message to the breakout rooms" : "Възникна грешка при изпращането на съобщение до стаи за отделно събрание",
    "An error occurred while requesting assistance" : "Възникна грешка при заявка за съдействие",
    "An error occurred while resetting the request for assistance" : "Възникнала е грешка при възстановяване на заявката за съдействие",
    "An error occurred while joining breakout room" : "Възникна грешка при присъединяването към стаята за отделно събрание",
    "{guest} (guest)" : "{guest} (гост)",
    "Poll draft has been saved" : "Черновата на анкетата е запаметена",
    "An error occurred while submitting your vote" : "Възникна грешка при изпращането на вашето гласуване",
    "An error occurred while ending the poll" : "Възникна грешка при приключване на анкетата",
    "Failed to add reaction" : "Неуспешно добавяне на реакция",
    "Failed to remove reaction" : "Неуспешно премахване на реакция",
    "Error while uploading file \"{fileName}\"" : "Грешка при качването на файл „{fileName}“",
    "Not enough free space to upload file \"{fileName}\"" : "Няма достатъчно свободно място за качване на файл „{fileName}“",
    "You are not allowed to share files" : "Нямате право да споделяте файлове",
    "Error while sharing file" : "Грешка при споделяне на файл",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Браузърът, който използвате, не се поддържа напълно от Nextcloud Talk. Моля, използвайте най-новата версия на Mozilla Firefox, Microsoft Edge, Google Chrome, Opera или Apple Safari.",
    "Later today – {timeLocale}" : "По-късно днес - {timeLocale}",
    "Tomorrow – {timeLocale}" : "Утре - {timeLocale}",
    "This weekend – {timeLocale}" : "Този уикенд - {timeLocale}",
    "Next week – {timeLocale}" : "Следващата седмица - {timeLocale}",
    "Message link copied to clipboard" : "Връзката към съобщението е копирана в клипборда",
    "Conversation link copied to clipboard" : "Връзката към разговора е копирана в клипборда",
    "The link could not be copied" : "Връзката не можа да бъде копирана",
    "Error while parsing a PROPFIND error" : "Грешка при синтактичния анализ на грешка в PROPFIND",
    "Sending signaling message has failed" : "Изпращането на сигнално съобщение е неуспешно",
    "Lost connection to signaling server. Trying to reconnect." : "Загубена връзка със сървъра за сигнализация. Опит за повторно свързване.",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "Конфигурираният сървър за сигнализация трябва да бъде актуализиран, за да е съвместим с тази версия на приложениетоTalk. Моля, свържете се с вашия администрация.",
    "Please reload the page." : "Моля, презаредете страницата.",
    "Do not disturb" : "Не безпокойте",
    "Away" : "Отсъстващ",
    "Microphone {number}" : "Микрофон  {number}",
    "Camera {number}" : "Камера {number}",
    "Speaker {number}" : "Високоговорител {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Изглежда, че говорите със заглушен звук, моля, включете звука, за да ви чуват другите",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Не можа да се установи връзка с поне един участник. Може да е необходим TURN сървър за вашия сценарий. Моля, помолете администратора си да настрои такъв, като следвате {linkstart}тази документация{linkend}.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Това отнема повече време от очакваното. Предоставени ли са вече права за медии (или отхвърлени)? Ако отговорът е да, моля, рестартирайте браузъра си, тъй като аудиото и видеото не работят ",
    "Access to microphone & camera is only possible with HTTPS" : "Достъпът до микрофона и камерата е възможен само при HTTPS",
    "Please move your setup to HTTPS" : "Моля, преместете настройката си в HTTPS",
    "Access to microphone & camera was denied" : "Достъпът до микрофона и камерата е отказан",
    "WebRTC is not supported in your browser" : "WebRTC не се поддържа във вашия браузър",
    "Please use a different browser like Firefox or Chrome" : "Моля, използвайте друг браузър като Firefox или Chrome",
    "Error while accessing microphone & camera" : "Грешка при достъп до микрофон и камера",
    "%s Talk on your mobile devices" : "%s Talk на мобилните ви устройства",
    "Join conversations at any time, anywhere, on any device." : "Присъединяване към разговори по всяко време, навсякъде и на всяко устройство.",
    "Android app" : "Android приложение",
    "iOS app" : "iOS приложениер",
    "__language_name__" : "Български",
    "Tasks" : "Задачи",
    "Notes" : "Бележки",
    "Reports" : "Доклади",
    "Talk conversation for event" : "Talk разговор за събитие",
    "Talk recording from {time} ({conversation})" : "Запис на разговор от {time} ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Резултати от анкетата • %n гласа","Резултати от анкетата • %n гласа"],
    "Submit vote" : "Изпращане на гласуване",
    "Your privacy setting has been saved" : " Настройката ви за поверителност е запазена",
    "Your personal setting has been saved" : "Личната бележка е запаметена",
    "Failed to save sounds setting" : "Неуспешно запазване на настройката за звуци",
    "Sounds setting saved" : "Настройката за звуци е запазена",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Присъединихте се към разговора в друг прозорец или устройство. Това в момента не се поддържа от Nextcloud Talk, така че тази сесия беше затворена."
},
"nplurals=2; plural=(n != 1);");
