OC.L10N.register(
    "spreed",
    {
    "a conversation" : "대화",
    "(Duration %s)" : "(시간 %s)",
    "You attended a call with {user1}" : "{user1} 님과의 통화에 참가함",
    "_%n guest_::_%n guests_" : ["손님 %n명"],
    "You attended a call with {user1} and {user2}" : "{user1}, {user2} 님과의 통화에 참가함",
    "You attended a call with {user1}, {user2} and {user3}" : "{user1}, {user2}, {user3} 님과의 통화에 참가함",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "{user1}, {user2}, {user3}, {user4} 님과의 통화에 참가함",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "{user1}, {user2}, {user3}, {user4}, {user5} 님과의 통화에 참가함",
    "_%n other_::_%n others_" : ["외 %n명"],
    "{actor} invited you to {call}" : "{actor} 님이 {call}에 초대함",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "당신은 <strong>대화</strong>에 초대되었거나 <strong>통화</strong>를 했습니다.",
    "Other activities" : "다른 활동",
    "Talk" : "토크",
    "Guest" : "손님",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Nextcloud 토크에 오신 것을 환영합니다.\n이 대화에서  Nextcloud 토크에서 사용 가능한 새 기능들에 대해 알아볼 수 있습니다.",
    "## New in Talk %s" : "## Talk %s의 새로운 기능",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- 이제 Edge와 Safari 브라우저를 음성 통화와 영상 통화에 사용할 수 있습니다.",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- 이제 일대일 대화가 지속되며 더 이상 실수로 그룹 대화로 전환되지 않습니다. 또한 참가자 중 한 명이 대화에서 나가더라도 대화는 더 이상 자동으로 삭제되지 않습니다. 두 참가자가 모두 나가는 경우에만 서버에서 대화가 삭제됩니다.",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- 당신은 \"@all\"을 채팅에 기재하여 참가자들에게 알릴 수 있습니다.",
    "- With the \"arrow-up\" key you can repost your last message" : "- \"방향키 위\" 키로 마지막 메시지를 다시 보낼 수 있습니다.",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- 이제 토크에서 명령어를 사용할 수 있습니다. 관리자가 설정한 명령어를 확인하려면, 채팅에 \"/help\"를 입력하세요.",
    "- With projects you can create quick links between conversations, files and other items" : "- 당신은 프로젝트를 통해 대화, 파일 및 기타 항목 간에 빠른 링크를 생성할 수 있습니다.",
    "- You can now mention guests in the chat" : "- 이제 채팅 메시지로 손님 계정을 언급할 수 있습니다.",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- 대화에 로비를 만들 수 있습니다. 다른 사용자와 손님들이 대기하는 동안, 중재자들이 미리 채팅에 참가하여 모임을 준비할 수 있습니다.",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- 이제 메시지에 직접 회신하여 다른 사용자에게 메시지의 내용을 더 자세히 설명할 수 있습니다.",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- 이제 대화 및 참가자를 검색하면 기존 대화를 필터링하여 이전 대화를 훨씬 쉽게 찾을 수 있습니다.",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- 이제 서클 앱이 설치되어 있으면 대화에 커스텀 사용자 그룹을 추가할 수 있습니다.",
    "- Check out the new grid and call view" : "- 새로운 그리드 및 통화 화면을 확인하세요.",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- 이제 기기에서 채팅으로 곧바로 파일을 업로드 하고 드래그&드롭 할 수 있습니다.",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- 이제 공유된 파일을 채팅 화면에서 뷰어 앱을 통해 직접 열 수 있습니다.",
    "- You can now search for chats and messages in the unified search in the top bar" : "- 상단 바의 검색을 통해 채팅이나 메시지를 검색할 수 있습니다.",
    "- Spice up your messages with emojis from the emoji picker" : "- 이모티콘 선택을 통해 이모티콘을 사용하여 대화를 꾸며보세요.",
    "- You can now change your camera and microphone while being in a call" : "- 통화중에 당신의 카메라와 마이크를 변경할 수 있습니다.",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- 대화에 설명을 추가하여, 로그인한 사용자들이 쉽게 찾고 참가할 수 있도록 할 수 있습니다.",
    "- See a read status and send failed messages again" : "- 읽음 상태를 보고 실패한 메시지를 다시 보냅니다.",
    "- Raise your hand in a call with the R key" : "- R 키를 사용하여 통화 중 손을 들어보세요.",
    "- Join the same conversation and call from multiple devices" : "- 여러 기기에서 같은 대화에 참가하고, 통화할 수 있습니다.",
    "- Send voice messages, share your location or contact details" : "- 음성 메시지를 보내거나, 위치 또는 연락처 정보를 공유하세요.",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- 대화에 그룹을 추가하면 새 그룹 구성원이 자동으로 참가자로 추가",
    "- A preview of your audio and video is shown before joining a call" : "- 통화에 참가하기 전에 자신의 음성과 영상을 미리 볼 수 있습니다.",
    "- You can now blur your background in the newly designed call view" : "- 이제 새로 디자인된 통화 보기에서 배경을 흐리게 할 수 있습니다.",
    "- Moderators can now assign general and individual permissions to participants" : "- 중재자는 이제 참가자에게 일반 및 개별 권한을 할당할 수 있습니다.",
    "- You can now react to chat messages" : "- 이제 채팅 메시지에 반응할 수 있습니다.",
    "- In the sidebar you can now find an overview of the latest shared items" : "- 이제 사이드바에서 최신 공유 항목의 개요를 찾을 수 있습니다.",
    "- Use a poll to collect the opinions of others or settle on a date" : "- 의견이나 일정을 조율하기 위해 투표를 사용할 수 있습니다.",
    "- Configure an expiration time for chat messages" : "- 채팅 메시지에 표시 만료 기한을 설정하세요.",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- 단체 대화방에서 다른 참가자에게 알리지 않고 통화를 시작할 수 있습니다. 통화를 시작한 이후 참가자에게 개별적으로 통화 알림을 보낼 수 있습니다.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- 급한 일이 아니라면, 받는이에게 알림이 가지 않는 채팅 메시지를 보낼 수 있습니다.",
    "- Emojis can now be autocompleted by typing a \":\"" : "- \":\"를 입력해서 이모지를 자동 완성으로 보낼 수 있습니다.",
    "- Link various items using the new smart-picker by typing a \"/\"" : "\"/\"를 눌러 새로운 스마트 피커를 사용하여 다양한 아이템을 연결하세요.",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- 중재자는 이제 소회의실들을 만들 수 있습니다. (High-performance backend 필요)",
    "- Calls can now be recorded (requires the High-performance backend)" : "- 통화는 이제 저장될 수 있습니다. (High-performance backend 필요)",
    "- Conversations can now have an avatar or emoji as icon" : "- 이제 대화에서 아바타와 이모지를 아이콘으로 사용할 수 있습니다.",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- 이제 영상 통화에서 흐린 배경 외에도 가상 배경을 사용할 수 있습니다.",
    "- Reactions are now available during calls" : "- 이제 통화중 반응을 할 수 있습니다.",
    "- Typing indicators show which users are currently typing a message" : "- 타이핑 표시기는 현재 어떤 사용자가 메시지를 입력하고 있는지 보여줍니다.",
    "- Groups can now be mentioned in chats" : "- 이제 채팅에서 그룹을 언급할 수 있습니다.",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- 전사 제공자 앱이 등록된 경우 통화 녹음이 자동으로 전사됩니다.",
    "- Chat messages can be translated if a translation provider app is registered" : "- 번역 제공자 앱이 등록된 경우 채팅 메시지를 번역할 수 있습니다.",
    "- **Markdown** can now be used in _chat_ messages" : "- 이제 _채팅_ 메시지에서 **마크다운**을 사용할 수 있습니다.",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- 웹훅을 통해 봇을 사용할 수 있습니다. 자세한 정보는 문서를 참조하십시오. https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "- 채팅 메시지에 알림을 설정하여 나중에 다시 확인하십시오",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- **나에게 메모** 대화방을 사용하여 메모를 남기고 복수의 기기에서 정보를 공유하십시오.",
    "- Captions allow to send a message with a file at the same time" : "- 파일과 파일에 대한 설명을 동시에 발송할 수 있습니다.",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- 발언자의 영상이 이제 화면 공유시 표시되며, 통화에서의 반응이 애니메이션화 됩니다.",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- 내용은 이제 로그인한 생성자나 중재자에 의해 6시간 동안 편집이 가능합니다.",
    "- Unsent message drafts are now saved in your browser" : "- 보내지 않은 메세지 초안은 이제 브라우저에 저장됩니다.",
    "- Text chatting can now be done in a federated way with other Talk servers" : "- 다른 토크서버와의 문자대화는 이제 연합으로 가능해 집니다.",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- 이제 중재자는 대화에 다시 참여하지 못하도록 계정과 게스트를 차단할 수 있습니다.",
    "Talk updates ✅" : "토크 업데이트 내역 ✅",
    "Reaction deleted by author" : "작성자가 삭제한 반응",
    "{actor} created the conversation" : "{actor}님이 대화방을 만들었습니다.",
    "You created the conversation" : "대화방을 만들었습니다.",
    "System created the conversation" : "시스템에서 대화를 만들었습니다.",
    "An administrator created the conversation" : "관리자가 대화를 만들었습니다.",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor}님이 대화방의 이름을 \"%1$s\" 에서 \"%2$s\"로 변경했습니다.",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "당신이 대화의 이름을 %1$s 에서 %2$s 로 변경했습니다.",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "관리자가 대화의 이름을 \"%1$s\"에서 \"%2$s\"(으)로 변경했습니다.",
    "{actor} set the description" : "{actor}님이 설명을 설정했습니다.",
    "You set the description" : "대화방 정보를 설정했습니다.",
    "An administrator set the description" : "관리자가 설명을 설정합니다.",
    "{actor} removed the description" : "{actor}님이 설명을 삭제했습니다.",
    "You removed the description" : "당신이 설명을 삭제했습니다.",
    "An administrator removed the description" : "관리자가 설명을 삭제했습니다.",
    "You started a call" : "통화를 시작했습니다.",
    "{actor} started a call" : "{actor}님이 통화를 시작했습니다.",
    "Incoming call" : "수신 통화",
    "{actor} joined the call" : "{actor}님이 통화에 참가했습니다.",
    "You joined the call" : "통화에 참가했습니다.",
    "{actor} left the call" : "{actor}님이 통화를 떠났습니다.",
    "You left the call" : "통화를 떠났습니다.",
    "{actor} unlocked the conversation" : "{actor}님이 대화 제한을 해제했습니다.",
    "You unlocked the conversation" : "당신이 대화 잠금을 풀었습니다.",
    "An administrator unlocked the conversation" : "관리자가 대화 잠금을 풀었습니다.",
    "{actor} locked the conversation" : "{actor}님이 대화를 제한했습니다.",
    "You locked the conversation" : "당신이 대화를 잠갔습니다.",
    "An administrator locked the conversation" : "관리자가 대화를 잠갔습니다.",
    "{actor} limited the conversation to the current participants" : "{actor}이/가 현재 참가자들로 대화를 제한하였습니다.",
    "You limited the conversation to the current participants" : "현재 참가자들로 대화를 제한하였습니다.",
    "An administrator limited the conversation to the current participants" : "관리자가 현재 참가자들로 대화를 제한하였습니다.",
    "{actor} opened the conversation to registered users" : "{actor}이/가 등록된 사용자에게 대화를 열었습니다.",
    "You opened the conversation to registered users" : "등록된 사용자에게 대화를 열었습니다.",
    "An administrator opened the conversation to registered users" : "관리자가 등록된 사용자에게 대화를 열었습니다.",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor}님이 가입된 사용자들과 Guests 앱을 통해 만들어진 사용자들에게 대화를 열었습니다.",
    "You opened the conversation to registered users and users created with the Guests app" : "가입된 사용자들과 Guests 앱을 통해 만들어진 사용자들에게 대화를 열었습니다.",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "관리자가 가입된 사용자들과 Guests 앱을 통해 만들어진 사용자들에게 대화를 열었습니다.",
    "The conversation is now open to everyone" : "이 대화는 모든 사람들에게 열려 있습니다.",
    "{actor} opened the conversation to everyone" : "{actor}님이 대화를 모두에게 허용했습니다.",
    "You opened the conversation to everyone" : "당신이 대화를 모든 사람들에게 열었습니다.",
    "{actor} restricted the conversation to moderators" : "{actor}님이 대화를 중재자만 허용했습니다.",
    "You restricted the conversation to moderators" : "당신이 대화를 중재자들로 제한했습니다.",
    "{actor} started breakout rooms" : "{actor}님이 소회의실을 시작했습니다.",
    "You started breakout rooms" : "소회의실을 시작했습니다.",
    "{actor} stopped breakout rooms" : "{actor}님이 소회의실을 중지했습니다.",
    "You stopped breakout rooms" : "소회의실을 중지했습니다.",
    "{actor} allowed guests" : "{actor}님이 손님 계정을 허용했습니다.",
    "You allowed guests" : "손님을 허용했습니다.",
    "An administrator allowed guests" : "관리자가 손님을 허용했습니다.",
    "{actor} disallowed guests" : "{actor}님이 손님 계정을 불허용했습니다.",
    "You disallowed guests" : "손님을 불허용했습니다.",
    "An administrator disallowed guests" : "관리자가 손님을 불허용했습니다.",
    "{actor} set a password" : "{actor}님이 암호를 설정했습니다.",
    "You set a password" : "당신이 암호를 설정했습니다.",
    "An administrator set a password" : "관리자가 암호를 설정했습니다.",
    "{actor} removed the password" : "{actor}님이 암호를 제거했습니다.",
    "You removed the password" : "당신이 암호를 제거했습니다.",
    "An administrator removed the password" : "관리자가 암호를 제거했습니다.",
    "{actor} added {user}" : "{actor}님이 {user}님을 초대했습니다.",
    "You joined the conversation" : "대화에 참가했습니다.",
    "{actor} joined the conversation" : "{actor}님이 대화에 참가했습니다.",
    "You added {user}" : "{user}님을 추가했습니다.",
    "{actor} added you" : "{actor}님이 당신을 초대했습니다.",
    "An administrator added you" : "관리자가 당신을 추가했습니다.",
    "An administrator added {user}" : "관리자가 {user}님을 추가했습니다.",
    "You left the conversation" : "당신이 대화를 떠났습니다.",
    "{actor} left the conversation" : "{actor}님이 대화를 떠났습니다.",
    "{actor} removed {user}" : "{actor}님이 {user}님을 내보냈습니다.",
    "You removed {user}" : "{user}님을 제거했습니다.",
    "{actor} removed you" : "{actor}님이 당신을 내보냈습니다.",
    "An administrator removed you" : "관리자가 당신을 제거했습니다.",
    "An administrator removed {user}" : "관리자가 {user}님을 제거했습니다.",
    "{actor} invited {federated_user}" : "{actor}님이 {federated_user}님을 초대했습니다",
    "You invited {federated_user}" : "{federated_user}님을 초대했습니다.",
    "An administrator invited {federated_user}" : "관리자가 {federated_user}님을 초대했습니다.",
    "{federated_user} accepted the invitation" : "{federated_user}님이 초대를 수락함",
    "{actor} removed {federated_user}" : "{actor}님이 {federated_user}님을 제거함",
    "You removed {federated_user}" : "{federated_user}님을 제거함",
    "An administrator removed {federated_user}" : "관리자가 {federated_user}님을 제거함",
    "{federated_user} declined the invitation" : "{federated_user}님이 초대를 거부함",
    "{actor} added group {group}" : "{actor}님이 {group} 그룹을 추가함",
    "You added group {group}" : "{group} 그룹을 추가함",
    "An administrator added group {group}" : "관리자가 {group} 그룹을 추가함",
    "{actor} removed group {group}" : "{actor}님이 {group} 그룹을 제거함",
    "You removed group {group}" : "{group} 그룹을 제거함",
    "An administrator removed group {group}" : "관리자가 {group} 그룹을 제거함",
    "{actor} added {phone}" : "{actor}님이 {phone}(을)를 추가했습니다.",
    "You added {phone}" : "{phone}(을)를 추가했습니다.",
    "An administrator added {phone}" : "관리자가 {phone}(을)를 추가했습니다.",
    "{actor} removed {phone}" : "{actor}님이 {phone}(을)를 제거했습니다.",
    "You removed {phone}" : "{phone}(을)를 제거했습니다.",
    "An administrator removed {phone}" : "관리자가 {phone}(을)를 제거했습니다.",
    "{actor} promoted {user} to moderator" : "{actor}님이 {user}님에게 중재자 권한을 부여했습니다.",
    "You promoted {user} to moderator" : "{user}님에게 중재자 권한을 부여했습니다.",
    "{actor} promoted you to moderator" : "{actor}님이 당신에게 중재자 권한을 부여했습니다.",
    "An administrator promoted you to moderator" : "관리자가 당신에게 중재자 권한을 부여했습니다.",
    "An administrator promoted {user} to moderator" : "관리자가 {user}님에게 중재자 권한을 부여했습니다. ",
    "{actor} demoted {user} from moderator" : "{actor}님이 {user}님의 중재자 권한을 제거했습니다.",
    "You demoted {user} from moderator" : "당신이 {user}의 진행자 권한을 제거했습니다.",
    "{actor} demoted you from moderator" : "{actor}님이 당신의 중재자 권한을 제거했습니다.",
    "An administrator demoted you from moderator" : "관리자가 당신의 중재자 권한을 제거했습니다.",
    "An administrator demoted {user} from moderator" : "관리자가 {user}의 중재자 권한을 제거했습니다.",
    "{actor} shared a file which is no longer available" : "{actor}님이 더 이상 사용할 수 없는 파일을 공유했습니다.",
    "You shared a file which is no longer available" : "당신이 더 이상 사용할 수 없는 파일을 공유했습니다.",
    "The shared location is malformed" : "공유된 위치가 잘못되었습니다.",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor}님이 이 대화를 다른 채팅과 동기화 하기 위해 Matterbridge를 구성했습니다.",
    "You set up Matterbridge to synchronize this conversation with other chats" : "이 대화를 다른 채팅과 동기화 하기 위해 Matterbridge를 구성했습니다.",
    "{actor} updated the Matterbridge configuration" : "{actor}님이 Matterbridge 구성을 수정했습니다.",
    "You updated the Matterbridge configuration" : "Matterbridge 구성을 수정했습니다.",
    "{actor} removed the Matterbridge configuration" : "{actor}님이 Matterbridge 구성을 제거했습니다.",
    "You removed the Matterbridge configuration" : "Matterbridge 구성을 제거했습니다.",
    "{actor} started Matterbridge" : "{actor}님이 Matterbridge를 시작했습니다.",
    "You started Matterbridge" : "Matterbridge를 시작했습니다.",
    "{actor} stopped Matterbridge" : "{actor}님이 Matterbridge를 중단했습니다.",
    "You stopped Matterbridge" : "Matterbridge를 중단했습니다.",
    "{actor} deleted a message" : "{actor}님이 메시지를 삭제했습니다.",
    "You deleted a message" : "메시지를 삭제했습니다.",
    "{actor} edited a message" : "{actor}님이 메시지를 수정했습니다.",
    "You edited a message" : "메시지를 수정했습니다.",
    "{actor} deleted a reaction" : "{actor}님이 반응을 삭제했습니다.",
    "You deleted a reaction" : "반응을 삭제했습니다.",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["메시지의 유효 기간을 %n주로 설정했습니다."],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["메시지의 유효 기간을 %n일로 설정했습니다."],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["메시지의 유효 기간을 %n시간으로 설정했습니다."],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["메시지의 유효 기간을 %n분으로 설정했습니다."],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor}님이 메시지의 유효 기간을 %n주로 설정했습니다."],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor}님이 메시지의 유효 기간을 %n일로 설정했습니다."],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor}님이 메시지의 유효 기간을 %n시간으로 설정했습니다."],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor}님이 메시지의 유효 기간을 %n분으로 설정했습니다."],
    "{actor} disabled message expiration" : "{actor}님이 메시지의 유효 기간을 해제했습니다.",
    "You disabled message expiration" : "메시지의 유효 기간을 해제했습니다.",
    "{actor} cleared the history of the conversation" : "{actor}님이 대화의 기록을 지웠습니다.",
    "You cleared the history of the conversation" : "대화의 기록을 지웠습니다.",
    "{actor} set the conversation picture" : "{actor}님이 대화의 사진을 설정했습니다.",
    "You set the conversation picture" : "대화의 사진을 설정했습니다.",
    "{actor} removed the conversation picture" : "{actor}님이 대화의 사진을 제거했습니다.",
    "You removed the conversation picture" : "대화에 사진을 제거했습니다.",
    "{actor} ended the poll {poll}" : "{actor}님이 {poll} 투표를 끝냈습니다.",
    "You ended the poll {poll}" : "{poll} 투표를 끝냈습니다.",
    "{actor} started the video recording" : "{actor}님이 녹화를 시작했습니다.",
    "You started the video recording" : "녹화를 시작했습니다.",
    "{actor} stopped the video recording" : "{actor}님이 녹화를 중단했습니다.",
    "You stopped the video recording" : "녹화를 중단했습니다.",
    "{actor} started the audio recording" : "{actor}님이 녹음을 시작했습니다.",
    "You started the audio recording" : "녹음을 시작했습니다.",
    "{actor} stopped the audio recording" : "{actor}님이 녹음을 중단했습니다.",
    "You stopped the audio recording" : "녹음을 중단했습니다.",
    "The recording failed" : "녹음/녹화를 하지 못했습니다.",
    "Someone voted on the poll {poll}" : "누군가가 {poll} 투표에 투표했습니다.",
    "Message deleted by author" : "작성자가 메시지를 삭제함",
    "Message deleted by {actor}" : "{actor}님이 메시지를 삭제함",
    "Message deleted by you" : "메시지를 삭제함",
    "Deleted user" : "삭제된 사용자",
    "Unknown number" : "알 수 없는 번호",
    "Administration" : "관리",
    "System" : "시스템",
    "%s (guest)" : "%s (손님)",
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor}님이 %n명의 손님이 있는 통화를 끝냈습니다. (길이: {duration})"],
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor}님이 {user1}님과의 통화를 끝냈습니다. (길이: {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor}님이 {user1}, {user2}님과의 통화를 끝냈습니다. (길이: {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor}님이 {user1}, {user2}, {user3}님과의 통화를 끝냈습니다. (길이: {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor}님이 {user1}, {user2}, {user3}, {user4}님과의 통화를 끝냈습니다. (길이: {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor}님이 {user1}, {user2}, {user3}, {user4}, {user5}님과의 통화를 끝냈습니다. (길이: {duration})",
    "Message of {user} in {conversation}" : "{conversation}에서 {user}님의 메시지",
    "Message of {user}" : "{user}님의 메시지",
    "Message of a deleted user in {conversation}" : "{conversation}에서 삭제된 사용자의 메시지",
    "Talk conversations" : "토크 대화 목록",
    "Talk to %s" : "%s 님과 대화",
    "An error occurred. Please contact your administrator." : "오류가 발생했습니다. 관리자에게 연락해 주세요.",
    "Storage quota exceeded" : "저장소 할당량 초과됨",
    "File not found" : "파일을 찾을 수 없음",
    "File is not shared, or shared but not with the user" : "파일을 공유하지 않았거나, 사용자에게 공유하지 않았습니다.",
    "No account available to delete." : "삭제할 수 있는 계정이 없습니다.",
    "Poll" : "투표",
    "No image file provided" : "이미지 파일을 제공 받지 않음",
    "File is too big" : "파일이 너무 큼",
    "Invalid file provided" : "잘못된 파일 지정됨",
    "Invalid image" : "잘못된 사진",
    "Unknown filetype" : "알 수 없는 파일 형식",
    "Talk mentions" : "토크 인용 목록",
    "Say hi to your friends and colleagues!" : "여러분의 친구 및 동료들에게 인사하세요!",
    "No unread mentions" : "읽지 않은 언급 없음",
    "Call in progress" : "통화 진행중",
    "You were mentioned" : "당신이 언급되었습니다.",
    "Write to conversation" : "대화에 기록하기",
    "Writes event information into a conversation of your choice" : "선택한 대화에 일정에 대한 정보를 기록합니다.",
    "Conversation invitation" : "대화 초대",
    "Description" : "설명",
    "You can also dial-in via phone with the following details" : "다음 세부 정보를 참고하여 전화를 걸 수도 있습니다.",
    "Dial-in information" : "전화 접속 정보",
    "Meeting ID" : "모임 ID",
    "Your PIN" : "당신의 PIN",
    "Meeting" : "회의",
    "Password request: %s" : "암호 요구사항: %s",
    "Private conversation" : "비공개 대화",
    "Deleted user (%s)" : "삭제된 사용자 (%s)",
    "Failed to upload call recording" : "통화 녹음/녹화를 업로드하지 못했습니다.",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "녹음/녹화 서버가 {call} 통화의 녹음/녹화를 업로드하지 못했습니다. 관리자에게 연락해 주세요.",
    "Share to chat" : "채팅에 공유",
    "Dismiss notification" : "알림 해제",
    "Call recording now available" : "현재 통화 녹음/녹화 사용 가능",
    "The recording for the call in {call} was uploaded to {file}." : "{call} 통화의 녹음/녹화를 {file}에 업로드했습니다.",
    "Transcript now available" : "현재 전사 사용 가능",
    "The transcript for the call in {call} was uploaded to {file}." : "{call} 통화의 전사를 {file}에 업로드했습니다.",
    "Failed to transcript call recording" : "통화의 녹음을 전사하지 못했습니다.",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "서버가 {call} 통화의 {file} 녹음 파일을 전사하지 못했습니다. 관리자에게 연락해 주세요.",
    "Accept" : "수락",
    "Decline" : "거절",
    "New message" : "새로운 메시지",
    "Reminder" : "알림",
    "Notification" : "공지",
    "Reminder: You in {call}" : "알림: {call}의 당신",
    "Reminder: {user} in {call}" : "알림: {call}의 {user}님",
    "Reminder: Deleted user in {call}" : "알림: {call}의 삭제된 사용자",
    "Reminder: {guest} (guest) in {call}" : "알림: {call}의 {guest}님(손님)",
    "Reminder: Guest in {call}" : "알림: {call}의 손님",
    "{user} reacted with {reaction}" : "{user}님이 {reaction}(으)로 반응했습니다.",
    "{user} reacted with {reaction} in {call}" : "{user}님이 {call}에서 {reaction}(으)로 반응했습니다.",
    "Deleted user reacted with {reaction} in {call}" : "삭제된 사용자가 {call}에서 {reaction}(으)로 반응했습니다.",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest}님(손님)이 {call}에서 {reaction}(으)로 반응했습니다.",
    "Guest reacted with {reaction} in {call}" : "손님이 {call}에서 {reaction}(으)로 반응했습니다.",
    "{user} in {call}" : "{user} 가 {call} 상태 ",
    "Deleted user in {call}" : "{call}에서 삭제된 사용자",
    "{guest} (guest) in {call}" : "{guest}님(손님) {call} 상태",
    "Guest in {call}" : "손님 {call} 상태",
    "{user} sent you a private message" : "{user}님이 당신에게 비공개 메시지를 보냈습니다.",
    "{user} sent a message in conversation {call}" : "{user}님이 대화에서 {call}메시지를 전송했습니다.",
    "A deleted user sent a message in conversation {call}" : "삭제된 사용자가 {call} 대화에서 메시지를 전송했습니다.",
    "{guest} (guest) sent a message in conversation {call}" : "{guest}님(손님)이 {call} 대화에서 메시지를 전송했습니다. ",
    "A guest sent a message in conversation {call}" : "손님이 {call} 대화에서 메시지를 전송했습니다.",
    "{user} replied to your private message" : "{user}님이 당신의 비공개 메시지에 답변했습니다.",
    "{user} replied to your message in conversation {call}" : "{user}님이 {call} 대화에서 당신의 메시지에 답변했습니다.",
    "A deleted user replied to your message in conversation {call}" : "삭제된 사용자가 {call} 대화에서 당신의 메시지에 답변했습니다. ",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest}님(손님)이 {call} 대화에서 당신의 메시지에 답변했습니다.",
    "A guest replied to your message in conversation {call}" : "손님이 {call} 대화에서 당신의 메시지에 답변했습니다.",
    "Reminder: You in private conversation {call}" : "알림: 비공개 대화 {call}의 당신",
    "Reminder: A deleted user in private conversation {call}" : "알림: 비공개 대화 {call}의 삭제된 사용자",
    "Reminder: {user} in private conversation" : "알림: 비공개 대화의 {user}님",
    "Reminder: You in conversation {call}" : "알림: 대화 {call}의 당신",
    "Reminder: {user} in conversation {call}" : "알림: 대화 {call}의 {user}님",
    "Reminder: A deleted user in conversation {call}" : "알림: 대화 {call}의 삭제된 사용자",
    "Reminder: {guest} (guest) in conversation {call}" : "알림: 대화 {call}의 {guest}님(손님)",
    "Reminder: A guest in conversation {call}" : "알림: 대화 {call}의 손님",
    "{user} reacted with {reaction} to your private message" : "{users}님이 당신의 비공개 메시지에 {reaction}(으)로 반응했습니다.",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{users}님이 {call} 대화에서 당신의 메시지에 {reaction}(으)로 반응했습니다.",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "삭제된 사용자가 {call} 대화에서 당신의 메시지에 {reaction}(으)로 반응했습니다.",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest}님(손님)이 {call} 대화에서 당신의 메시지에 {reaction}(으)로 반응했습니다.",
    "A guest reacted with {reaction} to your message in conversation {call}" : "손님이 {call} 대화에서 당신의 메시지에 {reaction}(으)로 반응했습니다.",
    "{user} mentioned you in a private conversation" : "{user}님이 비공개 대화에서 당신을 언급했습니다.",
    "{user} mentioned group {group} in conversation {call}" : "{users}님이 {call} 대화에서 {group} 그룹을 언급했습니다.",
    "{user} mentioned everyone in conversation {call}" : "{users}님이 {call} 대화에서 모두를 언급했습니다.",
    "{user} mentioned you in conversation {call}" : "{user}님이 {call} 대화에서 당신을 언급했습니다.",
    "A deleted user mentioned group {group} in conversation {call}" : "삭제된 사용자가 {call} 대화에서 {group} 그룹을 언급했습니다.",
    "A deleted user mentioned everyone in conversation {call}" : "삭제된 사용자가 {call} 대화에서 모두를 언급했습니다.",
    "A deleted user mentioned you in conversation {call}" : "삭제된 사용자가 {call} 대화에서 당신을 언급했습니다.",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest}님(손님)이 {call} 대화에서 {group} 그룹을 언급했습니다.",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest}님(손님)이 {call} 대화에서 모두를 언급했습니다.",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest}님(손님)이 {call} 대화에서 당신을 언급했습니다.",
    "A guest mentioned group {group} in conversation {call}" : "손님이 {call} 대화에서 {group} 그룹을 언급했습니다.",
    "A guest mentioned everyone in conversation {call}" : "손님이 {call} 대화에서 모두를 언급했습니다.",
    "A guest mentioned you in conversation {call}" : "손님이 {call} 대화에서 당신을 언급했습니다.",
    "View message" : "메시지 보기",
    "Dismiss reminder" : "알림 무시",
    "View chat" : "채팅 보기",
    "{user} invited you to a group conversation: {call}" : "{user} 가 당신을 그룹 대화 {call}에 초대했습니다.",
    "Join call" : "통화 참가하기",
    "Answer call" : "통화 응답",
    "{user} would like to talk with you" : "{user}님이 당신과 대화하길 원합니다.",
    "Call back" : "다시 통화",
    "You missed a call from {user}" : "당신이 {user}님의 통화를 놓쳤습니다.",
    "A group call has started in {call}" : "그룹 통화가 {call}에 시작됨",
    "You missed a group call in {call}" : "{call}의 그룹 통화를 놓쳤습니다.",
    "{email} is requesting the password to access {file}" : "{email}(이)가 {file}에 접근하기 위한 암호를 요청합니다.",
    "{email} tried to request the password to access {file}" : "{email}(이)가 {file}에 접근하기 위한 암호를 요청하려 시도했습니다.",
    "Someone is requesting the password to access {file}" : "어떤 사람이 {file}에 접근하기 위한 암호를 요청합니다.",
    "Someone tried to request the password to access {file}" : "어떤 사람이 {file} 에접근하기 위한 암호를 요청하려 시도했습니다.",
    "Open settings" : "설정 열기",
    "Hosted signaling server added" : "호스트된 시그널링 서버 추가됨",
    "The hosted signaling server is now configured and will be used." : "이제 호스트된 시그널링 서버가 구성되었으며 사용됩니다.",
    "Hosted signaling server removed" : "호스트된 시그널링 서버 제거됨",
    "The hosted signaling server was removed and will not be used anymore." : "호스트된 시그널링 서버가 제거되었으며 더 이상 사용되지 않습니다.",
    "Hosted signaling server changed" : "호스트된 시그널링 서버 변경됨",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "호스트된 신호 서버 계정 상태를 \"{oldstatus}\" 에서  \"{newstatus}\" 로 변경했습니다.",
    "pending" : "보류 중",
    "active" : "활성",
    "expired" : "만료됨",
    "blocked" : "차단됨",
    "error" : "오류",
    "The certificate of {host} expires in {days} days" : "{host}의 인증서가 {days}일 후 만료됩니다.",
    "The certificate of {host} expired" : "{host}의 인증서가 만료되었습니다.",
    "Contact via Talk" : "토크로 연락",
    "Open Talk" : "토크 열기",
    "Default" : "기본값",
    "Presentation" : "프레젠테이션",
    "Webinar" : "웨비나",
    "Conversations" : "대화",
    "Messages in current conversation" : "현재 대화의 메시지",
    "{user}" : "{user}",
    "Messages" : "메시지",
    "{user} in {conversation}" : "{conversation}의 {user}",
    "Messages in other conversations" : "다른 대화의 메시지",
    "One-to-one rooms always need to show the other users avatar" : "일대일 대화방은 항상 아바타를 다른 사용자에게 표시해야 합니다.",
    "Invalid emoji character" : "잘못된 이모지 문자",
    "Invalid background color" : "잘못된 배경 색",
    "Avatar image is not square" : "아바타 사진이 정사각형이 아님",
    "Room {number}" : "{number}번 대화방",
    "Other" : "기타",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "평가판 서버에 연결할 수 없으므로 평가판을 요청하지 못했습니다. 나중에 다시 시도해 주십시오.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "이 인스턴스를 인증하는 데 문제가 있습니다. 인스턴스의 URL을 확인하기 위해 외부에서 연결할 수 없는 것일 수 있습니다.",
    "Something unexpected happened." : "예상하지 못한 일이 일어났습니다.",
    "The URL is invalid." : "URL이 잘못되었습니다.",
    "An HTTPS URL is required." : "HTTPS URL이 필요합니다.",
    "The email address is invalid." : "이메일 주소가 잘못되었습니다.",
    "The language is invalid." : "언어가 잘못되었습니다.",
    "The country is invalid." : "국가가 잘못되었습니다.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "평가판의 요청에 문제가 있습니다. 자세한 내용은 로그를 확인하십시오.",
    "Too many requests are send from your servers address. Please try again later." : "서버 주소에서 너무 많은 요청을 보냅니다. 나중에 다시 시도해 주십시오.",
    "There is already a trial registered for this Nextcloud instance." : "이 Nextcloud 인스턴스에 대한 평가판이 이미 등록되어 있습니다.",
    "Something unexpected happened. Please try again later." : "예상하지 못한 일이 일어났습니다. 나중에 다시 시도해 주십시오.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "평가판 서버의 동작이 잘못되어 평가판을 요청하지 못했습니다. 나중에 다시 시도해 주십시오.",
    "Trial requested but failed to get account information. Please check back later." : "평가판이 요청되었지만 계정 정보를 가져오지 못했습니다. 나중에 다시 확인하십시오.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "이 요청을 인증하는 데 문제가 있습니다. URL을 확인하기 위해 외부에서 연결할 수 없을 수 있습니다.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "평가판 서버의 오류 때문에 계정 정보를 가져오는데 실패했습니다. 나중에 다시 확인해 주세요.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "계정 정보를 가져오는 데 문제가 있습니다. 자세한 내용은 로그를 확인하십시오.",
    "There is no such account registered." : "해당하는 등록된 계정이 없습니다.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "평가판 서버에 연결할 수 없기 때문에 계정 정보를 가져오지 못했습니다. 나중에 다시 확인하십시오.",
    "Deleting the hosted signaling server account failed. Please check back later." : "호스트된 시그널링 서버 계정을 삭제하지 못했습니다. 나중에 다시 확인하십시오.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "평가판 서버의 동작이 잘못되어 계정을 삭제하지 못했습니다. 나중에 다시 확인하십시오.",
    "There is a problem with deleting the account. Please check your logs for further information." : "계정을 삭제하는 데 문제가 있습니다. 자세한 내용은 로그를 확인하십시오.",
    "Too many requests are sent from your servers address. Please try again later." : "서버 주소에서 너무 많은 요청이 전송되었습니다. 나중에 다시 시도 해주십시오.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "평가판 서버에 연결할 수 없기 때문에 계정을 삭제하지 못했습니다. 나중에 다시 확인하십시오.",
    "Note to self" : "나에게 메모",
    "A place for your private notes, thoughts and ideas" : "개인 메모와 생각, 아이디어를 남길 수 있는 곳",
    "Andorra" : "안도라",
    "United Arab Emirates" : "아랍에미리트",
    "Afghanistan" : "아프가니스탄",
    "Antigua and Barbuda" : "앤티가바부다",
    "Anguilla" : "앵귈라",
    "Albania" : "알바니아",
    "Armenia" : "아르메니아",
    "Angola" : "앙골라",
    "Antarctica" : "남극",
    "Argentina" : "아르헨티나",
    "American Samoa" : "미국령 사모아",
    "Austria" : "오스트리아",
    "Australia" : "오스트레일리아",
    "Aruba" : "아루바",
    "Åland Islands" : "올란드 제도",
    "Azerbaijan" : "아제르바이잔",
    "Bosnia and Herzegovina" : "보스니아 헤르체고비나",
    "Barbados" : "바베이도스",
    "Bangladesh" : "방글라데시",
    "Belgium" : "벨기에",
    "Burkina Faso" : "부르키나 파소",
    "Bulgaria" : "불가리아",
    "Bahrain" : "바레인",
    "Burundi" : "부룬디",
    "Benin" : "베냉",
    "Saint Barthélemy" : "성 바르텔레미",
    "Bermuda" : "버뮤다",
    "Brunei Darussalam" : "브루나이",
    "Bolivia, Plurinational State of" : "볼리비아",
    "Bonaire, Sint Eustatius and Saba" : "보나이러",
    "Brazil" : "브라질",
    "Bahamas" : "바하마",
    "Bhutan" : "부탄",
    "Bouvet Island" : "부베 섬",
    "Botswana" : "보츠와나",
    "Belarus" : "벨라루스",
    "Belize" : "벨리즈",
    "Canada" : "캐나다",
    "Cocos (Keeling) Islands" : "코코스 킬링 제도",
    "Congo, the Democratic Republic of the" : "콩고",
    "Central African Republic" : "중앙아프리카공화국",
    "Congo" : "콩고",
    "Switzerland" : "스위스",
    "Côte d'Ivoire" : "코트디부아르",
    "Cook Islands" : "쿡 제도",
    "Chile" : "칠레",
    "Cameroon" : "카메룬",
    "China" : "중국",
    "Colombia" : "콜롬비아",
    "Costa Rica" : "코스타리카",
    "Cuba" : "쿠바",
    "Cabo Verde" : "카보베르데",
    "Curaçao" : "퀴라소",
    "Christmas Island" : "크리스마스 섬",
    "Cyprus" : "사이프러스",
    "Czechia" : "체코",
    "Germany" : "독일",
    "Djibouti" : "지부티",
    "Denmark" : "덴마크",
    "Dominica" : "도미니카",
    "Dominican Republic" : "도미니카공화국",
    "Algeria" : "알제리",
    "Ecuador" : "에콰도르",
    "Estonia" : "에스토니아",
    "Egypt" : "이집트",
    "Western Sahara" : "서사하라",
    "Eritrea" : "에리트레아",
    "Spain" : "스페인",
    "Ethiopia" : "에티오피아",
    "Finland" : "핀란드",
    "Fiji" : "피지",
    "Falkland Islands (Malvinas)" : "포클랜드제도 (말비나스)",
    "Micronesia, Federated States of" : "미크로네시아",
    "Faroe Islands" : "패로제도",
    "France" : "프랑스",
    "Gabon" : "가봉",
    "United Kingdom of Great Britain and Northern Ireland" : "영국",
    "Grenada" : "그레나다",
    "Georgia" : "조지아",
    "French Guiana" : "프랑스령 기아나",
    "Guernsey" : "건지",
    "Ghana" : "가나",
    "Gibraltar" : "지브롤터",
    "Greenland" : "그린랜드",
    "Gambia" : "잠비아",
    "Guinea" : "기니",
    "Guadeloupe" : "과들루프",
    "Equatorial Guinea" : "적도 기니",
    "Greece" : "그리스",
    "South Georgia and the South Sandwich Islands" : "사우스조지아 사우스샌드위치 제도",
    "Guatemala" : "과테말라",
    "Guam" : "괌",
    "Guinea-Bissau" : "기니비사우",
    "Guyana" : "가이아나",
    "Hong Kong" : "홍콩",
    "Heard Island and McDonald Islands" : "허드 맥도널드 제도",
    "Honduras" : "온두라스",
    "Croatia" : "크로아티아",
    "Haiti" : "아이티",
    "Hungary" : "헝가리",
    "Indonesia" : "인도네시아",
    "Ireland" : "아일랜드",
    "Israel" : "이스라엘",
    "Isle of Man" : "맨섬",
    "India" : "인도",
    "British Indian Ocean Territory" : "영국령인도양식민지",
    "Iraq" : "이라크",
    "Iran, Islamic Republic of" : "이란",
    "Iceland" : "아이슬란드",
    "Italy" : "이탈리아",
    "Jersey" : "저지",
    "Jamaica" : "자메이카",
    "Jordan" : "요르단",
    "Japan" : "일본",
    "Kenya" : "케냐",
    "Kyrgyzstan" : "키르기스스탄",
    "Cambodia" : "캄보디아",
    "Kiribati" : "키리바시",
    "Comoros" : "코모로",
    "Saint Kitts and Nevis" : "세인트키츠 네비스",
    "Korea, Democratic People's Republic of" : "조선민주주의인민공화국",
    "Korea, Republic of" : "대한민국",
    "Kuwait" : "쿠웨이트",
    "Cayman Islands" : "케이맨 제도",
    "Kazakhstan" : "카자흐스탄",
    "Lao People's Democratic Republic" : "라오스",
    "Lebanon" : "레바논",
    "Saint Lucia" : "세인트루시아",
    "Liechtenstein" : "리히텐슈타인",
    "Sri Lanka" : "스리랑카",
    "Liberia" : "라이베리아",
    "Lesotho" : "레소토",
    "Lithuania" : "리투아니아",
    "Luxembourg" : "룩셈부르크",
    "Latvia" : "라트비아",
    "Libya" : "리비아",
    "Morocco" : "모로코",
    "Monaco" : "모나코",
    "Moldova, Republic of" : "몰도바",
    "Montenegro" : "몬테네그로",
    "Saint Martin (French part)" : "세인트마틴섬",
    "Madagascar" : "마다가스카르",
    "Marshall Islands" : "마셜제도",
    "North Macedonia" : "북마케도니아",
    "Mali" : "말리",
    "Myanmar" : "미얀마",
    "Mongolia" : "몽골",
    "Macao" : "마카오",
    "Northern Mariana Islands" : "북마리아나제도",
    "Martinique" : "마르티니크",
    "Mauritania" : "모리타니",
    "Montserrat" : "몬세라트",
    "Malta" : "몰타",
    "Mauritius" : "모리셔스",
    "Maldives" : "몰디브",
    "Malawi" : "말라위",
    "Mexico" : "멕시코",
    "Malaysia" : "말레이시아",
    "Mozambique" : "모잠비크",
    "Namibia" : "나미비아",
    "New Caledonia" : "뉴칼레도니아",
    "Niger" : "니제르",
    "Norfolk Island" : "노퍽 섬",
    "Nigeria" : "나이지리아",
    "Nicaragua" : "니카라과",
    "Netherlands" : "네덜란드",
    "Norway" : "노르웨이",
    "Nepal" : "네팔",
    "Nauru" : "나우루",
    "Niue" : "니우에 섬",
    "New Zealand" : "뉴질랜드",
    "Oman" : "오만",
    "Panama" : "파나마",
    "Peru" : "페루",
    "French Polynesia" : "프랑스령폴리네시아",
    "Papua New Guinea" : "파푸아뉴기니",
    "Philippines" : "필리핀",
    "Pakistan" : "파키스탄",
    "Poland" : "폴란드",
    "Saint Pierre and Miquelon" : "생피에르 미클롱",
    "Pitcairn" : "핏케언 제도",
    "Puerto Rico" : "푸에르토리코",
    "Palestine, State of" : "팔레스타인",
    "Portugal" : "포르투갈",
    "Palau" : "팔라우",
    "Paraguay" : "파라과이",
    "Qatar" : "카타르",
    "Réunion" : "레위니옹",
    "Romania" : "루마니아",
    "Serbia" : "세르비아",
    "Russian Federation" : "러시아",
    "Rwanda" : "르완다",
    "Saudi Arabia" : "사우디아라비아",
    "Solomon Islands" : "솔로몬제도",
    "Seychelles" : "세이셸",
    "Sudan" : "수단",
    "Sweden" : "스웨덴",
    "Singapore" : "싱가포르",
    "Saint Helena, Ascension and Tristan da Cunha" : "세인트헬레나 어센션 트리스탄다쿠냐",
    "Slovenia" : "슬로베니아",
    "Svalbard and Jan Mayen" : "스발바르 얀마옌 제도",
    "Slovakia" : "슬로바키아",
    "Sierra Leone" : "시에라리온",
    "San Marino" : "산마리노",
    "Senegal" : "세네갈",
    "Somalia" : "소말리아",
    "Suriname" : "수리남",
    "South Sudan" : "남수단",
    "Sao Tome and Principe" : "상투메 프린시페 민주 공화국",
    "El Salvador" : "엘살바도르",
    "Sint Maarten (Dutch part)" : "신트마르턴",
    "Syrian Arab Republic" : "시리아",
    "Eswatini" : "에스와티니",
    "Turks and Caicos Islands" : "터크스카이코스 제도",
    "Chad" : "차드",
    "French Southern Territories" : "프랑스령 남부와 남극지역",
    "Togo" : "토고",
    "Thailand" : "타이",
    "Tajikistan" : "타지키스탄",
    "Tokelau" : "토켈라우",
    "Timor-Leste" : "동티모르",
    "Turkmenistan" : "투르크메니스탄",
    "Tunisia" : "튀니지",
    "Tonga" : "통가",
    "Turkey" : "터키",
    "Trinidad and Tobago" : "트리니다드토바고",
    "Tuvalu" : "투발루",
    "Taiwan, Province of China" : "대만",
    "Tanzania, United Republic of" : "탄자니아",
    "Ukraine" : "우크라이나",
    "Uganda" : "우간다",
    "United States Minor Outlying Islands" : "미국령 군소 제도",
    "United States of America" : "미국",
    "Uruguay" : "우루과이",
    "Uzbekistan" : "우즈베키스탄",
    "Holy See" : "바티칸시국",
    "Saint Vincent and the Grenadines" : "세인트빈센트 그레나딘",
    "Venezuela, Bolivarian Republic of" : "베네수엘라",
    "Virgin Islands, British" : "버진 아일랜드",
    "Virgin Islands, U.S." : "버진 아일랜드",
    "Viet Nam" : "베트남",
    "Vanuatu" : "바누아투",
    "Wallis and Futuna" : "왈리스에푸투나",
    "Samoa" : "사모아",
    "Yemen" : "예멘",
    "Mayotte" : "마요트섬",
    "South Africa" : "남아프리카공화국",
    "Zambia" : "잠비아",
    "Zimbabwe" : "짐바브웨",
    "Federation" : "연합",
    "High-performance backend" : "고성능 백엔드",
    "Error: Cannot connect to server" : "오류: 서버에 연결할 수 없습니다.",
    "Error: Server did not respond with proper JSON" : "오류: 서버가 올바른 JSON으로 응답하지 않습니다.",
    "Error: Certificate expired" : "오류: 인증서 만료",
    "Could not get version" : "버전을 가져올 수 없습니다.",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "오류: 사용 중인 버전: {version}; 이 버전의 토크와 호환되기 위해서 서버를 업데이트해야 합니다.",
    "Error: Server responded with: {error}" : "오류: 서버가 응답함: {error}",
    "Error: Unknown error occurred" : "오류: 알 수 없는 오류가 발생했습니다.",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "경고: 실행중인 버전: {version}; 서버가 이 버전의 Talk의 모든 기능을 지원하지 않습니다, 없는 기능: {features}",
    "Recording backend" : "녹음/녹화 백엔드",
    "SIP configuration" : "SIP 구성",
    "Invalid date, date format must be YYYY-MM-DD" : "잘못된 날짜입니다, YYYY-MM-DD 형식이어야 합니다.",
    "Conversation not found" : "대화를 찾을 수 없음",
    "Chat, video & audio-conferencing using WebRTC" : "WebRTC를 사용한 채팅, 영상 및 오디오 회의",
    "Leave call" : "통화 떠나기",
    "Navigating away from the page will leave the call in {conversation}" : "페이지에서 다른 페이지로 이동하면 {conversation}의 통화를 떠납니다.",
    "Stay in call" : "통화에 남기",
    "Discuss this file" : "이 파일에 대해 논의",
    "Share this file with others to discuss it" : "이 파일을 다른 이에게 공유하여 논의",
    "Share this file" : "이 파일 공유",
    "Join conversation" : "대화 참가",
    "This conversation is password-protected." : "이 대화는 암호로 보호되어 있습니다.",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "사용 중인 IP 주소에서 암호를 너무 많이 틀렸습니다. 30초 후에 다시 로그인할 수 있습니다.",
    "The password is wrong. Try again." : "암호가 잘못되었습니다. 다시 시도하십시오",
    "Password" : "암호",
    "Submit" : "제출",
    "Error requesting the password." : "암호를 요청하는 중 오류가 발생했습니다.",
    "Request password" : "암호 요청",
    "This conversation has ended" : "이 대화는 종료되었습니다.",
    "Error occurred when joining the conversation" : "대화에 참가하는 중 오류 발생",
    "Close Talk sidebar" : "토크 사이드바 닫기",
    "Open Talk sidebar" : "토크 사이드바 열기",
    "Everyone" : "모두",
    "Users and moderators" : "사용자 및 중재자",
    "Moderators only" : "중재자만",
    "Disable calls" : "통화 비활성화",
    "Save changes" : "변경 사항 저장",
    "Saving …" : "저장 중 …",
    "Saved!" : "저장했습니다!",
    "Limit to groups" : "그룹으로 제한",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "하나 이상의 그룹이 선택되면, 선택된 그룹의 구성원만 대화에 참가할 수 있습니다.",
    "Guests can still join public conversations." : "손님 계정은 여전히 공개 대화에 참가할 수 있습니다.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "더이상 토크를 사용할 수 없는 사용자는 지난 대화에 참가자로 목록에 계속 남아있으며 이들의 메시지도 유지됩니다.",
    "Limit using Talk" : "토크 사용 제한",
    "Limit creating a public and group conversation" : "공개 및 그룹 대화 만들기 제한",
    "Limit creating conversations" : "대화 만들기 제한",
    "Limit starting a call" : "통화 시작 제한",
    "Limit starting calls" : "통화 시작 제한",
    "When a call has started, everyone with access to the conversation can join the call." : "통화가 시작되면, 접근 권한이 있는 모두가 통화에 참가할 수 있습니다.",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "다음 봇들이 이 서버에 설치되었습니다. 문서에서 {linkstart1}당신의 봇을 만드는 방법{linkend}을 찾아보거나 {linkstart2}활성화할 봇들의 목록{linkend}을 확인할 수 있습니다.",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "이 서버에 설치된 봇이 없습니다. 문서에서 {linkstart1}당신의 봇을 만드는 방법{linkend}을 찾아보거나 {linkstart2}활성화할 봇들의 목록{linkend}을 확인할 수 있습니다.",
    "Description is not provided" : "설명이 주어지지 않았습니다.",
    "Locked for moderators" : "중재자로 잠김",
    "Enabled" : "활성화",
    "Disabled" : "비활성화됨",
    "Bots settings" : "봇 설정",
    "State" : "상태",
    "Name" : "이름",
    "Last error" : "마지막 오류",
    "Total errors count" : "총 오류 수",
    "Find more bots" : "봇 더 찾기",
    "Beta" : "베타",
    "Enable Federation in Talk app" : "Talk 앱에서 Federation 활성화",
    "Permissions" : "권한",
    "All messages" : "모든 메시지",
    "@-mentions only" : "@-언급만",
    "Off" : "꺼짐",
    "General settings" : "일반 설정",
    "Default notification settings" : "기본 알림 설정",
    "Default group notification" : "기본 그룹 알림",
    "Default group notification for new groups" : "새 그룹에 대한 기본 그룹 알림",
    "Integration into other apps" : "다른 앱에 통합",
    "Allow conversations on files" : "파일에서 대화 허용",
    "Allow conversations on public shares for files" : "파일의 공개 공유에서 대화 허용",
    "Enable encryption" : "암호화 사용",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "위의 버튼을 클릭하면 양식에 있는 정보가 Strucktur AG의 서버로 전송됩니다. 자세한 내용은 {linkstart}spreed.eu{linkend}에서 확인할 수 있습니다.",
    "Pending" : "대기 중",
    "Error" : "오류",
    "Blocked" : "차단됨",
    "Active" : "활동적인",
    "Expired" : "만료됨",
    "Never" : "하지 않음",
    "The trial could not be requested. Please try again later." : "평가판을 요청할 수 없습니다. 나중에 다시 시도해 주십시오.",
    "The account could not be deleted. Please try again later." : "계정을 삭제할 수 없습니다. 나중에 다시 시도해 주세요.",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "당사의 파트너 Struktur AG는 호스팅된 시그널링 서버를 요청할 수 있는 서비스를 제공합니다. 이 경우 아래 양식만 작성하면 Nextcloud에서 요청하게 됩니다. 서버가 설정되면 인증 정보가 자동으로 채워집니다. 기존 신호 시그널링 설정을 덮어씁니다.",
    "URL of this Nextcloud instance" : "이 Nextcloud 인스턴스의 URL",
    "Full name of the user requesting the trial" : "평가판을 요청하는 사용자의 전체 이름",
    "Email of the user" : "사용자의 이메일",
    "Language" : "언어",
    "Country" : "Country",
    "Request signaling server trial" : "요청 신호 서버 평가판",
    "You can see the current status of your hosted signaling server in the following table." : "당신은 다음 표에서 호스트된 시그널링 서버의 현재 상태를 볼 수 있습니다.",
    "Status" : "상태",
    "Created at" : "만든 날짜:",
    "Expires at" : "만료 날짜",
    "Limits" : "제한",
    "Yes" : "예",
    "No" : "아니오",
    "Delete the signaling server account" : "신호 서버 계정 삭제",
    "_%n user_::_%n users_" : ["%n명의 사용자"],
    "Installed version: {version}" : "설치된 버전 : {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "Matterbridge를 설치해 Nextcloud 토크를 다른 서비스에 연결할 수 있습니다. {linkstart1}GitHub page{linkend}에 방문해 자세히 알아보세요. 앱 다운로드와 설치에 시간이 걸릴 수 있습니다. 시간이 초과되는 경우 {linkstart2}Nextcloud 앱 스토어{linkend}에서 수동으로 설치하세요.",
    "Matterbridge binary was not found or couldn't be executed." : "Matterbridge 바이너리 파일을 찾을 수 없거나 실행할 수 없습니다.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "당신은 구성을 통해 Matterbridge 바이너리의 경로를 수동으로 설정할 수도 있습니다. 자세한 내용은 {linkstart}Matterbridge 통합 설명서{linkend}를 확인하십시오.",
    "Downloading …" : "다운로드 중 ...",
    "Install Talk Matterbridge" : "토크 Matterbridge 설치",
    "An error occurred while installing the Matterbridge app" : "Matterbridge 앱을 설치하는 중 오류가 발생했습니다.",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "토크에 Matterbridge를 설치하는 중 오류가 발생했습니다. 수동으로 설치해 주세요.",
    "Failed to execute Matterbridge binary." : "Matterbridge 바이너리를 실행하지 못했습니다.",
    "Matterbridge integration" : "Matterbridge 통합",
    "Enable Matterbridge integration" : "Matterbridge 통합 사용",
    "Status: Checking connection" : "상태: 연결 확인",
    "OK: Running version: {version}" : "확인: 실행 중인 버전: {version}",
    "Error: Server seems to be a Signaling server" : "오류: 서버가 시그널링 서버인 것 같습니다.",
    "Recording backend URL" : "녹음/녹화 백엔드 URL",
    "Validate SSL certificate" : "SSL 인증서 확인",
    "Delete this server" : "이 서버 삭제",
    "Test this server" : "이 서버 테스트",
    "Disabled for all calls" : "모든 통화에 대해 비활성화됨",
    "Enabled for all calls" : "모든 통화에 대해 활성화됨",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "PHP의 \"upload_max_filesize\", \"post_max_size\"의 설정으로 인해 {maxUpload} 크기의 파일까지 업로드가 가능합니다.",
    "Recording backend settings saved" : "녹음/녹화 백엔드 설정 저장됨",
    "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation." : "중재자는 동의를 대화 레벨에서  활성화하도록 허가됩니다. 각 참가자는 이 대화의 모든 통화에 참여하기 전에 녹음/녹화를 위한 동의가 필요합니다.",
    "The consent to be recorded will be required for each participant before joining every call." : "통화에 참가하는 모든 이들에게 녹음/녹화에 대한 동의가 필요합니다.",
    "The consent to be recorded is not required." : "녹음/녹화에 대한 동의가 필요하지 않습니다.",
    "Add a new recording backend server" : "새 녹음/녹화 백엔드 추가",
    "Shared secret" : "공유된 비밀 값",
    "Recording consent" : "녹음/녹화 동의",
    "SIP configuration saved!" : "SIP 설정 저장됨!",
    "Enable SIP Dial-out option" : "SIP Dial-out 옵션 활성화",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "지원되는 SIP Dial-out 기능을 위해 시그널링 서버를 업데이트해야 합니다.",
    "Restrict SIP configuration" : "SIP 구성 제한",
    "Enable SIP configuration" : "SIP 구성 사용",
    "Only users of the following groups can enable SIP in conversations they moderate" : "다음 그룹의 사용자만 이들이 중재자 권한으로 있는 대화에서 SIP를 사용할 수 있습니다.",
    "Phone number (Country)" : "전화번호(국가)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "이 정보를 초대 이메일로 보냈으며 모든 참가자들의 사이드바에 표시했습니다.",
    "High-performance backend URL" : "고성능 백엔드 URL",
    "High-performance backend settings saved" : "고성능 백엔드 설정 저장됨",
    "STUN server URL" : "STUN 서버 URL",
    "The server address is invalid" : "서버 주소가 잘못되었습니다.",
    "STUN settings saved" : "STUN 설정 저장됨",
    "STUN servers" : "STUN 서버",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN 서버는 라우터 뒤에 있는 참가자의 공인 IP 주소를 판단하는 데 사용합니다.",
    "Add a new STUN server" : "새 STUN 서버 추가",
    "{schema} scheme must be used with a domain" : "{schema} 스키마에 도메인을 사용해야 합니다.",
    "{option1} and {option2}" : "{option1}(과)와 {option2}",
    "{option} only" : "{option}만",
    "OK: Successful ICE candidates returned by the TURN server" : "확인: TURN 서버에서 반환한 성공적인 ICE 후보",
    "Error: No working ICE candidates returned by the TURN server" : "오류: TURN 서버에서 반환된 작동 중인 ICE 후보가 없습니다.",
    "Testing whether the TURN server returns ICE candidates" : "TURN 서버가 ICE 후보를 반환하는지 테스트",
    "TURN server schemes" : "TURN 서버 스키마",
    "TURN server URL" : "TURN 서버 URL",
    "TURN server secret" : "TURN 서버 비밀",
    "TURN server protocols" : "TURN 서버 프로토콜",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "TURN 서버는 방화벽 뒤에 있는 참가자들의 트래픽을 중계하는 데 쓰입니다. 각 참가자가 서로에게 연결을 하지 못한다면 TURN 서버를 사용해야 할 가능성이 높습니다. {linkstart}이 문서{linkend}에서 설치 지침을 확인하세요.",
    "TURN settings saved" : "TURN 설정 저장됨",
    "TURN servers" : "TURN 서버",
    "Add a new TURN server" : "새 TURN 서버 추가",
    "Failed" : "실패",
    "OK" : "확인",
    "Checking …" : "검사 중…",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "실패: WebAssembly가 이 브라우저에서 비활성화되었거나 지원되지 않습니다. WebAssembly를 활성화하거나 이를 지원하는 브라우저를 사용하여 확인하십시오.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "실패: \".wasm\" 및 \".tflite\" 파일이 웹 서버에서 제대로 반환되지 않았습니다. 토크의 문서에서 \"시스템 요구 사항\" 섹션을 확인하십시오.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "확인: \".wasm\" 및 \".tflite\" 파일이 웹 서버에서 정상적으로 반환되었습니다.",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "현재 PHP와 Apache 설정이 호환되지 않는 것 같습니다. PHP는 오직 MPM_PREFORK 모듈과 함께 사용되어야 하며, PHP-FPM은 오직 MPM_EVENT 모듈과 함께 사용되어야 합니다.",
    "Web server setup checks" : "웹 서버 설정 확인",
    "Files required for virtual background can be loaded" : "가상 배경에 필요한 파일을 불러올 수 있습니다.",
    "Federated user" : "연합 사용자",
    "Assign participants to rooms" : "참가자를 대화방에 배정",
    "Configure breakout rooms" : "소회의실 설정",
    "Number of breakout rooms" : "소회의실 수",
    "You can create from 1 to 20 breakout rooms." : "1개에서 20개의 소회의실을 만들 수 있습니다.",
    "Assignment method" : "배정 방법",
    "Automatically assign participants" : "참가자 자동 배정",
    "Manually assign participants" : "참가자 수동 배정",
    "Allow participants to choose" : "참가자가 선택하도록 허용",
    "Create rooms" : "대화방 만들기",
    "Confirm" : "확인",
    "Create breakout rooms" : "소회의실 만들기",
    "Reset" : "초기화",
    "Delete breakout rooms" : "소회의실 삭제",
    "Room {roomNumber}" : "{roomNumber}번 대화방",
    "Current breakout rooms and settings will be lost" : "현재 소회의실의 설정이 모두 사라집니다.",
    "Cancel" : "취소",
    "Unassigned participants" : "배정되지 않은 참가자",
    "Back" : "뒤로",
    "Assign" : "배정",
    "Add participant \"{user}\"" : "참가자 \"{user}\" 추가",
    "Now" : "지금",
    "Loading …" : "불러오는 중 ...",
    "From" : "보낸사람",
    "To" : "받는사람",
    "Calendar" : "일정",
    "Attendees" : "참석자",
    "Save" : "저장",
    "Search participants" : "참가자 찾기",
    "No results" : "결과 없음",
    "Done" : "완료",
    "Raise hand" : "손들기",
    "Raise hand (R)" : "손들기 (R)",
    "Lower hand" : "손 내리기",
    "Lower hand (R)" : "손 내리기 (R)",
    "Exit full screen (F)" : "전체 화면 나가기 (F)",
    "Full screen (F)" : "전체 화면 (F)",
    "Speaker view" : "말하는 사람 보기",
    "Grid view" : "바둑판식 보기",
    "This conversation is read-only" : "이 대화는 읽기 전용입니다.",
    "Reload" : "새로 고침",
    "{nickName} raised their hand." : "{nickName}님이 손을 들었습니다.",
    "A participant raised their hand." : "한 참가자가 손을 들었습니다.",
    "Collapse stripe" : "스트라이프 접기",
    "Expand stripe" : "스트라이프 확장",
    "Previous page of videos" : "영상의 이전 페이지",
    "Next page of videos" : "영상의 다음 페이지",
    "Connecting …" : "연결 중...",
    "Calling …" : "통화 거는 중...",
    "Waiting for {user} to join the call" : "{user}님이 통화에 참가하기를 기다리고 있습니다.",
    "Waiting for others to join the call …" : "다른 사람을 기다리는 중 …",
    "You can invite others in the participant tab of the sidebar" : "사이드바의 참가자 탭에서 다른 사람들을 초대할 수 있음",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "당신은 사이드바의 참가자 탭에서 다른 사용자를 초대하거나 이 링크를 공유하여 다른 사용자를 초대할 수 있습니다!",
    "Share this link to invite others!" : "다른 사람을 초대하려면 링크를 공유하십시오!",
    "Copy link" : "링크 복사",
    "You are not allowed to enable audio" : "오디오를 활성화할 수 없습니다.",
    "No audio. Click to select device" : "오디오가 없습니다. 클릭해서 장치를 선택하세요.",
    "Mute audio" : "소리 음소거",
    "Mute audio (M)" : "소리 음소거(M)",
    "Unmute audio" : "소리 음소거 해제",
    "Unmute audio (M)" : "소리 음소거 해제(M)",
    "None" : "없음",
    "Access to camera was denied" : "카메라에 대한 접근이 거부되었습니다.",
    "Error while accessing camera: It is likely in use by another program" : "카메라 액세스 오류: 다른 프로그램에서 사용 중일 수 있습니다.",
    "Error while accessing camera" : "카메라에 접근하는 중 오류 발생",
    "You have been muted by a moderator" : "당신이 중재자에 의해 음소거되었습니다.",
    "You are not allowed to enable video" : "영상을 활성화할 수 없습니다.",
    "No video. Click to select device" : "영상이 없습니다. 클릭해서 장치를 선택하세요.",
    "Disable video" : "비디오 비활성화",
    "Disable video (V)" : "영상 비활성화(V)",
    "Enable video" : "영상 활성화",
    "Enable video (V)" : "영상 활성화(V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "영상 활성화 - 영상을 처음 활성화하면 연결이 잠깐 끊어집니다.",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "영상 활성화(V) - 영상을 처음 활성화하면 연결이 잠시 중단됩니다.",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "영상을 활성화합니다. 처음으로 영상을 활성화하면 연결이 잠시 중단됩니다.",
    "Show presenter" : "발표자 표시",
    "You" : "나",
    "Mute" : "음소거",
    "Muted" : "음소거됨",
    "Show screen" : "화면 보이기",
    "Stop following" : "따라가기 중지",
    "Connection could not be established …" : "연결을 설정할 수 없습니다…",
    "Connection was lost and could not be re-established …" : "연결이 끊어져 다시 설정할 수 없습니다...",
    "Connection could not be established. Trying again …" : "연결을 설정할 수 없습니다. 다시 시도 중…",
    "Connection lost. Trying to reconnect …" : "연결이 끊어졌습니다. 다시 연결하는 중…",
    "Connection problems …" : "연결 문제 …",
    "Collapse" : "접기",
    "Expand" : "확장",
    "You need to be logged in to upload files" : "파일을 업로드하려면 로그인해야 합니다.",
    "Drop your files to upload" : "여기에 파일을 올려 업로드하기",
    "Conversation messages" : "대화 메시지",
    "Scroll to bottom" : "맨 아래로 스크롤",
    "Post message" : "메시지 게시",
    "Favorite" : "즐겨찾기",
    "Date:" : "날짜:",
    "Note:" : "메모:",
    "Hide details" : "자세한 정보 숨기기",
    "Show details" : "세부 정보",
    "Error while updating conversation name" : "대화 이름을 설정하는 중 오류 발생",
    "Error while updating conversation description" : "대화 설명을 업데이트하는 중 오류 발생",
    "Enter a name for this conversation" : "이 대화의 이름을 입력하세요.",
    "Edit conversation name" : "대화 이름 수정",
    "Edit conversation description" : "대화 설명 편집",
    "Enter a description for this conversation" : "이 대화에 대한 설명을 입력하세요.",
    "Picture" : "사진",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "다음 봇들을 이 대화에서 활성화할 수 있습니다. 관리자에게 연락해 더 많은 봇들을 설치하세요.",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "이 서버에 설치된 봇이 없습니다. 관리자에게 연락해 봇들을 설치하세요.",
    "Disable" : "사용 안함",
    "Enable" : "활성화",
    "Breakout rooms" : "소회의실",
    "Manage breakout rooms" : "소회의실 관리",
    "Set up breakout rooms for this conversation" : "이 대화에 소회의실을 구성",
    "Please select a valid PNG or JPG file" : "올바른 PNG 또는 JPG 파일을 선택하세요.",
    "Choose your conversation picture" : "대화의 사진을 고르세요.",
    "Choose" : "선택",
    "Error setting conversation picture" : "대화의 사진을 설정하는 중 오류 발생",
    "Could not set the conversation picture: {error}" : "대화의 사진을 설정할 수 없습니다: {error}",
    "Error cropping conversation picture" : "사진을 자르는 중 오류 발생",
    "Error removing conversation picture" : "대화의 사진을 제거하는 중 오류 발생",
    "Set emoji as conversation picture" : "이모지를 대화의 사진으로 설정",
    "Set background color for conversation picture" : "대화의 사진에 배경 색을 지정",
    "Upload conversation picture" : "대화의 사진을 업로드",
    "Choose conversation picture from files" : "대화의 사진을 파일에서 고르기",
    "Remove conversation picture" : "대화의 사진 제거",
    "The file must be a PNG or JPG" : "파일은 PNG 또는 JPG여야 합니다.",
    "Set picture" : "사진 설정",
    "Default permissions modified for {conversationName}" : "{conversationName}의 기본 권한이 수정되었습니다.",
    "Could not modify default permissions for {conversationName}" : "{conversationName}의 기본 권한을 수정할 수 없습니다.",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "이 대화의 참가자에 대한 기본 권한을 편집합니다. 이 설정들은 중재자에게 영향을 미치지 않습니다.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "이 부분의 권한이 수정될 때마다, 이전에 각 참가자에게 배정된 맞춤 권한들이 사라집니다.",
    "All permissions" : "모든 권한",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "참가자는 통화를 시작하고, 통화에 참가하고, 오디오 및 영상을 활성화하고, 화면을 공유할 수 있는 권한이 있습니다.",
    "Restricted" : "제한됨",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "참가자는 통화에 참가할 수 있지만 중재자가 수동으로 권한을 부여할 때까지 오디오나 영상을 활성화하거나 화면을 공유할 수 없습니다.",
    "Advanced permissions" : "고급 권한",
    "Edit permissions" : "권한 수정",
    "Conversation settings" : "대화 설정",
    "Basic Info" : "기본 정보",
    "Personal" : "개인",
    "Moderation" : "중재",
    "Setup overview" : "설정 개요",
    "Breakout Rooms" : "소회의실",
    "Matterbridge" : "Matterbridge",
    "Bots" : "봇",
    "Danger zone" : "위험 지역",
    "Leave conversation" : "대화 나가기",
    "You need to promote a new moderator before you can leave the conversation" : "대화를 떠나기 전 새 중재자를 임명해야 합니다.",
    "Delete conversation" : "대화 삭제",
    "Do you really want to delete \"{displayName}\"?" : "\"{displayName}\"(을)를 정말 삭제하시겠습니까?",
    "Error while deleting conversation" : "대화를 삭제하는 동안 오류가 발생했습니다.",
    "Delete all chat messages" : "모든 채팅 메시지 삭제",
    "Do you really want to delete all messages in \"{displayName}\"?" : "정말 \"{displayName}\"의 모든 대화를 삭제하시겠습니까?",
    "Error while clearing chat history" : "채팅 기록을 지우는 동안 오류가 발생했습니다.",
    "Be careful, these actions cannot be undone." : "주의하세요. 이 작업은 취소할 수 없습니다.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "대화를 떠난 후 비공개 대화에 다시 참가하려면 초대가 필요합니다. 공개 대화는 언제든지 다시 참가할 수 있습니다.",
    "Permanently delete this conversation." : "이 대화를 영구적으로 삭제합니다.",
    "Delete chat messages" : "채팅 메시지 삭제",
    "Permanently delete all the messages in this conversation." : "이 대화의 모든 메시지를 영구적으로 삭제합니다.",
    "_%n hour_::_%n hours_" : ["%n시간"],
    "_%n day_::_%n days_" : ["%n일"],
    "_%n week_::_%n weeks_" : ["%n주"],
    "Custom expiration time" : "만료 시간 정하기",
    "Message expiration disabled" : "메시지 만료 비활성화",
    "Message expiration set: {duration}" : "설정된 메시지 만료 기간: {duration}",
    "Error when trying to set message expiration" : "메시지 만료 기간 설정 중 오류 발생",
    "Message expiration" : "메시지 만료",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "채팅 메시지가 특정 시간 이후에 만료될 수 있습니다. 참고: 채팅에서 공유된 파일들은 소유자에게서 삭제 되지 않지만, 대화에서 더이상 공유되지 않습니다.",
    "Set message expiration" : "메시지 만료 설정",
    "Current message expiration" : "현재의 메시지 만료",
    "Guest access" : "게스트 접속",
    "Allow guests to join this conversation via link" : "손님이 링크를 통해 이 대화에 참가하도록 허용",
    "Password protection" : "암호 보호",
    "Set a password" : "암호 설정",
    "Change password" : "암호 변경",
    "Enter new password" : "새 암호 입력",
    "Save password" : "암호 저장",
    "Guests are allowed to join this conversation via link" : "손님이 링크를 통해 이 대화에 참여할 수 있습니다.",
    "Guests are not allowed to join this conversation" : "손님은 이 대화에 참여할 수 없습니다.",
    "Resend invitations" : "초대 재전송",
    "This conversation is open to both registered users and users created with the Guests app" : "이 대화는 가입된 사용자와 Guests 앱을 통해 만들어진 사용자 모두에게 열려있습니다.",
    "This conversation is open to registered users" : "이 대화는 가입된 사용자들에게 열려 있습니다.",
    "This conversation is limited to the current participants" : "이 대화는 현재 참가자들로 제한되어 있습니다.",
    "You opened the conversation to both registered users and users created with the Guests app" : "대화를 가입된 사용자와 Guests 앱을 통해 만들어진 사용자 모두에게 열었습니다.",
    "Error occurred when opening or limiting the conversation" : "대화를 열거나 제한하는 중에 오류가 발생했습니다.",
    "Open conversation to registered users, showing it in search results" : "대화를 가입된 사용자들에게 공개하고, 검색 결과에 표시",
    "Also open to users created with the Guests app" : "또한 Guests 앱을 통해 생성된 사용자에게 공개됨",
    "Open conversation" : "대화 공개",
    "Start time has been updated" : "시작 시간이 업데이트 되었습니다.",
    "Error occurred while updating start time" : "시작 시간을 업데이트하는 중에 오류 발생",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "로비를 활성화하면 진행 중인 통화에서 중재자가 아닌 이들이 제거됩니다.",
    "Enable lobby, restricting the conversation to moderators" : "로비를 활성화하여 중재자들로 대화를 제한",
    "Meeting start time" : "모임 시작 시간",
    "Start time (optional)" : "시작 시간 (선택 사항)",
    "Error occurred when locking the conversation" : "대화를 잠그는 동안 오류가 발생했습니다.",
    "Error occurred when unlocking the conversation" : "대화 잠금을 해제하는 동안 오류가 발생했습니다.",
    "Lock conversation" : "대화 잠금",
    "This will also terminate the ongoing call." : "이렇게 하면 진행 중인 통화도 종료됩니다.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "아무도 메시지를 작성하거나 통화를 시작할 수 없도록 대화 잠그기",
    "Edit" : "편집",
    "More information" : "더 많은 정보",
    "Delete" : "삭제",
    "Add new bridged channel to current conversation" : "현재 대화에 새로운 채널 연결",
    "unknown state" : "알 수 없는 상태",
    "running" : "실행중",
    "not running, check Matterbridge log" : "실행 중이지 않습니다. Matterbridge 로그를 확인하십시오.",
    "not running" : "실행 중이지 않습니다.",
    "Bridge saved" : "연결 저장",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Matterbridge를 사용하여 다양한 인스턴트 메시징 시스템의 채널을 연결할 수 있습니다.",
    "More info on Matterbridge" : "Matterbridge에 대한 더 많은 정보",
    "Messaging systems" : "메시징 시스템",
    "Enable bridge" : "가능한 연결",
    "Show Matterbridge log" : "Matterbridge 로그 보기",
    "Log content" : "로그 내용",
    "Notifications" : "알림",
    "Notify about calls in this conversation" : "이 대화의 통화에 대해 알림",
    "Important conversation" : "중요한 대화",
    "Recording consent is required for calls in this conversation" : "이 대화의 통화에서 녹음/녹화 동의 필요",
    "Recording consent is not required for calls in this conversation" : "이 대화의 통화에서 녹음/녹화 동의 불필요",
    "Recording consent requirement was updated" : "녹음/녹화 동의 필요 여부가 바뀌었습니다.",
    "Error occurred while updating recording consent" : "녹음/녹화 동의를 바꾸는 중 오류 발생",
    "Recording Consent" : "녹음/녹화 동의",
    "Recording consent cannot be changed once a call or breakout session has started." : "녹음/녹화 동의는 통화나 소회의 세션이 시작되면 바꿀 수 없습니다.",
    "Require recording consent before joining call in this conversation" : "이 대화에 참여하기 전 녹음/녹화 동의 필요",
    "Recording consent is required for all calls" : "모든 통화에서 녹음/녹화 동의 필요",
    "SIP dial-in is now possible without PIN requirement" : "이제 PIN 없이 SIP 전화 접속이 가능합니다.",
    "SIP dial-in is now enabled" : "이제 SIP 전화 접속이 활성화됨",
    "SIP dial-in is now disabled" : "이제 SIP 전화 접속을 사용할 수 없습니다.",
    "Error occurred when enabling SIP dial-in" : "SIP 전화 접속을 활성화하는 동안 오류가 발생했습니다.",
    "Error occurred when disabling SIP dial-in" : "SIP 전화 접속을 비활성화하는 동안 오류가 발생했습니다.",
    "Phone and SIP dial-in" : "전화 및 SIP 전화 연결",
    "Enable phone and SIP dial-in" : "전화 및 SIP 전화 연결 활성화",
    "Allow to dial-in without a PIN" : "PIN 없이 전화 접속 허용",
    "Join" : "참가",
    "Error while creating the conversation" : "대화를 만드는 중에 오류 발생",
    "Create a new conversation" : "새 대화 만들기",
    "Join open conversations" : "공개 대화에 참가",
    "Call a phone number" : "전화번호에 전화",
    "Unread mentions" : "읽지 않은 언급",
    "Create conversation" : "대화 만들기",
    "Enter your name" : "이름을 입력하세요",
    "Submit name and join" : "이름을 등록하고 참가",
    "Log in" : "로그인",
    "An error occurred while calling a phone number" : "전화번호에 전화하는 중 오류 발생",
    "Phone number could not be called: {error}" : "전화번호에 전화할 수 없음: {error}",
    "Phone number could not be called" : "전화번호에 전화할 수 없습니다.",
    "Search participants or phone numbers" : "참가자 및 전화번호 검색",
    "Creating the conversation …" : "대화 만드는 중...",
    "Mark as read" : "읽은 것으로 표시",
    "Mark as unread" : "읽지 않은 것으로 표시",
    "Remove from favorites" : "즐겨찾기에서 제거",
    "Add to favorites" : "즐겨찾기에 추가",
    "You need to promote a new moderator before you can leave the conversation." : "대화를 종료하려면 새 중재자를 임명해야 합니다.",
    "Conversation actions" : "대화 작업",
    "Home" : "집",
    "Unread" : "읽지 않음",
    "Alphabetically" : "가나다순",
    "No matches found" : "일치하는 항목 없음",
    "No conversations found" : "대화를 찾을 수 없습니다.",
    "You have no unread mentions." : "읽지 않은 언급이 없습니다.",
    "You have no unread messages." : "읽지 않은 메시지가 없습니다.",
    "An error occurred while performing the search" : "검색을 수행하는 동안 오류가 발생했습니다.",
    "Conversation list" : "대화 목록",
    "Unread messages" : "읽지 않은 메시지",
    "Clear filters" : "필터링 제거",
    "New personal note" : "새 개인 메모",
    "Clear filter" : "필터 지우기",
    "App settings" : "앱 설정",
    "Users" : "사용자",
    "Groups" : "그룹",
    "Other sources" : "다른 출처",
    "Open conversations" : "대화 열기",
    "No search results" : "검색 결과 없음",
    "Users and groups" : "사용자와 그룹",
    "The meeting will start soon" : "회의가 곧 시작됩니다.",
    "This meeting is scheduled for {startTime}" : "모임이 {startTime}에 예정되었습니다.",
    "You are currently waiting in the lobby" : "대화방 로비에서 대기 중입니다.",
    "Select microphone" : "마이크 선택",
    "No microphone available" : "사용 가능한 마이크 없음",
    "Select camera" : "카메라 선택",
    "No camera available" : "사용 가능한 카메라 없음",
    "Select a device" : "장치 선택",
    "Test" : "테스트",
    "Devices" : "장치",
    "Backgrounds" : "배경",
    "No audio" : "오디오 없음",
    "No camera" : "카메라 없음",
    "Calls are not supported in your browser" : "이 브라우저가 통화를 지원하지 않습니다.",
    "Access to microphone is only possible with HTTPS" : "HTTPS를 통해서만 마이크에 액세스할 수 있음",
    "Access to microphone was denied" : "마이크 접근이 거부되었습니다.",
    "Error while accessing microphone" : "마이크에 접근하는 중 오류 발생",
    "Access to camera is only possible with HTTPS" : "HTTPS에서만 카메라에 접근할 수 있습니다.",
    "The call is being recorded." : "통화가 녹음/녹화되고 있습니다.",
    "The call might be recorded." : "통화가 녹음/녹화됩니다.",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "녹음/녹화는 당신의 목소리, 카메라의 화상, 화면 공유를 포함할 수 있습니다. 통화에 참여하기 전 당신의 동의가 필요합니다.",
    "Give consent to the recording of this call" : "이 통화의 녹화/녹음에 동의",
    "Start recording immediately with the call" : "통화하는 즉시 녹음/녹화를 시작",
    "Apply settings" : "설정 적용",
    "Select virtual office background" : "가상 사무실 배경 선택",
    "Select virtual home background" : "가상 집 배경 선택",
    "Select virtual abstract background" : "가상 추상화 배경 선택",
    "Select virtual beach background" : "가상 해변 배경 선택",
    "Select virtual park background" : "가상 공원 배경 선택",
    "Select virtual theater background" : "가상 극장 배경 선택",
    "Select virtual library background" : "가상 도서관 배경 선택",
    "Select virtual space station background" : "가상 우주 정거장 배경 선택",
    "Error while uploading the file" : "파일 업로드 중 오류 발생",
    "Select a file" : "파일 선택",
    "Invalid path selected" : "잘못된 경로가 선택됨",
    "Select virtual background from file {fileName}" : "{fileName}파일에서 가상 배경 선택",
    "Blur" : "흐림",
    "Upload" : "업로드",
    "Files" : "파일",
    "(editing)" : "(수정중)",
    "(edited)" : "(수정됨)",
    "The message has expired or has been deleted" : "메시지가 만료되었거나 삭제되었습니다.",
    "Cancel quote" : "인용 취소",
    "24 hours" : "24시간",
    "7 days" : "7일",
    "Clear reminder – {timeLocale}" : "알림 지우기 – {timeLocale}",
    "Message text copied to clipboard" : "메시지 텍스트를 클립보드에 복사했습니다.",
    "Message text could not be copied" : "메시지 텍스트를 클립보드에 복사할 수 없습니다.",
    "Message forwarded to \"Note to self\"" : "메시지가 \"나에게 메모\"로 전달되었습니다",
    "Error while forwarding message to \"Note to self\"" : "메시지를 \"나에게 메모\"로 전달하는 중 오류 발생",
    "A reminder was successfully removed" : "알림이 성공적으로 제거되었습니다.",
    "Error occurred when removing a reminder" : "알림을 제거하는 중 오류가 발생했습니다.",
    "A reminder was successfully set at {datetime}" : "알림이 {datetime}(으)로 성공적으로 설정되었습니다.",
    "Error occurred when creating a reminder" : "알림을 만드는 중 오류가 발생했습니다.",
    "Add a reaction to this message" : "이 메시지에 반응 추가",
    "Reply" : "답장",
    "More actions" : "더 많은 동작",
    "Set reminder" : "알림 설정",
    "Reply privately" : "비공개로 답장",
    "Edit message" : "메시지 편집",
    "Copy message" : "메시지 복사",
    "Copy message link" : "메시지 링크 복사",
    "Go to file" : "파일로 이동",
    "Forward message" : "메시지 전달",
    "Translate" : "번역:",
    "Set custom reminder" : "사용자 지정 알림 설정",
    "Close reactions menu" : "반응 메뉴 닫기",
    "React with {emoji}" : "{emoji}(으)로 반응",
    "React with another emoji" : "다른 이모지로 반응",
    "Choose a conversation to forward the selected message." : "선택한 메시지를 전달할 대화를 선택하세요.",
    "Error while forwarding message" : "메시지를 전달하는 동안 오류가 발생했습니다.",
    "The message has been forwarded to {selectedConversationName}" : "메시지를 {selectedConversationName}에 전달했습니다.",
    "Dismiss" : "무시",
    "Go to conversation" : "대화로 이동",
    "Detect language" : "언어 감지",
    "The message could not be translated" : "메시지를 번역할 수 없습니다.",
    "Translation copied to clipboard" : "번역을 클립보드로 복사함",
    "Translation could not be copied" : "번역을 복사할 수 없습니다.",
    "Translate message" : "메시지 번역",
    "Source language to translate from" : "번역될 원본의 언어",
    "Translate from" : "다음을 번역",
    "Target language to translate into" : "번역할 목표 언어",
    "Translate to" : "다음으로 번역",
    "Translating" : "번역 중",
    "Copy translated text" : "번역한 텍스트 복사",
    "Send now" : "지금 보내기",
    "Message read by everyone who shares their reading status" : "읽기 상태를 공개한 모든 사용자가 메시지를 읽음",
    "Message sent" : "메시지 보냄",
    "Deleting message" : "메시지 삭제",
    "Message deleted successfully" : "메시지가 성공적으로 삭제됨",
    "Message could not be deleted because it is too old" : "메시지가 너무 오래되어 삭제할 수 없습니다.",
    "Only normal chat messages can be deleted" : "일반 채팅 메시지만 삭제할 수 있습니다.",
    "An error occurred while deleting the message" : "메시지를 지우는 중 오류 발생",
    "Your browser does not support playing audio files" : "귀하의 브라우저는 오디오 파일 재생을 지원하지 않습니다.",
    "Contact" : "연락처",
    "{stack} in {board}" : "{board}의 {stack}",
    "Deck Card" : "덱 카드",
    "Remove {fileName}" : "{fileName} 제거",
    "Open this location in OpenStreetMap" : "OpenStreetMap에서 이 위치를 엽니다.",
    "Sending message" : "메시지 보내는 중",
    "Failed to send the message. Click to try again" : "메시지를 보내지 못했습니다. 다시 시도하려면 클릭하세요.",
    "Not enough free space to upload file" : "파일을 업로드할 여유 공간이 부족합니다.",
    "You cannot send messages to this conversation at the moment" : "지금은 이 대화에 메시지를 보낼 수 없습니다.",
    "_%n vote_::_%n votes_" : ["%n 표"],
    "Open poll" : "투표 열기",
    "See results" : "결과 보기",
    "No permission to post reactions in this conversation" : "이 대화에 반응을 게시할 권한이 없습니다.",
    "Add more reactions" : "반응 더 추가",
    "Show or collapse system messages" : "시스템 메시지를 보이거나 접기",
    "No messages" : "메시지가 없음",
    "All messages have expired or have been deleted." : "모든 메시지가 삭제되었거나 만료되었습니다.",
    "Cancel search" : "검색 취소",
    "Add a phone number" : "전화번호를 추가하세요.",
    "All set, the conversation \"{conversationName}\" was created." : "모두 설정했으며,  \"{conversationName}\" 대화가 만들어졌습니다.",
    "Create a new group conversation" : "새 그룹 대화 생성",
    "Add participants" : "참가자 추가",
    "Conversation visibility" : "대화 가시성",
    "Allow guests to join via link" : "링크를 통해 손님이 참가하도록 허용",
    "Enter password" : "암호 입력",
    "This conversation has been locked" : "이 대화는 잠겨있습니다.",
    "No permission to post messages in this conversation" : "이 대화에 메시지를 게시할 수 있는 권한이 없음",
    "Joining conversation …" : "대화에 들어가는 중...",
    "Send message" : "메시지 보내기",
    "Send without notification" : "알림 없이 전송",
    "File to share" : "공유할 파일",
    "Add emoji" : "이모지 추가",
    "Send later" : "나중에 보내기",
    "Cancel editing" : "수정 취소",
    "{user} is out of office and might not respond." : "{user}가 부재중이어서 응답하지 않을 수 있습니다.",
    "Share from {nextcloud}" : "{nextcloud}에서 공유",
    "Share from Files" : "파일에서 공유",
    "Share files to the conversation" : "대화로 파일 공유",
    "Upload from device" : "이 기기에서 업로드",
    "Create new poll" : "새 투표 만들기",
    "Smart picker" : "스마트 피커",
    "Record voice message" : "음성 메시지 녹음",
    "End recording and send" : "녹음 종료 및 보내기",
    "Dismiss recording" : "녹음 무시",
    "Access to the microphone was denied" : "마이크에 대한 액세스가 거부되었습니다.",
    "Microphone either not available or disabled in settings" : "마이크를 사용할 수 없거나 설정에서 비활성화됨",
    "Error while recording audio" : "녹음 중 오류",
    "New file" : "새 파일",
    "Blank" : "여백",
    "Error while creating file" : "파일을 만드는 중 오류 발생",
    "Create and share a new file" : "새 파일을 만들고 공유",
    "Name of the new file" : "새 파일의 이름",
    "Create file" : "파일 만들기",
    "Someone is typing …" : "누군가 입력 중입니다…",
    "{user1} is typing …" : "{user1}님이 입력 중입니다…",
    "{user1} and {user2} are typing …" : "{user1}님과 {user2}님이 입력 중입니다…",
    "{user1}, {user2} and {user3} are typing …" : "{user1}님, {user2}님과 {user3}님이 입력 중입니다…",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}님, {user2}님, {user3}님과 %n명의 사람들이 입력 중입니다…"],
    "Add more files" : "파일 더 추가",
    "Send" : "보내기",
    "In this conversation <strong>{user}</strong> can:" : "이 대화에서 <strong>{user}</strong>님이 할 수 있는 것:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "<strong>{conversationName}</strong>의 참가자들의 기본 권한 수정",
    "Start a call" : "통화 시작",
    "Skip the lobby" : "로비 건너 뛰기",
    "Can post messages and reactions" : "메시지 게시 및 반응 가능",
    "Enable the microphone" : "마이크 활성화",
    "Enable the camera" : "카메라 활성화",
    "Share the screen" : "화면 공유",
    "Update permissions" : "권한 업데이트",
    "Updating permissions" : "권한 업데이트",
    "Create poll" : "투표 만들기",
    "Question" : "질문",
    "Ask a question" : "질문하기",
    "Answers" : "답변",
    "Answer {option}" : "답변 {option}",
    "Delete poll option" : "투표 옵션 삭제",
    "Add answer" : "답변 추가",
    "Settings" : "설정",
    "Anonymous poll" : "익명 투표",
    "Multiple answers" : "여러 개의 답변",
    "You voted for this option" : "이 옵션에 투표했습니다.",
    "End poll" : "투표를 끝내다",
    "Change your vote" : "투표 수정",
    "Results" : "결과들",
    "Voted participants" : "투표한 참가자",
    "Send a message to \"{roomName}\"" : "\"{roomName}\"에 메시지 보내기",
    "Hide list of participants" : "참가자 목록 숨기기",
    "Show list of participants" : "참가자 목록 보이기",
    "Assistance requested in {roomName}" : "{roomName}에서 요청한 지원",
    "The message was sent to \"{roomName}\"" : "메시지를 \"{roomName}\"에 전송했습니다.",
    "Dismiss request for assistance" : "지원 요청 무시",
    "Send message to room" : "대화방에 메시지 보내기",
    "Back to main room" : "주 대화방으로 돌아가기",
    "Back to your room" : "대화방으로 돌아가기",
    "Message all rooms" : "모든 대화방에 메시지 보내기",
    "Start session" : "세션 시작",
    "Start a call before you start a breakout room session" : "소회의실을 시작하기 전 통화 시작하기",
    "Stop session" : "세션 중단",
    "The message was sent to all breakout rooms" : "메시지를 모든 소회의실에 전송했습니다.",
    "Send a message to all breakout rooms" : "모든 소회의실에 메시지 보내기",
    "Breakout rooms are not started" : "소회의실을 시작하지 않았습니다.",
    "Disable lobby" : "로비 비활성화",
    "Settings for participant \"{user}\"" : "참가자 \"{user}\"에 대한 설정",
    "Participant \"{user}\"" : "참가자 \"{user}\"",
    "moderator" : "중재자",
    "bot" : "봇",
    "guest" : "손님",
    "{time} talking …" : "{time} 대화중…",
    "{time} talking time" : "대화한 시간 {time}",
    "Raised their hand" : "(이)가 손을 들었습니다.",
    "Joined with video" : "영상과 함께 참가",
    "Joined via phone" : "전화기와 결합됨",
    "Joined with audio" : "소리와 함께 참가",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "텍스트가 {maxLength}글자보다 짧거나 같아야 합니다. 현재 텍스트가 {charactersCount}글자입니다.",
    "Remove group and members" : "그룹 및 구성원 제거",
    "Remove participant" : "참가자 삭제",
    "Notification was sent to {displayName}" : "{displayName}님에게 알림을 보냈습니다.",
    "Could not send notification to {displayName}" : "{displayName}님에게 알림을 보낼 수 없음",
    "Permissions granted to {displayName}" : "{displayName}님에게 권한이 부여됨",
    "Could not modify permissions for {displayName}" : "{displayName}님의 권한을 수정할 수 없음",
    "Permissions removed for {displayName}" : "{displayName}님의 권한이 제거됨",
    "Permissions set to default for {displayName}" : "{displayName}님의 권한이 기본 값으로 설정됨",
    "in the lobby" : "로비에서",
    "Dial out phone" : "전화 걸기",
    "Hang up phone" : "전화 끊기",
    "Move back to lobby" : "로비로 나가기",
    "Move to conversation" : "대화로 이동",
    "Dial-in PIN" : "전화 접속 PIN",
    "Demote from moderator" : "중재자 권한 박탈",
    "Promote to moderator" : "중재자 권한 부여",
    "Resend invitation" : "초대 재전송",
    "Send call notification" : "통화 알림 보내기",
    "Dial out phone number" : "전화번호로 전화 걸기",
    "Resume call for phone number" : "전화번호로 전화 재개",
    "Reset custom permissions" : "사용자 정의 권한 재설정",
    "Grant all permissions" : "모든 권한 승인",
    "Remove all permissions" : "모든 권한 제거",
    "Remove" : "삭제",
    "Permissions modified for {displayName}" : "{displayName}님의 권한이 수정됨",
    "Add users or groups" : "사용자나 그룹 추가",
    "Add users" : "사용자 추가",
    "Add groups" : "그룹 추가",
    "Add other sources" : "다른 출처 추가",
    "Add emails" : "이메일 추가",
    "Integrations" : "통합",
    "Add federated users" : "연합 사용자 추가",
    "Searching …" : "검색 중...",
    "Search for more users" : "사용자 더 검색",
    "Search or add participants" : "참가자 검색 및 추가",
    "Invitation was sent to {actorId}" : "{actorId}님에게 초대를 보냈습니다.",
    "An error occurred while adding the participants" : "참가자를 추가하는 동안 오류가 발생했습니다.",
    "Participants" : "참가자",
    "Participants ({count})" : "참가자({count})",
    "Open chat" : "대화방 열기",
    "You have new unread messages in the chat." : "채팅에 읽지 않은 새 메시지가 있습니다.",
    "You have been mentioned in the chat." : "채팅에서 언급되었습니다.",
    "Chat" : "대화",
    "Details" : "세부사항",
    "Shared items" : "공유된 항목들",
    "Until" : "까지",
    "No results found" : "결과 없음",
    "Load more results" : "더 많은 결과 불러오기",
    "Projects" : "프로젝트",
    "No shared items" : "공유된 항목이 없습니다.",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "대화 링크",
    "No open conversations found" : "공개 대화를 찾을 수 없습니다",
    "Either there are no open conversations or you joined all of them." : "공개 대화가 없거나 모두 참가했습니다.",
    "Check spelling or use complete words." : "맞춤법을 확인하거나 완전한 단어를 사용하세요.",
    "Search conversations or users" : "대화 또는 사용자 검색",
    "Select conversation" : "대화 선택",
    "Display name: {name}" : "표시되는 이름: {name}",
    "Edit display name" : "표시 이름 수정",
    "Save name" : "이름 저장",
    "Error while saving sounds setting" : "소리 설정을 저장하는 중 오류가 발생했습니다.",
    "Play sounds when participants join or leave a call" : "참가자가 통화에 들어오거나 나갈 때 소리 재생",
    "Notification settings" : "알림 설정",
    "Default language" : "기본 언어",
    "Select location for attachments" : "첨부 파일 위치 선택",
    "Error while setting attachment folder" : "첨부 파일 폴더 설정 중 오류 발생",
    "Error while setting read status privacy" : "읽기 상태 개인 정보를 설정하는 중 오류 발생",
    "Error while setting typing status privacy" : "입력 상태 공개 설정을 하는 동안 오류 발생",
    "Privacy" : "프라이버시",
    "Attachments folder" : "첨부 파일 폴더",
    "Toggle full screen" : "전체 화면 전환",
    "Search" : "검색",
    "Focus the chat input" : "채팅 입력에 포커스",
    "Unfocus the chat input to use shortcuts" : "바로 가기를 사용하려면 채팅 입력 포커스 해제",
    "Shortcuts while in a call" : "통화 중 바로 가기",
    "Camera on and off" : "카메라 켜기 및 끄기",
    "Microphone on and off" : "마이크 켜고 끄기",
    "Raise or lower hand" : "손을 들거나 내리기",
    "Push to talk or push to mute" : "눌러서 대화 또는 음소거",
    "Start call silently" : "조용히 통화 시작",
    "Start call" : "통화 시작",
    "You will be able to join the call only after a moderator starts it." : "중재자가 통화를 시작한 후에만 통화에 참할 수 있습니다.",
    "End call for everyone" : "모든 이들에 대해 통화 끝내기",
    "Starting the recording" : "녹음/녹화 시작 중",
    "Recording" : "녹음/녹화 중",
    "The call has been running for one hour." : "통화가 한 시간동안 진행되었습니다.",
    "Cancel recording start" : "녹음/녹화 시작 취소",
    "Stop recording" : "녹음/녹화 중단",
    "Send a reaction" : "반응 보내기",
    "React with {reaction}" : "{reaction}(으)로 반응하기",
    "_%n participant in call_::_%n participants in call_" : ["%n명의 참가자가 통화 중"],
    "You are not allowed to enable screensharing" : "화면 공유를 활성화할 수 없습니다.",
    "No screensharing" : "화면 공유 없음",
    "Screensharing options" : "화면 공유 옵션",
    "Enable screensharing" : "화면 공유 활성화",
    "Bad sent video and screen quality." : "전송하는 영상 및 화면 품질이 좋지 않습니다.",
    "Bad sent screen quality." : "전송하는 화면의 품질이 좋지 않습니다.",
    "Bad sent video quality." : "전송하는 영상의 품질이 좋지 않습니다.",
    "Bad sent audio, video and screen quality." : "전송하는 소리와 영상 및 화면의 품질이 좋지 않습니다.",
    "Bad sent audio and screen quality." : "전송하는 소리 및 화면의 품질이 좋지 않습니다.",
    "Bad sent audio and video quality." : "전송하는 소리와 영상의 품질이 좋지 않습니다.",
    "Bad sent audio quality." : "전송된 소리의 품질이 좋지 않습니다.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "당신의 인터넷 연결 또는 컴퓨터가 혼잡해 다른 참가자들이 당신의 화면을 볼 수 없을 수도 있습니다. 이를 개선하려면 화면 공유를 하는 동안 배경 흐림을 끄거나 영상을 비활성화 해보세요.",
    "Disable background blur" : "배경 흐림 비활성화",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "당신의 인터넷 연결 또는 컴퓨터가 혼잡해 다른 참가자들이 당신의 화면을 볼 수 없을 수도 있습니다. 이를 개선하려면 화면 공유를 하는 동안 영상을 비활성화 해보세요.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "당신의 인터넷 연결 또는 컴퓨터가 혼잡해 다른 참가자들이 당신의 화면을 볼 수 없을 수도 있습니다.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "당신의 인터넷 연결 또는 컴퓨터가 혼잡해 다른 참가자들이 당신을 볼 수 없을 수도 있습니다.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "당신의 인터넷 연결 또는 컴퓨터가 혼잡해 다른 참가자들이 당신을 알아듣고 볼 수 없을 수도 있습니다. 이를 개선하려면 화면 공유를 하는 동안 배경 흐림을 끄거나 영상을 비활성화 해보세요.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "당신의 인터넷 연결 또는 컴퓨터가 혼잡해 다른 참가자들이 당신을 알아듣고 볼 수 없을 수도 있습니다. 이를 개선하려면 화면 공유를 하는 동안 영상을 비활성화 해보세요.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "당신의 인터넷 연결 또는 컴퓨터가 혼잡해 다른 참가자들이 당신을 알아듣고 볼 수 없거나 당신의 화면을 볼 수 없을 수도 있습니다. 이를 개선하려면 화면 공유를 비활성화 해보세요.",
    "Disable screenshare" : "화면 공유 끄기",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "당신의 인터넷 연결 또는 컴퓨터가 혼잡해 다른 참가자들이 당신을 알아듣고 볼 수 없을 수도 있습니다. 이를 개선하려면 배경 흐림이나 영상을 비활성화 해보세요.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "당신의 인터넷 연결 또는 컴퓨터가 혼잡해 다른 참가자들이 당신을 알아듣고 볼 수 없을 수도 있습니다. 이를 개선하려면 영상을 비활성화 해보세요.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "당신의 인터넷 연결 또는 컴퓨터가 혼잡해 다른 참가자들이 당신을 알아듣고 볼 수 없을 수도 있습니다.",
    "Screen sharing is not supported by your browser." : "이 브라우저에서는 화면 공유를 지원하지 않습니다.",
    "Screen sharing requires the page to be loaded through HTTPS." : "화면을 공유하려면 HTTPS를 통해 페이지를 로드 해야 합니다.",
    "Screensharing requires the page to be loaded through HTTPS." : "화면 공유를 사용하려면 HTTPS로 페이지를 불러 와야 합니다.",
    "An error occurred while starting screensharing." : "화면 공유를 시작하는 중 오류가 발생했습니다.",
    "Show your screen" : "내 화면 보이기",
    "Stop screensharing" : "화면 공유 중지",
    "Mute others" : "다른 사람 음소거",
    "Start recording" : "녹음/녹화 시작",
    "Set up breakout rooms" : "소회의실 구성",
    "Remove participant {name}" : "참가자 {name} 제거",
    "Keep" : "보관",
    "Open dialpad" : "다이얼패드 열기",
    "Select a region" : "지역 선택",
    "Search …" : "...를 검색",
    "Message without mention" : "언급이 없는 메시지",
    "Mention myself" : "자신을 언급하기",
    "The conversation does not exist" : "대화가 존재하지 않습니다.",
    "Join a conversation or start a new one!" : "대화에 참가하거나 새 대화를 시작하세요!",
    "Duplicate session" : "중복 세션",
    "Creating and joining a conversation with \"{userid}\"" : "{userid}님과의 대화를 생성하고 참가합니다",
    "Join a conversation or start a new one" : "대화에 참가하거나 새 대화 시작",
    "Nextcloud URL" : "Nextcloud URL",
    "Nextcloud user" : "Nextcloud 사용자",
    "User password" : "사용자 암호",
    "Talk conversation" : "토크 대화",
    "Skip TLS verification" : "TLS 확인 건너뛰기",
    "Matrix server URL" : "Matrix 서버 URL",
    "User" : "사용자",
    "Matrix channel" : "Matrix 채널",
    "Mattermost server URL" : "Mattermost 서버 URL",
    "Mattermost user" : "Mattermost 사용자",
    "Team name" : "팀명",
    "Channel name" : "채널 이름",
    "Rocket.Chat server URL" : "Rocket.Chat 서버 URL",
    "User name or email address" : "사용자 이름 또는 이메일 주소",
    "Rocket.Chat channel" : "Rocket.Chat 채널",
    "Zulip server URL" : "Zulip 서버 URL",
    "Bot user name" : "봇 사용자 이름",
    "Bot API key" : "봇 API 키 ",
    "Zulip channel" : "Zulip 채널",
    "API token" : "API 토큰",
    "Slack channel" : "Slack 채널",
    "Server ID or name" : "서버 아이디 또는 이름",
    "Channel" : "채널",
    "Login" : "로그인",
    "Chat ID" : "채팅 아이디",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "IRC 서버 URL (e.g. chat.freenode.net:6667)",
    "Nickname" : "별명",
    "Connection password" : "연결 암호",
    "IRC channel" : "IRC 채널",
    "Channel password" : "채널 암호",
    "NickServ nickname" : "NickServ 닉네임",
    "NickServ password" : "NickServ 암호",
    "Use TLS" : "TLS 사용",
    "Use SASL" : "SASL 사용",
    "Tenant ID" : "Tenant 아이디",
    "Client ID" : "클라이언트 ID",
    "Team ID" : "팀 아이디",
    "Thread ID" : "Thread 아이디",
    "XMPP/Jabber server URL" : "XMPP/Jabber 서버 URL",
    "MUC server URL" : "MUC 서버 URL",
    "Jabber ID" : "Jabber 아이디",
    "Media" : "미디어",
    "Polls" : "투표",
    "Deck cards" : "덱 카드",
    "Voice messages" : "음성 메시지",
    "Locations" : "위치",
    "Call recordings" : "통화 녹음/녹화",
    "Audio" : "오디오",
    "Show all media" : "모든 미디어 표시",
    "Show all files" : "모든 파일 보기",
    "Show all polls" : "모든 투표 보기",
    "Show all deck cards" : "모든 덱 카드 보기",
    "Show all voice messages" : "모든 음성 메시지 보기",
    "Show all locations" : "모든 위치 표시",
    "Show all call recordings" : "모든 통화 녹음/녹화 보기",
    "Show all audio" : "모든 오디오 표시",
    "Show all other" : "다른 모든 항목 표시",
    "Group" : "그룹",
    "Team" : "팀",
    "You reconnected to the call" : "통화에 다시 연결했습니다.",
    "{actor} reconnected to the call" : "{actor}님이 통화에 다시 연결했습니다.",
    "You and {user0} left the call" : "당신과 {user0}님이 통화를 떠났습니다.",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["당신과 {user0}님 및 %n명의 참가자가 통화를 떠났습니다."],
    "{user0} and {user1} left the call" : "{user0}님과 {user1}님이 통화를 떠났습니다.",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["{user0}님과 {user1}님 및 %n명의 참가자가 통화를 떠났습니다."],
    "You: {lastMessage}" : "당신: {lastMessage}",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "(edited by you)" : "(당신에 의해 수정됨)",
    "(edited by a deleted user)" : "(삭제된 사용자에 의해 수정됨)",
    "(edited by {moderator})" : "({moderator}에 의해 수정됨)",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "다른 창이나 기기에서 세션이 작동 중일 때 대화에 참가하려고 합니다. 이 기능은 현재 Nextcloud 토크에서 지원되지 않습니다. 어떻게 할까요?",
    "Leave this page" : "이 페이지 떠나기",
    "Join here" : "여기에 참가",
    "An error occurred while posting deck card to conversation" : "대화에 덱 카드를 게시하는 동안 오류가 발생했습니다.",
    "Post to a conversation" : "대화에 게시",
    "Post to conversation" : "대화에 게시",
    "The recording failed. Please contact your administrator." : "녹음/녹화가 실패했습니다. 관리자에게 연락해 주세요.",
    "An error occurred while posting location to conversation" : "대화에 위치를 게시하는 동안 오류가 발생했습니다.",
    "Share to a conversation" : "대화에 공유",
    "Share to conversation" : "대화에 공유",
    "Error while clearing conversation history" : "대화 기록을 지우는 동안 오류가 발생했습니다.",
    "Error occurred while allowing guests" : "손님을 허용하는 동안 오류가 발생했습니다.",
    "Error occurred while disallowing guests" : "손님을 불허용하는 동안 오류가 발생했습니다.",
    "Error occurred when restricting the conversation to moderator" : "대화를 진행자로 제한하는 동안 오류가 발생했습니다.",
    "Error occurred when opening the conversation to everyone" : "모든 사용자에게 대화를 여는 동안 오류가 발생했습니다.",
    "Conversation password has been saved" : "대화 암호가 저장되었습니다.",
    "Conversation password has been removed" : "대화 암호가 제거되었습니다.",
    "Error occurred while saving conversation password" : "대화 암호를 저장하는 동안 오류가 발생했습니다.",
    "Call recording is starting." : "통화 녹화/녹음을 시작하고 있습니다.",
    "Call recording stopped while starting." : "통화 녹음/녹화가 시작 중 중단되었습니다.",
    "Call recording stopped. You will be notified once the recording is available." : "통화 녹음/녹화가 중단되었습니다. 가능해지면 다시 알려드리겠습니다.",
    "Conversation picture set" : "대화 사진 설정됨",
    "Conversation picture deleted" : "대화 사진 삭제됨",
    "Could not delete the conversation picture" : "대화 사진을 삭제할 수 없음",
    "Could not post message: {errorMessage}" : "메시지를 게시할 수 없음 : {errorMessage}",
    "An error occurred while fetching the participants" : "참가자를 가져오는 동안 오류가 발생했습니다.",
    "Could not send invitation to {actorId}" : "{actorId}님에게 초대를 보낼 수 없음",
    "Invitations sent" : "초대 전송됨",
    "Error occurred when sending invitations" : "초대장을 보내는 동안 오류가 발생했습니다.",
    "An error occurred while creating breakout rooms" : "소회의실을 만드는 중 오류가 발생했습니다.",
    "An error occurred while re-ordering the attendees" : "참석자를 재정렬 하는 동안 오류가 발생했습니다.",
    "An error occurred while deleting breakout rooms" : "소회의실을 삭제하는 동안 오류가 발생했습니다.",
    "An error occurred while starting breakout rooms" : "소회의실을 시작하는 동안 오류가 발생했습니다.",
    "An error occurred while stopping breakout rooms" : "소회의실을 중단하는 동안 오류가 발생했습니다.",
    "An error occurred while sending a message to the breakout rooms" : "소회의실에 메시지를 보내는 동안 오류가 발생했습니다.",
    "An error occurred while requesting assistance" : "지원을 요청하는 동안 오류가 발생했습니다.",
    "An error occurred while resetting the request for assistance" : "지원 요청을 재설정 하는 동안 오류가 발생했습니다.",
    "An error occurred while joining breakout room" : "소회의실에 참가하는 동안 오류가 발생했습니다.",
    "{guest} (guest)" : "{guest}님(손님)",
    "An error occurred while submitting your vote" : "투표를 제출하는 중 오류가 발생했습니다.",
    "An error occurred while ending the poll" : "투표를 끝내는 중 오류가 발생했습니다.",
    "Failed to add reaction" : "반응을 추가하는 데 실패했습니다.",
    "Failed to remove reaction" : "반응을 삭제하는 데 실패했습니다.",
    "Error while uploading file \"{fileName}\"" : "\"{fileName}\" 파일을 업로드하는 중 오류 발생",
    "Not enough free space to upload file \"{fileName}\"" : "\"{fileName}\" 파일을 업로드할 여유 공간이 없음",
    "You are not allowed to share files" : "파일을 공유할 수 없습니다.",
    "Error while sharing file" : "파일 공유하는 도중 오류",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "사용 중인 브라우저는 Nextcloud 토크에서 완전히 지원되지 않습니다. 최신 버전의 Mozilla Firefox, Microsoft Edge, Google Chrome, Opera 또는 Apple Safari를 사용하세요.",
    "Later today – {timeLocale}" : "오늘 나중 – {timeLocale}",
    "Tomorrow – {timeLocale}" : "내일 – {timeLocale}",
    "This weekend – {timeLocale}" : "이번 주말 – {timeLocale}",
    "Next week – {timeLocale}" : "다음주 – {timeLocale}",
    "Message link copied to clipboard" : "메시지 링크가 클립보드에 복사되었습니다.",
    "Conversation link copied to clipboard" : "대화 링크가 클립보드에 복사되었습니다.",
    "The link could not be copied" : "링크를 복사할 수 없습니다.",
    "Sending signaling message has failed" : "시그널링 메시지를 보내지 못했습니다.",
    "Lost connection to signaling server. Trying to reconnect." : "시그널링 서버와의 연결이 끊어졌습니다. 다시 연결하는 중입니다.",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "시그널링 서버가 이 버전의 Nextcloud와 호환되도록 업데이트 해야 합니다. 관리자에게 연락해주세요.",
    "Please reload the page." : "페이지를 새로 고치십시오.",
    "Do not disturb" : "방해 금지",
    "Away" : "자리 비움",
    "Microphone {number}" : "마이크 {number}",
    "Camera {number}" : "카메라 {number}",
    "Speaker {number}" : "스피커 {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "음소거 된 상태로 말하고 있는 것 같습니다. 다른 사람이 들을 수 있도록 자신의 음소거를 해제하세요.",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "하나 이상의 참가자와 연결을 맺을 수 없습니다. 이 상황에 TURN 서버가 필요할 수 있습니다. 관리자가 {linkstart}이 문서{linkend}를 따라 설정하도록 요청해 주세요.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "예상보다 오래 걸립니다. 미디어 권한을 이미 허가 또는 거부하셨나요? 그렇다면 소리 및 영상을 사용하지 못하므로 브라우저를 다시 시작하세요.",
    "Access to microphone & camera is only possible with HTTPS" : "마이크와 카메라에는 HTTPS로만 접근할 수 있음",
    "Please move your setup to HTTPS" : "설정을 HTTPS로 바꾸십시오.",
    "Access to microphone & camera was denied" : "마이크 및 카메라 접근이 거부됨",
    "WebRTC is not supported in your browser" : "웹 브라우저에서 WebRTC를 지원하지 않음",
    "Please use a different browser like Firefox or Chrome" : "Firefox 및 Chrome과 같은 다른 웹 브라우저를 사용하십시오",
    "Error while accessing microphone & camera" : "마이크와 카메라에 접근하는 중 오류 발생",
    "%s Talk on your mobile devices" : "모바일 기기에서 %s Talk 사용하기",
    "Join conversations at any time, anywhere, on any device." : "언제 어디서나, 원하는 기기에서 대화에 참가하세요.",
    "Android app" : "Android 앱",
    "iOS app" : "iOS 앱",
    "__language_name__" : "한국어",
    "Tasks" : "작업",
    "Notes" : "메모",
    "Reports" : "리포트들",
    "Set reminder for later today" : "알림을 오늘 나중으로 설정",
    "Set reminder for tomorrow" : "알림을 내일로 설정",
    "Set reminder for this weekend" : "알림을 이번 주말로 설정",
    "Set reminder for next week" : "알림을 다음주로 설정",
    "Open poll • You voted already" : "투표 열기 • 이미 투표함",
    "Open poll • Click to vote" : "투표 열기 • 클릭해 투표",
    "Poll • Ended" : " 투표 • 종료됨",
    "Talk recording from {time} ({conversation})" : "{time}의 대화 녹음 ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["투표 결과 • %n개 표"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["투표 열기 • %n표"],
    "Submit vote" : "투표하기",
    "Your privacy setting has been saved" : "개인 정보 설정이 저장되었습니다.",
    "Failed to save sounds setting" : "소리 설정을 저장하지 못했습니다.",
    "Sounds setting saved" : "소리 설정이 저장되었습니다.",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "다른 창이나 기기에서 대화에 참가했습니다. 이 기능은 현재 Nextcloud 토크에서 지원되지 않으며, 현재 세션은 종료됩니다."
},
"nplurals=1; plural=0;");
