<?php

declare(strict_types=1);
/**
 * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */

namespace OCA\Talk\Command\Room;

use OC\Core\Command\Base;
use OCA\Talk\Exceptions\RoomNotFoundException;
use OCA\Talk\Room;
use Stecman\Component\Symfony\Console\BashCompletion\CompletionContext;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

class Delete extends Base {
	use TRoomCommand;

	#[\Override]
	protected function configure(): void {
		$this
			->setName('talk:room:delete')
			->setDescription('Deletes a room')
			->addArgument(
				'token',
				InputArgument::REQUIRED,
				'Token of the room to delete'
			);
	}

	protected function execute(InputInterface $input, OutputInterface $output): int {
		$token = $input->getArgument('token');

		try {
			$room = $this->manager->getRoomByToken($token);
		} catch (RoomNotFoundException $e) {
			$output->writeln('<error>Room not found.</error>');
			return 1;
		}

		if ($room->isFederatedConversation()) {
			$output->writeln('<error>Room is a federated conversation.</error>');
			return 1;
		}

		if (in_array($room->getType(), [Room::TYPE_ONE_TO_ONE], true)) {
			$output->writeln('<error>Room is a private (1 to 1) conversation.</error>');
			return 1;
		}

		$this->roomService->deleteRoom($room);

		$output->writeln('<info>Room successfully deleted.</info>');
		return 0;
	}

	#[\Override]
	public function completeArgumentValues($argumentName, CompletionContext $context) {
		switch ($argumentName) {
			case 'token':
				return $this->completeTokenValues($context);
		}

		return parent::completeArgumentValues($argumentName, $context);
	}
}
