OC.L10N.register(
    "spreed",
    {
    "Other activities" : "Alia aktivado",
    "Talk" : "Paroli",
    "Guest" : "Gasto",
    "Message deleted by author" : "Mesaĝo estas forigita per aǔtoro",
    "Administration" : "Administrado",
    "System" : "Sistemo",
    "Talk conversations" : "Buŝaj konversacioj",
    "Talk to %s" : "Paroli al %s",
    "File not found" : "Netrovita dosiero",
    "File is too big" : "Dosiero tro grandas",
    "Invalid file provided" : "Nevalida dosiero provizita",
    "Invalid image" : "Nevalida bildo",
    "Unknown filetype" : "Nekonata dosiertipo",
    "Description" : "Priskribo",
    "Dismiss notification" : "Forsendi sciigon",
    "Accept" : "Akcepti",
    "Decline" : "Malakcepti",
    "New message" : "Nova mesaĝo",
    "Notification" : "Atentigo",
    "error" : "eraro",
    "Default" : "Defaŭlta",
    "Avatar image is not square" : "Avatarbildo ne estas kvadrata",
    "Other" : "Alia",
    "Andorra" : "Andoro",
    "United Arab Emirates" : "Unuiĝintaj Arabaj Emirlandoj",
    "Afghanistan" : "Afganujo",
    "Antigua and Barbuda" : "Antigvo kaj Barbudo",
    "Anguilla" : "Angvilo",
    "Albania" : "Albanujo",
    "Armenia" : "Armenujo",
    "Angola" : "Angolo",
    "Antarctica" : "Antarkto",
    "Argentina" : "Argentino",
    "American Samoa" : "Usona Samoo",
    "Austria" : "Aŭstrujo",
    "Australia" : "Aŭstralio",
    "Aruba" : "Arubo",
    "Åland Islands" : "Alando",
    "Azerbaijan" : "Azerbajĝano",
    "Bosnia and Herzegovina" : "Bosnujo kaj Hercegovino",
    "Barbados" : "Barbado",
    "Bangladesh" : "Bangladeŝo",
    "Belgium" : "Belgujo",
    "Burkina Faso" : "Burkino",
    "Bulgaria" : "Bulgarujo",
    "Bahrain" : "Barejno",
    "Burundi" : "Burundo",
    "Benin" : "Benino",
    "Saint Barthélemy" : "Sankta Bartolomeo",
    "Bermuda" : "Bermudoj",
    "Brunei Darussalam" : "Brunejo",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius kaj Saba",
    "Brazil" : "Brazilo",
    "Bahamas" : "Bahamoj",
    "Bhutan" : "Butano",
    "Bouvet Island" : "Buvetinsulo",
    "Botswana" : "Bocvano",
    "Belarus" : "Belorusujo",
    "Belize" : "Belizo",
    "Canada" : "Kanado",
    "Cocos (Keeling) Islands" : "Kokosinsuloj",
    "Central African Republic" : "Centr-Afriko",
    "Congo" : "Kongo (Brazavila)",
    "Switzerland" : "Svislando",
    "Côte d'Ivoire" : "Ebur-Bordo",
    "Cook Islands" : "Kukinsuloj",
    "Chile" : "Ĉilio",
    "Cameroon" : "Kameruno",
    "China" : "Ĉinujo",
    "Colombia" : "Kolombio",
    "Costa Rica" : "Kostariko",
    "Cuba" : "Kubo",
    "Cabo Verde" : "Kaboverdo",
    "Curaçao" : "Kuracao",
    "Christmas Island" : "Kristnaskinsulo",
    "Cyprus" : "Kipro",
    "Czechia" : "Ĉeĥujo",
    "Germany" : "Germanujo",
    "Djibouti" : "Ĝibutio",
    "Denmark" : "Danujo",
    "Dominica" : "Dominiko",
    "Dominican Republic" : "Dominika Respubliko",
    "Algeria" : "Alĝerio",
    "Ecuador" : "Ekvadoro",
    "Estonia" : "Estonujo",
    "Egypt" : "Egiptujo",
    "Western Sahara" : "Okcidenta Saharo",
    "Eritrea" : "Eritreo",
    "Spain" : "Hispanujo",
    "Ethiopia" : "Etiopujo",
    "Finland" : "Finnlando",
    "Fiji" : "Fiĝio",
    "Falkland Islands (Malvinas)" : "Falklandoj",
    "Faroe Islands" : "Ferooj",
    "France" : "Francujo",
    "Gabon" : "Gabono",
    "United Kingdom of Great Britain and Northern Ireland" : "Britujo",
    "Grenada" : "Grenado",
    "Georgia" : "Kartvelujo",
    "French Guiana" : "Franca Gviano",
    "Guernsey" : "Gernezejo",
    "Ghana" : "Ganao",
    "Gibraltar" : "Ĝibraltaro",
    "Greenland" : "Gronlando",
    "Gambia" : "Gambio",
    "Guinea" : "Gvineo",
    "Guadeloupe" : "Gvadelupo",
    "Equatorial Guinea" : "Ekvatora Gvineo",
    "Greece" : "Grekujo",
    "South Georgia and the South Sandwich Islands" : "Sud-Georgio kaj Sud-Sandviĉinsuloj",
    "Guatemala" : "Gvatemalo",
    "Guam" : "Gvamo",
    "Guinea-Bissau" : "Gvineo-Bisaŭo",
    "Guyana" : "Gujano",
    "Hong Kong" : "Honkongo",
    "Heard Island and McDonald Islands" : "Herda kaj Makdonaldaj Insuloj",
    "Honduras" : "Honduro",
    "Croatia" : "Kroatujo",
    "Haiti" : "Haitio",
    "Hungary" : "Hungarujo",
    "Indonesia" : "Indonezio",
    "Ireland" : "Irlando",
    "Israel" : "Israelo",
    "Isle of Man" : "Manksinsulo",
    "India" : "Barato",
    "British Indian Ocean Territory" : "Brita Hindoceana Teritorio",
    "Iraq" : "Irako",
    "Iceland" : "Islando",
    "Italy" : "Italujo",
    "Jersey" : "Ĵerzejo",
    "Jamaica" : "Jamajko",
    "Jordan" : "Jordanio",
    "Japan" : "Japanujo",
    "Kenya" : "Kenjo",
    "Kyrgyzstan" : "Kirgizujo",
    "Cambodia" : "Kamboĝo",
    "Kiribati" : "Kiribato",
    "Comoros" : "Komoroj",
    "Saint Kitts and Nevis" : "Sankta Kristoforo kaj Neviso",
    "Kuwait" : "Kuvajto",
    "Cayman Islands" : "Kejmanoj",
    "Kazakhstan" : "Kazaĥujo",
    "Lao People's Democratic Republic" : "Laoso",
    "Lebanon" : "Libano",
    "Saint Lucia" : "Sankta Lucio",
    "Liechtenstein" : "Liĥtenŝtejno",
    "Sri Lanka" : "Srilanko",
    "Liberia" : "Liberio",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Litovujo",
    "Luxembourg" : "Luksemburgo",
    "Latvia" : "Latvujo",
    "Libya" : "Libio",
    "Morocco" : "Maroko",
    "Monaco" : "Monako",
    "Montenegro" : "Montenegro",
    "Saint Martin (French part)" : "Sankta Marteno (franca)",
    "Madagascar" : "Madagaskaro",
    "Marshall Islands" : "Marŝaloj",
    "Mali" : "Malio",
    "Myanmar" : "Birmo",
    "Mongolia" : "Mongolujo",
    "Macao" : "Makao",
    "Northern Mariana Islands" : "Nord-Marianoj",
    "Martinique" : "Martiniko",
    "Mauritania" : "Maŭritanio",
    "Montserrat" : "Moncerato",
    "Malta" : "Malto",
    "Mauritius" : "Maŭricio",
    "Maldives" : "Maldivoj",
    "Malawi" : "Malavio",
    "Mexico" : "Meksiko",
    "Malaysia" : "Malajzio",
    "Mozambique" : "Mozambiko",
    "Namibia" : "Namibio",
    "New Caledonia" : "Nov-Kaledonio",
    "Niger" : "Niĝero",
    "Norfolk Island" : "Norfolkinsulo",
    "Nigeria" : "Niĝerio",
    "Nicaragua" : "Nikaragvo",
    "Netherlands" : "Nederlando",
    "Norway" : "Norvegujo",
    "Nepal" : "Nepalo",
    "Nauru" : "Nauro",
    "Niue" : "Niuo",
    "New Zealand" : "Nov-Zelando",
    "Oman" : "Omano",
    "Panama" : "Panamo",
    "Peru" : "Peruo",
    "French Polynesia" : "Franca Polinezio",
    "Papua New Guinea" : "Papuo-Nov-Gvineo",
    "Philippines" : "Filipinoj",
    "Pakistan" : "Pakistano",
    "Poland" : "Pollando",
    "Saint Pierre and Miquelon" : "Sankta Piero kaj Mikelono",
    "Pitcairn" : "Pitkarna Insulo",
    "Puerto Rico" : "Puertoriko",
    "Palestine, State of" : "Palestino",
    "Portugal" : "Portugalujo",
    "Palau" : "Palaŭo",
    "Paraguay" : "Paragvajo",
    "Qatar" : "Kataro",
    "Réunion" : "Reunio",
    "Romania" : "Rumanujo",
    "Serbia" : "Serbujo",
    "Russian Federation" : "Rusujo",
    "Rwanda" : "Ruando",
    "Saudi Arabia" : "Sauda Arabujo",
    "Solomon Islands" : "Salomonoj",
    "Seychelles" : "Sejŝeloj",
    "Sudan" : "Sudano",
    "Sweden" : "Svedujo",
    "Singapore" : "Singapuro",
    "Saint Helena, Ascension and Tristan da Cunha" : "Sankta Heleno, Ascension kaj Tristan da Cunha",
    "Slovenia" : "Slovenujo",
    "Svalbard and Jan Mayen" : "Svalbardo",
    "Slovakia" : "Slovakujo",
    "Sierra Leone" : "Sieraleono",
    "San Marino" : "Sanmarino",
    "Senegal" : "Senegalo",
    "Somalia" : "Somalujo",
    "Suriname" : "Surinamo",
    "South Sudan" : "Sud-Sudano",
    "Sao Tome and Principe" : "Santomeo kaj Principeo",
    "El Salvador" : "Salvadoro",
    "Sint Maarten (Dutch part)" : "Sankta Marteno (nederlanda)",
    "Syrian Arab Republic" : "Sirio",
    "Turks and Caicos Islands" : "Turkoj kaj Kajkoj",
    "Chad" : "Ĉado",
    "French Southern Territories" : "Francaj Sudaj Teritorioj",
    "Togo" : "Togolando",
    "Thailand" : "Tajlando",
    "Tajikistan" : "Taĝikujo",
    "Tokelau" : "Tokelao",
    "Timor-Leste" : "Orienta Timoro",
    "Turkmenistan" : "Turkmenujo",
    "Tunisia" : "Tunizio",
    "Tonga" : "Tonga",
    "Turkey" : "Turkujo",
    "Trinidad and Tobago" : "Trinidado kaj Tobago",
    "Tuvalu" : "Tuvalo",
    "Tanzania, United Republic of" : "Tanzanio",
    "Ukraine" : "Ukrainujo",
    "Uganda" : "Ugando",
    "United States Minor Outlying Islands" : "Usonaj Malgrandaj Insuloj",
    "United States of America" : "Usono",
    "Uruguay" : "Urugvajo",
    "Uzbekistan" : "Uzbekujo",
    "Holy See" : "Sankta Seĝo",
    "Saint Vincent and the Grenadines" : "Sankta Vincento kaj Grenadinoj",
    "Viet Nam" : "Vjetnamujo",
    "Vanuatu" : "Vanuatuo",
    "Wallis and Futuna" : "Valiso kaj Futuno",
    "Samoa" : "Samoo",
    "Yemen" : "Jemeno",
    "Mayotte" : "Majoto",
    "South Africa" : "Sud-Afriko",
    "Zambia" : "Zambio",
    "Zimbabwe" : "Zimbabvo",
    "Federation" : "Federado",
    "Invalid date, date format must be YYYY-MM-DD" : "Nevalida dato; datoformo estu JJJJ-MM-TT",
    "The password is wrong. Try again." : "La pasvorto malĝustas. Provu denove.",
    "Password" : "Pasvorto",
    "Submit" : "Sendi",
    "Everyone" : "Ĉiuj",
    "Save changes" : "Konservi ŝanĝojn",
    "Saving …" : "Konservado...",
    "Saved!" : "Konservita!",
    "Limit to groups" : "Limigi al grupoj",
    "Disabled" : "Malŝaltita",
    "Name" : "Nomo",
    "Beta" : "Beta",
    "Enable encryption" : "Ŝalti ĉifradon",
    "Pending" : "Pritraktota",
    "Error" : "Eraro",
    "Blocked" : "Barita",
    "Expired" : "Senvalidiĝis",
    "Never" : "Neniam",
    "Language" : "Lingvo",
    "Country" : "Lando",
    "Status" : "Stato",
    "Created at" : "Kreita je",
    "Yes" : "Jes",
    "No" : "Ne",
    "OK" : "Bone",
    "Confirm" : "Konfirmi",
    "Reset" : "Restarigi",
    "Cancel" : "Nuligi",
    "Back" : "Antaŭen",
    "Loading …" : "Ŝargado...",
    "From" : "De",
    "To" : "Al",
    "Calendar" : "Kalendaro",
    "Attendees" : "Ĉeestontoj",
    "Save" : "Konservi",
    "No results" : "Neniu rezulto",
    "Done" : "Farita",
    "Grid view" : "Krada vido",
    "Reload" : "Reŝargi",
    "Copy link" : "Kopii ligilon",
    "None" : "Nenio",
    "You" : "Vi",
    "Collapse" : "Maletendi",
    "Favorite" : "Pliŝatata",
    "Date:" : "Dato:",
    "Hide details" : "Kaŝi la detalojn",
    "Show details" : "Montri la detalojn",
    "Disable" : "Malŝalti",
    "Enable" : "Ŝalti",
    "Choose" : "Elekti",
    "Restricted" : "Limigita",
    "Personal" : "Persona",
    "Password protection" : "Protektita per pasvorto",
    "Edit" : "Modifi",
    "Delete" : "Forigi",
    "Log content" : "Protokolenhavo",
    "Notifications" : "Sciigoj",
    "Join" : "Aliĝi",
    "Log in" : "Ensaluti",
    "Remove from favorites" : "Forigi el pliŝataĵoj",
    "Add to favorites" : "Aldoni al pliŝataĵoj",
    "Home" : "Hejmo",
    "Alphabetically" : "Alfabete",
    "Users" : "Uzantoj",
    "Groups" : "Grupoj",
    "Devices" : "Aparatoj",
    "Upload" : "Alŝuti",
    "Files" : "Dosieroj",
    "24 hours" : "24 horoj",
    "Reply" : "Respondi",
    "More actions" : "Pliaj agoj",
    "Translate" : "Traduku",
    "Dismiss" : "Preterpasi",
    "Contact" : "Kontakto",
    "Create new poll" : "Krei novan enketon",
    "Send" : "Sendi",
    "Settings" : "Agordoj",
    "Anonymous poll" : "Enketo sennoma",
    "guest" : "gasto",
    "Add users or groups" : "Add users or groups",
    "Searching …" : "Serĉado ...",
    "Chat" : "Babili",
    "Details" : "Detaloj",
    "Default language" : "Defaŭlta lingvo",
    "Privacy" : "Privateco",
    "Search" : "Serĉi",
    "Keep" : "Konservi",
    "Select a region" : "Elekti regionon",
    "User" : "Uzanto",
    "API token" : "API-ĵetono",
    "Login" : "Login",
    "Nickname" : "Kromnomo",
    "Client ID" : "Klientidentigilo",
    "Polls" : "Enketilo",
    "Audio" : "Sonaĵo",
    "Group" : "Grupo",
    "Please reload the page." : "Bonvolu reŝargi la paĝon.",
    "Android app" : "Android-aplikaĵo",
    "iOS app" : "iOS-aplikaĵo",
    "__language_name__" : "Esperanto",
    "Tasks" : "Taskoj"
},
"nplurals=2; plural=(n != 1);");
