"use strict";(self.webpackChunktalk=self.webpackChunktalk||[]).push([["files-sidebar-call-chunk"],{11184(e,t,a){a.r(t),a.d(t,{default:()=>h});var r=a(8756),d=a(68171),l=a(71749),i=a(45515),s=a(85168),u=a(53334),n=a(68121),o=a(59235),c=a(269);let b={class:"talk-sidebar-callview"},p=(0,r.pM)({__name:"FilesSidebarCallView",setup(e){let t,a,p,h;t=(0,n.l)(),a=!1,p=(0,r.EW)(()=>t.isNextcloudTalkHashDirty),(0,r.wB)(p,e=>{e&&!a&&h()}),h=()=>{a=!0,(0,s.Qg)((0,u.t)("spreed","The server was updated.")+"\n"+o.B,{timeout:s.DH})};let v=(0,c.v)(),k=(0,i.N)();function f(e){v.value||e.preventDefault()}return window.addEventListener("beforeunload",f),function(){let e=document.querySelector("header.app-sidebar-header");if(!e)return;e.classList.add("hidden-by-call");let t=document.querySelector(".app-sidebar__close");t?.setAttribute("data-theme-dark","true"),t?.setAttribute("disabled","true")}(),(0,r.xo)(()=>{window.removeEventListener("beforeunload",f),function(){let e=document.querySelector("header.app-sidebar-header");if(!e)return;e.classList.remove("hidden-by-call");let t=document.querySelector(".app-sidebar__close");t?.removeAttribute("data-theme-dark"),t?.removeAttribute("disabled")}()}),(e,t)=>((0,r.uX)(),(0,r.Wv)(r.Im,{to:"header.app-sidebar-header"},[(0,r.Lk)("div",b,[(0,r.bF)(l.A,{isInCall:"",isSidebar:""}),(0,r.bF)(d.A,{token:(0,r.R1)(k),isSidebar:""},null,8,["token"])])]))}}),h=(0,a(66262).default)(p,[["__scopeId","data-v-319663c6"]])}}]);
//# sourceMappingURL=talk-files-sidebar-call-chunk.js.map?v=d8a6ff1ad8288e02