OC.L10N.register(
    "spreed",
    {
    "a conversation" : "un conversación",
    "(Duration %s)" : "(Duración %s)",
    "You attended a call with {user1}" : "Atendiesti una llamada con «{user1}»",
    "_%n guest_::_%n guests_" : ["%n convidáu","%n convidaos"],
    "You attended a call with {user1} and {user2}" : "Atendiesti una llamada con «{user1}» y «{user2}»",
    "You attended a call with {user1}, {user2} and {user3}" : "Atendiesti una llamada con «{user1}», «{user2}» y «{user3}»",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Atendiesti una llamada con «{user1}», «{user2}», «{user3}» y «{user4}»",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Atendiesti una llamada con «{user1}», «{user2}», «{user3}», «{user4}» y «{user5}»",
    "_%n other_::_%n others_" : ["%n más","%n más"],
    "{actor} invited you to {call}" : "{actor} convidóte a «{call}»",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Convidáronte a una <strong>conversación</strong> o tuviesti una <strong>llamada</strong>",
    "Other activities" : "Otres actividaes",
    "Talk" : "Charra",
    "Guest" : "Convidáu",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Afáyate en Nextcloud Talk!\nNesta conversación vas recibir información tocante a les funciones nueves que tean disponibles en Nextcloud Talk.",
    "## New in Talk %s" : "## Novedaes de Talk %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Agora pues usar Microsoft Edge y Safari pa participar nes llamaes y videollamaes",
    "Talk updates ✅" : "Anovamientos de Talk ✅",
    "Reaction deleted by author" : "L'autor desanició la reaición",
    "{actor} created the conversation" : "{actor} creó la conversación",
    "You created the conversation" : "Creó la conversación",
    "System created the conversation" : "El sistema creó la conversación",
    "An administrator created the conversation" : "L'alministración creó la conversación",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} renomó la conversación «%1$s» a «%2$s»",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Renomesti la conversación «%1$s» a «%2$s»",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "L'alministración renomó la conversación «%1$s» a «%2$s»",
    "{actor} set the description" : "{actor} configuró la descripción",
    "You set the description" : "Configuresti la descripción",
    "An administrator set the description" : "L'alministración configuró la descripción",
    "{actor} removed the description" : "{actor} quitesti la descripción",
    "You removed the description" : "Quitesti la descripción",
    "An administrator removed the description" : "L'alministración quitó la descripción",
    "You started a silent call" : "Aniciesti una llamada silenciosa",
    "{actor} started a silent call" : "{actor} anició una llamada silenciosa",
    "You started a call" : "Aniciesti una llamada",
    "{actor} started a call" : "{actor} anició una llamada",
    "{actor} joined the call" : "{actor} xunióse a la llamada",
    "You joined the call" : "Xuniéstite a la llamada",
    "{actor} left the call" : "{actor} coló de la llamada",
    "You left the call" : "Colesti de la llamada",
    "{actor} unlocked the conversation" : "{actor} desbloquió la conversación",
    "You unlocked the conversation" : "Desbloquiesti la conversación",
    "An administrator unlocked the conversation" : "L'alministración desbloquió la conversación",
    "{actor} locked the conversation" : "{actor} bloquió la conversación",
    "You locked the conversation" : "Bloquiesti la conversación",
    "An administrator locked the conversation" : "L'alministración bloquió la conversación",
    "{actor} limited the conversation to the current participants" : "{actor} llendó'l númberu de participantes de la conversación al actual",
    "You limited the conversation to the current participants" : "Llendesti'l númberu de participantes de la conversación al actual",
    "An administrator limited the conversation to the current participants" : "L'alministración llendó'l númberu de participantes de la conversación al actual",
    "{actor} opened the conversation to registered users" : "{actor} abrió la conversación a usuarios rexistraos",
    "You opened the conversation to registered users" : "Abriesti la conversación a usuarios rexistraos",
    "An administrator opened the conversation to registered users" : "L'alministración abrió la conversación a usuarios rexistraos",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} abrió la conversación a usuarios rexistraos y usuarios creaos cola aplicación Convidaos",
    "You opened the conversation to registered users and users created with the Guests app" : "Abriesti la conversación a usuarios rexistraos y usuarios creaos cola aplicación Convidaos",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "L'alministración abrió la conversación a usuarios rexistraos y usuarios creaos cola aplicación Convidaos",
    "The conversation is now open to everyone" : "La conversación ta abierta a tol mundu",
    "{actor} opened the conversation to everyone" : "{actor} abrió la conversación a tol mundu",
    "You opened the conversation to everyone" : "Abriesti la conversación a tol mundu",
    "{actor} restricted the conversation to moderators" : "{actor} restrinxó la conversación a moderadores",
    "You restricted the conversation to moderators" : "Restrinxesti la conversación a moderadores",
    "{actor} started breakout rooms" : "{actor} activó les sales de grupu de trabayu",
    "You started breakout rooms" : "Aniciesti les sales de grupu de trabayu",
    "{actor} stopped breakout rooms" : "{actor} paró les sales de grupu de trabayu",
    "You stopped breakout rooms" : "Paresti les sales de grupu de trabayu",
    "{actor} allowed guests" : "{actor} permitió a los convidaos",
    "You allowed guests" : "Permitiesti a los convidaos",
    "An administrator allowed guests" : "L'alministrador permitió a los convidaos",
    "{actor} set a password" : "{actor} afitó una contraseña",
    "You set a password" : "Afitesti una contraseña",
    "An administrator set a password" : "L'alministración afitó una contraseña",
    "{actor} removed the password" : "{actor} quitó la contraseña",
    "You removed the password" : "Quitesti la contraseña",
    "An administrator removed the password" : "L'alministración quitó la contraseña",
    "{actor} added {user}" : "{actor} amestó a {user}",
    "You joined the conversation" : "Xuniéstite a la conversación",
    "{actor} joined the conversation" : "{actor} xunióse a la conversación",
    "You added {user}" : "Amestesti a {user}",
    "{actor} added you" : "{actor} amestóte",
    "An administrator added you" : "L'alministración amestóse",
    "An administrator added {user}" : "L'alministración amestó a {user}",
    "You left the conversation" : "Colesti de la conversación",
    "{actor} left the conversation" : "{actor} coló de la conversación",
    "{actor} removed {user}" : "{actor} quitó a {user}",
    "You removed {user}" : "Quitesti a {user}",
    "{actor} removed you" : "{actor} quitóte",
    "An administrator removed you" : "L'alministración quitóte",
    "An administrator removed {user}" : "L'alministración quitó a {user}",
    "{actor} invited {federated_user}" : "{actor} convidó a {federated_user}",
    "You invited {federated_user}" : "Convidesti a {federated_user}",
    "You accepted the invitation" : "Aceptesti la invitación",
    "{actor} invited you" : "{actor} convidóte",
    "An administrator invited you" : "L'alministración convidóte",
    "An administrator invited {federated_user}" : "L'alministración convidó a {federated_user}",
    "{federated_user} accepted the invitation" : "{federated_user} aceptó la invitación",
    "{actor} removed {federated_user}" : "{actor} quitó a {federated_user}",
    "You removed {federated_user}" : "Quitesti a {federated_user}",
    "An administrator removed {federated_user}" : "L'alministración quitó a {federated_user}",
    "{federated_user} declined the invitation" : "{federated_user} refugó la invitación",
    "{actor} added group {group}" : "{actor} amestó'l grupu «{group}»",
    "You added group {group}" : "Amestesti'l grupu «{group}»",
    "An administrator added group {group}" : "L'alministración amestó'l grupu «{group}»",
    "{actor} removed group {group}" : "{actor} quitó'l grupu «{group}»",
    "You removed group {group}" : "Quietesti'l grupu «{group}»",
    "An administrator removed group {group}" : "L'alministración quitó'l grupu «{group}»",
    "{actor} added team {circle}" : "{actor} amestó l'equipu «{circle}»",
    "You added team {circle}" : "Amestesti l'equipu «{circle}»",
    "An administrator added team {circle}" : "L'alministración amestó l'equipu «{circle}»",
    "{actor} removed team {circle}" : "{actor} quitó l'equipu «{circle}»",
    "You removed team {circle}" : "Quitesti l'equipu «{circle}»",
    "An administrator removed team {circle}" : "L'alministración quitó l'equipu «{circle}»",
    "{actor} added {phone}" : "{actor} amestó a {phone}",
    "You added {phone}" : "Amestesti a {phone}",
    "An administrator added {phone}" : "L'alministración amestó a {phone}",
    "{actor} removed {phone}" : "{actor} quitó a {phone}",
    "You removed {phone}" : "Quitesti a {phone}",
    "An administrator removed {phone}" : "L'alministración quitó a {phone}",
    "{actor} promoted {user} to moderator" : "{actor} ascendió a {user} a moderador",
    "You promoted {user} to moderator" : "Ascendiesti a {user} a moderador",
    "{actor} promoted you to moderator" : "{actor} ascendióte a moderador",
    "An administrator promoted you to moderator" : "L'alministración ascendióse a moderador",
    "An administrator promoted {user} to moderator" : "L'alministración ascendió a {usar} a moderador",
    "{actor} shared a file which is no longer available" : "{actor} compartió un ficheru que yá nun ta disponible",
    "You shared a file which is no longer available" : "Compartiesti un ficheru que yá nun ta disponible",
    "The shared location is malformed" : "La llocalización compartida ye incorreuta",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} configuró Matterbridge pa configurar esta conversación con otres charres",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Configuresti Matterbridge pa sincronizar esta conversación con otres charres",
    "{actor} updated the Matterbridge configuration" : "{actor} anovó la configuración de Matter bridge",
    "You updated the Matterbridge configuration" : "Anovesti la configuración de Matterbridge",
    "{actor} removed the Matterbridge configuration" : "{actor} quitó la configuración de Matterbridge",
    "You removed the Matterbridge configuration" : "Quitesti la configuración de Matterbridge",
    "{actor} started Matterbridge" : "{actor} anició Matterbridge",
    "You started Matterbridge" : "Aniciesti Matterbridge",
    "{actor} stopped Matterbridge" : "{actor} paró Matterbridge",
    "You stopped Matterbridge" : "Paresti Matterbridge",
    "{actor} deleted a message" : "{actor} desanició un mensaxe",
    "You deleted a message" : "Desaniciesti un mensaxe",
    "{actor} edited a message" : "{actor} editó un mensaxe",
    "You edited a message" : "Editesti un mensaxe",
    "{actor} deleted a reaction" : "{actor} desanició una reaición",
    "You deleted a reaction" : "Desaniciesti una reaición",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["Afitesti la caducidá de los mensaxes a %n selmana","Afitesti la caducidá de los mensaxes a %n selmanes"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["Afitesti la caducidá de los mensaxes a %n día","Afitesti la caducidá de los mensaxes a %n díes"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["Afitesti la caducidá de los mensaxes a %n hora","Afitesti la caducidá de los mensaxes a %n hores"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["Afitesti la caducidá de los mensaxes a %n minutu","Afitesti la caducidá de los mensaxes a %n minutos"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} afitó la caducidá de los mensaxes a %n selmana","{actor} afitó la caducidá de los mensaxes a %n selmanes"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} afitó la caducidá de los mensaxes a %n día","{actor} afitó la caducidá de los mensaxes a %n díes"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} afitó la caducidá de los mensaxes a %n hora","{actor} afitó la caducidá de los mensaxes a %n hores"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} afitó la caducidá de los mensaxes a %n minutu","{actor} afitó la caducidá de los mensaxes a %n minutos"],
    "{actor} disabled message expiration" : "{actor} desactivó la caducidá de los mensaxes",
    "You disabled message expiration" : "Desactivesti la caducidá de los mensaxes",
    "{actor} cleared the history of the conversation" : "{actor} borró l'historial de la conversación",
    "You cleared the history of the conversation" : "Borresti l'historial de la conversación",
    "{actor} set the conversation picture" : "{actor} afitó la semeya de la conversación",
    "You set the conversation picture" : "Afitesti la semeya de la conversación",
    "{actor} removed the conversation picture" : "{actor} quitó la semeya de la conversación",
    "You removed the conversation picture" : "Quitesti la semeya de la conversación",
    "{actor} ended the poll {poll}" : "{actor} finó la encuesta {poll}",
    "You ended the poll {poll}" : "Finesti la encuesta «{poll}»",
    "{actor} started the video recording" : "{actor} anició la grabación de videu",
    "You started the video recording" : "Aniciesti la grabación de videu",
    "{actor} stopped the video recording" : "{actor} paró la grabación de videu",
    "You stopped the video recording" : "Paresti la grabación de videu",
    "{actor} started the audio recording" : "{actor} anició la grabación d'audiu",
    "You started the audio recording" : "Aniciesti la grabación d'audiu",
    "{actor} stopped the audio recording" : "{actor} paró la grabación d'audiu",
    "You stopped the audio recording" : "Paresta la grabación d'audiu",
    "The recording failed" : "La grabación falló",
    "Someone voted on the poll {poll}" : "Daquién votó na encuesta «{poll}»",
    "Message deleted by author" : "L'autor desanició'l mensaxe",
    "Message deleted by {actor}" : "{actor} desanició'l mensaxe",
    "Message deleted by you" : "Desaniciesti'l mensaxe",
    "Deleted user" : "Usuariu desaniciáu",
    "Unknown number" : "Númberu desconocíu",
    "Administration" : "Alministración",
    "System" : "Sistema",
    "%s (guest)" : "%s (convidáu)",
    "Message of {user}" : "Mensaxe de: {user}",
    "Talk conversations" : "Conversaciones de Talk",
    "An error occurred. Please contact your administrator." : "Prodúxose un error. Ponte en contautu cola alministración.",
    "File not found" : "Nun s'atopó'l ficheru",
    "Poll" : "Encuesta",
    "No image file provided" : "Nun se fornió nengún ficheru d'imaxe",
    "File is too big" : "El ficheru ye mui grande",
    "Invalid file provided" : "Fornióse un ficheru inválidu",
    "Invalid image" : "La imaxe ye inválida",
    "Unknown filetype" : "El tipu de ficheru ye inválidu",
    "Talk mentions" : "Menciones de Talk",
    "More conversations" : "Más conversaciones",
    "Say hi to your friends and colleagues!" : "¡Saluda a amigos y colegues!",
    "No unread mentions" : "Nun hai nenguna mención ensin lleer",
    "Call in progress" : "Llamada en cursu",
    "You were mentioned" : "Mentáronte",
    "Write to conversation" : "Escribi na conversación",
    "Description" : "Descripción",
    "Private conversation" : "Conversación privada",
    "Failed to upload call recording" : "Nun se pue xubir la grabación de la llamada",
    "Dismiss notification" : "Escargar l'avisu",
    "Transcript now available" : "La trescripción ta disponible",
    "Failed to transcript call recording" : "Nun se pue trescribir la grabación de la llamada",
    "Accept" : "Aceptar",
    "Decline" : "Refugar",
    "New message" : "Mensaxe nuevu",
    "Notification" : "Avisu",
    "{user} reacted with {reaction}" : "{user} reaicionó con «{reaction}»",
    "{user} reacted with {reaction} in {call}" : "{user} reaicionó con «{reaction}» en: {call}",
    "{user} sent you a private message" : "{user} unvióte un mensaxe priváu",
    "{user} sent a message in conversation {call}" : "{user} unvióte un mensaxe priváu na conversación «{call}»",
    "A deleted user sent a message in conversation {call}" : "Un usuariu desaniciáu unvió un mensaxe na conversación «{call}»",
    "{user} mentioned you in a private conversation" : "«{user}» mentóte nuna conversación privada",
    "{user} mentioned you in conversation {call}" : "«{user}» mentóte na conversación «{call}»",
    "A guest mentioned you in conversation {call}" : "Un convidáu mentóte na conversión «{call}»",
    "View message" : "Ver el mensaxe",
    "Dismiss reminder" : "Escartar el recordatoriu",
    "View chat" : "Ver la charra",
    "Join call" : " Xunise a la llamada",
    "Answer call" : "Contestar a la llamada",
    "{user} would like to talk with you" : "{user} quier falar contigo",
    "Call back" : "Devolver la llamad",
    "You missed a call from {user}" : "Perdiesti una llamada de: {user}",
    "Open settings" : "Abrir la configuración",
    "pending" : "pendiente",
    "error" : "error",
    "Default" : "Por defeutu",
    "Presentation" : "Presentación",
    "Webinar" : "Webinariu",
    "Conversations" : "Conversaciones",
    "Messages in current conversation" : "Mensaxes na conversación actual",
    "{user}" : "{user}",
    "Messages" : "Mensaxes",
    "Messages in other conversations" : "Mensaxes n'otres conversaciones",
    "Avatar image is not square" : "La imaxe del avatar nun ye cuadrada",
    "Room {number}" : "Sala {number}",
    "Something unexpected happened." : "Prodúxose daqué inesperaos.",
    "The URL is invalid." : "La URL ye inválida.",
    "An HTTPS URL is required." : "Ríquese una URL HTTPS.",
    "The email address is invalid." : "La direición de corréu electrónicu ye inválida.",
    "The language is invalid." : "La llingua ye inválida.",
    "The country is invalid." : "El país ye inválidu",
    "Something unexpected happened. Please try again later." : "Prodúxose daqué inesperao. Volvi tentalo dempués.",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Emiratos Árabes Xuníos",
    "Afghanistan" : "Afganistán",
    "Antigua and Barbuda" : "Antigua y Barbuda",
    "Anguilla" : "Anguila",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "L'Antártida",
    "Argentina" : "Arxentina",
    "American Samoa" : "Samoa Americana",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Islles Åland",
    "Azerbaijan" : "Azerbaixán",
    "Bosnia and Herzegovina" : "Bosnia y Herzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladex",
    "Belgium" : "Bélxica",
    "Burkina Faso" : "Burkina Fasu",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Baḥréin",
    "Burundi" : "Burundi",
    "Benin" : "Benín",
    "Saint Barthélemy" : "San Bartolomé",
    "Bermuda" : "Les Bermudes",
    "Bonaire, Sint Eustatius and Saba" : "Caribe Neerlandés",
    "Brazil" : "Brasil",
    "Bahamas" : "Les Baḥames",
    "Bhutan" : "Bután",
    "Bouvet Island" : "Islla Bouvet",
    "Botswana" : "Botsuana",
    "Belarus" : "Bielorrusia",
    "Belize" : "Belize",
    "Canada" : "Canadá",
    "Cocos (Keeling) Islands" : "Islles Cocos (Keeling)",
    "Central African Republic" : "República Centroafricana",
    "Congo" : "El Congu",
    "Switzerland" : "Suiza",
    "Cook Islands" : "Islles Cook",
    "Chile" : "Chile",
    "Cameroon" : "Camerún",
    "China" : "China",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Cabu Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Islla Christmas",
    "Cyprus" : "Xipre",
    "Czechia" : "Chequia",
    "Germany" : "Alemaña",
    "Djibouti" : "Xibuti",
    "Denmark" : "Dinamarca",
    "Dominican Republic" : "República Dominicana",
    "Algeria" : "Arxelia",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estonia",
    "Egypt" : "Exiptu",
    "Western Sahara" : "Saḥara Occidental",
    "Eritrea" : "Eritrea",
    "Spain" : "España",
    "Ethiopia" : "Etiopía",
    "Finland" : "Finlandia",
    "Fiji" : "Islles Fixi",
    "Falkland Islands (Malvinas)" : "Islles Malvines",
    "Faroe Islands" : "Islles Feroe",
    "France" : "Francia",
    "Gabon" : "Gabón",
    "Grenada" : "Granada",
    "Georgia" : "Xeorxa",
    "French Guiana" : "Guyana Francesa",
    "Guernsey" : "Guérnesei",
    "Ghana" : "Ghana",
    "Gibraltar" : "Xibraltar",
    "Greenland" : "Groenlandia",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadalupe",
    "Equatorial Guinea" : "Guinea Ecuatorial",
    "Greece" : "Grecia",
    "South Georgia and the South Sandwich Islands" : "Islles Xeorxa del Sur y Sandwich del Sur",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bisáu",
    "Guyana" : "Guyana",
    "Hong Kong" : "Ḥong Kong",
    "Heard Island and McDonald Islands" : "Islles Heard Island y McDonald",
    "Honduras" : "Hondures",
    "Croatia" : "Croacia",
    "Haiti" : "Haití",
    "Hungary" : "Hungría",
    "Indonesia" : "Indonesia",
    "Ireland" : "Irlanda",
    "Israel" : "Israel",
    "Isle of Man" : "Islla de Man",
    "India" : "India",
    "British Indian Ocean Territory" : "Territoriu Británicu del Océanu de Índicu",
    "Iraq" : "Iraq",
    "Iceland" : "Islandia",
    "Italy" : "Italia",
    "Jamaica" : "Xamaica",
    "Jordan" : "Xordania",
    "Japan" : "Xapón",
    "Kenya" : "Kenia",
    "Kyrgyzstan" : "Kirguistán",
    "Cambodia" : "Camboya",
    "Kiribati" : "Kiribati",
    "Saint Kitts and Nevis" : "Saint Kitts y Nevis",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Islles Caimán",
    "Kazakhstan" : "Kazakstán",
    "Lao People's Democratic Republic" : "República Popular Democrática de Laos",
    "Lebanon" : "El Líbanu",
    "Saint Lucia" : "Santa Llucía",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesothu",
    "Lithuania" : "Lituania",
    "Luxembourg" : "Luxemburgu",
    "Latvia" : "Letonia",
    "Libya" : "Libia",
    "Morocco" : "Marruecos",
    "Monaco" : "Mónacu",
    "Montenegro" : "Montenegru",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Islles Márxal",
    "Mali" : "Malí",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Macáu",
    "Northern Mariana Islands" : "Islles Marianes del Norte",
    "Mauritania" : "Mauritania",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauriciu",
    "Maldives" : "Maldives",
    "Malawi" : "Malaui",
    "Mexico" : "Méxicu",
    "Malaysia" : "Malasia",
    "Mozambique" : "Mozambique",
    "Namibia" : "Namibia",
    "New Caledonia" : "Nueva Caledonia",
    "Niger" : "Níxer",
    "Norfolk Island" : "Islla Norfolk",
    "Nigeria" : "Nixeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Holanda",
    "Norway" : "Noruega",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nueva Zelanda",
    "Oman" : "Omán",
    "Panama" : "Panamá",
    "Peru" : "Perú",
    "French Polynesia" : "Polinesia Francesa",
    "Papua New Guinea" : "Papua Nueva Guinea",
    "Philippines" : "Filipines",
    "Pakistan" : "Paquistán",
    "Poland" : "Polonia",
    "Saint Pierre and Miquelon" : "Saint Pierre y Miquelón",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Puertu Ricu",
    "Palestine, State of" : "Palestina",
    "Portugal" : "Portugal",
    "Palau" : "Paláu",
    "Paraguay" : "Paraguái",
    "Qatar" : "Qatar",
    "Réunion" : "Reunión",
    "Romania" : "Rumanía",
    "Serbia" : "Serbia",
    "Russian Federation" : "Federación Rusa",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Arabia Saudita",
    "Solomon Islands" : "Islles Salomón",
    "Seychelles" : "Seixeles",
    "Sudan" : "Sudán",
    "Sweden" : "Suecia",
    "Singapore" : "Singapur",
    "Saint Helena, Ascension and Tristan da Cunha" : "Santa Lena",
    "Slovenia" : "Eslovenia",
    "Svalbard and Jan Mayen" : "Svalbard ya Islla Jan Mayen *",
    "Slovakia" : "Eslovaquia",
    "Sierra Leone" : "Sierra Lleona",
    "San Marino" : "San Marín",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Surinam",
    "South Sudan" : "Sudán del Sur",
    "Sao Tome and Principe" : "Santu Tomé y Príncipe",
    "El Salvador" : "El Salvador",
    "Turks and Caicos Islands" : "Islles Turques y Caicos",
    "Chad" : "Chad",
    "Togo" : "Togu",
    "Thailand" : "Tailandia",
    "Tajikistan" : "Taxiquistán",
    "Tokelau" : "Tokeláu",
    "Timor-Leste" : "Timor Oriental",
    "Turkmenistan" : "Turkmenistán",
    "Tunisia" : "Tunicia",
    "Tonga" : "Tonga",
    "Turkey" : "Turquía",
    "Trinidad and Tobago" : "Trinidá y Tobagu",
    "Tuvalu" : "Tuvalu",
    "Ukraine" : "Ucraína",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Islles Ultramarines Menores d'Estaos Xuníos",
    "Uruguay" : "Uruguái",
    "Uzbekistan" : "Uzbequistán",
    "Holy See" : "Santa Sede",
    "Saint Vincent and the Grenadines" : "San Vicente y Les Granadines",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis y Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Yeme",
    "Mayotte" : "Mayotte",
    "South Africa" : "Sudáfrica",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabue",
    "Federation" : "Federación",
    "High-performance backend" : "Backend de rindimientu altu",
    "Error: Cannot connect to server" : "Error: nun pue conectar al sirvidor",
    "Error: Certificate expired" : "Error: el certificáu caducó",
    "Could not get version" : "Nun se pudo consiguir la versión",
    "Error: Server responded with: {error}" : "Error: el sirvidor respondió con «{error}»",
    "Error: Unknown error occurred" : "Error: prodúxose un error desconocíu",
    "SIP configuration" : "Configuración de SIP",
    "Invalid date, date format must be YYYY-MM-DD" : "La data ye inválida, el so formatu ha ser AAAA-MM-DD",
    "Conversation not found" : "Nun s'atopó la converación",
    "Leave call" : "Colar de la llamada",
    "Stay in call" : "Quedar na llamada",
    "Share this file" : "Compartir esti ficheru",
    "Join conversation" : "Xunise a la conversación",
    "This conversation is password-protected." : "Esta conversación ta protexida con una contraseña.",
    "The password is wrong. Try again." : "La contraseña ye incorreuta. Volvi tentalo.",
    "Password" : "Contraseña",
    "Submit" : "Unviar",
    "Error requesting the password." : "Hebo un error al solicitar la contraseña.",
    "This conversation has ended" : "Esta conversación finó",
    "Error occurred when joining the conversation" : "Prodúxose un error al xunite a la conversación",
    "Everyone" : "Tol mundu",
    "Disable calls" : "Desactivar les llamaes",
    "Save changes" : "Guardar los cambeos",
    "Saving …" : "Guardando…",
    "Saved!" : "¡Guardóse!",
    "Description is not provided" : "Nun se fornió la descripción",
    "Enabled" : "Activóse",
    "Disabled" : "Desactivóse",
    "Bots settings" : "Configuración de los robós",
    "State" : "Estáu",
    "Name" : "Nome",
    "Total errors count" : "Númberu d'errores totales",
    "Find more bots" : "Atopar más robós",
    "Beta" : "Beta",
    "Permissions" : "Permisos",
    "All messages" : "Tolos mensaxes",
    "Off" : "Non",
    "General settings" : "Configuración xeneral",
    "Enable encryption" : "Activar el cifráu",
    "Pending" : "Pendiente",
    "Error" : "Error",
    "Active" : "Activa",
    "Expired" : "Caducó",
    "Never" : "Enxamás",
    "Language" : "Llingua",
    "Country" : "País",
    "Status" : "Estáu",
    "Created at" : "Data de creación",
    "Limits" : "Llendes",
    "Yes" : "Sí",
    "No" : "Non",
    "_%n user_::_%n users_" : ["%n usuariu","%n usuarios"],
    "Installed version: {version}" : "Versión instalada: {version}",
    "Downloading …" : "Baxando…",
    "An error occurred while installing the Matterbridge app" : "Prodúxose un error mentanto s'instalaba l'aplicación Matterbridge",
    "Status: Checking connection" : "Estáu: comprobando la conexón",
    "Delete this server" : "Desaniciar esti sirvidor",
    "Test this server" : "Probar esti sirvidor",
    "SIP configuration saved!" : "¡Guardóse la configuración de SIP!",
    "Error code" : "Códigu d'error",
    "High-performance backend URL" : "URL del backend de rindimientu altu",
    "High-performance backend settings saved" : "Guardóse la configuración del backend de rindimientu altu",
    "STUN server URL" : "URL del sirvidor STUN",
    "The server address is invalid" : "La direición del sirvidor ye inválida",
    "STUN settings saved" : "Guardóse la configuración STUN",
    "STUN servers" : "Sirvidores STUN",
    "{option1} and {option2}" : "{option1} y {option2}",
    "TURN server URL" : "URL de sirvidor TURN",
    "TURN server secret" : "Secretu del sirvidor TURN",
    "TURN server protocols" : "Protocolos del sirvidor TURN",
    "TURN settings saved" : "Guardóse la configuración de TURN",
    "TURN servers" : "Sirvidores TURN",
    "Failed" : "Falló",
    "OK" : "Normal",
    "Checking …" : "Comprobando…",
    "Federated user" : "Usuariu federáu",
    "Confirm" : "Confirmar",
    "Reset" : "Reafitar",
    "Room {roomNumber}" : "Sala {roomNumber}",
    "Cancel" : "Encaboxar",
    "Back" : "Atrás",
    "Now" : "Agora",
    "Loading …" : "Cargando…",
    "From" : "De",
    "To" : "Pa",
    "Calendar" : "Calendariu",
    "Attendees" : "Asistentes",
    "Save" : "Guardar",
    "No results" : "Nun hai nengún resultáu",
    "Done" : "Fecho",
    "Raise hand" : "Alzar la mano",
    "Lower hand" : "Baxar la mano",
    "This conversation is read-only" : "Esta conversación ye namás de llectura",
    "Reload" : "Volver cargar",
    "{nickName} raised their hand." : "«{nickName}» alzo la mano",
    "A participant raised their hand." : "Un participante alzó la mano.",
    "Previous page of videos" : "Páxina de vídeos anterior",
    "Next page of videos" : "Páxina de vídeos siguiente",
    "Connecting …" : "Conectando…",
    "Calling …" : "Llamando…",
    "Copy link" : "Copiar l'enllaz",
    "None" : "Nada",
    "Error while accessing camera" : "Hebo un error mentanto s'accedía a la cámara",
    "You are not allowed to enable video" : "Nun tienes permisu p'activar el videu",
    "No video. Click to select device" : "Nun hai videu. Calca pa seleicionar un preséu",
    "Disable video" : "Desactivar el videu",
    "Enable video" : "Activar el videu",
    "You" : "Tu",
    "Show screen" : "Amosar la pantalla",
    "Collapse" : "Recoyer",
    "Expand" : "Espander",
    "You need to be logged in to upload files" : "Tienes d'aniciar la sesión pa xubir ficheros",
    "Drop your files to upload" : "Suelta los ficheros pa xubilos",
    "Conversation messages" : "Mensaxes de la conversación",
    "Post message" : "Espublizar el mensaxe",
    "Federated conversation" : "Conversación federada",
    "Public conversation" : "Conversación pública",
    "Favorite" : "Meter en Favoritos",
    "Date:" : "Data:",
    "Hide details" : "Anubrir los detalles",
    "Show details" : "Amosar los detalles",
    "Error while updating conversation name" : "Hebo un error mentanto s'anovaba'l nome de la conversación",
    "Error while updating conversation description" : "Hebo un error mentanto s'anovaba la descripción de la conversación",
    "Enter a name for this conversation" : "Introduz un nome pa esta conversación",
    "Edit conversation name" : "Editar el nome de la conversación",
    "Edit conversation description" : "Editar la descripción de la conversación",
    "Enter a description for this conversation" : "Introduz una descripción pa esta conversación",
    "Picture" : "Semeya",
    "Disable" : "Desactivar",
    "Enable" : "Activar",
    "Choose" : "Escoyer",
    "Error removing conversation picture" : "Hebo un error al quitar la semeya de la conversación",
    "The file must be a PNG or JPG" : "El ficheru a ser PNG o JPG",
    "All permissions" : "Tolos permisos",
    "Restricted" : "Restrinxóse",
    "Advanced permissions" : "Permisos avanzaos",
    "Edit permissions" : "Editar los permisos",
    "Basic Info" : "Información básica",
    "Personal" : "Personal",
    "Matterbridge" : "Matterbridge",
    "Bots" : "Robós",
    "Danger zone" : "Zona de peligru",
    "Leave conversation" : "Colar de la conversación",
    "Delete conversation" : "Desaniciar la conversación",
    "Error while deleting conversation" : "Hebo un error mentanto se desaniciaba la conversación",
    "Delete all chat messages" : "Desaniciar los mensaxes de toles charres",
    "Error while clearing chat history" : "Hebo un error mentanto se borraba l'historial de la charra",
    "Be careful, these actions cannot be undone." : "Ten curiáu, estes aiciones nun se puen desfacer.",
    "Delete chat messages" : "Desaniciar los mensaxes de la charra",
    "_%n hour_::_%n hours_" : ["%n hora","%n hores"],
    "_%n day_::_%n days_" : ["%n día","%n díes"],
    "_%n week_::_%n weeks_" : ["%n selmana","%n selmanes"],
    "Error when trying to set message expiration" : "Hebo un error al tentar d'afitar la caducidá de los mensaxes",
    "Message expiration" : "Caducidá de los mensaxes",
    "Password protection" : "Proteición con contraseña",
    "Change password" : "Camudar la contraseña",
    "Enter new password" : "Introduz una contraseña nueva",
    "Save password" : "Guardar la contraseña",
    "This conversation is open to registered users" : "Esta conversación ta abierta a los usuarios rexistraos",
    "This conversation is limited to the current participants" : "Esta conversación ta llendada a los participantes actuales",
    "Error occurred when opening or limiting the conversation" : "Prodúxose un error al abrir o llendar la conversación",
    "Open conversation" : "Abrir la conversación",
    "Invalid language" : "La llingua ye inválida",
    "Error occurred while updating start time" : "Prodúxose un error mentanto s'anovaba la hora de comienzu",
    "Error occurred when locking the conversation" : "Prodúxose un error mentanto se bloquiaba la conversación",
    "Error occurred when unlocking the conversation" : "Prodúxose un error mentanto se desbloquiaba la conversación",
    "Lock conversation" : "Bloquiar la conversación",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Bloquia la conversación pa impidir que naide espublice mensaxes o anicie llamaes",
    "Edit" : "Editar",
    "More information" : "Más información",
    "Delete" : "Desaniciar",
    "unknown state" : "estáu desonocíu",
    "running" : "n'execución",
    "not running" : "nun ta n'execución",
    "Bridge saved" : "Guardóse la ponte",
    "Messaging systems" : "Sistemes de mensaxería",
    "Enable bridge" : "Activar la ponte",
    "Show Matterbridge log" : "Amosar el rexistru de Matterbridge",
    "Log content" : "Conteníu del rexistru",
    "Notifications" : "Avisos",
    "Important conversation" : "Converación importante",
    "Join" : "Xunise",
    "Error while creating the conversation" : "Hebo un error mentanto se creaba la conversación",
    "Unread mentions" : "Menciones ensin lleer",
    "Create conversation" : "Crear una conversación",
    "Log in" : "Aniciar la sesión",
    "An error occurred while calling a phone number" : "Prodúxose un error mentanto se llamaba a un númberu de teléfonu",
    "Phone number could not be called: {error}" : "Nun se pudo llamar al númberu de teléfonu: {error}",
    "Phone number could not be called" : "Nun se pudo llamar al númberu de teléfonu",
    "Creating the conversation …" : "Creando la conversación…",
    "Remove from favorites" : "Quitar de Favoritos",
    "Add to favorites" : "Meter en Favoritos",
    "Pending invitations" : "Invitaciones pendientes",
    "Decline invitation" : "Refugar la invitación",
    "Accept invitation" : "Aceptar la invitación",
    "No pending invitations" : "Nun hai nenguna invitación pendiente",
    "Home" : "Aniciu",
    "Unread" : "Ensin lleer",
    "Alphabetically" : "Alfabéticamente",
    "No matches found" : "Nun s'atopó nenguna coincidencia",
    "No conversations found" : "Nun s'atopó nenguna conversación",
    "You have no unread mentions." : "Nun tienes nenguna mención ensin lleer.",
    "You have no unread messages." : "Nun tienes nengún mensaxe ensin lleer.",
    "An error occurred while performing the search" : "Prodúxose un error mentanto se facía la busca",
    "Conversation list" : "Llista de conversaciones",
    "Unread messages" : "Mensaxes ensin lleer",
    "New personal note" : "Nota personal nueva",
    "Users" : "Usuarios",
    "Groups" : "Grupos",
    "Teams" : "Equipos",
    "Federated users" : "Usuarios federaos",
    "New private conversation" : "Conversación privada nueva",
    "Other sources" : "Otros oríxenes",
    "Open conversations" : "Abrir les conversaciones",
    "No search results" : "Nun hai nengún resultáu de la busca",
    "Users, groups and teams" : "Usuarios, grupos y equipos",
    "Users and groups" : "Usuarios y grupos",
    "Users and teams" : "Usuarios y equipos",
    "Groups and teams" : "Grupos y equipos",
    "You are currently waiting in the lobby" : "Tas na sala d'espera",
    "No microphone available" : "Nun hai nengún micrófonu disponible",
    "No camera available" : "Nun hai nenguna cámara disponible",
    "Devices" : "Preseos",
    "Backgrounds" : "Fondos",
    "Calls are not supported in your browser" : "Les llamaes nun son compatible col sirvidor",
    "Access to microphone is only possible with HTTPS" : "L'accesu al micrófonu namás ye posible con HTTPS",
    "Access to microphone was denied" : "Negóse l'accesu al micrófonu",
    "Error while accessing microphone" : "Hebo un error mentanto s'accedía al micrófonu",
    "Access to camera is only possible with HTTPS" : "L'accesu a la cámara namás ye posible con HTTPS",
    "The call is being recorded." : "La llamada ta grabándose",
    "Invalid path selected" : "Seleicionóse un camín inválidu",
    "Blur" : "Emborrinar",
    "Upload" : "Xunir",
    "Files" : "Ficheros",
    "(edited)" : "(editóse)",
    "The message has expired or has been deleted" : "El mensaxe caducó o desanicióse",
    "24 hours" : "24 hores",
    "7 days" : "7 díes",
    "Message text copied to clipboard" : "El testu del mensaxe copióse nel cartafueyu",
    "Message text could not be copied" : "El testu del mensaxe nun se pudo copiar",
    "A reminder was successfully removed" : "El recordatoriu quitóse correutamente",
    "Error occurred when removing a reminder" : "Prodúxose un error al quitar un recordatoriu",
    "Error occurred when creating a reminder" : "Prodúxose un error al crear un recordatoriu",
    "Reply" : "Responder",
    "More actions" : "Más aiciones",
    "Set reminder" : "Configurar un recordatoriu",
    "Reply privately" : "Responder per privao",
    "Edit message" : "Editar el mensaxe",
    "Copy message link" : "Copiar l'enllaz del mensaxe",
    "Go to file" : "Dir al ficheru",
    "Translate" : "Traducir",
    "Close reactions menu" : "Zarrar el menú de les reaiciones",
    "Dismiss" : "Escartar",
    "Go to conversation" : "Dir a la conversación",
    "Detect language" : "Detectar la llingua",
    "The message could not be translated" : "Nun se pudo traducir el mensaxe",
    "Translation copied to clipboard" : "La traducción copióse al cartafueyu",
    "Translation could not be copied" : "Nun se pudo copiar la traducción",
    "Translate message" : "Traducir el mensaxe",
    "Translating" : "Traduciendo",
    "Copy translated text" : "Copiar el testu traducíu",
    "Send now" : "Unviar agora",
    "Message sent" : "Unvióse'l mensaxe",
    "Deleting message" : "Desaniciando'l mensaxe",
    "An error occurred while deleting the message" : "Prodúxose un error mentanto se desaniciaba'l mensaxe",
    "Contact" : "Contautu",
    "Sending message" : "Unviando'l mensaxe",
    "Not enough free space to upload file" : "Nun hai abondu espaciu llibre pa xubir el ficheru",
    "You cannot send messages to this conversation at the moment" : "Pel momentu, nun pues unviar mensaxes a esta conversación",
    "Open poll" : "Abrir la encuesta",
    "See results" : "Ver los resultaos",
    "Reactions" : "Reaiciones",
    "Show all reactions" : "Amosar toles reaiciones",
    "Add more reactions" : "Amestar más reaiciones",
    "No messages" : "Nun hai nengún mensaxe",
    "Unpin" : "Lliberar",
    "Add participants" : "Amestar participantes",
    "Conversation visibility" : "Visibilidá de la conversación",
    "This conversation has been locked" : "Bloquióse esta conversación",
    "Send message" : "Unviar el mensaxe",
    "Send without notification" : "Unviar ensin avisar",
    "The message could not be edited" : "Nun se pudo editar el mensaxe",
    "File upload is not available in this conversation" : "La xuba de ficheros nun ta disponible nesta conversación",
    "Add emoji" : "Amestar un fustaxe",
    "Send later" : "Unviar dempués",
    "Smart picker" : "Selector intelixente",
    "New file" : "Ficheru nuevu",
    "Blank" : "Baleru",
    "Error while creating file" : "Hebo un error mentanto se creaba'l ficheru",
    "Name of the new file" : "Nome del ficheru nuevu",
    "{user1} is typing …" : "{user1} ta escribiendo…",
    "{user1} and {user2} are typing …" : "{user1} y {user2} tán escribiendo…",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} y {user3} tán escribiendo…",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} y %n más tán escribiendo…","{user1}, {user2}, {user3} y %n más tán escribiendo…"],
    "Add more files" : "Amestar más ficheros",
    "Send" : "Unviar",
    "In this conversation <strong>{user}</strong> can:" : "Nesta conversión, <strong>{user}</strong> pue:",
    "Start a call" : "Aniciar una llamada",
    "Skip the lobby" : "Saltar la sala d'espera",
    "Enable the microphone" : "Activar el micrófonu",
    "Enable the camera" : "Activar la cámara",
    "Share the screen" : "Compartir la pantalla",
    "Update permissions" : "Anovar los permisos",
    "Updating permissions" : "Anovando los permisos",
    "Create poll" : "Crear una encuesta",
    "Question" : "Entruga",
    "Ask a question" : "Entrugar",
    "Answers" : "Rempuestes",
    "Settings" : "Configuración",
    "Anonymous poll" : "Encuesta anónima",
    "You voted for this option" : "Votesti esta opción",
    "End poll" : "Finar la encuesta",
    "Change your vote" : "Cambiar el votu",
    "Results" : "Resultaos",
    "Send a message to \"{roomName}\"" : "¿Quies unviar un mensaxe a «{roomName}»?",
    "Show list of participants" : "Amosar la llista de participantes",
    "The message was sent to \"{roomName}\"" : "El mensaxe unvióse a «{roomName}»",
    "Back to main room" : "Volver a la sala principal",
    "Message all rooms" : "Xestionar toles sales",
    "Start session" : "Aniciar la sesión",
    "Stop session" : "Parar la sesión",
    "Disable lobby" : "Desactivar la sala d'espera",
    "moderator" : "moderador",
    "bot" : "robó",
    "guest" : "convidáu",
    "Ringing …" : "Sonando…",
    "Raised their hand" : "Alzó la mano",
    "in the lobby" : "na sala",
    "Resend invitation" : "Volver unviar la invitación",
    "Copy phone number" : "Copiar el númberu de teléfonu",
    "Grant all permissions" : "Conceder tolos permisos",
    "Remove all permissions" : "Quitar tolos permisos",
    "Remove" : "Quitar",
    "Add users, groups or teams" : "Amestar usuarios, grupos o equipos",
    "Add users or groups" : "Amestar usuarios o grupos",
    "Add users or teams" : "Amestar usuarios o equipos",
    "Add users" : "Amestar usuarios",
    "Add groups or teams" : "Amestar grupos o equipos",
    "Add groups" : "Amestar grupos",
    "Add teams" : "Amestar equipos",
    "Add other sources" : "Amestar otra fonte",
    "Add emails" : "Amestar direiciones de corréu electróniques",
    "Integrations" : "Integraciones",
    "Add federated users" : "Amestar usuarios federaos",
    "Searching …" : "Buscando…",
    "Search for more users" : "Buscar más usuarios",
    "Search or add participants" : "Buscar o amestar participantes",
    "An error occurred while adding the participants" : "Prodúxose un error mentanto s'amestaben los participantes",
    "Participants" : "Participantes",
    "Participants ({count})" : "Participantes ({count})",
    "Open chat" : "Abrir la charra",
    "You have new unread messages in the chat." : "Tienes mensaxes ensin lleer nuevos na charra.",
    "You have been mentioned in the chat." : "Mentáronte na charra.",
    "Chat" : "Charra",
    "Details" : "Detalles",
    "Shared items" : "Elementos compartíos",
    "No results found" : "Nun s'atopó nengún resultáu",
    "Load more results" : "Cargar más resultaos",
    "Projects" : "Proyeutos",
    "No shared items" : "Nun hai nengún elementu compartíu",
    "No open conversations found" : "Nun s'atopó nenguna conversación abierta",
    "Number is not valid" : "El númberu nun ye válidu",
    "Phone numbers" : "Númberos de teléfonu",
    "Display name: {name}" : "Nome visible: {name}",
    "Save name" : "Guardar el nome",
    "Error while saving sounds setting" : "Hebo un error mentanto se guardaba la configuración de soníu",
    "Notification settings" : "Configuración de los avisos",
    "Default language" : "Llingua predeterminada",
    "Privacy" : "Privacidá",
    "Search" : "Buscar",
    "Start call" : "Aniciar la llamada",
    "End call" : "Finar la llamada",
    "Stop recording" : "Parar la grabación",
    "Send a reaction" : "Unviar una reaición",
    "_%n participant in call_::_%n participants in call_" : ["%n participante na llamada","%n participantes na llamada"],
    "You are not allowed to enable screensharing" : "Nun tienes permisu p'activar la compartición de pantalla",
    "Screensharing options" : "Opciones de la compartición de pantalla",
    "Enable screensharing" : "Activar la compartición de pantalla",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "La conexón a internet o l'ordenador tán ocupaos y ye probable que los demás participantes nun seyan a ver la to pantalla. P'ameyorar esta situación, desactiva'l desenfoque del fondu o'l videu mentanto compartes la pantalla.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "La conexón a internet o l'ordenador tán ocupaos y ye probable que los demás participantes nun seyan a ver la to pantalla. P'ameyorar esta situación, prueba a desactivar el videu mentanto compartes la pantalla.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "La conexón a internet o l'ordenador tán ocupaos y ye probable que los demás participantes nun seyan a ver la to pantalla.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "La conexón a internet o l'ordenador tán ocupaos y ye probable que los demás participantes nun seyan a vete.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "La conexón a internet o l'ordenador tán ocupaos y ye probable que los demás participantes nun seyan entendete y vete. P'ameyorar esta situación, desactiva'l desenfoque del fondu o'l videu mentanto compartes la pantalla.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "La conexón a internet o l'ordenador tán ocupaos y ye probable que los demás participantes nun seyan entendete y vete. P'ameyorar esta situación, prueba a desactivar el videu mentanto compartes la pantalla.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "La conexón a internet o l'ordenador tán ocupaos y ye probable que los demás participantes nun seyan entendete y ver la to pantalla. P'ameyorar esta situación, prueba a desactivar la compartición de la pantalla.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "La conexón a internet o l'ordenador tán ocupaos y ye probable que los demás participantes nun seyan entendete y vete. P'ameyorar esta situación, prueba a desactivar el desenfoque del fondu.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "La conexón a internet o l'ordenador tán ocupaos y ye probable que los demás participantes nun seyan entendete y vete. P'ameyorar esta situación, prueba a desactivar el videu.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "La conexón a internet o l'ordenador tán ocupaos y ye probable que los demás participantes nun seyan entendete.",
    "Show your screen" : "Amosar la to pantalla",
    "Stop screensharing" : "Dexar de compartir la pantalla",
    "Start recording" : "Aniciar la grabación",
    "Keep" : "Caltener",
    "Open dialpad" : "Abrir el tecláu numbéricu",
    "Search …" : "Buscar…",
    "Mention everyone" : "Mentar a tol mundu",
    "The conversation does not exist" : "La conversación nun esiste",
    "Join a conversation or start a new one!" : "¡Xúnite una conversación o anicia una nueva!",
    "Duplicate session" : "Duplicar la sesión",
    "Join a conversation or start a new one" : "Xúnite a una conversación o anicia otra",
    "Nextcloud URL" : "URL de Nextcloud",
    "Nextcloud user" : "Usuariu de Nextcloud",
    "Talk conversation" : "Conversación de Talk",
    "Skip TLS verification" : "Saltar la verificación del TLS",
    "Matrix server URL" : "URL del sirvidor Matrix",
    "User" : "Usuariu",
    "Matrix channel" : "Canal de Matrix",
    "Mattermost server URL" : "URL del sirvidor Mattermost",
    "Mattermost user" : "Usuariu de Mattermost",
    "Team name" : "Nome del equipu",
    "Channel name" : "Nome de la canal",
    "Zulip server URL" : "URL del sirvidor Zulip",
    "Zulip channel" : "Canal de Zulip",
    "API token" : "Pase de l'API",
    "Slack channel" : "Canal de Slack",
    "Server ID or name" : "ID o nome del sirvidor",
    "Channel" : "Canal",
    "Login" : "Aniciar la sesión",
    "Chat ID" : "ID de la charra",
    "Nickname" : "Nomatu",
    "Connection password" : "Contraseña de la conexón",
    "IRC channel" : "Canal IRC",
    "Channel password" : "Contraseña de la canal",
    "NickServ nickname" : "Nomatu de NickServ",
    "NickServ password" : "Contraseña de NickServ",
    "Use TLS" : "Usar TLS",
    "Use SASL" : "Usar SASL",
    "Client ID" : "ID de veceru",
    "Team ID" : "ID d'equipu",
    "Thread ID" : "ID de filu",
    "Jabber ID" : "ID de Jabber",
    "Media" : "Multimedia",
    "Polls" : "Encuestes",
    "Voice messages" : "Mensaxes de voz",
    "Locations" : "Llugares",
    "Audio" : "Audiu",
    "Show all files" : "Amosar tolos ficheros",
    "Show all polls" : "Amosar toles encuestes",
    "Show all voice messages" : "Amosar tolos mensaxe de voz",
    "Show all locations" : "Amosar tolos llugares",
    "Group" : "Grupu",
    "Team" : "Equipu",
    "You and {user0} left the call" : "Tu y {user0} colestis de la canal",
    "You: {lastMessage}" : "Tu: {lastMessage}",
    "Leave this page" : "Colar d'esta páxina",
    "In conversation" : "Na conversación",
    "Error while clearing conversation history" : "Hebo un error mentanto se borraba l'historial de la conversación",
    "Error occurred while allowing guests" : "Prodúxose un error mentanto se permitíen a los convidaos",
    "Conversation password has been saved" : "Guardóse la contraseña de la conversación",
    "Conversation password has been removed" : "Quitóse la contraseña de la conversación",
    "Error occurred while saving conversation password" : "Prodúxose un error mentanto se guardaba la contraseña de la conversación",
    "Could not delete the conversation picture" : "Nun se pudo desaniciar la semeya de la conversación",
    "Could not post message: {errorMessage}" : "Nun se pudo espublizar el mensaxe: {errorMessage}",
    "Invitations sent" : "Unviáronse les invitaciones",
    "Error occurred when sending invitations" : "Prodúxose un error mentanto s'unviaben les conversaciones",
    "An error occurred while requesting assistance" : "Prodúxose un error mentanto se solicitaba l'asistencia",
    "An error occurred while accepting an invitation" : "Prodúxose un error mentanto s'aceptaba una invitación",
    "An error occurred while submitting your vote" : "Prodúxose un error mentanto s'unviaba'l votu",
    "An error occurred while ending the poll" : "Prodúxose un error mentanto finaba la encuesta",
    "Failed to add reaction" : "Nun se pue amestar la reaición",
    "Failed to remove reaction" : "Nun se pue desaniciar la reaición",
    "Error while uploading file \"{fileName}\"" : "Hebo un error mentanto se xubía'l ficheru «{fileName}»",
    "Not enough free space to upload file \"{fileName}\"" : "Nun hai abondu espaciu pa xubir el ficheru «{fileName}»",
    "You are not allowed to share files" : "Nun tienes permisu pa compartir ficheros",
    "Error while sharing file" : "Hebo un error mentanto se compartía'l ficheru",
    "_In %n hour_::_In %n hours_" : ["En %n hora","En %n hores"],
    "_%n minute _::_%n minutes_" : ["%n minutu","%n minutos"],
    "_In %n minute_::_In %n minutes_" : ["En %n minutu","En %n minutos"],
    "Tomorrow – {timeLocale}" : "Mañana – {timeLocale}",
    "This weekend – {timeLocale}" : "Esta fin de selmana – {timeLocale}",
    "Next week – {timeLocale}" : "La próxima selmana – {timeLocale}",
    "Conversation link copied to clipboard" : "L'enllaz de la conversación copióse nel cartafueyu",
    "The link could not be copied" : "Nun se pudo copiar l'enllaz",
    "Please reload the page." : "Volvi cargar la páxina.",
    "Do not disturb" : "Nun molestar",
    "Away" : "Ausente",
    "Microphone {number}" : "Micrófonu {number}",
    "Camera {number}" : "Cámara {number}",
    "Access to microphone & camera was denied" : "Negóse l'accesu al micrófonu y a la cámara",
    "WebRTC is not supported in your browser" : "WebRTC nun ye compatible col restolador",
    "Android app" : "Aplicación p'Android",
    "iOS app" : "Aplicación pa iOS",
    "__language_name__" : "Asturianu",
    "Call summary (%s)" : "Resume de llamaes (%s)",
    "Tasks" : "Xeres",
    "Notes" : "Notes",
    "Reports" : "Informes",
    "Call summary" : "Resume de llamaes",
    "Open poll • You voted already" : "Encuesta abierta • Yá votesti",
    "Open poll • Click to vote" : "Encuesta abierta • Calca pa votar",
    "Poll • Ended" : "Encuesta • Finó",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Resultaos de la encuesta • %n votu","Resultaos de la encuesta • %n votos"],
    "Submit vote" : "Unviar el votu",
    "Failed to save sounds setting" : "Nun se pue guardar la configuración de los soníos",
    "Sounds setting saved" : "Guardóse la configuración de los soníos"
},
"nplurals=2; plural=(n != 1);");
