OC.L10N.register(
    "spreed",
    {
    "a conversation" : "saruna",
    "(Duration %s)" : "(Ilgums %s)",
    "You attended a call with {user1}" : "Tu piedalījies zvanā ar {user1}",
    "_%n guest_::_%n guests_" : ["%n viesi","%n viesi","%n viesi"],
    "You attended a call with {user1} and {user2}" : "Tu piedalījies zvanā ar {user1} un {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Tu piedalījies zvanā ar {user1}, {user2} un {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Tu piedalījies zvanā ar {user1}, {user2}, {user3} un {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Tu piedalījies zvanā ar {user1}, {user2}, {user3}, {user4} un {user5}",
    "_%n other_::_%n others_" : ["%n other","%n cits","%n citi"],
    "{actor} invited you to {call}" : "{actor} uzaicināja Tevi {call}",
    "Talk" : "Runāt",
    "Guest" : "Viesis",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Viens pret vienu sarunas tagad ir pastāvīgas, un tās vairs nevar nejauši pārveidot par kopu sarunām. Kā arī, kad viens no dalībniekiem pamet sarunu, tā vairs netiek automātiski izdzēsta. Tikai ja abi dalībnieki izies, saruna tiks izdzēsta no servera",
    "- In the sidebar you can now find an overview of the latest shared items" : "- Sānu joslā tagad var atrast pēdējo kopīgoto vienumu pārskatu",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- Saruna **Piezīme sev** ir izmantojama, lai veiktu piezīmes un kopīgotu informāciju starp savām ierīcēm",
    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- Sapulces uzlabotas ar viesu, kuri uzaicināti e-pastā, atpazīšanu, dalībnieku saraksta ievietošanu, aptauju melnraksti un dalībnieku sarakstu lejupielādēšanu.",
    "Talk updates ✅" : "Talk atjauninājumi ✅",
    "{actor} created the conversation" : "{actor} izveidoja sarunu",
    "You created the conversation" : "Tu izveidoji sarunu",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} pārdēvēja sarunu no \"%1$s\" uz \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Tu pārdēvēji sarunu no \"%1$s\" uz \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Pārvaldītājs pārdēvēja sarunu no \"%1$s\" uz \"%2$s\"",
    "You removed the description" : "Tu noņēmi aprakstu",
    "You started a call" : "Tu uzsāki zvanu",
    "{actor} started a call" : "{actor} sācis zvanu",
    "{actor} joined the call" : "{actor} pievienojies zvanam",
    "You joined the call" : "Tu pievienojies zvanam",
    "{actor} left the call" : "{actor} pameta zvanu",
    "You left the call" : "Tu pameti zvanu",
    "{actor} unlocked the conversation" : "{actor} atslēdz sarunu",
    "You unlocked the conversation" : "Tu atslēdzi sarunu",
    "{actor} locked the conversation" : "{actor} bloķē sarunu",
    "You locked the conversation" : "Tu aizslēdzi sarunu",
    "{actor} allowed guests" : "{actor} atļauj viesus",
    "You allowed guests" : "Tu atļāvi viesus",
    "{actor} disallowed guests" : "{actor} nepieļāva viesus",
    "You disallowed guests" : "Tu neatļāvi viesus",
    "{actor} set a password" : "{actor} iestatīja paroli",
    "You set a password" : "Tu iestatīji paroli",
    "{actor} removed the password" : "{actor} noņēma paroli",
    "You removed the password" : "Tu noņēmi paroli",
    "{actor} added {user}" : "{actor} pievienoja {user}",
    "You joined the conversation" : "Tu pievienojies sarunai",
    "{actor} joined the conversation" : "{actor} pievienojās sarunai",
    "You added {user}" : "Tu pievienoji {user}",
    "{actor} added you" : "{actor} pievienoja Tevi",
    "You left the conversation" : "Tu pameti sarunu",
    "{actor} left the conversation" : "{actor} pameta sarunu",
    "{actor} removed {user}" : "{actor} noņēma {user}",
    "You removed {user}" : "Tu noņēmi {user}",
    "{actor} removed you" : "{actor} noņēma Tevi",
    "You removed {federated_user}" : "Tu noņēmi {federated_user}",
    "You added {phone}" : "Tu pievienoji {phone}",
    "You removed {phone}" : "Tu noņēmi {phone}",
    "{actor} promoted {user} to moderator" : "{actor} iecēla {user} par satura pārraudzītāju",
    "You promoted {user} to moderator" : "Tu iecēli {user} par satura pārraudzītāju",
    "{actor} promoted you to moderator" : "{actor} iecēla Tevi par satura pārraudzītāju",
    "{actor} demoted {user} from moderator" : "{actor} pazemināja {user} no satura pārraudzītāja",
    "You demoted {user} from moderator" : "Tu pazemināji {user} no satura pārraudzītāja",
    "{actor} demoted you from moderator" : "{actor} pazemināja Tevi no satura pārraudzītāja",
    "{actor} shared a file which is no longer available" : "{actor} kopīgoja datni, kas vairs nav pieejama",
    "You shared a file which is no longer available" : "Tu kopīgoji datni, kas vairs nav pieejama",
    "Message deleted by author" : "Ziņojumu izdzēsa autors",
    "Administration" : "Pārvaldīšana",
    "System" : "Sistēma",
    "%s (guest)" : "%s (viesis)",
    "Talk conversations" : "Sarunas",
    "Talk to %s" : "Runāt ar %s",
    "File not found" : "Datne nav atrasta",
    "File is not shared, or shared but not with the user" : "Datne nav koplietota vai koplietots, bet nav koplietots ar lietotāju",
    "File is too big" : "Datne ir par lielu",
    "Invalid file provided" : "Norādīta nederīga datne",
    "Invalid image" : "Nederīgs attēls",
    "Unknown filetype" : "Nezināms datnes veids",
    "Talk mentions" : "Pieminēšana Talk",
    "More conversations" : "Vairāk sarunu",
    "Say hi to your friends and colleagues!" : "Sasveicinies ar saviem draugiem un kolēģiem!",
    "No unread mentions" : "Nav nelasītu pieminēšanu",
    "Conversation invitation" : "Sarunas uzaicinājums",
    "Description" : "Apraksts",
    "Meeting" : "Tikšanās",
    "Password request: %s" : "Paroles pieprasījums: %s",
    "Private conversation" : "Privāta saruna",
    "Dismiss notification" : "Noraidīt paziņojumu",
    "Accept" : "Pieņemt",
    "Decline" : "Noraidīt",
    "New message" : "Jauna ziņa",
    "Reminder" : "Atgādinājums",
    "{user} sent you a private message" : "{user} nosūtīja jums privātu ziņojumu",
    "{user} sent a message in conversation {call}" : "{user} nosūtīja ziņu sarunā {call}",
    "A deleted user sent a message in conversation {call}" : "Izdzēsts lietotājs nosūtīja ziņojumu sarunā {call}",
    "A guest sent a message in conversation {call}" : "Viesis nosūtījis ziņojumu sarunā {call}",
    "{user} mentioned you in a private conversation" : "{user} tevi pieminēja privātā sarunā",
    "{user} mentioned you in conversation {call}" : "{user} pieminēja Tevi sarunā {call}",
    "A deleted user mentioned you in conversation {call}" : "Izdzēsts lietotājs pieminēja Tevi sarunā {call}",
    "A guest mentioned you in conversation {call}" : "Viesis pieminēja Tevi sarunā {call}",
    "{user} invited you to a group conversation: {call}" : "{user} uzaicināja Tevi uz grupas sarunu: {call}",
    "Join call" : "Pievienoties zvanam",
    "{user} would like to talk with you" : "{user} vēlas runāt ar Tevi",
    "A group call has started in {call}" : "Grupas zvans ir sācies {call}",
    "Open settings" : "Atvērt iestatījumus",
    "error" : "kļūda",
    "Open Talk" : "Atvērt Talk",
    "Default" : "Noklusējuma",
    "Presentation" : "Prezentācija",
    "Avatar image is not square" : "Avatar attēls nav kvadrāts",
    "Other" : "Cits",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Neizdevās izdzēst kontu, jo pārbaudes serveris nepareizi uzvedās. Lūgums atgriezties vēlāk.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Neizdevās izdzēst kontu, jo pārbaudes serveris nav sasniedzams. Lūgums atgriezties vēlāk.",
    "Note to self" : "Piezīme sev",
    "Let's get started!" : "Sāksim!",
    "## ⚙️ Manage conversation settings\n\nIn the conversation menu, you can access various settings to manage your conversations, such as:\n* Edit conversation info\n* Manage notifications\n* Apply numerous moderation rules\n* Configure access and security\n* Enable bots\n* and more!" : "## Sarunas iestatījumu pārvaldīšana\n\nSarunas izvēlnē var piekļūt dažādiem iestatījumiem, lai pārvaldītu savas sarunas. Piemēram:\n* labot informāciju par sarunām;\n* pārvaldīt paziņojumus;\n* pielietot dažādas satura pārraudzības kārtulas;\n* konfigurēt piekļuvi un drošību;\n* iespējot robotprogrammatūru;\n* un vēl.",
    "Andorra" : "Andora",
    "United Arab Emirates" : "Apvienotie Arābu Emirāti",
    "Afghanistan" : "Afganistāna",
    "Antigua and Barbuda" : "Antigva un Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albānija",
    "Armenia" : "Armēnija",
    "Angola" : "Angola",
    "Antarctica" : "Antarktika",
    "Argentina" : "Argentīna",
    "American Samoa" : "Amerikas Samoa",
    "Austria" : "Austija",
    "Australia" : "Austrālija",
    "Aruba" : "Aruba",
    "Åland Islands" : "Ālandu salas",
    "Azerbaijan" : "Azerbaidžāna",
    "Bosnia and Herzegovina" : "Bosnija un Hercogovina",
    "Barbados" : "Barbadosa",
    "Bangladesh" : "Bangladeša",
    "Belgium" : "Beļģija",
    "Burkina Faso" : "Burkinafaso",
    "Bulgaria" : "Bulgārija",
    "Bahrain" : "Bahreina",
    "Burundi" : "Burundija",
    "Benin" : "Benina",
    "Saint Barthélemy" : "Senbartelmī",
    "Bermuda" : "Bermudu salas",
    "Brunei Darussalam" : "Bruneja Darusalama",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sintēstatiusa un Saba",
    "Brazil" : "Brazīlija",
    "Bahamas" : "Bahamu salas",
    "Bhutan" : "Butāna",
    "Bouvet Island" : "Buvē sala",
    "Botswana" : "Botsvāna",
    "Belarus" : "Baltkrievija",
    "Belize" : "Beliza",
    "Canada" : "Kanāda",
    "Cocos (Keeling) Islands" : "Kokosu (Kīlinga) Salas",
    "Central African Republic" : "Centrālāfrikas Republika",
    "Congo" : "Kongo Republika",
    "Switzerland" : "Šveice",
    "Côte d'Ivoire" : "Kotdivuāra",
    "Cook Islands" : "Kuka salas",
    "Chile" : "Čīle",
    "Cameroon" : "Kamerūna",
    "China" : "Ķīna",
    "Colombia" : "Kolumbija",
    "Costa Rica" : "Kostarika",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Kaboverde",
    "Curaçao" : "Kirasao",
    "Christmas Island" : "Ziemassvētku sala",
    "Cyprus" : "Ķipra",
    "Czechia" : "Čehija",
    "Germany" : "Vācija",
    "Djibouti" : "Džibutija",
    "Denmark" : "Dānija",
    "Dominica" : "Dominika",
    "Dominican Republic" : "Dominikānas Republika",
    "Algeria" : "Alžīrija",
    "Ecuador" : "Ekvadora",
    "Estonia" : "Igaunija",
    "Egypt" : "Ēģipte",
    "Western Sahara" : "Rietumsahāra",
    "Eritrea" : "Eritreja",
    "Spain" : "Spānija",
    "Ethiopia" : "Etiopija",
    "Finland" : "Somija",
    "Fiji" : "Fidži",
    "Falkland Islands (Malvinas)" : "Folklenda salas (Malvinas)",
    "Faroe Islands" : "Fēru salas",
    "France" : "Francija",
    "Gabon" : "Gabona",
    "United Kingdom of Great Britain and Northern Ireland" : "Lielbritānijas un Ziemeļīrijas Apvienotā Karaliste",
    "Grenada" : "Grenādā",
    "Georgia" : "Gruzija",
    "French Guiana" : "Franču Gviāna",
    "Guernsey" : "Gērnsija",
    "Ghana" : "Gana",
    "Gibraltar" : "Ģibraltārs",
    "Greenland" : "Grīnlande",
    "Gambia" : "Gambija",
    "Guinea" : "Gvineja",
    "Guadeloupe" : "Gvadelupa",
    "Equatorial Guinea" : "Ekvatoriālā Gvineja",
    "Greece" : "Grieķija",
    "South Georgia and the South Sandwich Islands" : "Dienviddžordžija un Dienvidsendviču salas",
    "Guatemala" : "Gvatemala",
    "Guam" : "Guama",
    "Guinea-Bissau" : "Gvineja-Bisava",
    "Guyana" : "Gajana",
    "Hong Kong" : "Honkonga",
    "Heard Island and McDonald Islands" : "Hērda Sala un Makdonalda Salas",
    "Honduras" : "Hondurasa",
    "Croatia" : "Horvātija",
    "Haiti" : "Haiti",
    "Hungary" : "Ungārija",
    "Indonesia" : "Indonēzija",
    "Ireland" : "Īrija",
    "Israel" : "Izraēla",
    "Isle of Man" : "Menas sala",
    "India" : "Indija",
    "British Indian Ocean Territory" : "Britu Indijas Okeāna Teritorija",
    "Iraq" : "Irāka",
    "Iceland" : "Islande",
    "Italy" : "Itālija",
    "Jersey" : "Džērsija",
    "Jamaica" : "Jamaika",
    "Jordan" : "Jordānija",
    "Japan" : "Japāna",
    "Kenya" : "Kenija",
    "Kyrgyzstan" : "Kirgizstāna",
    "Cambodia" : "Kambodža",
    "Kiribati" : "Kiribati",
    "Comoros" : "Komoras",
    "Saint Kitts and Nevis" : "Sentkitsa un Nevisa",
    "Kuwait" : "Kuveita",
    "Cayman Islands" : "Kaimanu Salas",
    "Kazakhstan" : "Kazahstāna",
    "Lao People's Democratic Republic" : "Laosas Tautas Demokrātiskā Republika",
    "Lebanon" : "Lebanona",
    "Saint Lucia" : "Sentlūsija",
    "Liechtenstein" : "Lihtenšteina",
    "Sri Lanka" : "Šrilanka",
    "Liberia" : "Libērija",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Lietuve",
    "Luxembourg" : "Luksemburga",
    "Latvia" : "Latvija",
    "Libya" : "Lībija",
    "Morocco" : "Maroka",
    "Monaco" : "Monako",
    "Montenegro" : "Melnkalne",
    "Saint Martin (French part)" : "Senmartēna (Francijas teritorija)",
    "Madagascar" : "Madagaskāra",
    "Marshall Islands" : "Māršala salas",
    "Mali" : "Mali",
    "Myanmar" : "Činlande",
    "Mongolia" : "Mongolija",
    "Macao" : "Makao",
    "Northern Mariana Islands" : "Ziemeļu Marianas salas",
    "Martinique" : "Martinika",
    "Mauritania" : "Mauritānija",
    "Montserrat" : "Montserrata",
    "Malta" : "Malta",
    "Mauritius" : "Maurīcija",
    "Maldives" : "Maldīvu salas",
    "Malawi" : "Malāvija",
    "Mexico" : "Meksika",
    "Malaysia" : "Malaizija",
    "Mozambique" : "Mozambika",
    "Namibia" : "Namībija",
    "New Caledonia" : "Jaunkaledonija",
    "Niger" : "Nigēra",
    "Norfolk Island" : "Norfolkas sala",
    "Nigeria" : "Nigērija",
    "Nicaragua" : "Nikaragva",
    "Netherlands" : "Nīderlande",
    "Norway" : "Norvēģija",
    "Nepal" : "Nepāla",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Jaunzēlande",
    "Oman" : "Omāna",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Franču Polinēzija",
    "Papua New Guinea" : "Papua-Jaungvineja",
    "Philippines" : "Filipīnas",
    "Pakistan" : "Paķistāna",
    "Poland" : "Polija",
    "Saint Pierre and Miquelon" : "Senpjēra un Mikelona",
    "Pitcairn" : "Pitkērna",
    "Puerto Rico" : "Puertoriko",
    "Palestine, State of" : "Palestīna",
    "Portugal" : "Portugāle",
    "Palau" : "Palau",
    "Paraguay" : "Paragvaja",
    "Qatar" : "Katāra",
    "Réunion" : "Reinjona",
    "Romania" : "Rumānija",
    "Serbia" : "Serbija",
    "Russian Federation" : "Krievijas Federācija",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Saūda Arābija",
    "Solomon Islands" : "Zālamana salas",
    "Seychelles" : "Seišelas",
    "Sudan" : "Sudāna",
    "Sweden" : "Zviedrija",
    "Singapore" : "Singapūra",
    "Saint Helena, Ascension and Tristan da Cunha" : "Svētās Helēnas sala, Debesbraukšanas sala un Tristana da Kuņas salas",
    "Slovenia" : "Slovēnija",
    "Svalbard and Jan Mayen" : "Svalbārai un Jana Majena",
    "Slovakia" : "Slovākija",
    "Sierra Leone" : "Sjerraleone",
    "San Marino" : "Sanmarīno",
    "Senegal" : "Senegāla",
    "Somalia" : "Somālija",
    "Suriname" : "Surinama",
    "South Sudan" : "Dienvidsudāna",
    "Sao Tome and Principe" : "Santome un Prinsipi",
    "El Salvador" : "Salvadora",
    "Sint Maarten (Dutch part)" : "Sintmārtena (Nīderlandes teritorija)",
    "Syrian Arab Republic" : "Sīrijas Republika",
    "Turks and Caicos Islands" : "Tērksas un Kaikosas salas",
    "Chad" : "Čada",
    "French Southern Territories" : "Francijas Dienvidjūru Zemes",
    "Togo" : "Togo",
    "Thailand" : "Taizeme",
    "Tajikistan" : "Tadžikistāna",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Austrumtimora",
    "Turkmenistan" : "Turkmenistāna",
    "Tunisia" : "Tunisija",
    "Tonga" : "Tonga",
    "Turkey" : "Turcija",
    "Trinidad and Tobago" : "Trinidāda un Tobāgo",
    "Tuvalu" : "Tuvalu",
    "Tanzania, United Republic of" : "Tanzānija, Apvienotā Republika",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "ASV Mazās aizjūras salas",
    "United States of America" : "Amerikas Savienotās Valstis",
    "Uruguay" : "Urugvaja",
    "Uzbekistan" : "Uzbekistāna",
    "Holy See" : "Vatikāns",
    "Saint Vincent and the Grenadines" : "Sentvinsenta un Grenadīnas",
    "Viet Nam" : "Vjetnama",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Volisa un Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Jemena",
    "Mayotte" : "Majota",
    "South Africa" : "Dienvidāfrika",
    "Zambia" : "Zambija",
    "Zimbabwe" : "Zimbabve",
    "Federation" : "Federācija",
    "Invalid date, date format must be YYYY-MM-DD" : "Nederīgs datums, datuma formātam jābūt YYYY-MM-DD",
    "Conversation not found" : "Saruna nav atrasta",
    "Chat, video & audio-conferencing using WebRTC" : "Video un audio konferences, izmantojot WebRTC",
    "Leave call" : "Pamest zvanu",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "Mēs esam noteikuši vairākus nederīgus paroles mēģinājumus no šīs IP adreses, tādējādi nākamā pieteikšanās ir ierobežota līdz 30 sekundēm.",
    "The password is wrong. Try again." : "Nepareiza parole. Jāmēģina vēlreiz.",
    "Password" : "Parole",
    "Submit" : "Iesniegt",
    "Error requesting the password." : "Kļūda, pieprasot paroli.",
    "Request password" : "Pieprasīt paroli",
    "This conversation has ended" : "Šī saruna ir beigusies",
    "Everyone" : "Visi",
    "Save changes" : "Saglabāt izmaiņas",
    "Saving …" : "Saglabā ...",
    "Saved!" : "Saglabāts!",
    "Limit to groups" : "Grupu ierobežojums",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Ja ir atlasīta vismaz viena grupa, tikai cilvēki no sarakstā uzskaitītajām grupām var piedalīties sarunās.",
    "Guests can still join public conversations." : "Viesi joprojām var pievienoties publiskām sarunām.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Lietotāji, kas vairs nevar izmantot Talk, joprojām tiks uzrādīti kā dalībnieki viņu iepriekšējās sarunās, kā arī tiks paturētas viņu ziņas.",
    "Enabled" : "Iespējots",
    "Disabled" : "Atspējots",
    "State" : "Stāvoklis",
    "Name" : "Nosaukums",
    "Beta" : "Beta",
    "Permissions" : "Atļaujas",
    "General settings" : "Vispārīgi iestatījumi",
    "Enable encryption" : "Ieslēgt šifrēšanu",
    "Pending" : "Gaida",
    "Error" : "Kļūda",
    "Never" : "Nekad",
    "Language" : "Valoda",
    "Country" : "Valsts",
    "Status" : "Status",
    "Created at" : "Izveidots plkst.",
    "Yes" : "Jā",
    "No" : "Nē",
    "Validate SSL certificate" : "Pārbaudīt SSL sertifikātu",
    "Delete this server" : "Izdzēst šo serveri",
    "Test this server" : "Testēt šo serveri",
    "Shared secret" : "Koplietojams noslēpums",
    "STUN server URL" : "STUN servera URL",
    "STUN servers" : "STUN serveris",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN serveris tiek izmantots, lai noteiktu maršrutētāja dalībnieku publisko IP adresi.",
    "TURN server URL" : "TURN servera URL",
    "TURN server secret" : "TURN servera noslēpums",
    "TURN server protocols" : "TURN servera protokols",
    "TURN servers" : "TURN serveris",
    "Failed" : "Neizdevās",
    "OK" : "Labi",
    "Confirm" : "Apstiprināt",
    "Reset" : "Atiestatīt",
    "Cancel" : "Atcelt",
    "Back" : "Atpakaļ",
    "Now" : "Tagad",
    "Loading …" : "Ielādē…",
    "From" : "No",
    "To" : "Līdz",
    "Calendar" : "Kalendārs",
    "Attendees" : "Dalībnieki",
    "Save" : "Saglabāt",
    "No results" : "Nav iznākuma",
    "Done" : "Pabeigts",
    "Exit full screen (F)" : "Iziet no pilnekrāna (F)",
    "Grid view" : "Režģa izkārtojums",
    "Waiting for others to join the call …" : "Gaidot citus pievienoties zvanam …",
    "You can invite others in the participant tab of the sidebar" : "Sānjoslā, dalībnieku cilnē var uzaicināt citus dalībniekus",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Sānjoslas dalībnieku cilnē varat uzaicināt citus lietotājus vai kopīgot šo saiti, lai uzaicinātu citus.",
    "Share this link to invite others!" : "Kopīgo šo saiti, lai uzaicinātu citus!",
    "Copy link" : "Ievietot saiti starpliktuvē",
    "Mute audio" : "Izslēgt audio skaņu",
    "None" : "Nav",
    "Disable video" : "Atspējot video",
    "Enable video" : "Iespējot video",
    "You" : "Tu",
    "Show screen" : "Rādīt ekrānu",
    "Collapse" : "Sakļaut",
    "Favorite" : "Izlasē",
    "Manage the list of banned users in this conversation." : "Pārvaldīt šīs sarunas liegto lietotāju sarakstu.",
    "Date:" : "Datums:",
    "Hide details" : "Paslēpt informāciju",
    "Show details" : "Rādīt informāciju",
    "Disable" : "Deaktivēt",
    "Enable" : "Iespējot",
    "Choose" : "Izvēlēties",
    "The file must be a PNG or JPG" : "Datnei jābūt PNG vai JPG",
    "Restricted" : "Ierobežota",
    "Personal" : "Personīgs",
    "Setup overview" : "Uzstādīšanas pārskats",
    "Leave conversation" : "Atstāt sarunu",
    "Delete conversation" : "Izdzēst sarunu",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Tiklīdz saruna ir pamesta, lai pievienotos slēgtai sarunai, ir nepieciešams uzaicinājums. Atvērtai sarunai var jebkurā brīdī pievienoties no jauna.",
    "_%n hour_::_%n hours_" : ["%n stundu","%n stunda","%n stundas"],
    "Password protection" : "Password protection",
    "Open conversation" : "Atvērt sarunu",
    "Edit" : "Labot",
    "Delete" : "Izdzēst",
    "Notifications" : "Paziņojumi",
    "Join" : "Pievienoties",
    "Hello, {displayName}" : "Sveiciens, {displayName}!",
    "Create and copy link" : "Izveidot saiti un ievietot starpliktuvē",
    "Open calendar" : "Atvērt kalendāru",
    "Log in" : "Pieteikties",
    "Remove from favorites" : "Noņemt no izlases",
    "Add to favorites" : "Pievienot izlasei",
    "You need to promote a new moderator before you can leave the conversation." : "Ir nepieciešams iecelt jaunu satura pārraudzītāju, lai Tu varētu pamest sarunu.",
    "Home" : "Sākums",
    "Alphabetically" : "Alfabētiskā secībā",
    "You have no unread mentions." : "Nav nelasītu pieminēšanu.",
    "Clear filter" : "Notīrīt atlasi",
    "App settings" : "Lietotnes iestatījumi",
    "Users" : "Lietotāji",
    "Groups" : "Grupas",
    "Teams" : "Komandas",
    "Open conversations" : "Atvērt sarunas",
    "Users and teams" : "Lietotāji un komandas",
    "Devices" : "Ierīces",
    "No audio" : "Nav audio",
    "Invalid path selected" : "Atlasīts nederīgs ceļš",
    "Upload" : "Augšupielādēt",
    "Files" : "Datnes",
    "24 hours" : "24 stundas",
    "7 days" : "7 dienas",
    "Message forwarded to \"Note to self\"" : "Ziņojums pārvirzīts uz “Piezīme sev”",
    "Error while forwarding message to \"Note to self\"" : "Kļūda ziņojuma pārvirzīšanas uz “Piezīme sev” laikā",
    "Reply" : "Atbildēt",
    "Go to file" : "Doties uz datni",
    "Translate" : "Tulkot",
    "Dismiss" : "Atmest",
    "Contact" : "Kontaktpersona",
    "File to share" : "Kopīgojamā datne",
    "Upload from device" : "Augšupielādēt no ierīces",
    "New file" : "Jauna datne",
    "Add more files" : "Pievienot vairāk datņu",
    "Send" : "Sūtīt",
    "Settings" : "Iestatījumi",
    "Results" : "Rezultāti",
    "moderator" : "satura pārraudzītājs",
    "guest" : "viesis",
    "Remove participant" : "Noņemt dalībnieku",
    "Demote from moderator" : "Pazemināt no satura pārraudzītāja",
    "Promote to moderator" : "Iecelt par satura pārraudzītāju",
    "Remove" : "Noņemt",
    "Add users or groups" : "Add users or groups",
    "Add users or teams" : "Pievienot lietotājus vai komandas",
    "Add teams" : "Pievienot komandas",
    "Searching …" : "Meklē...",
    "Participants" : "Dalībnieki",
    "Open chat" : "Atvērt tērzēšanu",
    "Chat" : "Tērzēt",
    "Details" : "Informācija",
    "From User" : "No lietotāja",
    "Load more results" : "Ielādēt vairāk iznākumu",
    "Projects" : "Projekti",
    "Link to a conversation" : "Saite uz sarunu",
    "Select conversation" : "Izvēlēties sarunu",
    "Notification settings" : "Paziņojumu iestatījumi",
    "Error while setting read status privacy" : "Kļūda lasīšanas stāvokļa privātuma iestatīšanas laikā",
    "Error while setting typing status privacy" : "Kļūda rakstīšanas stāvokļa privātuma iestatīšanas laikā",
    "Privacy" : "Privātums",
    "Search" : "Meklēt",
    "Start call" : "Sākt zvanu",
    "All tasks done!" : "Visi uzdevumi paveikti.",
    "_{done} of %n task_::_{done} of %n tasks_" : ["{done} no %n uzdevumiem","{done} no %n uzdevuma","{done} no %n uzdevumiem"],
    "You are not allowed to enable screensharing" : "Nav ļauts iespējot ekrāna kopīgošanu",
    "No screensharing" : "Nav ekrāna kopīgošanas",
    "Screensharing options" : "Ekrāna kopīgošanas iespējas",
    "Enable screensharing" : "Iespējot ekrāna kopīgošanu",
    "Screensharing requires the page to be loaded through HTTPS." : "Ekrāna kopīgošanai ir nepieciešams lapu ielādēt ar HTTPS.",
    "An error occurred while starting screensharing." : "Ekrāna kopīgošanas uzsākšanas laikā atgadījās kļūda.",
    "Show your screen" : "Rādīt savu ekrānu",
    "Stop screensharing" : "Apturēt ekrāna kopīgošanu",
    "Start recording" : "Uzsākt ierakstīšanu",
    "Open Calendar" : "Atvērt kalendāru",
    "Would you like to delete this conversation?" : "Vai izdzēst šo sarunu?",
    "Keep" : "Paturēt",
    "Select a region" : "Atlasīt apgabalu",
    "Duplicate session" : "Pavairot sesiju",
    "Join a conversation or start a new one" : "Pievienoties sarunai vai sākt jaunu",
    "User" : "Lietotājs",
    "API token" : "API pilnvara",
    "Login" : "Pieteikumvārds",
    "Nickname" : "Iesauka",
    "Client ID" : "Klienta ID",
    "Media" : "Informācijas nesēji",
    "Polls" : "Aptaujas",
    "Audio" : "Audio",
    "Show all files" : "Parādīt visas datnes",
    "Show all polls" : "Parādīt visas aptaujas",
    "Group" : "Grupa",
    "Team" : "Komanda",
    "You and {user0} left the call" : "Tu un {user0} pametāt zvanu",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Search in conversation: {conversation}" : "Meklēt sarunā: {conversation}",
    "Error while sharing file" : "Kļūda datnes kopīgošanā",
    "Later today – {timeLocale}" : "Vēlāk šodien – {timeLocale}",
    "Please reload the page." : "Lūgums pārlādēt lapu",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Tas aizņem vairāk laika, nekā paredzēts. Vai multivides atļaujas jau ir piešķirtas (vai noraidītas)? Ja atbilde ir “jā”, lūgums palaist savu pārlūku no jauna, jo ir skaņas un video atteice",
    "Access to microphone & camera is only possible with HTTPS" : "Piekļuve mikrofonam un kamerai ir iespējama izmantojot tikai HTTPS",
    "Please move your setup to HTTPS" : "Lūgums pārvietot serveri uz HTTPS",
    "Access to microphone & camera was denied" : "Tika noraidīta piekļuve mikrofonam un kamerai",
    "WebRTC is not supported in your browser" : "Pārlūkā netiek atbalstīts WebRTC",
    "Please use a different browser like Firefox or Chrome" : "Lūgums izmantot citu pārlūku, piemēram, Firefox vai Chrome",
    "Error while accessing microphone & camera" : "Kļūda, piekļūstot mikrofonam un kamerai",
    "%s Talk on your mobile devices" : "%s Sarunas mobilajās ierīcēs",
    "Android app" : "Android lietotne",
    "iOS app" : "iOS lietotne",
    "__language_name__" : "Latviešu",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "Zvanu apkopojuma robotprogrammatūra izveido pārskata ziņojumu pēc zvana, uzskaitot visus dalībniekus un izklāstot uzdevumus",
    "Tasks" : "Uzdevumi",
    "Notes" : "Piezīmes",
    "Reports" : "Atskaites",
    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "{notify_push} nav uzstādīts, tas var novest pie veiktspējas sarežģījumiem, kad izmanto darbvirsmas klientus.",
    "Set reminder for later today" : "Iestatīt atgādinājumu vēlākam šodien"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
