OC.L10N.register(
    "spreed",
    {
    "_%n guest_::_%n guests_" : ["%n inivitado","%n inivitados","%n inivitados"],
    "Talk" : "Hablar",
    "Guest" : "Invitado",
    "Message deleted by author" : "Mensaje eliminado por el autor",
    "Administration" : "Administración",
    "System" : "Sistema",
    "Storage quota exceeded" : "Se excedió la cuota de almacenamiento",
    "File not found" : "Archivo no encontrado",
    "File is too big" : "El archivo es demasiado grande.",
    "Invalid file provided" : "Archivo proporcionado inválido",
    "Invalid image" : "Imagen inválida",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Description" : "Descripción",
    "Dismiss notification" : "Eliminar notificación",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "New message" : "Mensaje nuevo",
    "Open settings" : "Abrir opciones",
    "error" : "error",
    "Default" : "Predeterminado",
    "Messages" : "Mensajes",
    "Avatar image is not square" : "La imagen del avatar no es un cuadrado",
    "Other" : "Otro",
    "Federation" : "Federación",
    "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, favor de seguir el formato AAAA-MM-DD",
    "Leave call" : "Dejar la llamada",
    "The password is wrong. Try again." : "Error en la contraseña. Inténtelo de nuevo.",
    "Password" : "Contraseña",
    "Submit" : "Enviar",
    "Everyone" : "Todos",
    "Save changes" : "Guardar cambios",
    "Saved!" : "¡Guardado!",
    "Limit to groups" : "Limitar a grupos",
    "Enabled" : "Habilitado",
    "Disabled" : "Deshabilitado",
    "State" : "Estado",
    "Name" : "Nombre",
    "Beta" : "Beta",
    "Permissions" : "Permisos",
    "Off" : "Apagado",
    "General settings" : "Configuraciones generales",
    "Enable encryption" : "Habilitar encripción",
    "Pending" : "Pendiente",
    "Error" : "Error",
    "Blocked" : "Bloqueado",
    "Never" : "Nunca",
    "Language" : "Idioma",
    "Country" : "País",
    "Status" : "Estatus",
    "Created at" : "Creado en",
    "Yes" : "Sí",
    "_%n user_::_%n users_" : ["%n usuario","%n usuarios","%n usuarios"],
    "TURN server protocols" : "Protocolos del servidor TURN",
    "Failed" : "Error",
    "OK" : "OK",
    "Confirm" : "Confirmar",
    "Reset" : "Restablecer",
    "Cancel" : "Cancelar",
    "Back" : "Atrás",
    "Calendar" : "Calendario",
    "Attendees" : "Asistentes",
    "Save" : "Guardar",
    "No results" : "Sin resultados",
    "Done" : "Terminado",
    "Grid view" : "Vista de cuadrícula",
    "Reload" : "Recargar",
    "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
    "Copy link" : "Copiar enlace",
    "Mute audio" : "Silenciar audio",
    "None" : "Ninguno",
    "Disable video" : "Deshabilitar video",
    "You" : "Usted",
    "Collapse" : "Colapsar",
    "Favorite" : "Favorito",
    "Note:" : "Nota:",
    "Hide details" : "Ocultar detalles",
    "Show details" : "Mostrar detalles",
    "Disable" : "Deshabilitar",
    "Enable" : "Activar",
    "Choose" : "Elige",
    "The file must be a PNG or JPG" : "El archivo debe ser PNG o JPG",
    "Restricted" : "Restringido",
    "Personal" : "Personal",
    "Leave conversation" : "Dejar la conversación",
    "Delete conversation" : "Eliminar conversación",
    "Password protection" : "Protección con contraseña",
    "Set a password" : "Establecer una contraseña",
    "Edit" : "Editar",
    "More information" : "Más información",
    "Delete" : "Eliminar",
    "Log content" : "Contenido del registro",
    "Notifications" : "Notificaciones",
    "Log in" : "Iniciar sesión",
    "Remove from favorites" : "Eliminado de favoritos",
    "Add to favorites" : "Agregar a favoritos",
    "Home" : "Casa",
    "Alphabetically" : "Alfabéticamente",
    "Users" : "Ususarios",
    "Groups" : "Grupos",
    "Devices" : "Dispositivos",
    "Upload" : "Cargar",
    "Files" : "Archivos",
    "24 hours" : "24 horas",
    "Reply" : "Responder",
    "Translate" : "Traducir",
    "Dismiss" : "Despedir",
    "Contact" : "Contacto",
    "Send message" : "Enviar mensaje",
    "New file" : "Nuevo archivo",
    "Send" : "Enviar",
    "Settings" : "Ajustes",
    "Remove" : "Eliminar",
    "Add users or groups" : "Agregar usuarios o grupos",
    "Searching …" : "Buscando ...",
    "Participants" : "Participantes",
    "Chat" : "Chat",
    "Details" : "Detalles",
    "Load more results" : "Cargar más resultados",
    "Notification settings" : "Configuración de las notificaciones",
    "Privacy" : "Privacidad",
    "Search" : "Buscar",
    "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
    "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
    "Show your screen" : "Mostrar su pantalla",
    "Stop screensharing" : "Dejar de compartir la pantalla",
    "Keep" : "Mantener",
    "User" : "Usuario",
    "API token" : "Ficha del API",
    "Login" : "Inicio de sesión",
    "Nickname" : "Apodo",
    "Client ID" : "ID del cliente",
    "Media" : "Media",
    "Locations" : "Ubicaciones",
    "Audio" : "Audio",
    "Group" : "Grupo",
    "Please reload the page." : "Favor de volver a cargar la página.",
    "Do not disturb" : "No molestar",
    "Away" : "Lejos",
    "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
    "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
    "WebRTC is not supported in your browser" : "WebRTC no está soportado en su navegador",
    "Please use a different browser like Firefox or Chrome" : "Favor de usar un navegador diferente como Firefox o Chrome",
    "Error while accessing microphone & camera" : "Se pressentó un error al acceder al micrófono & cámara",
    "Android app" : "Aplicación android",
    "iOS app" : "Aplicación iOS",
    "__language_name__" : "Español (Argentina)",
    "Tasks" : "Tareas",
    "Notes" : "Notas",
    "Reports" : "Reportes"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
