OC.L10N.register(
    "spreed",
    {
    "a conversation" : "Một cuộc đàm thoại",
    "(Duration %s)" : "(Thời lượng %s)",
    "You attended a call with {user1}" : "Bạn đã tham dự một cuộc gọi với {user1}",
    "_%n guest_::_%n guests_" : ["%n khách"],
    "You attended a call with {user1} and {user2}" : "Bạn đã tham dự một cuộc gọi với {user1} và {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Bạn đã tham dự một cuộc gọi với {user1}, {user2} và {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Bạn đã tham dự một cuộc gọi với {user1}, {user2}, {user3} và {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Bạn đã tham dự một cuộc gọi với {user1}, {user2}, {user3}, {user4} và {user5}",
    "_%n other_::_%n others_" : ["%n khác"],
    "{actor} invited you to {call}" : "{actor} mời bạn tham dự {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Bạn đã được mời vào <strong>cuộc trò chuyện</strong> hoặc có 1  <strong>cuộc gọi</strong>",
    "Other activities" : "Hoạt động khác",
    "Talk" : "Trò chuyện",
    "Guest" : "Khách",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge và Safari hiện có thể được sử dụng để tham gia vào các cuộc gọi âm thanh và video",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Giờ đây, bạn có thể thông báo cho tất cả những người tham gia bằng cách đăng \"@all\" vào cuộc trò chuyện",
    "- With the \"arrow-up\" key you can repost your last message" : "- Với phím \"mũi tên lên\", bạn có thể đăng lại tin nhắn cuối cùng của mình",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "Talk hiện có thể có các lệnh, hãy gửi \"/ help\" dưới dạng tin nhắn trò chuyện nếu quản trị viên của bạn có định một số cấu hình",
    "- With projects you can create quick links between conversations, files and other items" : "- Với các dự án, bạn có thể tạo liên kết nhanh giữa các cuộc hội thoại, tệp và các mục khác",
    "- You can now mention guests in the chat" : "- Bây giờ bạn có thể đề cập đến khách trong cuộc trò chuyện",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "Các cuộc trò chuyện bây giờ có thể có sảnh đợi. Điều này sẽ cho phép người kiểm duyệt tham gia trò chuyện và gọi điện để chuẩn bị cuộc họp, trong khi người dùng và khách phải đợi",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Giờ đây, bạn có thể trực tiếp trả lời tin nhắn cho những người dùng khác để họ biết thêm ngữ cảnh về nội dung tin nhắn của bạn",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Tìm kiếm các cuộc trò chuyện và người tham gia giờ đây cũng sẽ lọc các cuộc trò chuyện hiện có của bạn, giúp việc tìm kiếm các cuộc trò chuyện trước đó dễ dàng hơn nhiều",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Giờ đây, bạn có thể thêm nhóm người dùng tùy chỉnh vào cuộc trò chuyện khi ứng dụng vòng kết nối được cài đặt",
    "- Check out the new grid and call view" : "- Kiểm tra lưới mới và chế độ xem cuộc gọi",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Giờ đây, bạn có thể tải lên và kéo các tệp tin trực tiếp từ thiết bị của mình vào cuộc trò chuyện",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Các tệp được chia sẻ hiện được mở trực tiếp bên trong chế độ xem trò chuyện bằng ứng dụng trình xem",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Giờ đây, bạn có thể tìm kiếm các cuộc trò chuyện và tin nhắn trong tìm kiếm hợp nhất ở thanh trên cùng",
    "- Spice up your messages with emojis from the emoji picker" : "- Thêm gia vị cho tin nhắn của bạn bằng các biểu tượng cảm xúc từ bộ chọn biểu tượng cảm xúc",
    "- You can now change your camera and microphone while being in a call" : "- Giờ đây, bạn có thể thay đổi máy ảnh và micrô của mình khi đang gọi điện",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Cung cấp cho các cuộc trò chuyện của bạn một số ngữ cảnh kèm theo mô tả và mở nó ra để người dùng đã đăng nhập có thể tìm thấy nó và tự tham gia",
    "- See a read status and send failed messages again" : "- Xem trạng thái đã đọc và gửi lại tin nhắn không thành công",
    "- Raise your hand in a call with the R key" : "- Giơ tay của bạn trong cuộc họp bằng phím R",
    "- Join the same conversation and call from multiple devices" : "- Tham gia cùng một cuộc trò chuyện và gọi nhau từ nhiều thiết bị khác nhau",
    "- Send voice messages, share your location or contact details" : "- Gửi những tin nhắn thoại, chia sẻ vị trí hiện tại hoặc những thông tin liên hệ",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Thêm nhiều nhóm vào cuộc trò chuyện và những thành viên mới của nhóm sẽ tự động được thêm như là những thành viên",
    "Talk updates ✅" : "Cập nhật Talk ✅",
    "{actor} created the conversation" : "{actor} đã tạo đàm thoại",
    "You created the conversation" : "Bạn đã tạo đàm thoại",
    "An administrator created the conversation" : "Quản trị viên đã tạo cuộc trò chuyện",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} đã đổi tên cuộc hội thoại từ \"%1$s\" thành \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Bạn đã đổi tên cuộc hội thoại từ \"%1$s\" thành \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Quản trị viên đã đổi tên cuộc trò chuyện từ \"%1$s\" thành \"%2$s\"",
    "{actor} set the description" : "{actor} đổi thông tin mô tả",
    "You set the description" : "Bạn đã đổi thông tin mô tả",
    "An administrator set the description" : "Một quản trị viên đã đổi thông tin mô tả",
    "{actor} removed the description" : "{actor} đã xóa miêu tả",
    "You removed the description" : "Bạn đá xóa miêu tả",
    "An administrator removed the description" : "Một quản trị viên đã xóa miêu tả",
    "You started a call" : "Bạn đã thực hiện một cuộc gọi",
    "{actor} started a call" : "{actor} đã thực hiện một cuộc gọi",
    "{actor} joined the call" : "{actor} đã tham gia cuộc gọi",
    "You joined the call" : "Bạn đã tham gia cuộc gọi",
    "{actor} left the call" : "{actor} đã rời khỏi cuộc gọi",
    "You left the call" : "Bạn đã rời khỏi cuộc gọi",
    "{actor} unlocked the conversation" : "{actor} đã mở khóa cuộc trò chuyện",
    "You unlocked the conversation" : "Bạn đá mở khóa cuộc trò chuyện",
    "An administrator unlocked the conversation" : "Một quản trị viên đã mở khóa cuộc trò chuyện",
    "{actor} locked the conversation" : "{actor} đã khóa cuộc trò chuyện",
    "You locked the conversation" : "Bạn đá khóa cuộc trò chuyện",
    "An administrator locked the conversation" : "Một quản trị viên đã khóa cuộc trò chuyện",
    "{actor} limited the conversation to the current participants" : "{actor} đã giới hạn cuộc trò chuyện với người dùng hiện tại",
    "You limited the conversation to the current participants" : "Bạn đã giới hạn cuộc trò chuyện với người dùng hiện tại",
    "An administrator limited the conversation to the current participants" : "Một quản trị viên đã giới hạn cuộc trò chuyện với người dùng hiện tại",
    "{actor} opened the conversation to registered users" : "{actor} mở cuộc trò chuyện với người dùng đã đăng kí",
    "You opened the conversation to registered users" : "Bạn đã mở cuộc trò chuyện với người dùng đã đăng kí",
    "An administrator opened the conversation to registered users" : "Một quản trị viên đã mở cuộc trò chuyện với người dùng đã đăng kí",
    "The conversation is now open to everyone" : "Cuộc trò chuyện được mở cho tất cả",
    "{actor} opened the conversation to everyone" : "{actor} đã mở cuộc trò chuyện cho tất cả",
    "You opened the conversation to everyone" : "Bạn đã mở cuộc trò chuyện cho tất cả",
    "{actor} restricted the conversation to moderators" : "{actor} giới hạn cuộc trò chuyện với người kiểm duyệt",
    "You restricted the conversation to moderators" : "Bạn giới hạn cuộc trò chuyện với người kiểm duyệt",
    "{actor} allowed guests" : "{actor} đã cho phép khách mời",
    "You allowed guests" : "Bạn đã cho phép khách mời",
    "An administrator allowed guests" : "Quản trị viên đã cho phép khách",
    "{actor} disallowed guests" : "{actor} đã không cho phép khách mời",
    "You disallowed guests" : "Bạn đã không cho phép khách mời",
    "An administrator disallowed guests" : "Quản trị viên đã không cho phép khách",
    "{actor} set a password" : "{actor} đã đặt mật khẩu",
    "You set a password" : "Bạn đã đặt một mật khẩu",
    "An administrator set a password" : "Quản trị viên đã đặt mật khẩu",
    "{actor} removed the password" : "{actor} đã xóa mật khẩu",
    "You removed the password" : "Bạn đã xóa mật khẩu",
    "An administrator removed the password" : "Quản trị viên đã xóa mật khẩu",
    "{actor} added {user}" : "{actor} đã thêm {user}",
    "You joined the conversation" : "Bạn đã tham gia cuộc trò chuyện",
    "{actor} joined the conversation" : "{actor} đã tham gia cuộc trò chuyện",
    "You added {user}" : "Bạn đã thêm {user}",
    "{actor} added you" : "{actor} đã thêm bạn vào",
    "An administrator added you" : "Quản trị viên đã thêm bạn",
    "An administrator added {user}" : "Quản trị viên đã thêm {user}",
    "You left the conversation" : "Bạn đã rời cuộc trò chuyện",
    "{actor} left the conversation" : "{actor} đã rời khỏi cuộc hội thoại",
    "{actor} removed {user}" : "{actor} đã mời {user} ra ngoài",
    "You removed {user}" : "Bạn đã mời {user} ra ngoài. ",
    "{actor} removed you" : "{actor} đã mời bạn ra ngoài.",
    "An administrator removed you" : "Quản trị viên đã xóa bạn",
    "An administrator removed {user}" : "Quản trị viên đã xóa {user}",
    "{actor} added group {group}" : "{actor} đã thêm nhóm {group}",
    "You added group {group}" : "Bạn đã thêm nhóm {group}",
    "An administrator added group {group}" : "Một quản trị viên đã thêm nhóm {group}",
    "{actor} removed group {group}" : "{actor} đã xóa nhóm {group}",
    "You removed group {group}" : " Bạn đã xóa nhóm {group}",
    "An administrator removed group {group}" : "Một quản trị viên đã xóa nhóm {group}",
    "{actor} promoted {user} to moderator" : "{actor} đã giới thiệu {user} thành người kiểm duyệt",
    "You promoted {user} to moderator" : "Bạn đã bầu chọn {user} là người kiểm duyệt",
    "{actor} promoted you to moderator" : "{actor} đã bầu chọn cho bạn là người kiểm duyệt",
    "An administrator promoted you to moderator" : "Quản trị viên đã thăng cấp bạn lên người kiểm duyệt",
    "An administrator promoted {user} to moderator" : "Quản trị viên đã thăng cấp {user} thành quản trị viên",
    "{actor} demoted {user} from moderator" : "{actor} phản đối {user} là người kiểm duyệt",
    "You demoted {user} from moderator" : "Bạn đã phản đối {user} là người kiểm duyệt",
    "{actor} demoted you from moderator" : "{actor} đã phản đối bạn là người kiểm duyệt",
    "An administrator demoted you from moderator" : "Quản trị viên đã giáng cấp bạn khỏi người kiểm duyệt",
    "An administrator demoted {user} from moderator" : "Quản trị viên đã giáng cấp {user} khỏi người kiểm duyệt",
    "{actor} shared a file which is no longer available" : "{actor} đã chia sẻ một tệp không còn tồn tại",
    "You shared a file which is no longer available" : "Bạn đã chia sẻ một tệp không còn tồn tại",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} đã thiết lập Matterbridge để đồng bộ hóa cuộc trò chuyện này với các cuộc trò chuyện khác.",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Bạn thiết lập Matterbridge để đồng bộ hóa cuộc trò chuyện này với các cuộc trò chuyện khác.",
    "{actor} updated the Matterbridge configuration" : "{actor} đã cập nhật cấu hình của Matterbridge",
    "You updated the Matterbridge configuration" : "Bạn đã cập nhật cấu hình của Matterbridge",
    "{actor} removed the Matterbridge configuration" : "{actor} đã xóa cấu hình của Matterbridge",
    "You removed the Matterbridge configuration" : "Bạn đã xóa cấu hình của Matterbridge",
    "{actor} started Matterbridge" : "{actor} đã khởi động Matterbridge",
    "You started Matterbridge" : "Bạn đã khởi động Matterbridge",
    "{actor} stopped Matterbridge" : "{actor} đã dừng Matterbridge",
    "You stopped Matterbridge" : "Bạn đã đừng Matterbridge",
    "{actor} deleted a message" : "{actor} đã xóa tin nhắn",
    "You deleted a message" : "Bạn đã xóa tin nhắn",
    "{actor} cleared the history of the conversation" : "{actor} đã xóa lịch sử của cuộc gọi",
    "You cleared the history of the conversation" : "Bạn đã xóa lịch sử của cuộc gọi",
    "Message deleted by author" : "Tin nhắn đã xóa bởi tác giả",
    "Message deleted by {actor}" : "Tin nhắn đã xóa bởi {actor}",
    "Message deleted by you" : "Tin nhắn đá xóa bởi bạn",
    "Administration" : "Quản trị viên",
    "System" : "Hệ thống",
    "%s (guest)" : "%s (khách mời)",
    "Talk to %s" : "Trò chuyện với %s",
    "File not found" : "Không tìm thấy tập tin",
    "File is not shared, or shared but not with the user" : "Tệp này không được chia sẻ, hoạc được chia sẻ nhưng không phải với người dùng này",
    "No account available to delete." : "Không có tài khoản nào để xóa",
    "No image file provided" : "Không có tệp ảnh nào được cung cấp",
    "File is too big" : "Tệp quá lớn",
    "Invalid file provided" : "Tệp đã cung cấp không hợp lệ",
    "Invalid image" : "Ảnh không hợp lệ",
    "Unknown filetype" : "Loại tệp không xác định",
    "Talk mentions" : "Đề cập trong cuộc trò chuyện",
    "Say hi to your friends and colleagues!" : "Gửi lòi chào đến bạn bè và đồng nghiệp",
    "No unread mentions" : "Không có đề cập nào chưa đọc",
    "Call in progress" : "Cuộc gọi đang chờ",
    "You were mentioned" : "Bạn đã được nhắc tới",
    "Write to conversation" : "Viết vào cuộc trò chuyên",
    "Writes event information into a conversation of your choice" : "Viết thông tin sự kiện vào một cuộc trò chuyện bạn chọn",
    "Conversation invitation" : "Lời mời vào cuộc trò chuyện",
    "Description" : "Mô tả",
    "You can also dial-in via phone with the following details" : "Bạn cũng có thể quay số qua điện thoại với các thông tin chi tiết sau",
    "Dial-in information" : "Thông tin quay số",
    "Meeting ID" : "Id cuộc họp",
    "Your PIN" : "Mã PIN của bạn",
    "Meeting" : "Cuộc họp",
    "Password request: %s" : "Yêu cầu mật khẩu: %s",
    "Private conversation" : "Cuộc trò chuyện bí mật",
    "Deleted user (%s)" : "Người dùng đã xóa (%s)",
    "Dismiss notification" : "Bỏ qua thông báo ",
    "Accept" : "Đồng ý",
    "Decline" : "Từ chối",
    "New message" : "Tin nhắn mới",
    "Reminder" : "Lịch nhắc hẹn",
    "Notification" : "Thông báo",
    "{user} in {call}" : "{user} trong {call}",
    "Deleted user in {call}" : "Người dùng đã xóa trong {call}",
    "{guest} (guest) in {call}" : "{guest} (khách) trong {call}",
    "Guest in {call}" : "Khách trong {call}",
    "{user} sent you a private message" : "{user} đã gửi cho bạn một tin nhắn riêng",
    "{user} sent a message in conversation {call}" : "{user} gửi tin nhắn trong cuộc trò chuyện{call}",
    "A deleted user sent a message in conversation {call}" : "Một người dùng đã xóa gửi tin nhắn trong cuộc trò chuyện {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (khách) gửi tin nhắn trong cuộc trò chuyện {call}",
    "A guest sent a message in conversation {call}" : "Khách gửi tin nhắn trong cuộc trò chuyện {call}",
    "{user} replied to your private message" : "{user} phản hồi lại tin nhắn bí mật của bạn",
    "{user} replied to your message in conversation {call}" : "{user} phản hồi lại tin nhắn của bạn trong cuộc trò chuyện {call}",
    "A deleted user replied to your message in conversation {call}" : "Một người dùng bị xóa đã trả lời tin nhắn của bạn trong cuộc trò chuyện {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (khách) đã phản hồi tin nhắn của bạn trong cuộc trò chuyện {call}",
    "A guest replied to your message in conversation {call}" : "Một khách đã trả lời tin nhắn của bạn trong cuộc trò chuyện {call}",
    "{user} mentioned you in a private conversation" : "{user} đã đề cập đến bạn trong cuộc trò chuyện riêng",
    "{user} mentioned you in conversation {call}" : "{user} nhắc đến bạn trong cuộc trò chuyện {call}",
    "A deleted user mentioned you in conversation {call}" : "Một người dùng bị xóa đã đề cập đến bạn trong cuộc trò chuyện {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (khách) đã đề cập đến bạn trong cuộc trò chuyện {call}",
    "A guest mentioned you in conversation {call}" : "Một khách đã đề cập đến bạn trong cuộc trò chuyện {call}",
    "View chat" : "Xem trò chuyện",
    "{user} invited you to a group conversation: {call}" : "{user} đã mời bạn tham gia cuộc trò chuyện nhóm: {call}",
    "Join call" : "Tham gia cuộc gọi",
    "Answer call" : "Trả lời cuộc gọi",
    "{user} would like to talk with you" : "{user} muốn nói chuyện với bạn",
    "Call back" : "Gọi lại",
    "You missed a call from {user}" : "Bạn đã lỡ cuộc gọi từ {user}",
    "A group call has started in {call}" : "Một cuộc gọi nhóm đã được thực hiện trong {call}",
    "You missed a group call in {call}" : "Bạn đã lỡ cuộc gọi nhóm trong {call}",
    "{email} is requesting the password to access {file}" : "{email} đang yêu cầu mật khẩu để truy cập {file}",
    "{email} tried to request the password to access {file}" : "{email} đã cố gắng yêu cầu mật khẩu để truy cập {file}",
    "Someone is requesting the password to access {file}" : "Ai đó đang yêu cầu mật khẩu để truy cập {file}",
    "Someone tried to request the password to access {file}" : "Ai đó đã cố gắng yêu cầu mật khẩu để truy cập {file}",
    "Open settings" : "Mở thiết đặt",
    "The hosted signaling server is now configured and will be used." : "Máy chủ báo hiệu hiện đã được định cấu hình và sẽ được sử dụng",
    "The hosted signaling server was removed and will not be used anymore." : "Máy chủ báo hiệu đã bị xóa và sẽ không được sử dụng nữa.",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "Tài khoản máy chủ báo hiệu đã thay đổi trạng thái từ \"{oldstatus}\" thành \"{newstatus}\".",
    "error" : "Lỗi",
    "Default" : "Mặc định",
    "Presentation" : "Buổi thuyết trình",
    "Conversations" : "Đàm thoại",
    "{user}" : "{user}",
    "Messages" : "Thông điệp",
    "{user} in {conversation}" : "{user} trong {conversation}",
    "Messages in other conversations" : "Tin nhắn trong cuộc trò chuyện khác",
    "Other" : "Khác",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "Không thể yêu cầu dùng thử vì không thể truy cập được máy chủ dùng thử. Vui lòng thử lại sau.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Có vấn đề với xác thực của phiên bản này. Có thể không thể truy cập từ bên ngoài để xác minh URL của nó.",
    "Something unexpected happened." : "Một điều gì đó không mong muốn đã xảy ra.",
    "The URL is invalid." : "URL không hợp lệ.",
    "An HTTPS URL is required." : "URL HTTPS là bắt buộc.",
    "The email address is invalid." : "Địa chỉ email không hợp lệ.",
    "The language is invalid." : "Ngôn ngữ không hợp lệ.",
    "The country is invalid." : "Quốc gia không hợp lệ.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Có vấn đề với yêu cầu của bản dùng thử. Vui lòng kiểm tra nhật ký của bạn để biết thêm thông tin",
    "Too many requests are send from your servers address. Please try again later." : "Quá nhiều yêu cầu được gửi từ địa chỉ máy chủ của bạn. Vui lòng thử lại sau.",
    "There is already a trial registered for this Nextcloud instance." : "Đã có một bản dùng thử được đăng ký cho phiên bản vWorkspace này.",
    "Something unexpected happened. Please try again later." : "Một điều gì đó không mong muốn đã xảy ra. Vui lòng thử lại sau.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "Không thể yêu cầu dùng thử vì máy chủ dùng thử hoạt động sai. Vui lòng thử lại sau.",
    "Trial requested but failed to get account information. Please check back later." : "Đã yêu cầu dùng thử nhưng không lấy được thông tin tài khoản. Vui lòng kiểm tra lại sau.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Đã xảy ra sự cố với việc xác thực yêu cầu này. Có thể không thể truy cập từ bên ngoài để xác minh URL của nó.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "Không tìm nạp được thông tin tài khoản vì máy chủ dùng thử hoạt động sai. Vui lòng kiểm tra lại sau.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Đã xảy ra sự cố khi tìm nạp thông tin tài khoản. Vui lòng kiểm tra nhật ký của bạn để biết thêm thông tin.",
    "There is no such account registered." : "Không có tài khoản như vậy được đăng ký.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "Không thể tìm nạp thông tin tài khoản vì không thể truy cập được máy chủ dùng thử. Vui lòng kiểm tra lại sau.",
    "Deleting the hosted signaling server account failed. Please check back later." : "Không xóa được tài khoản máy chủ báo hiệu. Vui lòng kiểm tra lại sau.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Không thể xóa tài khoản vì máy chủ dùng thử hoạt động sai. Vui lòng kiểm tra lại sau.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Đã xảy ra sự cố khi xóa tài khoản. Vui lòng kiểm tra nhật ký của bạn để biết thêm thông tin.",
    "Too many requests are sent from your servers address. Please try again later." : "Quá nhiều yêu cầu được gửi từ địa chỉ máy chủ của bạn. Vui lòng thử lại sau.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Không thể xóa tài khoản vì không thể truy cập được máy chủ dùng thử. Vui lòng kiểm tra lại sau.",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Các Tiểu vương quốc Ả Rập Thống nhất",
    "Afghanistan" : "Afghanistan",
    "Antigua and Barbuda" : "Antigua và Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Nam Cực",
    "Argentina" : "Argentina",
    "American Samoa" : "American Samoa",
    "Austria" : "Áo",
    "Australia" : "Úc",
    "Aruba" : "Aruba",
    "Åland Islands" : "Quần đảo Åland",
    "Azerbaijan" : "Azerbaijan",
    "Bosnia and Herzegovina" : "Bosnia và Herzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Bỉ",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei Darussalam" : "Brunei",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius và Saba",
    "Brazil" : "Brazil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Đảo Bouvet",
    "Botswana" : "Botswana",
    "Belarus" : "Belarus",
    "Belize" : "Belize",
    "Canada" : "Canada",
    "Cocos (Keeling) Islands" : "Quần đảo Cocos (Keeling)",
    "Central African Republic" : "Cộng hòa Trung Phi",
    "Congo" : "Congo",
    "Switzerland" : "Thụy Sĩ",
    "Côte d'Ivoire" : "Bờ Biển Ngà",
    "Cook Islands" : "Quần đảo Cook",
    "Chile" : "Chile",
    "Cameroon" : "Cameroon",
    "China" : "Trung Quốc",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Cabo Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Đảo Christmas",
    "Cyprus" : "Síp",
    "Czechia" : "Séc",
    "Germany" : "Đức",
    "Djibouti" : "Djibouti",
    "Denmark" : "Đan Mạch",
    "Dominica" : "Dominica",
    "Dominican Republic" : "Cộng hòa Dominica",
    "Algeria" : "Algeria",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estonia",
    "Egypt" : "Ai Cập",
    "Western Sahara" : "Tây Sahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Tây Ban Nha",
    "Ethiopia" : "Ethiopia",
    "Finland" : "Phần Lan",
    "Fiji" : "Fiji",
    "Falkland Islands (Malvinas)" : "Quần đảo Falkland (Malvinas)",
    "Faroe Islands" : "Quần đảo Faroe",
    "France" : "Pháp",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Vương quốc Anh",
    "Grenada" : "Grenada",
    "Georgia" : "Georgia",
    "French Guiana" : "Guiana thuộc Pháp",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Greenland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Xích Đạo Guinea",
    "Greece" : "Hy Lạp",
    "South Georgia and the South Sandwich Islands" : "Nam Georgia và Quần đảo Nam Sandwich",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hồng Kông",
    "Heard Island and McDonald Islands" : "Đảo Heard và QĐ McDonald",
    "Honduras" : "Honduras",
    "Croatia" : "Croatia",
    "Haiti" : "Haiti",
    "Hungary" : "Hungary",
    "Indonesia" : "Indonesia",
    "Ireland" : "Ireland",
    "Israel" : "Israel",
    "Isle of Man" : "Đảo Man",
    "India" : "Ấn Độ",
    "British Indian Ocean Territory" : "Lãnh thổ Ấn Độ Dương thuộc Anh",
    "Iraq" : "Iraq",
    "Iceland" : "Iceland",
    "Italy" : "Ý",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordan",
    "Japan" : "Nhật Bản",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kyrgyzstan",
    "Cambodia" : "Campuchia",
    "Kiribati" : "Kiribati",
    "Comoros" : "Comoros",
    "Saint Kitts and Nevis" : "Saint Kitts và Nevis",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Quần đảo Cayman",
    "Kazakhstan" : "Kazakhstan",
    "Lao People's Democratic Republic" : "Lào",
    "Lebanon" : "Li-băng",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Lithuania",
    "Luxembourg" : "Luxembourg",
    "Latvia" : "Latvia",
    "Libya" : "Libya",
    "Morocco" : "Ma-rốc",
    "Monaco" : "Monaco",
    "Montenegro" : "Montenegro",
    "Saint Martin (French part)" : "Saint Martin (phần thuộc Pháp)",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Quần đảo Marshall",
    "North Macedonia" : "Bắc Macedonia",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mông Cổ",
    "Macao" : "Ma Cao",
    "Northern Mariana Islands" : "Quần đảo Bắc Mariana",
    "Martinique" : "Martinique",
    "Mauritania" : "Mauritania",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Maldives",
    "Malawi" : "Malawi",
    "Mexico" : "Mexico",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mozambique",
    "Namibia" : "Namibia",
    "New Caledonia" : "New Caledonia",
    "Niger" : "Niger",
    "Norfolk Island" : "Đảo Norfolk",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Hà Lan",
    "Norway" : "Na Uy",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "New Zealand",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Polynesia thuộc Pháp",
    "Papua New Guinea" : "Papua New Guinea",
    "Philippines" : "Philippines",
    "Pakistan" : "Pakistan",
    "Poland" : "Ba Lan",
    "Saint Pierre and Miquelon" : "Saint Pierre và Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Palestine, State of" : "Palestine",
    "Portugal" : "Bồ Đào Nha",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Réunion" : "Réunion",
    "Romania" : "Romania",
    "Serbia" : "Serbia",
    "Russian Federation" : "Nga",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Ả Rập Xê Út",
    "Solomon Islands" : "Quần đảo Solomon",
    "Seychelles" : "Seychelles",
    "Sudan" : "Sudan",
    "Sweden" : "Thụy Điển",
    "Singapore" : "Singapore",
    "Saint Helena, Ascension and Tristan da Cunha" : "Saint Helena, Ascension và Tristan da Cunha",
    "Slovenia" : "Slovenia",
    "Svalbard and Jan Mayen" : "Svalbard và Jan Mayen",
    "Slovakia" : "Slovakia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Suriname",
    "South Sudan" : "Nam Sudan",
    "Sao Tome and Principe" : "Sao Tome và Principe",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "Sint Maarten (phần thuộc Hà Lan)",
    "Syrian Arab Republic" : "Cộng hòa Ả Rập Syria",
    "Turks and Caicos Islands" : "Quần đảo Turks và Caicos",
    "Chad" : "Chad",
    "French Southern Territories" : "Vùng đất phía Nam và châu Nam Cực thuộc Pháp",
    "Togo" : "Togo",
    "Thailand" : "Thái Lan",
    "Tajikistan" : "Tajikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Đông Timor",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisia",
    "Tonga" : "Tonga",
    "Turkey" : "Thổ Nhĩ Kỳ",
    "Trinidad and Tobago" : "Trinidad và Tobago",
    "Tuvalu" : "Tuvalu",
    "Tanzania, United Republic of" : "Tanzania",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Các đảo nhỏ xa trung tâm Hoa Kỳ",
    "United States of America" : "Hoa Kỳ",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Tòa Thánh",
    "Saint Vincent and the Grenadines" : "Saint Vincent và Grenadines",
    "Viet Nam" : "Việt Nam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis và Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Yemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Nam Phi",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Federation" : "Kết nối Liên Bang ",
    "High-performance backend" : "Backend hiệu suất cao",
    "Error: Server did not respond with proper JSON" : "Lỗi: Máy chủ không phản hồi với JSON thích hợp",
    "Error: Server responded with: {error}" : "Lỗi: Máy chủ phản hồi: {error}",
    "Error: Unknown error occurred" : "Lỗi: Đã xảy ra lỗi không xác định",
    "SIP configuration" : "Cấu hình SIP",
    "Invalid date, date format must be YYYY-MM-DD" : "Định dạng ngày không hợp lệ phải là YYYY-MM-DD",
    "Conversation not found" : "Không tìm thấy cuộc hội thoại",
    "Chat, video & audio-conferencing using WebRTC" : "Trò chuyện, hội thảo âm thanh và video bằng WebRTC",
    "Leave call" : "Rời khỏi cuộc gọi",
    "Navigating away from the page will leave the call in {conversation}" : "Điều hướng khỏi trang sẽ rời khỏi cuộc gọi trong {cuộc trò chuyện}",
    "Stay in call" : "Giữ cuộc gọi",
    "Discuss this file" : "Thảo luận về tệp này",
    "Share this file with others to discuss it" : "Chia sẻ tệp này với những người khác để thảo luận về nó",
    "Share this file" : "Chia sẻ tệp này",
    "Join conversation" : "Tham gia cuộc trò chuyện",
    "The password is wrong. Try again." : "Sai mật khẩu. Thử lại.",
    "Password" : "Mật khẩu",
    "Submit" : "Gửi đi",
    "Error requesting the password." : "Lỗi khi đang yêu cầu mật khẩu.",
    "Request password" : "Yêu cầu mật khẩu",
    "This conversation has ended" : "Cuộc trò chuyện này đã kết thúc",
    "Everyone" : "Tất cả mọi người",
    "Users and moderators" : "Người dùng và người kiểm duyệt",
    "Moderators only" : "Chỉ người kiểm duyệt",
    "Save changes" : "Lưu thay đổi",
    "Saving …" : "Đang lưu ...",
    "Saved!" : "Đã lưu!",
    "Limit to groups" : "Giới hạn nhóm",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Khi ít nhất một nhóm được chọn, chỉ những người thuộc các nhóm được liệt kê mới có thể tham gia cuộc trò chuyện.",
    "Guests can still join public conversations." : "Khách vẫn có thể tham gia những cuộc trò chuyện công khai",
    "Limit using Talk" : "Hạn chế sử dụng Talk",
    "Limit creating a public and group conversation" : "Hạn chế tạo cuộc trò chuyện công khai và nhóm",
    "Limit creating conversations" : "Hạn chế tạo cuộc trò chuyện",
    "Limit starting a call" : "Hạn chế bắt đầu cuộc gọi",
    "Limit starting calls" : "Hạn chế bắt đầu cuộc gọi",
    "When a call has started, everyone with access to the conversation can join the call." : "Khi cuộc gọi bắt đầu, mọi người có quyền truy cập vào cuộc trò chuyện đều có thể tham gia cuộc gọi.",
    "Enabled" : "Đá kích hoạt",
    "Disabled" : "Tắt",
    "State" : "Trạng thái",
    "Name" : "Tên",
    "All messages" : "Tất cả tin nhắn",
    "Off" : "Tắt",
    "General settings" : "Cài đặt chung",
    "Default notification settings" : "Cài đặt thông báo mặc định",
    "Default group notification" : "Thông báo nhóm mặc định",
    "Default group notification for new groups" : "Thông báo nhóm mặc định cho các nhóm mới",
    "Integration into other apps" : "Tích hợp vào các ứng dụng khác",
    "Allow conversations on files" : "Cho phép các cuộc trò chuyện trên tệp",
    "Allow conversations on public shares for files" : "Cho phép các cuộc trò chuyện chia sẻ công khai đối với các tệp",
    "Enable encryption" : "Bật mã hóa",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "Bằng cách nhấp vào nút phía trên, thông tin trong biểu mẫu sẽ được gửi đến máy chủ của Struktur AG. Bạn có thể tìm thêm thông tin tại {linkstart} spreed.eu {linkend}.",
    "Pending" : "Đang dừng",
    "Error" : "Lỗi",
    "Blocked" : "Bị chặn",
    "Active" : "Hoạt động",
    "Expired" : "Đã hết hạn",
    "Never" : "Không bao giờ",
    "The trial could not be requested. Please try again later." : "Không thể yêu cầu thử nghiệm. Vui lòng thử lại sau.",
    "The account could not be deleted. Please try again later." : "Không thể xóa tài khoản. Vui lòng thử lại sau.",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Đối tác Struktur AG của chúng tôi cung cấp một dịch vụ mà một máy chủ báo hiệu được lưu trữ có thể được yêu cầu. Đối với điều này, bạn chỉ cần điền vào biểu mẫu bên dưới và vWorkspace của bạn sẽ yêu cầu nó. Sau khi máy chủ được thiết lập cho bạn, thông tin đăng nhập sẽ tự động được điền. Điều này sẽ ghi đè cài đặt máy chủ báo hiệu hiện có.",
    "URL of this Nextcloud instance" : "URL của phiên bản vWorkspace này",
    "Full name of the user requesting the trial" : "Tên đầy đủ của người dùng yêu cầu bản dùng thử",
    "Language" : "Ngôn ngữ",
    "Country" : "Quốc gia",
    "Request signaling server trial" : "Yêu cầu dùng thử máy chủ báo hiệu",
    "You can see the current status of your hosted signaling server in the following table." : "Bạn có thể xem trạng thái hiện tại của máy chủ báo hiệu trong bảng sau.",
    "Status" : "Trạng thái",
    "Created at" : "Được tạo ra vào lúc",
    "Expires at" : "Hết hạn vào",
    "Limits" : "Giới hạn",
    "Yes" : "Có",
    "No" : "Không",
    "Delete the signaling server account" : "Xóa tài khoản máy chủ báo hiệu",
    "_%n user_::_%n users_" : ["%n người dùng"],
    "Installed version: {version}" : "Phiên bản đã cài đặt: {version}",
    "Matterbridge binary was not found or couldn't be executed." : "Nhị phân Matterbridge không được tìm thấy hoặc không thể được thực thi",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Bạn cũng có thể đặt đường dẫn đến nhị phân Matterbridge theo cách thủ công thông qua cấu hình. Kiểm tra {linkstart} tài liệu tích hợp Matterbridge {linkend} để biết thêm thông tin.",
    "Downloading …" : "Đang tải ...",
    "Install Talk Matterbridge" : "Cài đặt Talk Matterbridge",
    "Failed to execute Matterbridge binary." : "Không thực thi được mã nhị phân Matterbridge.",
    "Matterbridge integration" : "Tích hợp Matterbridge ",
    "Enable Matterbridge integration" : "Bật tích hợp Matterbridge",
    "Status: Checking connection" : "Trạng thái: Đang kiểm tra kết nối",
    "OK: Running version: {version}" : "OK: Phiên bản đang chạy: {version}",
    "Validate SSL certificate" : "Xác thực chứng chỉ SSL",
    "Delete this server" : "Xóa máy chủ này",
    "Test this server" : "Kiểm tra máy chủ này",
    "Shared secret" : "Chia sẽ mật khẩu",
    "Restrict SIP configuration" : "Hạn chế cấu hình SIP",
    "Enable SIP configuration" : "Bật cấu hình SIP",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Chỉ những người dùng thuộc các nhóm sau mới có thể bật SIP trong các cuộc trò chuyện mà họ kiểm duyệt",
    "Phone number (Country)" : "Số điện thoại (Quốc gia)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Thông tin này được gửi trong thư điện tử mời cũng như hiển thị trong thanh bên cho tất cả những người tham gia.",
    "High-performance backend URL" : "URL backend hiệu suất cao",
    "STUN server URL" : "URL máy chủ STUN",
    "STUN servers" : "Máy chủ STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Máy chủ STUN được sử dụng để xác định địa chỉ IP công khai của người tham gia phía sau bộ định tuyến.",
    "{schema} scheme must be used with a domain" : "Lược đồ {schema} phải được sử dụng với một miền",
    "{option1} and {option2}" : "{option1} và {option2}",
    "{option} only" : "Chỉ {option}",
    "OK: Successful ICE candidates returned by the TURN server" : "OK: Các ứng viên ICE thành công do máy chủ TURN trả về",
    "Error: No working ICE candidates returned by the TURN server" : "Lỗi: Không có ứng cử viên ICE nào đang hoạt động được máy chủ TURN trả về",
    "Testing whether the TURN server returns ICE candidates" : "Kiểm tra xem máy chủ TURN có trả về các ứng viên ICE hay không",
    "TURN server schemes" : "Lược đồ máy chủ TURN",
    "TURN server URL" : "URL máy chủ TURN",
    "TURN server secret" : "Bảo mật máy chủ TURN",
    "TURN server protocols" : "Giao thức máy chủ TURN",
    "TURN servers" : "Máy chủ TURN",
    "OK" : "OK",
    "Federated user" : "Người dùng được liên kết",
    "Confirm" : "Xác nhận",
    "Reset" : "Đặt lại",
    "Cancel" : "Hủy",
    "Back" : "Quay lại",
    "Add participant \"{user}\"" : "Thêm người tham gia \"{user}\"",
    "Loading …" : "Đang tải …",
    "From" : "Từ",
    "To" : "Tới",
    "Calendar" : "Lịch",
    "Attendees" : "Người tham gia",
    "Save" : "Lưu",
    "Search participants" : "Tìm kiếm người tham gia",
    "No results" : "Không có kết quả",
    "Done" : "Hoàn thành",
    "Raise hand" : "Giơ tay",
    "Lower hand" : "Đặt tay xuống",
    "Speaker view" : "Chế độ xem người gọi điện",
    "Grid view" : "Xem dạng Lưới",
    "This conversation is read-only" : "Cuộc trò chuyện này ở chế độ chỉ đọc",
    "Reload" : "Tải lại",
    "{nickName} raised their hand." : "{nickName} giơ tay.",
    "A participant raised their hand." : "Một người tham gia giơ tay.",
    "Collapse stripe" : "Thu gọi sọc",
    "Expand stripe" : "Mở rộng sọc",
    "Previous page of videos" : "Trang trước của video",
    "Next page of videos" : "Trang tiếp theo của video",
    "Connecting …" : "Đang kết nối …",
    "Waiting for others to join the call …" : "Đang chờ người khác tham gia cuộc gọi…",
    "You can invite others in the participant tab of the sidebar" : "Bạn có thể mời những người khác trong tab người tham gia của thanh bên",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Bạn có thể mời những người khác trong tab người tham gia của thanh bên hoặc chia sẻ liên kết này để mời những người khác!",
    "Share this link to invite others!" : "Chia sẻ liên kết này để mời những người khác!",
    "Copy link" : "Sao chép liên kết",
    "Mute audio" : "Tắt âm thanh",
    "Unmute audio" : "Bật âm thanh",
    "None" : "Không có",
    "Access to camera was denied" : "Quyền truy cập vào máy ảnh đã bị từ chối",
    "Error while accessing camera" : "Lỗi khi truy cập máy ảnh",
    "You have been muted by a moderator" : "Bạn đã bị người kiểm duyệt tắt tiếng",
    "Disable video" : "Tắt Video",
    "Enable video" : "Bật Video",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Bật video. Kết nối của bạn sẽ bị gián đoạn trong thời gian ngắn khi bật video lần đầu tiên",
    "You" : "Bạn",
    "Mute" : "Tắt tiếng",
    "Show screen" : "Hiện màn hình",
    "Stop following" : "Ngừng theo dõi",
    "Collapse" : "Thu gọn",
    "Expand" : "Mở rộng",
    "You need to be logged in to upload files" : "Bạn cần đăng nhập để tải tệp lên",
    "Drop your files to upload" : "Thả tệp của bạn để tải lên",
    "Conversation messages" : "Tin nhắn đàm thoại",
    "Scroll to bottom" : "Cuộn xuống dưới cùng",
    "Post message" : "Đăng tin nhắn",
    "Favorite" : "Ưa thích",
    "Date:" : "Ngày:",
    "Hide details" : "Ẩn chi tiết",
    "Show details" : "Hiển thị chi tiết",
    "Error while updating conversation description" : "Lỗi khi cập nhật mô tả cuộc trò chuyện",
    "Edit conversation description" : "Chỉnh sửa mô tả cuộc trò chuyện",
    "Disable" : "Tắt",
    "Enable" : "Bật",
    "Choose" : "Chọn",
    "The file must be a PNG or JPG" : "Tệp phải là PNG hoặc JPG",
    "Restricted" : "Bị giới hạn",
    "Conversation settings" : "Cài đặt cuộc trò chuyện",
    "Personal" : "Cá nhân",
    "Danger zone" : "Khu vực nguy hiểm",
    "Leave conversation" : "Rời khỏi cuộc đàm thoại",
    "Delete conversation" : "Xóa cuộc trò chuyện",
    "Do you really want to delete \"{displayName}\"?" : "Bạn có thực sự muốn xóa \"{displayName}\" không?",
    "Error while deleting conversation" : "Lỗi khi xóa cuộc trò chuyện",
    "Be careful, these actions cannot be undone." : "Hãy cẩn thận, không thể hoàn tác những hành động này.",
    "Password protection" : "Password protection",
    "Set a password" : "Đặt mật khẩu",
    "Save password" : "Lưu mật khẩu",
    "Resend invitations" : "Gửi lại lời mời",
    "Error occurred when opening or limiting the conversation" : "Đã xảy ra lỗi khi mở hoặc giới hạn cuộc trò chuyện",
    "Start time has been updated" : "Thời gian bắt đầu đã được cập nhật",
    "Error occurred while updating start time" : "Đã xảy ra lỗi khi cập nhật thời gian bắt đầu",
    "Meeting start time" : "Thời gian bắt đầu cuộc họp",
    "Start time (optional)" : "Thời gian bắt đầu (tùy chọn)",
    "Error occurred when locking the conversation" : "Đã xảy ra lỗi khi khóa cuộc trò chuyện",
    "Error occurred when unlocking the conversation" : "Đã xảy ra lỗi khi mở khóa cuộc trò chuyện",
    "Lock conversation" : "Khóa cuộc trò chuyện",
    "This will also terminate the ongoing call." : "Điều này cũng sẽ kết thúc cuộc gọi đang diễn ra.",
    "Edit" : "Chỉnh sửa",
    "More information" : "Thêm thông tin",
    "Delete" : "Xóa",
    "Add new bridged channel to current conversation" : "Thêm kênh bắc cầu mới vào cuộc trò chuyện hiện tại",
    "unknown state" : "trạng thái không xác định",
    "running" : "đang chạy",
    "not running, check Matterbridge log" : "không chạy, kiểm tra nhật kí Matterbridge",
    "not running" : "không chạy",
    "Bridge saved" : "Cầu nối đã được lưu",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Bạn có thể kết nối các kênh từ các hệ thống nhắn tin tức thời khác nhau với Matterbridge.",
    "More info on Matterbridge" : "Thông tin thêm về Matterbridge",
    "Enable bridge" : "Bật cầu nối",
    "Show Matterbridge log" : "Hiển thị nhật kí Matterbridge",
    "Notifications" : "Thông báo",
    "SIP dial-in is now enabled" : "Quay số SIP hiện đã được bật",
    "SIP dial-in is now disabled" : "Tính năng quay số SIP hiện đã bị tắt",
    "Error occurred when enabling SIP dial-in" : "Đã xảy ra lỗi khi bật quay số SIP",
    "Error occurred when disabling SIP dial-in" : "Đã xảy ra lỗi khi tắt quay số SIP",
    "Join" : "Tham gia",
    "Error while creating the conversation" : "Lỗi khi tạo cuộc trò chuyện",
    "Create conversation" : "Tạo cuộc trò chuyện",
    "Log in" : "Đăng nhập",
    "Mark as read" : "Đánh dấu đã đọc",
    "Mark as unread" : "Đánh dấu là chưa đọc",
    "Remove from favorites" : "Xóa khỏi ưa thích",
    "Add to favorites" : "Thêm vào ưa thích",
    "You need to promote a new moderator before you can leave the conversation." : "Bạn cần chọn người kiểm duyệt mới trước khi có thể rời khỏi cuộc trò chuyện.",
    "Conversation actions" : "Hoạt động cuộc trò chuyện",
    "Home" : "Trang nhà",
    "Alphabetically" : "Theo bảng chữ cái",
    "No conversations found" : "Không tìm thấy cuộc trò chuyện nào",
    "An error occurred while performing the search" : "Đã xảy ra lỗi khi thực hiện tìm kiếm",
    "Conversation list" : "Danh sách cuộc trò chuyện",
    "Unread messages" : "Tin nhắn chưa đọc",
    "Clear filter" : "Xóa bộ lọc",
    "Users" : "Người dùng",
    "Groups" : "Nhóm",
    "Other sources" : "Những nguồn khác",
    "Open conversations" : "Mở cuộc trò chuyện",
    "No search results" : "Không có kết quả tìm kiếm",
    "Users and groups" : "Người dùng và nhóm",
    "You are currently waiting in the lobby" : "Bạn hiện đang đợi ở sảnh đợi",
    "Select microphone" : "Chọn micrô",
    "No microphone available" : "Không có micrô",
    "Select camera" : "Chọn camera",
    "No camera available" : "Không có camera khả dụng",
    "No audio" : "Không có âm thanh",
    "No camera" : "Không có máy ảnh",
    "Calls are not supported in your browser" : "Cuộc gọi không được hỗ trợ trong trình duyệt của bạn",
    "Access to microphone is only possible with HTTPS" : "Chỉ có thể truy cập vào micrô với HTTPS",
    "Access to microphone was denied" : "Quyền truy cập vào micrô đã bị từ chối",
    "Error while accessing microphone" : "Lỗi khi truy cập micrô",
    "Access to camera is only possible with HTTPS" : "Chỉ có thể truy cập vào camera với HTTPS",
    "Invalid path selected" : "Đường dẫn đã chọn không hợp lệ",
    "Upload" : "Tải lên",
    "Files" : "Tệp",
    "24 hours" : "24 tiếng",
    "Reply" : "Trả l",
    "More actions" : "Nhiều hành động hơn",
    "Set reminder" : "Thiết lập nhắc nhở",
    "Reply privately" : "Trả lời riêng tư",
    "Copy message link" : "Sao chép liên kết tin nhắn",
    "Go to file" : "Tới tập tin",
    "Translate" : "Dịch",
    "Dismiss" : "Bỏ qua",
    "Message read by everyone who shares their reading status" : "Tin nhắn được đọc bởi tất cả những người chia sẻ trạng thái đọc của họ",
    "Message sent" : "Tin nhắn đã gửi",
    "Deleting message" : "Đang xóa tin nhắn",
    "Message deleted successfully" : "Đã xóa tin nhắn thành công",
    "Message could not be deleted because it is too old" : "Không thể xóa tin nhắn vì nó quá cũ",
    "Only normal chat messages can be deleted" : "Chỉ những tin nhắn trò chuyện bình thường mới có thể bị xóa",
    "An error occurred while deleting the message" : "Đã xảy ra lỗi khi xóa tin nhắn",
    "Contact" : "Liên hệ",
    "{stack} in {board}" : "{stack} trong {board}",
    "Deck Card" : "Thẻ bài",
    "Sending message" : "Đang gửi tin nhắn",
    "Failed to send the message. Click to try again" : "Không gửi được tin nhắn. Bấm để thử lại",
    "Not enough free space to upload file" : "Không đủ dung lượng trống để tải tệp lên",
    "No messages" : "Không có tin nhắn",
    "Create a new group conversation" : "Tạo một cuộc trò chuyện nhóm mới",
    "Add participants" : "Thêm người tham gia",
    "Allow guests to join via link" : "Cho phép khách tham gia qua liên kết",
    "This conversation has been locked" : "Cuộc trò chuyện này đã bị khóa",
    "No permission to post messages in this conversation" : "Không có quyền đăng tin nhắn trong cuộc trò chuyện này",
    "Joining conversation …" : "Tham gia cuộc trò chuyện …",
    "Send message" : "Gửi thông điệp",
    "File to share" : "Tệp để chia sẻ",
    "Add emoji" : "Thêm biểu tượng cảm xúc",
    "Share from Files" : "Chia sẻ từ Thư mục",
    "Share files to the conversation" : "Chia sẻ tệp với cuộc trò chuyện",
    "New file" : "Tập tin mới",
    "Blank" : "‎Trống‎",
    "Add more files" : "Thêm nhiều tập tin",
    "Send" : "Gửi",
    "Settings" : "Thiết lập",
    "Results" : "Kết quả",
    "Disable lobby" : "Vô hiệu hóa sảnh đợi",
    "Settings for participant \"{user}\"" : "Cài đặt cho người tham gia \"{user}\"",
    "Participant \"{user}\"" : "Người tham gia \"{user}\"",
    "moderator" : "Người kiểm duyệt",
    "guest" : "khách",
    "Raised their hand" : "Giơ tay của họ",
    "Joined with video" : "Đã tham gia qua video",
    "Joined via phone" : "Đã tham gia qua điện thoại",
    "Joined with audio" : "Đã tham gia qua audio",
    "Remove participant" : "Xóa người tham gia",
    "Dial-in PIN" : "Mã PIN quay số",
    "Demote from moderator" : "Hạ uy tín từ người kiểm duyệt",
    "Promote to moderator" : "Giới thiệu người kiểm duyệt",
    "Resend invitation" : "Gửi lại lời mời",
    "Remove" : "Xoá",
    "Add users or groups" : "Add users or groups",
    "Add users" : "Thêm người dùng",
    "Add groups" : "Thêm nhóm",
    "Add other sources" : "Thêm các nguồn khác",
    "Add emails" : "Thêm email",
    "Integrations" : "Các bộ tích hợp",
    "Searching …" : "Đang tìm kiếm ...",
    "Search for more users" : "Tìm kiếm thêm người dùng",
    "Search or add participants" : "Tìm kiếm hoặc thêm người dùng",
    "An error occurred while adding the participants" : "Đã xảy ra lỗi khi thêm người tham gia",
    "Participants" : "Người tham gia",
    "Chat" : "Trò chuyện",
    "Details" : "Chi tiết",
    "No results found" : "Không tìm thấy kết quả",
    "Load more results" : "Tải thêm kết quả",
    "Projects" : "Dự án",
    "Link to a conversation" : "Liên kết đến một cuộc trò chuyện",
    "Search conversations or users" : "Tìm kiếm cuộc trò chuyện hoặc người dùng",
    "Select conversation" : "Chọn cuộc trò chuyện",
    "Edit display name" : "Chỉnh sửa tên hiển thị",
    "Notification settings" : "Cài đặt thông báo",
    "Default language" : "Ngôn ngữ mặc định",
    "Select location for attachments" : "Chọn vị trí cho tệp đính kèm",
    "Error while setting attachment folder" : "Lỗi khi cấu hình thư mục tệp đính kèm",
    "Error while setting read status privacy" : "Lỗi khi đặt quyền riêng tư của trạng thái đã đọc",
    "Privacy" : "Bảo mật",
    "Attachments folder" : "Thư mục đính kèm",
    "Search" : "Tìm",
    "Focus the chat input" : "Tập trung vào đầu vào trò chuyện",
    "Unfocus the chat input to use shortcuts" : "Bỏ tập trung vào đầu vào trò chuyện để sử dụng các phím tắt",
    "Shortcuts while in a call" : "Các phím tắt khi đang gọi điện",
    "Microphone on and off" : "Bật và tắt micrô",
    "Raise or lower hand" : "Giơ tay hoặc hạ tay",
    "Push to talk or push to mute" : "Nhấn để nói hoặc tắt tiếng",
    "Start call" : "Bắt đầu cuộc gọi",
    "You will be able to join the call only after a moderator starts it." : "Bạn sẽ chỉ có thể tham gia cuộc gọi sau khi người kiểm duyệt bắt đầu cuộc gọi.",
    "Screensharing options" : "Tùy chọn chia sẻ màn hình",
    "Enable screensharing" : "Bật chia sẽ màn hình",
    "Bad sent video and screen quality." : "Chất lượng màn hình và video đã gửi kém.",
    "Bad sent screen quality." : "Chất lượng màn hình đã gửi kém.",
    "Bad sent video quality." : "Chất lượng video đã gửi kém.",
    "Bad sent audio, video and screen quality." : "Chất lượng âm thanh, video và màn hình được gửi kém.",
    "Bad sent audio and screen quality." : "Chất lượng âm thanh và màn hình đã gửi kém.",
    "Bad sent audio and video quality." : "Chất lượng âm thanh và video được gửi kém.",
    "Bad sent audio quality." : "Chất lượng âm thanh đã gửi kém.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Kết nối internet hoặc máy tính của bạn đang bận và những người tham gia khác có thể không nhìn thấy màn hình của bạn.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Kết nối internet hoặc máy tính của bạn đang bận và những người tham gia khác có thể không nhìn thấy bạn.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Kết nối internet hoặc máy tính của bạn đang bận và những người tham gia khác có thể không hiểu và nhìn thấy bạn. Để cải thiện tình hình, hãy thử tắt video của bạn trong khi thực hiện chia sẻ màn hình.",
    "Disable screenshare" : "Tắt chia sẻ màn hình",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Kết nối internet hoặc máy tính của bạn đang bận và những người tham gia khác có thể không hiểu và nhìn thấy bạn. Để cải thiện tình hình, hãy thử tắt video của bạn.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Kết nối internet hoặc máy tính của bạn đang bận và những người tham gia khác có thể không hiểu bạn.",
    "Screen sharing is not supported by your browser." : "Chia sẻ màn hình không được trình duyệt của bạn hỗ trợ.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Chia sẻ màn hình yêu cầu trang được tải qua HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "Chia sẻ màn hình yêu cầu trang phải tải qua HTTPS.",
    "An error occurred while starting screensharing." : "Đã xảy ra lỗi khi bắt đầu chia sẻ màn hình.",
    "Show your screen" : "Hiện màn hình của bạn",
    "Stop screensharing" : "Ngừng chia sẽ màn hình",
    "Mute others" : "Tắt tiếng người khác",
    "Keep" : "Giữ",
    "Select a region" : "Chọn một khu vực",
    "Message without mention" : "Tin nhắn không đề cập",
    "Mention myself" : "Nhắc đến chính mình",
    "The conversation does not exist" : "Cuộc trò chuyện không tồn tại",
    "Join a conversation or start a new one!" : "Tham gia một cuộc trò chuyện hoặc bắt đầu một cuộc trò chuyện mới!",
    "Duplicate session" : "Phiên trùng lặp",
    "Join a conversation or start a new one" : "Tham gia cuộc trò chuyện hoặc bắt đầu một cuộc trò chuyện mới",
    "Nextcloud URL" : "vWorkspace URL",
    "Nextcloud user" : "Người dùng vWorkspace",
    "User password" : "Mật khẩu người dùng",
    "Talk conversation" : "Nói chuyện",
    "Skip TLS verification" : "Bỏ qua xác minh TLS",
    "Matrix server URL" : "URL máy chủ ma trận",
    "User" : "Người dùng",
    "Matrix channel" : "Kênh ma trận",
    "Mattermost server URL" : "URL máy chủ Mattermost",
    "Mattermost user" : "Người dùng Mattermost",
    "Team name" : "Tên nhóm",
    "Channel name" : "Tên kênh",
    "Rocket.Chat server URL" : "URL máy chủ Rocket.Chat",
    "Rocket.Chat channel" : "Kênh Rocket.Chat",
    "Zulip server URL" : "URL máy chủ Zulip",
    "Bot user name" : "Tên người dùng bot",
    "Bot API key" : "Khóa API bot",
    "Zulip channel" : "Kênh Zulip",
    "API token" : "Tín chỉ API",
    "Slack channel" : "Kênh Slack",
    "Server ID or name" : "ID hoặc tên máy chủ",
    "Channel" : "Kênh",
    "Login" : "Login",
    "Chat ID" : "ID trò chuyện",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "URL máy chủ IRC (ví dụ: chat.freenode.net:6667)",
    "Nickname" : "Biệt danh",
    "Connection password" : "Mật khẩu kết nối",
    "IRC channel" : "Kênh IRC",
    "Channel password" : "Kênh mật khẩu",
    "NickServ nickname" : "Biệt hiệu NickServ",
    "NickServ password" : "Mật khẩu NickServ",
    "Use TLS" : "Sử dụng TLS",
    "Use SASL" : "Sử dụng SASL",
    "Tenant ID" : "ID người thuê",
    "Client ID" : "ID khách hàng",
    "Team ID" : "ID nhóm",
    "Thread ID" : "ID chủ đề",
    "XMPP/Jabber server URL" : "URL máy chủ XMPP/Jabber",
    "MUC server URL" : "URL máy chủ MUC",
    "Jabber ID" : "Mã Jabber",
    "Media" : "Phương tiện",
    "Locations" : "Các địa điểm",
    "Audio" : "Âm thanh",
    "Show all files" : "Hiện tất cả tệp",
    "Group" : "Nhóm",
    "Team" : "Đội",
    "You: {lastMessage}" : "Bạn: {lastMessage}",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Bạn đang cố gắng tham gia một cuộc trò chuyện trong khi có một phiên hoạt động trong một cửa sổ hoặc thiết bị khác. Điều này hiện không được vWorkspace Talk hỗ trợ. Bạn muốn làm gì?",
    "Leave this page" : "Rời khỏi trang này",
    "Join here" : "Tham gia tại đây",
    "Post to a conversation" : "Đăng lên một cuộc trò chuyện",
    "Post to conversation" : "Đăng lên cuộc trò chuyện",
    "Error occurred while allowing guests" : "Đã xảy ra lỗi khi cho phép khách",
    "Error occurred while disallowing guests" : "Đã xảy ra lỗi khi không cho phép khách",
    "Error occurred when restricting the conversation to moderator" : "Đã xảy ra lỗi khi giới hạn cuộc trò chuyện với người kiểm duyệt",
    "Error occurred when opening the conversation to everyone" : "Đã xảy ra lỗi khi mở cuộc trò chuyện với mọi người",
    "Conversation password has been saved" : "Mật khẩu cuộc trò chuyện đã được lưu",
    "Conversation password has been removed" : "Mật khẩu cuộc trò chuyện đã bị xóa",
    "Error occurred while saving conversation password" : "Đã xảy ra lỗi khi lưu mật khẩu cuộc trò chuyện",
    "Could not post message: {errorMessage}" : "Không thể đăng thông báo: {errorMessage}",
    "An error occurred while fetching the participants" : "Đã xảy ra lỗi khi tìm nạp những người tham gia",
    "Could not send invitation to {actorId}" : "Không thể gửi lời mời đến {actorId}",
    "Invitations sent" : "Lời mời đã được gửi",
    "Error occurred when sending invitations" : "Đã xảy ra lỗi khi gửi lời mời",
    "Error while uploading file \"{fileName}\"" : "Lỗi khi tải lên tệp \"{fileName}\"",
    "Not enough free space to upload file \"{fileName}\"" : "Không đủ dung lượng trống để tải lên tệp \"{fileName}\"",
    "Error while sharing file" : "Lỗi khi chia sẻ tệp",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Trình duyệt bạn đang sử dụng không được vWorkspace Talk hỗ trợ đầy đủ. Vui lòng sử dụng phiên bản mới nhất của Mozilla Firefox, Microsoft Edge, Google Chrome, Opera hoặc Apple Safari.",
    "Later today – {timeLocale}" : "Sau này - {timeLocale}",
    "Tomorrow – {timeLocale}" : "Ngày mai - {timeLocale}",
    "This weekend – {timeLocale}" : "Cuối tuần này - {timeLocale}",
    "Next week – {timeLocale}" : "Tuần sau - {timeLocale}",
    "Lost connection to signaling server. Trying to reconnect." : "Mất kết nối với máy chủ báo hiệu. Đang cố gắng kết nối lại.",
    "Please reload the page." : "Vui lòng tải lại trang.",
    "Do not disturb" : "Đừng làm phiền",
    "Away" : "Tạm vắng",
    "Microphone {number}" : "Micrô {number}",
    "Camera {number}" : "Máy ảnh {number}",
    "Speaker {number}" : "Người nói {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Có vẻ như bạn đang nói chuyện khi bị tắt tiếng, vui lòng tự bật tiếng để người khác nghe thấy bạn",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Không thể thiết lập kết nối với ít nhất một người tham gia. Máy chủ TURN có thể cần thiết cho tình huống của bạn. Vui lòng yêu cầu quản trị viên của bạn thiết lập một tài liệu sau {linkstart} tài liệu này {linkend}.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Quá trình này mất nhiều thời gian hơn dự kiến. Các quyền phương tiện đã được cấp (hoặc bị từ chối)? Nếu có, vui lòng khởi động lại trình duyệt của bạn, vì âm thanh và video không thành công",
    "Access to microphone & camera is only possible with HTTPS" : "Chỉ có thể truy cập micrô và máy ảnh bằng HTTPS",
    "Please move your setup to HTTPS" : "Vui lòng di chuyển thiết lập của bạn sang HTTPS",
    "Access to microphone & camera was denied" : "Quyền truy cập vào micrô và máy ảnh đã bị từ chối",
    "WebRTC is not supported in your browser" : "WebRTC không được hỗ trợ trong trình duyệt của bạn",
    "Please use a different browser like Firefox or Chrome" : "Vui lòng sử dụng một trình duyệt khác như Firefox hoặc Chrome",
    "Error while accessing microphone & camera" : "Lỗi khi truy cập micrô và máy ảnh",
    "%s Talk on your mobile devices" : "%sNói chuyện trên thiết bị di động của bạn ",
    "Join conversations at any time, anywhere, on any device." : "Tham gia các cuộc trò chuyện mọi lúc, mọi nơi, trên mọi thiết bị.",
    "Android app" : "Ứng dụng Android",
    "iOS app" : "Ứng dụng IOS",
    "__language_name__" : "Tiếng Việt",
    "Tasks" : "Nhiệm vụ",
    "Notes" : "Ghi chú",
    "Your privacy setting has been saved" : "Các thiết lập quyền riêng tư của bạn đã được lưu",
    "Failed to save sounds setting" : "Không thể lưu cài đặt âm thanh",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Bạn đã tham gia cuộc trò chuyện trong một cửa sổ hoặc thiết bị khác. Điều này hiện không được vWorkspace Talk hỗ trợ nên phiên này đã bị đóng."
},
"nplurals=1; plural=0;");
