OC.L10N.register(
    "spreed",
    {
    "a conversation" : "سۆھبەت",
    "(Duration %s)" : "(ئۇزۇنلۇقى %s)",
    "You attended a call with {user1}" : "سىز {user1} بىلەن تېلېفونغا قاتناشتىڭىز",
    "_%n guest_::_%n guests_" : ["%n مىھمان","%n مىھمانلار"],
    "You attended a call with {user1} and {user2}" : "سىز {user1} ۋە {user2} بىلەن تېلېفونغا قاتناشتىڭىز",
    "You attended a call with {user1}, {user2} and {user3}" : "سىز {user1}, {user2} ۋە {user3} بىلەن تېلېفونغا قاتناشتىڭىز",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "سىز {user1}, {user2}, {user3} ۋە {user4} بىلەن تېلېفونغا قاتناشتىڭىز",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "سىز {user1}, {user2}, {user3}, {user4} ۋە {user5} بىلەن تېلېفونغا قاتناشتىڭىز.",
    "_%n other_::_%n others_" : ["%n باشقا","%n باشقىلار"],
    "{actor} invited you to {call}" : "{actor} سىزنى {call} تەكلىپ قىلدى",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "سىز <strong> سۆھبەت </strong> گە تەكلىپ قىلىنغان ياكى <strong> تېلېفون </strong> بولغان",
    "Other activities" : "باشقا پائالىيەتلەر",
    "Talk" : "پاراڭ",
    "Guest" : "مېھمان",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Nextcloud سۆھبىتىگە خۇش كەپسىز!\nبۇ سۆھبەتتە سىزگە Nextcloud Talk دىكى يېڭى ئىقتىدارلار ھەققىدە ئۇچۇر بېرىلىدۇ.",
    "## New in Talk %s" : "## پاراڭ %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge ۋە Safari ھازىر ئاۋازلىق ۋە سىنلىق سۆزلىشىشكە قاتناشقىلى بولىدۇ",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- بىرمۇبىر سۆھبەت ھازىر داۋاملىشىۋاتىدۇ ، ئەمدى تاسادىپىي ھالدا گۇرۇپپا پاراڭلىرىغا ئايلاندۇرغىلى بولمايدۇ. يەنە قاتناشقۇچىلاردىن بىرى سۆھبەتتىن ئايرىلغاندا ، سۆھبەت ئەمدى ئاپتوماتىك ئۆچۈرۈلمەيدۇ. ھەر ئىككى قاتناشقۇچى ئايرىلسىلا ، سۆھبەت مۇلازىمېتىردىن ئۆچۈرۈلىدۇ",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- ھازىر پاراڭغا «@all» نى يوللاش ئارقىلىق بارلىق قاتناشقۇچىلارغا خەۋەر قىلالايسىز",
    "- With the \"arrow-up\" key you can repost your last message" : "- «يا ئوق» كۇنۇپكىسى ئارقىلىق ئاخىرقى ئۇچۇرىڭىزنى قايتا يوللىيالايسىز",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- سۆھبەتتە ھازىر بۇيرۇقلار بولىدۇ ، «/ ياردەم» نى پاراڭلىشىش ئۇچۇرى قىلىپ ئەۋەتىپ ، باشقۇرغۇچىڭىزنىڭ بەزىلىرىنى تەڭشىگەن-تەڭشىمىگەنلىكىنى كۆرۈڭ",
    "- With projects you can create quick links between conversations, files and other items" : "- تۈرلەر ئارقىلىق سۆھبەت ، ھۆججەت ۋە باشقا تۈرلەر ئارىسىدا تېز ئۇلىنىش ھاسىل قىلالايسىز",
    "- You can now mention guests in the chat" : "- ھازىر پاراڭدىكى مېھمانلارنى تىلغا ئالالايسىز",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- سۆھبەتتە ھازىر بىر لوبىخانا بولالايدۇ. بۇ رىياسەتچىلەرنىڭ سۆھبەتكە قاتنىشىشىغا ۋە تېلېفون قىلىپ يىغىننى تەييارلىشىغا يول قويىدۇ ، ئابونتلار ۋە مېھمانلار ساقلاشقا مەجبۇر بولىدۇ",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- سىز ھازىر باشقا ئىشلەتكۈچىلەرگە ئۇچۇرلىرىڭىزنىڭ مەزمۇنىنى تېخىمۇ كۆپ مەزمۇن بىلەن تەمىنلەيدىغان ئۇچۇرلارغا بىۋاسىتە جاۋاب قايتۇرالايسىز",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- سۆھبەت ۋە قاتناشقۇچىلارنى ئىزدەش ھازىر بار بولغان سۆھبەتلىرىڭىزنى سۈزۈپ ، ئىلگىرىكى سۆھبەتلەرنى تېپىشقا تېخىمۇ قولايلىق يارىتىدۇ",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- چەمبىرەك دېتالى قاچىلىغاندا ھازىر سۆھبەتكە ئىختىيارى ئىشلەتكۈچى گۇرۇپپىسىنى قوشالايسىز",
    "- Check out the new grid and call view" : "- يېڭى تور ۋە چاقىرىش كۆرۈنۈشىنى تەكشۈرۈپ بېقىڭ",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- ھازىر ھۆججەتلىرىڭىزنى ئۈسكۈنىڭىزدىن بىۋاسىتە پاراڭغا يۈكلىيەلەيسىز ۋە سۆرەلەيسىز",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- ئورتاق ھۆججەتلەر ھازىر كۆرۈرمەن ئەپلىرى بىلەن پاراڭلىشىش كۆرۈنۈشىنىڭ ئىچىدە بىۋاسىتە ئېچىلدى",
    "- You can now search for chats and messages in the unified search in the top bar" : "- سىز ھازىر ئۈستۈنكى بالداقتىكى بىرلىككە كەلگەن ئىزدەشتە پاراڭ ۋە ئۇچۇرلارنى ئىزدەيسىز",
    "- Spice up your messages with emojis from the emoji picker" : "- emoji تاللىغۇچتىن emojis بىلەن ئۇچۇرلىرىڭىزنى تېتىتقۇ",
    "- You can now change your camera and microphone while being in a call" : "- ھازىر تېلېفون قىلىۋاتقاندا كامېرا ۋە مىكروفونىڭىزنى ئۆزگەرتەلەيسىز",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- پاراڭلىرىڭىزغا بەزى مەزمۇنلارنى تەسۋىرلەپ بېرىڭ ھەمدە ئۇنى ئېچىڭ ، شۇنداق بولغاندا تىزىملاتقان ئابونتلار ئۇنى تاپالايدۇ ۋە ئۆزى قوشۇلالايدۇ",
    "- See a read status and send failed messages again" : "- ئوقۇش ھالىتىنى كۆرۈڭ ۋە مەغلۇپ بولغان ئۇچۇرلارنى قايتا ئەۋەتىڭ",
    "- Raise your hand in a call with the R key" : "- R كۇنۇپكىسى بىلەن تېلېفوندا قولىڭىزنى كۆتۈرۈڭ",
    "- Join the same conversation and call from multiple devices" : "- ئوخشاش سۆھبەتكە قاتنىشىڭ ۋە كۆپ ئۈسكۈنىدىن تېلېفون قىلىڭ",
    "- Send voice messages, share your location or contact details" : "- ئاۋازلىق ئۇچۇر ئەۋەتىڭ ، ئورنىڭىز ياكى ئالاقىلىشىش ئۇچۇرلىرىڭىزنى ئورتاقلىشىڭ",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- سۆھبەتكە گۇرۇپپا قوشۇڭ ، يېڭى گۇرۇپپا ئەزالىرى ئاپتوماتىك ھالدا قاتناشقۇچىلار سۈپىتىدە قوشۇلىدۇ",
    "- A preview of your audio and video is shown before joining a call" : "- تېلېفونغا كىرىشتىن بۇرۇن ئاۋازلىق ۋە سىننىڭ ئالدىن كۆرۈشى كۆرسىتىلىدۇ",
    "- You can now blur your background in the newly designed call view" : "- يېڭى لايىھەلەنگەن تېلېفون كۆرۈنۈشىدە ئارقا كۆرۈنۈشىڭىزنى خىرەلەشتۈرەلەيسىز",
    "- Moderators can now assign general and individual permissions to participants" : "- رىياسەتچىلەر ھازىر قاتناشقۇچىلارغا ئومۇمىي ۋە ئايرىم ئىجازەتلەرنى بېرەلەيدۇ",
    "- You can now react to chat messages" : "- ھازىر پاراڭلىشىش ئۇچۇرلىرىغا ئىنكاس قايتۇرالايسىز",
    "- In the sidebar you can now find an overview of the latest shared items" : "- يانبالداقتا سىز ئەڭ يېڭى ئورتاق بەھرىلىنىدىغان تۈرلەرنىڭ ئومۇمىي كۆرۈنۈشىنى تاپالايسىز",
    "- Use a poll to collect the opinions of others or settle on a date" : "- راي سىناش ئارقىلىق باشقىلارنىڭ پىكىرىنى توپلاڭ ياكى بىر كۈندە ھەل قىلىڭ",
    "- Configure an expiration time for chat messages" : "- پاراڭلىشىش ئۇچۇرلىرىنىڭ ۋاقتى توشىدۇ",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- چوڭ پاراڭلاردا باشقىلارغا خەۋەر قىلماي تېلېفون قىلىشنى باشلاڭ. تېلېفون باشلانغاندىن كېيىن ئايرىم تېلېفون ئۇقتۇرۇشى ئەۋەتەلەيسىز.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- جىددىي ئەھۋال بولمىسا تاپشۇرۇۋالغۇچىلارغا خەۋەر قىلماي پاراڭلىشىش ئۇچۇرلىرىنى ئەۋەتىڭ",
    "- Emojis can now be autocompleted by typing a \":\"" : "- Emojis ھازىر \":\" نى يېزىش ئارقىلىق ئاپتوماتىك تاماملىنىدۇ.",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- يېڭى ئەقلىي ئىقتىدارلىق تاللىغۇچ ئارقىلىق «/» نى يېزىش ئارقىلىق ھەر خىل تۈرلەرنى ئۇلاڭ",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- رىياسەتچىلەر ھازىر بۆسۈش ئۆيى قۇرالايدۇ (يۇقىرى ئىقتىدارلىق ئارقا كۆرۈنۈشنى تەلەپ قىلىدۇ)",
    "- Calls can now be recorded (requires the High-performance backend)" : "- تېلېفوننى ھازىر خاتىرىلىگىلى بولىدۇ (يۇقىرى ئىقتىدارلىق ئارقا كۆرۈنۈشنى تەلەپ قىلىدۇ)",
    "- Conversations can now have an avatar or emoji as icon" : "- سۆھبەت ھازىر سىنبەلگە سۈپىتىدە باش سۈرىتى ياكى emoji بولالايدۇ",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- مەۋھۇم تەگلىك ھازىر سىنلىق سۆزلىشىشتىكى قالايمىقان ئارقا كۆرۈنۈشتىن باشقا",
    "- Reactions are now available during calls" : "- ھازىر تېلېفون قىلىش جەريانىدا ئىنكاسلار بار",
    "- Typing indicators show which users are currently typing a message" : "- كىرگۈزۈش كۆرسەتكۈچلىرى قايسى ئابونتلارنىڭ ھازىر ئۇچۇر يېزىۋاتقانلىقىنى كۆرسىتىپ بېرىدۇ",
    "- Groups can now be mentioned in chats" : "- گۇرۇپپىلارنى ھازىر پاراڭلاردا تىلغا ئالغىلى بولىدۇ",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- ئەگەر ترانسكرىپسىيە تەمىنلىگۈچى دېتالى تىزىملاتسا ، تېلېفون خاتىرىلىرى ئاپتوماتىك كۆچۈرۈلىدۇ",
    "- Chat messages can be translated if a translation provider app is registered" : "- تەرجىمە تەمىنلىگۈچى ئەپ تىزىملاتقان بولسا پاراڭلىشىش ئۇچۇرلىرىنى تەرجىمە قىلىشقا بولىدۇ",
    "- **Markdown** can now be used in _chat_ messages" : "- ** Markdown ** نى _chat_ ئۇچۇرلىرىدا ئىشلىتىشكە بولىدۇ",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- Webhooks ھازىر bots نى يولغا قويالايدۇ. تېخىمۇ كۆپ ئۇچۇرغا ئېرىشمەكچى بولسىڭىز https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "- پاراڭلىشىش ئۇچۇرىغا ئەسكەرتىش ئورنىتىپ ، كېيىن ئۇقتۇرۇش قىلىنىدۇ",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- ** ئەسكەرتىش ئارقىلىق ئۆزىڭىزگە ** پاراڭ ئىشلىتىپ خاتىرە قالدۇرۇڭ ۋە ئۈسكۈنىڭىز ئارىسىدا ئۇچۇر ئورتاقلىشىڭ",
    "- Captions allow to send a message with a file at the same time" : "- خەتلەر بىرلا ۋاقىتتا ھۆججەت بىلەن ئۇچۇر ئەۋەتىشكە يول قويىدۇ",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- ئېكراننى ھەمبەھىرلەۋاتقاندا ياڭراتقۇنىڭ سىن كۆرۈنۈشى كۆرۈندى ، چاقىرىش ئىنكاسى جانلاندى",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- ئۇچۇرلارنى تىزىمغا كىرگەن ئاپتورلار ۋە رىياسەتچىلەر 6 سائەت تەھرىرلىيەلەيدۇ",
    "- Unsent message drafts are now saved in your browser" : "- ئەۋەتىلمىگەن ئۇچۇر لايىھەلىرى تور كۆرگۈچىڭىزدە ساقلاندى",
    "- Text chatting can now be done in a federated way with other Talk servers" : "- تېكىست پاراڭلىشىش ھازىر باشقا سۆھبەت مۇلازىمېتىرلىرى بىلەن فېدېراتسىيە ئۇسۇلدا ئېلىپ بېرىلسا بولىدۇ",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- رىياسەتچىلەر ھازىر ھېسابات ۋە مېھمانلارنى چەكلەپ ، ئۇلارنىڭ سۆھبەتكە قايتا كىرىشىنىڭ ئالدىنى ئالىدۇ",
    "- Upcoming calls from linked calendar events and out-of-office replacements are now shown in conversations" : "- ئۇلانغان كالېندار ھادىسىلىرى ۋە ئىشخانا سىرتىدىكى ئالماشتۇرۇشتىن كەلگەن تېلېفونلار ھازىر سۆھبەتتە كۆرسىتىلدى",
    "- Calls can now be done in a federated way with other Talk servers (requires the High-performance backend)" : "- چاقىرىشنى باشقا پاراڭ مۇلازىمېتىرلىرى بىلەن فېدېراتىپ ئۇسۇلدا قىلغىلى بولىدۇ (يۇقىرى ئىقتىدارلىق ئارقا كۆرۈنۈشنى تەلەپ قىلىدۇ)",
    "- Introducing the Nextcloud Talk desktop client for Windows, macOS and Linux: %s" : "- Windows، macOS ۋە Linux ئۈچۈن لايىھەلەنگەن Nextcloud Talk ئۈستەل يۈزى كىلىيېنتىنى تونۇشتۇرۇش: %s",
    "- Summarize call recordings and unread messages in chats with the Nextcloud Assistant" : "- Nextcloud ياردەمچىسى ئارقىلىق سۆھبەتلەردىكى تېلېفون خاتىرىلىرى ۋە ئوقۇلمىغان ئۇچۇرلارنى خۇلاسىلەڭ",
    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- تەكلىپ قىلىنغان مېھمانلارنى ئۇلارنىڭ ئېلخەت ئادرېسى ئارقىلىق تونۇش، قاتناشقۇچىلار تىزىملىكىنى ئىمپورت قىلىش، بېلەت تاشلاش لايىھەلىرىنى كىرگۈزۈش ۋە قاتناشقۇچىلار تىزىملىكىنى چۈشۈرۈش قاتارلىق ئۇسۇللار بىلەن يىغىنلارنى ياخشىلاش.",
    "- Archive conversations to stay focused" : "- دىققەتنى چاچماسلىق ئۈچۈن سۆھبەتنى ئارخىپلا",
    "- Schedule a meeting into your calendar from within a conversation" : "- سۆھبەت ئىچىدىن كالېندارىڭىزغا يىغىن پىلانلاڭ",
    "- Search for messages of the current conversation directly in the right sidebar" : "- نۆۋەتتىكى سۆھبەتنىڭ ئۇچۇرلىرىنى بىۋاسىتە ئوڭ تەرەپتىكى يان بالداقتىن ئىزدەڭ",
    "- See more conversations on a first glance with the new compact list (enable in the Talk settings)" : "- يېڭى قىسقا تىزىملىك ​​ئارقىلىق تېخىمۇ كۆپ سۆھبەتلەرنى دەسلەپكى قاراشتىلا كۆرۈڭ (سۆھبەت تەڭشەكلىرىدە قوزغىتىڭ)",
    "- Meeting conversations now sync the title and description from the calendar and are hidden with a search filter until they are close to the start" : "- يىغىن سۆھبەتلىرى ھازىر كالېنداردىكى ماۋزۇ ۋە چۈشەندۈرۈشنى ماسلاشتۇرىدۇ ھەمدە باشلىنىشقا يېقىنلاشقۇچە ئىزدەش فىلتىرى بىلەن يوشۇرۇلىدۇ.",
    "- Mark conversations as sensitive in the notification settings, to hide the message content from the conversation list and notifications" : "- ئۇچۇر مەزمۇنىنى سۆھبەت تىزىملىكى ۋە ئۇقتۇرۇشلاردىن يوشۇرۇش ئۈچۈن، ئۇقتۇرۇش تەڭشەكلىرىدە سۆھبەتلەرنى سەزگۈر دەپ بەلگىلەڭ.",
    "- To receive push notifications during \"Do not disturb\", mark conversations as important" : "- «بىئارام قىلماڭ» دېگەن ۋاقىتتا ئۇچۇر قوبۇل قىلىش ئۈچۈن، سۆھبەتلەرنى مۇھىم دەپ بەلگىلەڭ",
    "- Add other participants to a one-to-one call to create a new group call on the fly" : "- يېڭى گۇرۇپپا يىغىنىنى دەرھال قۇرۇش ئۈچۈن، باشقا قاتناشقۇچىلارنى يەككە-يەككە چاقىرىشقا قوشۇڭ",
    "- Use threads to keep your chat and discussions organized" : "- پاراڭلىشىش ۋە مۇزاكىرىلىرىڭىزنى تەرتىپلىك ساقلاش ئۈچۈن تېمىلارنى ئىشلىتىڭ",
    "- Live transcriptions now available during the call (requires the live-transcription ExApp and the High-performance backend)" : "- تېلېفون جەريانىدا نەق مەيداندىن تەرجىمە قىلىشقا بولىدۇ (نەق مەيداندىن تەرجىمە قىلىش ExApp ۋە يۇقىرى ئىقتىدارلىق ئارقا ئۇچىنى تەلەپ قىلىدۇ)",
    "_All %n participant_::_All %n participants_" : ["بارلىق %n قاتناشقۇچى","بارلىق %n قاتناشقۇچىلار"],
    "Talk updates ✅" : "پاراڭ يېڭىلاش ✅",
    "Reaction deleted by author" : "ئاپتور تەرىپىدىن ئۆچۈرۈلگەن ئىنكاس",
    "{actor} created the conversation" : "{actor} سۆھبەتنى قۇردى",
    "You created the conversation" : "سۆھبەتنى قۇردىڭىز",
    "System created the conversation" : "سىستېما سۆھبەتنى قۇردى",
    "An administrator created the conversation" : "باشقۇرغۇچى سۆھبەتنى قۇردى",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} سۆھبەتكە «%1$s» دىن «%2$s» غا ئۆزگەرتتى.",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "سۆھبەتنىڭ نامىنى «%1$s» دىن «%2$s» غا ئۆزگەرتتىڭىز.",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "بىر باشقۇرغۇچى سۆھبەتنىڭ نامىنى «%1$s» دىن «%2$s» غا ئۆزگەرتتى.",
    "{actor} set the description" : "{actor} چۈشەندۈرۈشنى بەلگىلەڭ",
    "You set the description" : "چۈشەندۈرۈشنى تەڭشىدىڭىز",
    "An administrator set the description" : "باشقۇرغۇچى چۈشەندۈرۈشنى بەلگىلىدى",
    "{actor} removed the description" : "{actor} چۈشەندۈرۈشنى ئۆچۈردى",
    "You removed the description" : "چۈشەندۈرۈشنى ئۆچۈردىڭىز",
    "An administrator removed the description" : "باشقۇرغۇچى بۇ چۈشەندۈرۈشنى ئۆچۈرۈۋەتتى",
    "You started a silent call" : "ئۈن-تىنسىز تېلېفون باشلىدىڭىز",
    "Outgoing silent call" : "چىققان ئۈنسىز تېلىفۇن",
    "{actor} started a silent call" : "{actor} جىمجىت تېلېفون باشلىدى",
    "Incoming silent call" : "كەلگەن ئۈنسىز تېلىفۇن",
    "You started a call" : "سىز تېلېفوننى باشلىدىڭىز",
    "Outgoing call" : "چاقىرغان تېلىفۇن",
    "{actor} started a call" : "{actor} چاقىرىشنى باشلىدى",
    "Incoming call" : "كەلگەن تېلىفۇن",
    "{actor} joined the call" : "{actor} چاقىرىققا قاتناشتى",
    "You joined the call" : "سىز تېلېفونغا قاتناشتىڭىز",
    "{actor} left the call" : "{actor} تېلېفوندىن ئايرىلدى",
    "You left the call" : "سىز تېلېفوندىن ئايرىلدىڭىز",
    "{actor} unlocked the conversation" : "{actor} سۆھبەتنى ئاچتى",
    "You unlocked the conversation" : "سۆھبەتنى ئاچتىڭىز",
    "An administrator unlocked the conversation" : "باشقۇرغۇچى سۆھبەتنى ئاچتى",
    "{actor} locked the conversation" : "{actor} سۆھبەتنى قۇلۇپلىدى",
    "You locked the conversation" : "سۆھبەتنى قۇلۇپلىدىڭىز",
    "An administrator locked the conversation" : "باشقۇرغۇچى سۆھبەتنى قۇلۇپلىدى",
    "{actor} limited the conversation to the current participants" : "{actor} سۆھبەتنى ھازىرقى قاتناشقۇچىلار بىلەنلا چەكلىدى",
    "You limited the conversation to the current participants" : "سىز سۆھبەتنى نۆۋەتتىكى قاتناشقۇچىلار بىلەنلا چەكلىدىڭىز",
    "An administrator limited the conversation to the current participants" : "بىر باشقۇرغۇچى سۆھبەتنى نۆۋەتتىكى قاتناشقۇچىلار بىلەنلا چەكلىدى",
    "{actor} opened the conversation to registered users" : "{actor} تىزىملاتقان ئابونتلارغا سۆھبەتنى ئاچتى",
    "You opened the conversation to registered users" : "سۆھبەتنى تىزىملاتقان ئىشلەتكۈچىلەرگە ئاچتىڭىز",
    "An administrator opened the conversation to registered users" : "باشقۇرغۇچى تىزىملاتقان ئابونتلارغا سۆھبەتنى ئاچتى",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} مېھمانلار دېتالى بىلەن قۇرغان تىزىملاتقان ئابونتلار ۋە ئىشلەتكۈچىلەرگە سۆھبەتنى ئاچتى",
    "You opened the conversation to registered users and users created with the Guests app" : "سىز مېھمانلار ئەپى بىلەن قۇرغان تىزىملاتقان ئابونتلار ۋە ئىشلەتكۈچىلەرگە سۆھبەتنى ئاچتىڭىز",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "بىر باشقۇرغۇچى مېھمانلار دېتالى بىلەن قۇرغان تىزىملاتقان ئابونتلار ۋە ئىشلەتكۈچىلەرگە سۆھبەتنى ئاچتى",
    "The conversation is now open to everyone" : "سۆھبەت ھازىر كۆپچىلىككە ئېچىۋېتىلدى",
    "{actor} opened the conversation to everyone" : "{actor} كۆپچىلىككە سۆھبەتنى ئاچتى",
    "You opened the conversation to everyone" : "سۆھبەتنى كۆپچىلىككە ئاچتىڭىز",
    "{actor} restricted the conversation to moderators" : "{actor} رىياسەتچىلەر بىلەن سۆھبەتنى چەكلىدى",
    "You restricted the conversation to moderators" : "رىياسەتچىلەر بىلەن سۆھبەتنى چەكلىدىڭىز",
    "{actor} started breakout rooms" : "{actor} بۆسۈش ئۆيلىرىنى باشلىدى",
    "You started breakout rooms" : "بۆسۈش ئۆيلىرىنى باشلىدىڭىز",
    "{actor} stopped breakout rooms" : "{actor} بۆسۈش ئۆيلىرىنى توختاتتى",
    "You stopped breakout rooms" : "بۆسۈش ئۆيلىرىنى توختاتتىڭىز",
    "{actor} allowed guests" : "{actor} مېھمانلارغا رۇخسەت قىلدى",
    "You allowed guests" : "مېھمانلارغا رۇخسەت قىلدىڭىز",
    "An administrator allowed guests" : "باشقۇرغۇچى مېھمانلارغا رۇخسەت قىلدى",
    "{actor} disallowed guests" : "{actor} مېھمانلارنى رەت قىلدى",
    "You disallowed guests" : "مېھمانلارنى رەت قىلدىڭىز",
    "An administrator disallowed guests" : "باشقۇرغۇچى مېھمانلارنى رەت قىلدى",
    "{actor} set a password" : "{actor} پارول بەلگىلەڭ",
    "You set a password" : "پارول بەلگىلىدىڭىز",
    "An administrator set a password" : "باشقۇرغۇچى پارول بەلگىلىدى",
    "{actor} removed the password" : "{actor} پارولنى ئېلىۋەتتى",
    "You removed the password" : "پارولنى ئۆچۈردىڭىز",
    "An administrator removed the password" : "باشقۇرغۇچى پارولنى ئۆچۈرۈۋەتتى",
    "{actor} added {user}" : "{actor} قوشۇلدى {user}",
    "You joined the conversation" : "سۆھبەتكە قاتناشتىڭىز",
    "{actor} joined the conversation" : "{actor} سۆھبەتكە قاتناشتى",
    "You added {user}" : "سىز {user} نى قوشتىڭىز",
    "{actor} added you" : "{actor} سىزنى قوشتى",
    "An administrator added you" : "باشقۇرغۇچى سىزنى قوشتى",
    "An administrator added {user}" : "باشقۇرغۇچى {user} نى قوشتى",
    "You left the conversation" : "سۆھبەتتىن ئايرىلدىڭىز",
    "{actor} left the conversation" : "{actor} سۆھبەتتىن ئايرىلدى",
    "{actor} removed {user}" : "{actor} چىقىرىۋېتىلدى {user}",
    "You removed {user}" : "سىز {user} نى ئۆچۈردىڭىز",
    "{actor} removed you" : "{actor} سىزنى ئېلىۋەتتى",
    "An administrator removed you" : "باشقۇرغۇچى سىزنى ئۆچۈرۈۋەتتى",
    "An administrator removed {user}" : "باشقۇرغۇچى {user} نى ئۆچۈردى",
    "{actor} invited {federated_user}" : "{actor} تەكلىپ قىلىنغان {federated_user}",
    "You invited {federated_user}" : "سىز {federated_user} نى تەكلىپ قىلدىڭىز",
    "You accepted the invitation" : "تەكلىپنى قوبۇل قىلدىڭىز",
    "{actor} invited you" : "{actor} سىزنى تەكلىپ قىلدى",
    "An administrator invited you" : "باشقۇرغۇچى سىزنى تەكلىپ قىلدى",
    "An administrator invited {federated_user}" : "باشقۇرغۇچى {federated_user} نى تەكلىپ قىلدى",
    "{federated_user} accepted the invitation" : "{federated_user} تەكلىپنى قوبۇل قىلدى",
    "{actor} removed {federated_user}" : "{actor} چىقىرىۋېتىلدى {federated_user}",
    "You removed {federated_user}" : "ئۆچۈرۈۋەتتىڭىز {federated_user}",
    "You declined the invitation" : "تەكلىپنى رەت قىلدىڭىز",
    "An administrator removed {federated_user}" : "باشقۇرغۇچى {federated_user} نى چىقىرۋەتتى",
    "{federated_user} declined the invitation" : "{federated_user} تەكلىپنى رەت قىلدى",
    "{actor} added group {group}" : "{actor} قوشۇلغان گۇرۇپپا {group}",
    "You added group {group}" : "گۇرۇپپا {group} قوشتىڭىز",
    "An administrator added group {group}" : "باشقۇرغۇچى گۇرۇپپا {group} قوشتى",
    "{actor} removed group {group}" : "{actor} چىقىرىۋېتىلگەن گۇرۇپپا {group}",
    "You removed group {group}" : "گۇرۇپپا {group} ئۆچۈردىڭىز",
    "An administrator removed group {group}" : "باشقۇرغۇچى گۇرۇپپا {group} ئۆچۈردى",
    "{actor} added team {circle}" : "{actor} قوشۇلغان گۇرۇپپا {circle}",
    "You added team {circle}" : "گۇرۇپپا {circle} قوشتىڭىز",
    "An administrator added team {circle}" : "باشقۇرغۇچى گۇرۇپپا {circle} قوشتى",
    "{actor} removed team {circle}" : "{actor} چىقىرىۋېتىلگەن گۇرۇپپا {circle}",
    "You removed team {circle}" : "گۇرۇپپا {circle} ئۆچۈردىڭىز",
    "An administrator removed team {circle}" : "باشقۇرغۇچى گۇرۇپپا {circle} ئۆچۈردى",
    "{actor} added {phone}" : "{actor} قوشۇلدى {phone}",
    "You added {phone}" : "{phone} قوشتىڭىز",
    "An administrator added {phone}" : "باشقۇرغۇچى {phone} قوشتى",
    "{actor} removed {phone}" : "{actor} چىقىرىۋېتىلدى {phone}",
    "You removed {phone}" : "{phone} ئېلىۋەتتىڭىز",
    "An administrator removed {phone}" : "باشقۇرغۇچى {phone} ئېلىۋەتتى",
    "{actor} promoted {user} to moderator" : "{actor} ئۆستۈرۈلگەن {user} رىياسەتچىگە ئۆستۈرۈلدى",
    "You promoted {user} to moderator" : "سىز {user} نى رىياسەتچىگە ئۆستۈردىڭىز",
    "{actor} promoted you to moderator" : "{actor} سىزنى رىياسەتچىگە ئۆستۈردى",
    "An administrator promoted you to moderator" : "باشقۇرغۇچى سىزنى رىياسەتچىگە ئۆستۈردى",
    "An administrator promoted {user} to moderator" : "باشقۇرغۇچى {user} نى رىياسەتچىگە ئۆستۈردى",
    "{actor} demoted {user} from moderator" : "رىياسەتچىدىن {actor} تۆۋەنلىتىلگەن {user}",
    "You demoted {user} from moderator" : "سىز {user} نى رىياسەتچىدىن چۈشۈردىڭىز",
    "{actor} demoted you from moderator" : "{actor} سىزنى رىياسەتچىدىن چۈشۈردى",
    "An administrator demoted you from moderator" : "باشقۇرغۇچى سىزنى رىياسەتچىدىن چۈشۈردى",
    "An administrator demoted {user} from moderator" : "باشقۇرغۇچى {user} نى رىياسەتچىدىن چۈشۈردى",
    "{actor} shared a file which is no longer available" : "{actor} ئەمدى ئىشلەتكىلى بولمايدىغان ھۆججەتنى ھەمبەھىرلىدى",
    "You shared a file which is no longer available" : "ئەمدى ئىشلەتكىلى بولمايدىغان ھۆججەتنى ئورتاقلاشتىڭىز",
    "File shares are currently not supported in federated conversations" : "فېدېراتسىيە پاراڭلىرىدا ھۆججەت ھەمبەھىرلىرىنى قوللىمايدۇ",
    "The shared location is malformed" : "ئورتاق بەھرىلىنىدىغان ئورۇن خاتا",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} Mat بۇ سۆھبەتنى باشقا پاراڭلار بىلەن ماس قەدەمدە ماسلاشتۇرۇش ئۈچۈن Matterbridge نى قۇردى",
    "You set up Matterbridge to synchronize this conversation with other chats" : "سىز بۇ سۆھبەتنى باشقا پاراڭلار بىلەن ماس قەدەمدە ماسلاشتۇرۇش ئۈچۈن Matterbridge نى قۇردىڭىز",
    "{actor} created thread {title}" : "{actor} يىپ {title} نى قۇردى",
    "You created thread {title}" : "سىز يىپ {title} نى قۇردىڭىز",
    "{actor} renamed thread {title}" : "{actor} يىپ {title} نىڭ ئىسمىنى ئۆزگەرتتى",
    "You renamed thread {title}" : "سىز يىپ {title} نىڭ ئىسمىنى ئۆزگەرتتىڭىز",
    "{actor} updated the Matterbridge configuration" : "{actor} Matterbridge سەپلىمىسىنى يېڭىلىدى",
    "You updated the Matterbridge configuration" : "Matterbridge سەپلىمىسىنى يېڭىلىدىڭىز",
    "{actor} removed the Matterbridge configuration" : "{actor} Matterbridge سەپلىمىسىنى ئېلىۋەتتى",
    "You removed the Matterbridge configuration" : "Matterbridge سەپلىمىسىنى ئۆچۈردىڭىز",
    "{actor} started Matterbridge" : "{actor} Matterbridge نى باشلىدى",
    "You started Matterbridge" : "سىز Matterbridge نى باشلىدىڭىز",
    "{actor} stopped Matterbridge" : "{actor} Matterbridge نى توختاتتى",
    "You stopped Matterbridge" : "سىز Matterbridge نى توختاتتىڭىز",
    "{actor} deleted a message" : "{actor} ئۇچۇرنى ئۆچۈردى",
    "You deleted a message" : "سىز بىر ئۇچۇرنى ئۆچۈردىڭىز",
    "{actor} edited a message" : "{actor} ئۇچۇرنى تەھرىرلىدى",
    "You edited a message" : "سىز بىر ئۇچۇرنى تەھرىرلىدىڭىز",
    "{actor} pinned a message" : "{actor} بىر ئۇچۇرنى مىخلىدى",
    "You pinned a message" : "سىز بىر ئۇچۇرنى مىخلىدىڭىز",
    "{actor} unpinned a message" : "{actor} بىر ئۇچۇرنى مىخلىمىدىڭىز",
    "Message was automatically unpinned" : "ئۇچۇر ئاپتۇماتىك مىخلانمىدى",
    "You unpinned a message" : "سىز بىر ئۇچۇرنى مىخلىمىدىڭىز",
    "{actor} deleted a reaction" : "{actor} بىر ئىنكاسنى ئۆچۈردى",
    "You deleted a reaction" : "سىز بىر ئىنكاسنى ئۆچۈردىڭىز",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["سىز ئۇچۇر مۇددىتىنى %n ھەپتىگە تەڭشىدىڭىز","سىز ئۇچۇر مۇددىتىنى %n ھەپتىگە تەڭشىدىڭىز"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["سىز ئۇچۇر مۇددىتىنى %n كۈنگە تەڭشىدىڭىز","سىز ئۇچۇر مۇددىتىنى %n كۈنگە تەڭشىدىڭىز"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["سىز ئۇچۇر مۇددىتىنى %n سائەتكە تەڭشىدىڭىز","سىز ئۇچۇر مۇددىتىنى %n سائەتكە تەڭشىدىڭىز"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["سىز ئۇچۇر مۇددىتىنى %n مىنۇتقا تەڭشىدىڭىز","سىز ئۇچۇر مۇددىتىنى %n مىنۇتقا تەڭشىدىڭىز"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} ئۇچۇر مۇددىتىنى %n ھەپتىگە تەڭشىدى","{actor} ئۇچۇر مۇددىتىنى %n ھەپتىگە تەڭشىدى"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} ئۇچۇر مۇددىتىنى %n كۈنگە تەڭشىدى","{actor} ئۇچۇر مۇددىتىنى %n كۈنگە تەڭشىدى"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} ئۇچۇر مۇددىتىنى %n سائەتكە تەڭشىدى","{actor} ئۇچۇر مۇددىتىنى %n سائەتكە تەڭشىدى"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} ئۇچۇر مۇددىتىنى %n مىنۇتقا تەڭشىدى","{actor} ئۇچۇر مۇددىتىنى %n مىنۇتقا تەڭشىدى"],
    "{actor} disabled message expiration" : "{actor} چەكلەنگەن ئۇچۇرنىڭ ۋاقتى توشىدۇ",
    "You disabled message expiration" : "ئۇچۇرنىڭ مۇددىتى توشتى",
    "{actor} cleared the history of the conversation" : "{actor} سۆھبەتنىڭ تارىخىنى تازىلىدى",
    "You cleared the history of the conversation" : "سۆھبەتنىڭ تارىخىنى تازىلىدىڭىز",
    "{actor} set the conversation picture" : "{actor} سۆھبەت رەسىمىنى تەڭشىدى",
    "You set the conversation picture" : "سۆھبەت رەسىمىنى تەڭشىدىڭىز",
    "{actor} removed the conversation picture" : "{actor} سۆھبەت رەسىمىنى ئېلىۋەتتى",
    "You removed the conversation picture" : "سۆھبەت رەسىمىنى ئۆچۈردىڭىز",
    "{actor} ended the poll {poll}" : "{actor} راي سىناش {poll} نى ئاخىرلاشتۇردى",
    "You ended the poll {poll}" : "راي سىناش {poll} نى ئاخىرلاشتۇردىڭىز",
    "{actor} started the video recording" : "{actor} سىن خاتىرىسىنى باشلىدى",
    "You started the video recording" : "سىن خاتىرىسىنى باشلىدىڭىز",
    "{actor} stopped the video recording" : "{actor} سىن خاتىرىسىنى توختاتتى",
    "You stopped the video recording" : "سىن خاتىرىسىنى توختاتتىڭىز",
    "{actor} started the audio recording" : "{actor} ئاۋاز خاتىرىسىنى باشلىدى",
    "You started the audio recording" : "ئاۋاز خاتىرىسىنى باشلىدىڭىز",
    "{actor} stopped the audio recording" : "{actor} ئاۋاز خاتىرىسىنى توختاتتى",
    "You stopped the audio recording" : "ئاۋاز خاتىرىسىنى توختاتتىڭىز",
    "The recording failed" : "خاتىرىلەش مەغلۇپ بولدى",
    "Someone voted on the poll {poll}" : "بەزىلەر بېلەت تاشلاش {poll} تاشلاشقا بېلەت تاشلىدى",
    "Message deleted by author" : "ئاپتور تەرىپىدىن ئۆچۈرۈلگەن ئۇچۇر",
    "Message deleted by {actor}" : "ئۇچۇر {actor} by تەرىپىدىن ئۆچۈرۈلدى",
    "Message deleted by you" : "سىز تەرىپىدىن ئۆچۈرۈلگەن ئۇچۇر",
    "Deleted user" : "ئىشلەتكۈچى ئۆچۈرۈلدى",
    "Unknown number" : "نامەلۇم نومۇر",
    "Administration" : "باشقۇرۇش",
    "System" : "سىستېما",
    "%s (guest)" : "%s (مېھمان)",
    "Missed call" : "جاۋاپسىز تېلىفۇن",
    "Unanswered call" : "جاۋاپسىز تېلىفۇن",
    "Call ended (Duration {duration})" : "چاقىرىش ئاخىرلاشتى (ئۇزۇنلۇقى {duration})",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "چاقىرىش ئاخىرلاشتى ، چۈنكى ئۇ ئەڭ يۇقىرى چاقىرىش ۋاقتىغا يەتتى (ۋاقتى {duration} ۋاقتى)",
    "{actor} ended the call (Duration {duration})" : "{actor} چاقىرىقنى ئاخىرلاشتۇردى (ئۇزۇنلۇقى {duration})",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["%n مېھمان بىلەن بولغان سۆھبەت ئاخىرلاشتى، چۈنكى سۆھبەت ۋاقتى ئەڭ ئۇزۇن ۋاقىتقا يەتتى (ئۇزۇنلۇقى {duration})","%n مېھمان بىلەن بولغان سۆھبەت ئاخىرلاشتى، چۈنكى سۆھبەت ۋاقتى ئەڭ ئۇزۇن ۋاقىتقا يەتتى (ئۇزۇنلۇقى {duration})"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["%n مېھمان بىلەن بولغان سۆھبەت ئاخىرلاشتى (ئۇزۇنلۇق {duration})","%n مېھمان بىلەن بولغان سۆھبەت ئاخىرلاشتى (ئۇزۇنلۇق {duration})"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} مىھمان %n بىلەن بولغان تېلىفۇننى ئاخىرلاشتۇردى (ئۇزۇنلۇقى {duration}) ","{actor} مىھمان %n بىلەن بولغان تېلىفۇننى ئاخىرلاشتۇردى (ئۇزۇنلۇقى {duration}) "],
    "Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})" : "{user1} بىلەن بولغان تېلېفون ئاخىرلاشتى ، چۈنكى ئۇ ئەڭ يۇقىرى چاقىرىش ۋاقتىغا يەتتى (ۋاقتى {duration})",
    "Call with {user1} ended (Duration {duration})" : "{user1} with بىلەن چاقىرىش ئاخىرلاشتى (ۋاقتى {duration})",
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} چاقىرىشنى {user1} بىلەن ئاخىرلاشتۇردى (ۋاقتى {duration})",
    "Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})" : "{user1} ۋە {user2} بىلەن چاقىرىش ئاخىرلاشتى ، چۈنكى ئۇ ئەڭ يۇقىرى چاقىرىش ۋاقتىغا يەتتى (داۋاملىشىش ۋاقتى {duration})",
    "Call with {user1} and {user2} ended (Duration {duration})" : "{user1} ۋە {user2} بىلەن چاقىرىش ئاخىرلاشتى (ۋاقتى {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} چاقىرىشنى {user1} ۋە {user2} (ۋاقتى {duration}) بىلەن ئاخىرلاشتۇردى",
    "Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})" : "{user1}، {user2} ۋە {user3} بىلەن چاقىرىش ئاخىرلاشتى، چۈنكى ئۇ ئەڭ يۇقىرى چاقىرىش ۋاقتىغا يەتتى (داۋاملىشىش ۋاقتى {duration})",
    "Call with {user1}, {user2} and {user3} ended (Duration {duration})" : "{user1} ، {user2} ۋە {user3} بىلەن تېلېفون ئاخىرلاشتى (ۋاقتى {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} چاقىرىشنى {user1}, {user2} ۋە {user3} (ۋاقتى {duration}) بىلەن ئاخىرلاشتۇردى",
    "Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})" : "ئەڭ يۇقىرى چاقىرىش ۋاقتى (ۋاقتى {duration} ۋاقتى) غا يەتكەنلىكى ئۈچۈن {user1} ، {user2} ، {user3} ۋە {user4} بىلەن تېلېفون ئاخىرلاشتى.",
    "Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})" : "{user1} ، {user2} ، {user3} ۋە {user4} بىلەن تېلېفون ئاخىرلاشتى (ۋاقتى {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} چاقىرىشنى {user1}, {user2}, {user3} ۋە {user4} (ۋاقتى {duration}) بىلەن ئاخىرلاشتۇردى.",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})" : "ئەڭ يۇقىرى چاقىرىش ۋاقتى (ۋاقتى {duration} ۋاقتى) غا يەتكەنلىكى ئۈچۈن {user1}, {user2}, {user3}, {user4} ۋە {user5} بىلەن تېلېفون ئاخىرلاشتى.",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})" : "{user1}, {user2}, {user3}, {user4} ۋە {user5} بىلەن تېلېفون ئاخىرلاشتى (ۋاقتى {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} چاقىرىشنى {user1}, {user2}, {user3}, {user4} ۋە {user5} بىلەن ئاخىرلاشتۇردى (ۋاقتى {duration})",
    "Message of {user} in {conversation}" : "{user} نىڭ {conversation} دىكى ئۇچۇرى",
    "Message of {user}" : "{user} نىڭ ئۇچۇرى",
    "Message of a deleted user in {conversation}" : "{conversation} ئۆچۈرۈلگەن ئىشلەتكۈچىنىڭ ئۇچۇرى",
    "Talk conversations" : "پاراڭلىشىش",
    "Talk to %s" : "%s بىلەن پاراڭلىشىڭ",
    "An error occurred. Please contact your administrator." : "خاتالىق كۆرۈلدى. باشقۇرغۇچىڭىز بىلەن ئالاقىلىشىڭ.",
    "Storage quota exceeded" : "ساقلاش نورمىسى ئېشىپ كەتتى",
    "File not found" : "ھۆججەت تېپىلمىدى",
    "File is not shared, or shared but not with the user" : "ھۆججەت ئورتاقلاشمايدۇ ، ھەمبەھىرلەنمەيدۇ ، ئەمما ئىشلەتكۈچى بىلەن ئورتاقلاشمايدۇ",
    "No account available to delete." : "ئۆچۈرگىلى بولىدىغان ھېسابات يوق.",
    "Poll" : "راي سىناش",
    "Password needs to be set" : "پارول ئورنىتىلىشى كېرەك",
    "Uploading the file failed" : "ھۆججەتنى چىقىرىش مەغلۇپ بولدى",
    "No image file provided" : "رەسىم ھۆججىتى تەمىنلەنمىدى",
    "File is too big" : "ھۆججەت بەك چوڭ",
    "Invalid file provided" : "ئىناۋەتسىز ھۆججەت تەمىنلەندى",
    "Invalid image" : "ئىناۋەتسىز رەسىم",
    "Unknown filetype" : "نامەلۇم ھۆججەت شەكلى",
    "Talk mentions" : "سۆھبەت تىلغا ئېلىنىدۇ",
    "More conversations" : "تېخىمۇ كۆپ سۆھبەت",
    "Say hi to your friends and colleagues!" : "دوستلىرىڭىز ۋە خىزمەتداشلىرىڭىزغا سالام!",
    "No unread mentions" : "ئوقۇلمىغان تىلغا ئېلىنمايدۇ",
    "Call in progress" : "چاقىرىش داۋاملىشىۋاتىدۇ",
    "You were mentioned" : "سىز تىلغا ئېلىندى",
    "Write to conversation" : "سۆھبەتكە يېزىڭ",
    "Writes event information into a conversation of your choice" : "پائالىيەت ئۇچۇرىنى ئۆزىڭىز تاللىغان سۆھبەتكە يېزىدۇ",
    "Missing email field in header line" : "ماۋزو قۇرىدا ئېلخەت ئورنى كەم",
    "Following lines are invalid: %s" : "تۆۋەندىكى قۇرلار ئىناۋەتسىز: %s",
    "%1$s invited you to conversation \"%2$s\"." : "%1$s سىزنى سۆھبەت \"%2$s\" كە تەكلىپ قىلدى.",
    "You were invited to conversation \"%s\"." : "سىز سۆھبەت \"%s\" كە تەكلىپ قىلىندىڭىز.",
    "Conversation invitation" : "سۆھبەت تەكلىپنامىسى",
    "Scheduled time" : "ۋاقىت ئورۇنلاشتۇرۇش",
    "Description" : "چۈشەندۈرۈش",
    "You can also dial-in via phone with the following details" : "تۆۋەندىكى تەپسىلاتلار بىلەن تېلېفون ئارقىلىق تېلېفون قىلالايسىز",
    "Dial-in information" : "تېلېفون نومۇرى",
    "Meeting ID" : "يىغىن كىملىكى",
    "Your PIN" : "PIN",
    "Click the button below to join the lobby now." : "ھازىر زالغا قوشۇلۇش ئۈچۈن تۆۋەندىكى كۇنۇپكىنى چېكىڭ.",
    "Click the link below to join the lobby now." : "ھازىر زالغا قوشۇلۇش ئۈچۈن تۆۋەندىكى ئۇلىنىشنى چېكىڭ.",
    "Join lobby for \"%s\"" : "\"%s\" نىڭ زالىغا كىرىڭ",
    "Click the button below to join the conversation now." : "ھازىر يىغىنغا قوشۇلۇش ئۈچۈن تۆۋەندىكى كۇنۇپكىنى چېكىڭ.",
    "Click the link below to join the conversation now." : "ھازىر يىغىنغا قوشۇلۇش ئۈچۈن تۆۋەندىكى ئۇلىنىشنى چېكىڭ.",
    "Join \"%s\"" : "\"%s\" غا كىر",
    "Meeting" : "يىغىن",
    "Password request: %s" : "پارول تەلىپى:%s",
    "Private conversation" : "شەخسىي سۆھبەت",
    "Deleted user (%s)" : "ئۆچۈرۈلگەن ئىشلەتكۈچى (%s)",
    "Failed to upload call recording" : "چاقىرىش خاتىرىسىنى يۈكلىيەلمىدى",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "خاتىرىلەش مۇلازىمىتىرى چاقىرىش {call} خاتىرىسىنى يۈكلىيەلمىدى. مەمۇرىي ئورگان بىلەن ئالاقىلىشىڭ.",
    "Share to chat" : "پاراڭلىشىڭ",
    "Dismiss notification" : "ئۇقتۇرۇشنى ئەمەلدىن قالدۇرۇش",
    "Call recording now available" : "ھازىر تېلېفون خاتىرىسىنى ئىشلەتكىلى بولىدۇ",
    "The recording for the call in {call} was uploaded to {file}." : "{call} in دىكى چاقىرىشنىڭ خاتىرىسى {file} گە يۈكلەندى.",
    "Transcript now available" : "ھازىر تېكىست نۇسخىسى بار",
    "The transcript for the call in {call} was uploaded to {file}." : "{call} in دىكى چاقىرىشنىڭ خاتىرىسى {file} گە يۈكلەندى.",
    "Failed to transcript call recording" : "تېلېفون خاتىرىسىنى خاتىرىلەش مەغلۇب بولدى",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "مۇلازىمېتىر {file} in دىكى چاقىرىش ئۈچۈن {call} دىكى خاتىرىسىنى خاتىرىلىيەلمىدى. مەمۇرىي ئورگان بىلەن ئالاقىلىشىڭ.",
    "Call summary now available" : "چاقىرىش خۇلاسىسى ھازىر تەييار",
    "The summary for the call in {call} was uploaded to {file}." : "{call} دىكى چاقىرىشنىڭ قىسقىچە مەزمۇنى {file} غا يۈكلەندى.",
    "Failed to summarize call recording" : "تېلېفون خاتىرىسىنى خۇلاسىلەش مەغلۇپ بولدى",
    "The server failed to summarize the recording at {file} for the call in {call}. Please reach out to the administration." : "سېرۋېر {call} دىكى چاقىرىش ئۈچۈن {file} دىكى خاتىرىنى خۇلاسىلىيەلمىدى. باشقۇرۇش بىلەن ئالاقىلىشىڭ.",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} سىزنى {remoteServer} دىكى {roomName} غا قاتنىشىشقا تەكلىپ قىلدى",
    "Accept" : "قوبۇل قىلىڭ",
    "Decline" : "رەت قىلىڭ",
    "{user1} invited you to a federated conversation" : "{user1} سىزنى فېدېراتسىيە سۆھبەتكە تەكلىپ قىلدى",
    "Someone reacted" : "بىرەيلەن ئىنكاس بىلدۈردى",
    "New message" : "يېڭى ئۇچۇر",
    "Reminder" : "ئەسكەرتىش",
    "Someone mentioned you" : "بىرەيلەن سىزنى تىلغا ئالدى",
    "Notification" : "ئۇقتۇرۇش",
    "Someone reacted in a private conversation" : "بىرەيلەن شەخسىي سۆھبەتتە ئىنكاس بىلدۈردى",
    "You received a message in a private conversation" : "سىز بىر شەخسىي سۆھبەتتە ئۇچۇر تاپشۇرۋالدىڭىز",
    "Reminder in a private conversation" : "بىر شەخسىي سۆھبەتتىكى ئەسكەرتمە",
    "Someone mentioned you in a private conversation" : "بىرەيلەن سىزنى شەخسىي سۆھبەتتە تىلغا ئالدى",
    "Notification in a private conversation" : "بىر شەخسىي سۆھبەت ئۇختۇرۇشى",
    "Reminder: You in {call}" : "ئەسكەرتىش: سىز {call}",
    "Reminder: {user} in {call}" : "ئەسكەرتىش: {user} {call}",
    "Reminder: Deleted user in {call}" : "ئەسكەرتىش: {call} in دىكى ئىشلەتكۈچى ئۆچۈرۈلدى",
    "Reminder: {guest} (guest) in {call}" : "ئەسكەرتىش: {guest} دىكى {call} (مېھمان)",
    "Reminder: Guest in {call}" : "ئەسكەرتىش: {call} in دىكى مېھمان",
    "{user} reacted with {reaction}" : "{user} {reaction} بىلەن ئىنكاس قايتۇردى",
    "{user} reacted with {reaction} in {call}" : "{user} چاقىرىش {call}تا {reaction} بىلەن ئىنكاس قايتۇردى",
    "Deleted user reacted with {reaction} in {call}" : "ئۆچۈرۈلگەن ئىشلەتكۈچى {reaction} دىكى {call} بىلەن ئىنكاس قايتۇردى",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest} (مېھمان) {reaction} {call} بىلەن ئىنكاس قايتۇردى",
    "Guest reacted with {reaction} in {call}" : "مېھمان {reaction} دىكى {call} بىلەن ئىنكاس قايتۇردى",
    "{user} in {call}" : "{user} {call}",
    "Deleted user in {call}" : "{call} in دىكى ئىشلەتكۈچى ئۆچۈرۈلدى",
    "{guest} (guest) in {call}" : "{call} دىكى {guest} (مېھمان)",
    "Guest in {call}" : "{call} دىكى مېھمان",
    "{user} sent you a private message" : "{user} سىزگە شەخسىي ئۇچۇر ئەۋەتتى",
    "{user} sent a message in conversation {call}" : "{user} سۆھبەتتە ئۇچۇر ئەۋەتتى {call}",
    "A deleted user sent a message in conversation {call}" : "ئۆچۈرۈلگەن ئىشلەتكۈچى پاراڭلىشىش {call} غا ئۇچۇر ئەۋەتتى",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (مېھمان) سۆھبەتتە ئۇچۇر ئەۋەتتى {call}",
    "A guest sent a message in conversation {call}" : "بىر مېھمان سۆھبەتتە {call} ئۇچۇر ئەۋەتتى",
    "{user} replied to your private message" : "{user} شەخسىي ئۇچۇرىڭىزغا جاۋاب بەردى",
    "{user} replied to your message in conversation {call}" : "{user} سۆھبەتتىكى ئۇچۇرىڭىزغا {call} جاۋاب بەردى",
    "A deleted user replied to your message in conversation {call}" : "ئۆچۈرۈلگەن ئىشلەتكۈچى پاراڭلىشىش {call} ئۇچۇرىڭىزغا جاۋاب بەردى",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (مېھمان) سۆھبەتتىكى ئۇچۇرىڭىزغا {call} دەپ جاۋاب بەردى",
    "A guest replied to your message in conversation {call}" : "بىر مېھمان پاراڭلىشىش ئۇچۇرىڭىزغا {call} دەپ جاۋاب بەردى",
    "Reminder: You in private conversation {call}" : "ئەسكەرتىش: سىز شەخسىي سۆھبەتتە {call}",
    "Reminder: A deleted user in private conversation {call}" : "ئەسكەرتىش: شەخسىي سۆھبەتتە ئۆچۈرۈلگەن ئىشلەتكۈچى {call}",
    "Reminder: {user} in private conversation" : "ئەسكەرتىش: شەخسىي سۆھبەتتە {user}",
    "Reminder: You in conversation {call}" : "ئەسكەرتىش: سىز سۆھبەتتە {call}",
    "Reminder: {user} in conversation {call}" : "ئەسكەرتىش: سۆھبەتتە {user} تېلېفون {call}",
    "Reminder: A deleted user in conversation {call}" : "ئەسكەرتىش: سۆھبەتتە ئۆچۈرۈلگەن ئىشلەتكۈچى {call}",
    "Reminder: {guest} (guest) in conversation {call}" : "ئەسكەرتىش: سۆھبەتتە {guest} (مېھمان) {call}",
    "Reminder: A guest in conversation {call}" : "ئەسكەرتىش: سۆھبەتتىكى مېھمان {call}",
    "{user} reacted with {reaction} to your private message" : "{user} شەخسىي ئۇچۇرىڭىزغا {reaction} بىلەن ئىنكاس قايتۇردى",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} پاراڭدىكى ئۇچۇرىڭىزغا {reaction} بىلەن ئىنكاس قايتۇردى {call}",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "ئۆچۈرۈلگەن ئىشلەتكۈچى پاراڭلىشىش {reaction} ئۇچۇرىڭىزغا {call} بىلەن ئىنكاس قايتۇردى",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (مېھمان) پاراڭدىكى ئۇچۇرىڭىزغا {reaction} بىلەن ئىنكاس قايتۇردى {call}",
    "A guest reacted with {reaction} to your message in conversation {call}" : "بىر مېھمان پاراڭلىشىش {reaction} ئۇچۇرىڭىزغا {call} بىلەن ئىنكاس قايتۇردى",
    "{user} mentioned you in a private conversation" : "{user} شەخسىي سۆھبەتتە سىزنى تىلغا ئالدى",
    "{user} mentioned group {group} in conversation {call}" : "{user} تىلغا ئېلىنغان گۇرۇپپا {group} پاراڭلىشىش {call}",
    "{user} mentioned team {team} in conversation {call}" : "{user} بىر سۆھبەت {call} دە ئەتىرەت {team} نى تىلغا ئالدى",
    "{user} mentioned everyone in conversation {call}" : "{user} سۆھبەتتە ھەممەيلەننى تىلغا ئالدى {call}",
    "{user} mentioned you in conversation {call}" : "{user} سۆھبەتتە سىزنى تىلغا ئالدى {call}",
    "A deleted user mentioned group {group} in conversation {call}" : "ئۆچۈرۈلگەن ئىشلەتكۈچى {call} سۆھبەتتە {group} گۇرۇپپىسىنى تىلغا ئالدى",
    "A deleted user mentioned team {team} in conversation {call}" : "بىر ئۆچۈرۋېتىلگەن ئىشلەتكۈچى ئەتىرەت {team} نى سۆھبەت {call} دە تىلغا ئالدى",
    "A deleted user mentioned everyone in conversation {call}" : "ئۆچۈرۈلگەن ئىشلەتكۈچى پاراڭلىشىش {call} ھەممەيلەننى تىلغا ئالدى",
    "A deleted user mentioned you in conversation {call}" : "ئۆچۈرۈلگەن ئىشلەتكۈچى سۆھبەتتە {call} دە تىلغا ئالدى",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest} (مېھمان) سۆھبەتتە گۇرۇپپا {group} تىلغا ئېلىنغان {call}",
    "{guest} (guest) mentioned team {team} in conversation {call}" : "{guest} (مىھمان) سۆھبەت {call} دە ئەتىرەت {team} نى تىلغا ئالدى",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest} (مېھمان) سۆھبەتتە ھەممەيلەننى تىلغا ئالدى {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (مېھمان) سىزنى سۆھبەتتە تىلغا ئالدى {call}",
    "A guest mentioned group {group} in conversation {call}" : "بىر مېھمان سۆھبەتتە {group} گۇرۇپپا {call} تىلغا ئالدى",
    "A guest mentioned team {team} in conversation {call}" : "بىر مىھمان {call} سۆھبەتتە ئەتىرەت {team} نى تىلغا ئالدى",
    "A guest mentioned everyone in conversation {call}" : "بىر مېھمان سۆھبەتتە ھەممەيلەننى تىلغا ئالدى {call}",
    "A guest mentioned you in conversation {call}" : "بىر مېھمان سىزنى سۆھبەتتە تىلغا ئالدى {call}",
    "View message" : "ئۇچۇرنى كۆرۈش",
    "Dismiss reminder" : "ئەسكەرتىشنى ئەمەلدىن قالدۇرۇڭ",
    "View chat" : "پاراڭنى كۆرۈش",
    "{user} invited you to a group conversation: {call}" : "{user} سىزنى گۇرۇپپا سۆھبىتىگە تەكلىپ قىلدى: {call}",
    "Join call" : "چاقىرىشقا قوشۇلۇڭ",
    "Answer call" : "جاۋاب تېلېفونى",
    "{user} would like to talk with you" : "{user} سىز بىلەن پاراڭلىشىشنى خالايدۇ",
    "Call back" : "تېلېفون قىلىڭ",
    "You missed a call from {user}" : "{user} نىڭ تېلېفونىنى قولدىن بېرىپ قويدىڭىز",
    "Accept call" : "چاقىرىشنى قۇبۇللا",
    "Incoming phone call from {call}" : "{call} دىن كەلگەن تېلىفۇن",
    "You missed a phone call from {call}" : "{call} دىن كەلگەن تېلىفۇن چاقىرىشىنى ئۆتكۈزۋەتتىڭىز",
    "A group call has started in {call}" : "گۇرۇپپا چاقىرىش {call} دا باشلاندى",
    "You missed a group call in {call}" : "{call} in دىكى گۇرۇپپا چاقىرىشنى قولدىن بېرىپ قويدىڭىز",
    "{email} is requesting the password to access {file}" : "{email} پارول {file} كىرىشنى تەلەپ قىلىدۇ",
    "{email} tried to request the password to access {file}" : "{email} پارولنى {file} كىرىشنى تەلەپ قىلدى",
    "Someone is requesting the password to access {file}" : "بەزىلەر پارولنى {file} كىرىشنى تەلەپ قىلىدۇ",
    "Someone tried to request the password to access {file}" : "بەزىلەر پارولنى {file} كىرىشنى تەلەپ قىلماقچى بولدى",
    "Open settings" : "تەڭشەكلەرنى ئېچىڭ",
    "Hosted signaling server added" : "ساھىبجامال سىگنال مۇلازىمىتىرى قوشۇلدى",
    "The hosted signaling server is now configured and will be used." : "ساھىبخانلىق سىگنال مۇلازىمىتىرى ھازىر تەڭشەلدى ۋە ئىشلىتىلىدۇ.",
    "Hosted signaling server removed" : "ساھىبجامال سىگنال مۇلازىمىتىرى ئۆچۈرۈلدى",
    "The hosted signaling server was removed and will not be used anymore." : "ساھىبخانلىق سىگنال مۇلازىمېتىرى چىقىرىۋېتىلدى ، ئەمدى ئىشلىتىلمەيدۇ.",
    "Hosted signaling server changed" : "ساھىبجامال سىگنال مۇلازىمىتىرى ئۆزگەردى",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "ساھىبخانلىق سىگنال مۇلازىمىتىرى ھالىتىنى «{oldstatus}» دىن «{newstatus}» غا ئۆزگەرتتى.",
    "pending" : "ساقلىنىۋاتىدۇ",
    "active" : "ئاكتىپ",
    "expired" : "ۋاقتى توشتى",
    "blocked" : "توسۇلۇپ قالدى",
    "error" : "خاتالىق",
    "The certificate of {host} expires in {days} days" : "{host} گۇۋاھنامىسى {days} كۈندە توشىدۇ",
    "The certificate of {host} expired" : "{host} گۇۋاھنامىسى توشتى",
    "Contact via Talk" : "سۆھبەت ئارقىلىق ئالاقىلىشىڭ",
    "Open Talk" : "ئوچۇق سۆھبەت",
    "Default" : "كۆڭۈلدىكى",
    "Presentation" : "لېكسىيە",
    "Webinar" : "تور سۆھبىتى",
    "Conversations" : "سۆھبەت",
    "Messages in current conversation" : "نۆۋەتتىكى سۆھبەتتىكى ئۇچۇرلار",
    "{user}" : "{user}",
    "Messages" : "ئۇچۇرلار",
    "{user} in {conversation}" : "{conversation} دىكى {user}",
    "Messages in other conversations" : "باشقا سۆھبەتتىكى ئۇچۇرلار",
    "One-to-one rooms always need to show the other users avatar" : "بىر ئۆيدىن باشقا ئۆيلەر ھەمىشە باشقا ئىشلەتكۈچىلەرنىڭ باش سۈرىتىنى كۆرسىتىشى كېرەك",
    "Invalid emoji character" : "Emoji خاراكتېرى ئىناۋەتسىز",
    "Invalid background color" : "تەگلىك رەڭگى ئىناۋەتسىز",
    "Avatar image is not square" : "باش سۈرىتى چاسا ئەمەس",
    "Room {number}" : "ياتاق {number}",
    "Other" : "باشقا",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "سىناق مۇلازىمېتىرغا يەتكىلى بولمىغاچقا سىناق قىلىشنى تەلەپ قىلمىدى. كېيىن قايتا سىناڭ.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "بۇ مىسالنىڭ دەلىللىنىشىدە مەسىلە بار. بەلكىم ئۇنىڭ URL نى دەلىللەش ئۈچۈن سىرتتىن يەتكىلى بولمايدۇ.",
    "Something unexpected happened." : "ئويلىمىغان يەردىن بىر ئىش يۈز بەردى.",
    "The URL is invalid." : "URL ئىناۋەتسىز.",
    "An HTTPS URL is required." : "HTTPS URL تەلەپ قىلىنىدۇ.",
    "The email address is invalid." : "ئېلېكترونلۇق خەت ئادرېسى ئىناۋەتسىز.",
    "The language is invalid." : "تىل ئىناۋەتسىز.",
    "The country is invalid." : "دۆلەت ئىناۋەتسىز.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "سوتنىڭ تەلىپىدە مەسىلە بار. تېخىمۇ كۆپ ئۇچۇرغا ئېرىشىش ئۈچۈن خاتىرىڭىزنى تەكشۈرۈڭ.",
    "Too many requests are send from your servers address. Please try again later." : "بەك كۆپ تەلەپلەر مۇلازىمېتىر ئادرېسىڭىزدىن ئەۋەتىلىدۇ. كېيىن قايتا سىناڭ.",
    "There is already a trial registered for this Nextcloud instance." : "بۇ Nextcloud مىسالى ئۈچۈن ئاللىبۇرۇن سىناق قىلىنغان.",
    "Something unexpected happened. Please try again later." : "ئويلىمىغان يەردىن بىر ئىش يۈز بەردى. كېيىن قايتا سىناڭ.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "سىناق مۇلازىمېتىرى خاتا ھەرىكەت قىلغانلىقى ئۈچۈن سىناق قىلىشنى تەلەپ قىلالمىدى. كېيىن قايتا سىناڭ.",
    "Trial requested but failed to get account information. Please check back later." : "سىناق تەلەپ قىلىندى ، ئەمما ھېسابات ئۇچۇرىغا ئېرىشەلمىدى. كېيىن قايتا تەكشۈرۈپ بېقىڭ.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "بۇ تەلەپنىڭ دەلىللىنىشىدە مەسىلە بار. بەلكىم ئۇنىڭ URL نى دەلىللەش ئۈچۈن سىرتتىن يەتكىلى بولمايدۇ.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "سىناق مۇلازىمېتىرى خاتا ھەرىكەت قىلغانلىقى ئۈچۈن ھېسابات ئۇچۇرلىرىنى ئالالمىدى. كېيىن قايتا تەكشۈرۈپ بېقىڭ.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "ھېسابات ئۇچۇرلىرىنى ئېلىشتا مەسىلە بار. تېخىمۇ كۆپ ئۇچۇرغا ئېرىشىش ئۈچۈن خاتىرىڭىزنى تەكشۈرۈڭ.",
    "There is no such account registered." : "بۇ يەردە ھېسابات يوق.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "سىناق مۇلازىمېتىرىغا يەتكىلى بولمىغاچقا ھېسابات ئۇچۇرلىرىنى ئالالمىدى. كېيىن قايتا تەكشۈرۈپ بېقىڭ.",
    "Deleting the hosted signaling server account failed. Please check back later." : "ساھىبجامال سىگنال مۇلازىمېتىر ھېساباتىنى ئۆچۈرۈش مەغلۇب بولدى. كېيىن قايتا تەكشۈرۈپ بېقىڭ.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "سىناق مۇلازىمېتىرى خاتا ھەرىكەت قىلغانلىقى ئۈچۈن ھېساباتنى ئۆچۈرەلمىدى. كېيىن قايتا تەكشۈرۈپ بېقىڭ.",
    "There is a problem with deleting the account. Please check your logs for further information." : "ھېساباتنى ئۆچۈرۈشتە مەسىلە بار. تېخىمۇ كۆپ ئۇچۇرغا ئېرىشىش ئۈچۈن خاتىرىڭىزنى تەكشۈرۈڭ.",
    "Too many requests are sent from your servers address. Please try again later." : "مۇلازىمېتىر ئادرېسىڭىزدىن بەك كۆپ تەلەپ ئەۋەتىلدى. كېيىن قايتا سىناڭ.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "سىناق مۇلازىمېتىرغا يەتكىلى بولمىغاچقا ، ھېساباتنى ئۆچۈرەلمىدى. كېيىن قايتا تەكشۈرۈپ بېقىڭ.",
    "Note to self" : "ئۆزىڭىزگە دىققەت قىلىڭ",
    "A place for your private notes, thoughts and ideas" : "شەخسىي خاتىرىلىرىڭىز ، ئوي-پىكىرلىرىڭىز",
    "Transcript is AI generated and may contain mistakes" : "تېكىستنى AI يازغان ھەمدە خاتالىقلار مەۋجۇت بولىشى مۇمكىن",
    "Summary is AI generated and may contain mistakes" : "خۇلاسىنى AI يازغان ھەمدە خاتالىقلار بولىشى مۇمكىن",
    "Let's get started!" : "باشلايلى!",
    "**Nextcloud Talk** is a secure, self-hosted communication platform that integrates seamlessly with the Nextcloud ecosystem.\n\n#### Key Features of Nextcloud Talk:\n\n* Chat and messaging in private and group chats\n* Voice and video calls\n* File sharing and integration with other Nextcloud apps\n* Customizable conversation settings, moderation and privacy controls\n* Web, desktop and mobile (iOS and Android)\n* Private & secure communication\n\n Find out more in the [user documentation](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)." : "**Nextcloud Talk** بىخەتەر، ئۆز-ئۆزىنى باشقۇرىدىغان ئالاقە سۇپىسى بولۇپ، Nextcloud ئېكولوگىيە سىستېمىسى بىلەن مۇكەممەل بىر گەۋدىلىشىدۇ.\n\n#### Nextcloud Talk نىڭ ئاساسلىق ئالاھىدىلىكلىرى:\n\n* شەخسىي ۋە گۇرۇپپا سۆھبەتلىرىدە پاراڭلىشىش ۋە ئۇچۇر يوللاش\n* ئاۋازلىق ۋە سىنلىق تېلېفون قىلىش\n* ھۆججەت ئورتاقلىشىش ۋە باشقا Nextcloud قوللىنىشچان پروگراممىلىرى بىلەن بىر گەۋدىلەشتۈرۈش\n* خاسلاشتۇرغىلى بولىدىغان سۆھبەت تەڭشەكلىرى، باشقۇرۇش ۋە مەخپىيەتلىك كونتروللىرى\n* تور، ئۈستەل يۈزى ۋە يانفون (iOS ۋە Android)\n* شەخسىي ۋە بىخەتەر ئالاقە\n\n[ئىشلەتكۈچى ھۆججىتى] دىن تېخىمۇ كۆپ ئۇچۇرغا ئېرىشىڭ (https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html).",
    "# Welcome to Nextcloud Talk\n\nNextcloud Talk is a private and powerful messaging app that integrates with Nextcloud. Chat in private or group conversations, collaborate over voice and video calls, organize webinars and events, customize your conversations and more." : "# Nextcloud Talk غا خۇش كەپسىز\n\nNextcloud Talk Nextcloud بىلەن بىر گەۋدىلەشكەن شەخسىي ۋە كۈچلۈك ئۇچۇر يوللاش ئەپ دېتالى. شەخسىي ياكى گۇرۇپپا سۆھبەتلىرىدە پاراڭلىشىڭ، ئاۋازلىق ۋە سىنلىق تېلېفونلار ئارقىلىق ھەمكارلىشىڭ، تور سېمىنارلىرى ۋە پائالىيەتلەرنى تەشكىللەڭ، سۆھبەتلىرىڭىزنى خاسلاشتۇرۇڭ ۋە باشقا نۇرغۇن ئىشلارنى قىلىڭ.",
    "## 🎨 Format texts to create rich messages\n\nIn Nextcloud Talk, you can use Markdown syntax to format your messages. For example, apply **bold** or *italic* formatting, or `highlight texts as code`. You can even create tables and add headings to your text.\n\nNeed to fix a typo or change formatting? Edit your message by clicking \"Edit message\" in the message menu." : "## 🎨 مول مەزمۇنلۇق ئۇچۇرلار يارىتىش ئۈچۈن تېكىستلەرنى فورماتلاڭ\n\nNextcloud Talk تا، سىز Markdown سىنتاكسىسىنى ئىشلىتىپ ئۇچۇرلىرىڭىزنى فورماتلىيالايسىز. مەسىلەن، **قالىن** ياكى *قىيسىق* فورماتىنى قوللىنىڭ، ياكى 'كود سۈپىتىدە تېكىستلەرنى بەلگىلەڭ'. سىز ھەتتا جەدۋەللەرنى قۇرۇپ، تېكىستىڭىزگە ماۋزۇ قوشالايسىز.\n\nخاتالىقنى تۈزىتىش ياكى فورماتنى ئۆزگەرتىش كېرەكمۇ؟ ئۇچۇر تىزىملىكىدىكى «خەۋەرنى تەھرىرلەش» نى چېكىپ ئۇچۇرىڭىزنى تەھرىرلەڭ.",
    "## 🔗 Add attachments and links\n\nAttach files from your Nextcloud Hub using the \"+\" button. Share items from Files and various Nextcloud apps. Some apps even support interactive widgets, for example, the Text app." : "## 🔗 قوشۇمچە ھۆججەتلەر ۋە ئۇلىنىشلارنى قوشۇڭ\n\n«+» كۇنۇپكىسى ئارقىلىق Nextcloud مەركىزىڭىزدىكى ھۆججەتلەرنى قوشۇڭ. ھۆججەتلەر ۋە ھەر خىل Nextcloud قوللىنىشچان پروگراممىلىرىدىكى نەرسىلەرنى ئورتاقلىشىڭ. بەزى قوللىنىشچان پروگراممىلار ھەتتا ئۆز-ئارا تەسىر كۆرسىتىدىغان كىچىك پروگراممىلارنى قوللايدۇ، مەسىلەن، تېكىست قوللىنىشچان پروگراممىسى.",
    "## 💭 Let the conversations flow: mention users, react to messages and more\n\nYou can mention everybody in the conversation by using %s or mention specific participants by typing \"@\" and picking their name from the list." : "## 💭 سۆھبەتلەرنىڭ داۋاملىشىشىغا يول قويۇڭ: ئىشلەتكۈچىلەرنى تىلغا ئېلىڭ، ئۇچۇرلارغا ئىنكاس قايتۇرۇڭ ۋە باشقىلار\n\nسىز %s ئارقىلىق سۆھبەتتىكى ھەممەيلەننى تىلغا ئالالايسىز ياكى «@» دەپ يېزىپ تىزىملىكتىن ئۇلارنىڭ ئىسمىنى تاللاپ مەلۇم قاتناشقۇچىلارنى تىلغا ئالالايسىز.",
    "You can reply to messages, forward them to other chats and people, or copy message content." : "سىز ئۇچۇرلارنىڭ جاۋابىنى قايتۇرالايسىز، ئۇلارنى باشقا پاراڭلىشىش ۋە كىشىلەرگە يوللىيالايسىز ياكى ئۇچۇر مەزمۇنىنى كۆچۈرۈشىڭىز مۇمكىن.",
    "## ✨ Do more with Smart Picker\n\nSimply type \"/\" or go to the \"+\" menu to open the Smart Picker where you can attach various content to your messages. You can configure the Smart Picker to be able to add items from Nextcloud apps, GIFs, map locations, AI generated content and much more." : "## ✨ ئەقلىي تاللىغۇچ بىلەن تېخىمۇ كۆپ ئىشلارنى قىلىڭ\n\nپەقەت \"/\" بەلگىسىنى كىرگۈزۈڭ ياكى \"+\" تىزىملىكىگە كىرىپ، ئەقلىي تاللىغۇچنى ئېچىڭ، بۇ يەردە ئۇچۇرلىرىڭىزغا ھەر خىل مەزمۇنلارنى قوشالايسىز. سىز ئەقلىي تاللىغۇچنى Nextcloud ئەپلىرى، GIFلار، خەرىتە ئورۇنلىرى، سۈنئىي ئەقىل ئارقىلىق ھاسىل قىلىنغان مەزمۇنلار ۋە باشقا نۇرغۇن نەرسىلەردىن تۈرلەرنى قوشالايدىغان قىلىپ تەڭشىيەلەيسىز.",
    "## ⚙️ Manage conversation settings\n\nIn the conversation menu, you can access various settings to manage your conversations, such as:\n* Edit conversation info\n* Manage notifications\n* Apply numerous moderation rules\n* Configure access and security\n* Enable bots\n* and more!" : "## ⚙️ سۆھبەت تەڭشەكلىرىنى باشقۇرۇش\n\nسۆھبەت تىزىملىكىدە، سىز سۆھبەتلىرىڭىزنى باشقۇرۇش ئۈچۈن ھەر خىل تەڭشەكلەرگە كىرەلەيسىز، مەسىلەن:\n* سۆھبەت ئۇچۇرلىرىنى تەھرىرلەش\n* ئۇقتۇرۇشلارنى باشقۇرۇش\n* نۇرغۇن باشقۇرۇش قائىدىلىرىنى قوللىنىش\n* كىرىش ۋە بىخەتەرلىكنى تەڭشەش\n* روبوتلارنى قوزغىتىش\n* ۋە باشقىلار!",
    "Andorra" : "ئاندوررا",
    "United Arab Emirates" : "ئەرەب بىرلەشمە خەلىپىلىكى",
    "Afghanistan" : "ئافغانىستان",
    "Antigua and Barbuda" : "ئانتىگۇئا ۋە باربۇدا",
    "Anguilla" : "Anguilla",
    "Albania" : "ئالبانىيە",
    "Armenia" : "ئەرمىنىيە",
    "Angola" : "ئانگولا",
    "Antarctica" : "ئانتاركتىكا",
    "Argentina" : "ئارگېنتىنا",
    "American Samoa" : "American Samoa",
    "Austria" : "ئاۋسترىيە",
    "Australia" : "ئاۋسترالىيە",
    "Aruba" : "Aruba",
    "Åland Islands" : "Åland Islands",
    "Azerbaijan" : "ئەزەربەيجان",
    "Bosnia and Herzegovina" : "بوسنىيە-گېرتسېگوۋىنا",
    "Barbados" : "باربادوس",
    "Bangladesh" : "بېنگال",
    "Belgium" : "بېلگىيە",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "بۇلغارىيە",
    "Bahrain" : "بەھرەيىن",
    "Burundi" : "بۇرۇندى",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "بېرمۇدا",
    "Brunei Darussalam" : "برۇنېي دارۇسسالام",
    "Bolivia, Plurinational State of" : "بولىۋىيە ، كۆپ دۆلەت",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius and Saba",
    "Brazil" : "بىرازىلىيە",
    "Bahamas" : "باھاما",
    "Bhutan" : "بۇتان",
    "Bouvet Island" : "Bouvet Island",
    "Botswana" : "بوتسۋانا",
    "Belarus" : "بېلورۇسىيە",
    "Belize" : "Belize",
    "Canada" : "كانادا",
    "Cocos (Keeling) Islands" : "كوكوس (كېلىڭ) ئارىلى",
    "Congo, the Democratic Republic of the" : "كونگو ، دېموكراتىك جۇمھۇرىيىتى",
    "Central African Republic" : "ئوتتۇرا ئافرىقا جۇمھۇرىيىتى",
    "Congo" : "كونگو",
    "Switzerland" : "شىۋىتسارىيە",
    "Côte d'Ivoire" : "Côte d'Ivoire",
    "Cook Islands" : "كۇك تاقىم ئاراللىرى",
    "Chile" : "چىلى",
    "Cameroon" : "كامېرون",
    "China" : "جۇڭگو",
    "Colombia" : "كولۇمبىيە",
    "Costa Rica" : "كوستارىكا",
    "Cuba" : "كۇبا",
    "Cabo Verde" : "Cabo Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "روژدېستۋو ئارىلى",
    "Cyprus" : "سىپرۇس",
    "Czechia" : "چېخ",
    "Germany" : "گىرمانىيە",
    "Djibouti" : "جىبۇتى",
    "Denmark" : "دانىيە",
    "Dominica" : "Dominica",
    "Dominican Republic" : "دومىنىكا جۇمھۇرىيىتى",
    "Algeria" : "ئالجىرىيە",
    "Ecuador" : "ئېكۋادور",
    "Estonia" : "ئېستونىيە",
    "Egypt" : "مىسىر",
    "Western Sahara" : "غەربىي سەھرايى كەبىر",
    "Eritrea" : "Eritrea",
    "Spain" : "ئىسپانىيە",
    "Ethiopia" : "ئېفىيوپىيە",
    "Finland" : "فىنلاندىيە",
    "Fiji" : "فىجى",
    "Falkland Islands (Malvinas)" : "فالكلاند ئارىلى (مالۋىناس)",
    "Micronesia, Federated States of" : "Micronesia, Federated States of",
    "Faroe Islands" : "فارو ئارىلى",
    "France" : "فرانسىيە",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "بۈيۈك بىرىتانىيە ۋە شىمالىي ئىرېلاندىيە",
    "Grenada" : "Grenada",
    "Georgia" : "گرۇزىيە",
    "French Guiana" : "فرانسىيە گۋىزنىيسى",
    "Guernsey" : "Guernsey",
    "Ghana" : "گانا",
    "Gibraltar" : "جىبرالتار",
    "Greenland" : "Greenland",
    "Gambia" : "گامبىيە",
    "Guinea" : "گۋىنىيە",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "ئېكۋاتور گۋىنىيىسى",
    "Greece" : "گرېتسىيە",
    "South Georgia and the South Sandwich Islands" : "جەنۇبىي گرۇزىيە ۋە جەنۇبىي ساندۋىچ ئارىلى",
    "Guatemala" : "گۋاتېمالا",
    "Guam" : "گۇۋام",
    "Guinea-Bissau" : "گۋىنىيە-بىسساۋ",
    "Guyana" : "Guyana",
    "Hong Kong" : "شياڭگاڭ",
    "Heard Island and McDonald Islands" : "خارد ئارىلى ۋە ماكدونالد ئارىلى",
    "Honduras" : "خوندۇراس",
    "Croatia" : "كىرودىيە",
    "Haiti" : "ھايتى",
    "Hungary" : "ۋېنگىرىيە",
    "Indonesia" : "ھىندونېزىيە",
    "Ireland" : "ئىرېلاندىيە",
    "Israel" : "ئىسرائىلىيە",
    "Isle of Man" : "Isle of Man",
    "India" : "ھىندىستان",
    "British Indian Ocean Territory" : "ئەنگىلىيە ھىندى ئوكيان رايونى",
    "Iraq" : "ئىراق",
    "Iran, Islamic Republic of" : "ئىران ، ئىسلام جۇمھۇرىيىتى",
    "Iceland" : "ئىسلاندىيە",
    "Italy" : "ئىتالىيە",
    "Jersey" : "Jersey",
    "Jamaica" : "يامايكا",
    "Jordan" : "ئىئوردانىيە",
    "Japan" : "ياپۇنىيە",
    "Kenya" : "كېنىيە",
    "Kyrgyzstan" : "قىرغىزىستان",
    "Cambodia" : "كامبودژا",
    "Kiribati" : "Kiribati",
    "Comoros" : "Comoros",
    "Saint Kitts and Nevis" : "Saint Kitts and Nevis",
    "Korea, Democratic People's Republic of" : "كورېيە ، دېموكراتىك خەلق جۇمھۇرىيىتى",
    "Korea, Republic of" : "كورېيە جۇمھۇرىيىتى",
    "Kuwait" : "كۇۋەيت",
    "Cayman Islands" : "كايمان ئارىلى",
    "Kazakhstan" : "قازاقىستان",
    "Lao People's Democratic Republic" : "لائوس خەلق دېموكراتىك جۇمھۇرىيىتى",
    "Lebanon" : "لىۋان",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "سىرىلانكا",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "لىتۋا",
    "Luxembourg" : "لىيۇكسېمبۇرگ",
    "Latvia" : "لاتىۋىيە",
    "Libya" : "لىۋىيە",
    "Morocco" : "ماراكەش",
    "Monaco" : "موناكو",
    "Moldova, Republic of" : "مولدوۋا ، جۇمھۇرىيەت",
    "Montenegro" : "قاراتاغ",
    "Saint Martin (French part)" : "سانت مارتىن (فىرانسۇزچە قىسمى)",
    "Madagascar" : "ماداغاسقار",
    "Marshall Islands" : "مارشال تاقىم ئاراللىرى",
    "North Macedonia" : "شىمالىي ماكېدونىيە",
    "Mali" : "مالى",
    "Myanmar" : "بېرما",
    "Mongolia" : "موڭغۇلىيە",
    "Macao" : "ئاۋمېن",
    "Northern Mariana Islands" : "شىمالىي مارىئانا ئارىلى",
    "Martinique" : "Martinique",
    "Mauritania" : "ماۋرىتانىيە",
    "Montserrat" : "Montserrat",
    "Malta" : "مالتا",
    "Mauritius" : "ماۋرىتىئۇس",
    "Maldives" : "مالدىۋى",
    "Malawi" : "مالاۋى",
    "Mexico" : "مىكسىكا",
    "Malaysia" : "مالايسىيا",
    "Mozambique" : "موزامبىك",
    "Namibia" : "نامبىيە",
    "New Caledonia" : "يېڭى كالېدونىيە",
    "Niger" : "Niger",
    "Norfolk Island" : "نورفولك ئارىلى",
    "Nigeria" : "نىگېرىيە",
    "Nicaragua" : "نىكاراگۇئا",
    "Netherlands" : "گوللاندىيە",
    "Norway" : "نورۋېگىيە",
    "Nepal" : "نېپال",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "يېڭى زېلاندىيە",
    "Oman" : "ئومان",
    "Panama" : "پاناما",
    "Peru" : "پېرۇ",
    "French Polynesia" : "French Polynesia",
    "Papua New Guinea" : "پاپۇئا يېڭى گۋىنىيىسى",
    "Philippines" : "فىلىپپىن",
    "Pakistan" : "پاكىستان",
    "Poland" : "پولشا",
    "Saint Pierre and Miquelon" : "Saint Pierre and Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "پورتو رىكو",
    "Palestine, State of" : "پەلەستىن ، شىتات",
    "Portugal" : "پورتۇگالىيە",
    "Palau" : "Palau",
    "Paraguay" : "پاراگۋاي",
    "Qatar" : "قاتار",
    "Réunion" : "Réunion",
    "Romania" : "رۇمىنىيە",
    "Serbia" : "سېربىيە",
    "Russian Federation" : "رۇسىيە فېدېراتسىيەسى",
    "Rwanda" : "رىۋاندا",
    "Saudi Arabia" : "سەئۇدى ئەرەبىستان",
    "Solomon Islands" : "سۇلايمان تاقىم ئاراللىرى",
    "Seychelles" : "Seychelles",
    "Sudan" : "سۇدان",
    "Sweden" : "شىۋىتسىيە",
    "Singapore" : "سىنگاپور",
    "Saint Helena, Ascension and Tristan da Cunha" : "Saint Helena, Ascension and Tristan da Cunha",
    "Slovenia" : "سىلوۋېنىيە",
    "Svalbard and Jan Mayen" : "سۋالبارد ۋە يان مايېن",
    "Slovakia" : "سلوۋاكىيە",
    "Sierra Leone" : "سېررالېئون",
    "San Marino" : "سان مارىنو",
    "Senegal" : "سېنېگال",
    "Somalia" : "سومالى",
    "Suriname" : "Suriname",
    "South Sudan" : "جەنۇبىي سۇدان",
    "Sao Tome and Principe" : "سان توم ۋە پرىنسىپ",
    "El Salvador" : "سالۋادور",
    "Sint Maarten (Dutch part)" : "سىنت مارتىن (گوللاندىيە قىسمى)",
    "Syrian Arab Republic" : "سۈرىيە ئەرەب جۇمھۇرىيىتى",
    "Eswatini" : "Eswatini",
    "Turks and Caicos Islands" : "تۈركلەر ۋە كايكوس ئارىلى",
    "Chad" : "چاد",
    "French Southern Territories" : "فرانسىيەنىڭ جەنۇبىدىكى رايونلار",
    "Togo" : "توگو",
    "Thailand" : "تايلاند",
    "Tajikistan" : "تاجىكىستان",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "تۈركمەنىستان",
    "Tunisia" : "تۇنىس",
    "Tonga" : "تونگا",
    "Turkey" : "تۈركىيە",
    "Trinidad and Tobago" : "تىرىنىداد ۋە توباگو",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "تەيۋەن ، جۇڭگو ئۆلكىسى",
    "Tanzania, United Republic of" : "تانزانىيە ، بىرلەشمە جۇمھۇرىيىتى",
    "Ukraine" : "ئۇكرائىنا",
    "Uganda" : "ئۇگاندا",
    "United States Minor Outlying Islands" : "ئامېرىكا كىچىك تاشقى ئاراللار",
    "United States of America" : "ئامېرىكا قوشما شتاتلىرى",
    "Uruguay" : "ئۇرۇگۋاي",
    "Uzbekistan" : "ئۆزبېكىستان",
    "Holy See" : "Holy See",
    "Saint Vincent and the Grenadines" : "ئەۋلىيا ۋىنسېنت ۋە گرېنادىنلار",
    "Venezuela, Bolivarian Republic of" : "ۋېنېزۇئېلا ، بولىۋىيە جۇمھۇرىيىتى",
    "Virgin Islands, British" : "ۋىرگىن تاقىم ئارىلى ، ئەنگىلىيە",
    "Virgin Islands, U.S." : "ۋىرگىنىيە تاقىم ئارىلى ، ئامېرىكا",
    "Viet Nam" : "Vietnam Nam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "ۋاللىس ۋە فۇتۇنا",
    "Samoa" : "ساموئا",
    "Yemen" : "يەمەن",
    "Mayotte" : "مايوت",
    "South Africa" : "جەنۇبى ئافرىقا",
    "Zambia" : "زامبىيە",
    "Zimbabwe" : "زىمبابۋې",
    "Background blur" : "تەگلىك تۇتۇق",
    "Could not check for WASM loading support. Please check manually if your web server serves `.wasm` files." : "WASM يۈكلەشنى قوللىمىدى. تور مۇلازىمېتىرىڭىز `.wasm` ھۆججىتىگە مۇلازىمەت قىلسا قولدا تەكشۈرۈپ بېقىڭ.",
    "Your web server is not properly set up to deliver `.wasm` files. This is typically an issue with the Nginx configuration. For background blur it needs an adjustment to also deliver `.wasm` files. Compare your Nginx configuration to the recommended configuration in our documentation." : "تور مۇلازىمېتىرىڭىز `.wasm` ھۆججىتىنى يەتكۈزۈش ئۈچۈن مۇۋاپىق تەڭشەلمىدى. بۇ ئادەتتە Nginx سەپلىمىسىدىكى مەسىلە. تەگلىك تۇتۇقلىقى ئۈچۈن «.wasm» ھۆججىتىنى يەتكۈزۈش ئۈچۈنمۇ تەڭشەش كېرەك. Nginx سەپلىمىسىنى ھۆججەتلىرىمىزدىكى تەۋسىيە قىلىنغان سەپلىمىگە سېلىشتۇرۇڭ.",
    "Talk configuration values" : "پاراڭ سەپلىمە قىممىتى",
    "Forcing a call duration is only supported with system cron. Please enable system cron or remove the `max_call_duration` configuration." : "چاقىرىش ۋاقتىنى زورلاش پەقەت سىستېما cron بىلەنلا قوللىنىدۇ. سىستېما كروننى قوزغىتىڭ ياكى «max_call_duration» سەپلىمىسىنى ئۆچۈرۈڭ.",
    "Small `max_call_duration` values (currently set to %d) are not enforceable due to technical limitations. The background job is only executed every 5 minutes, so use at own risk." : "كىچىك `max_call_duration` قىممىتى (نۆۋەتتە %d قىلىپ تەڭشەلدى) تېخنىكىلىق چەكلىمىلەر سەۋەبىدىن ئىجرا قىلىنمايدۇ. تەگلىك خىزمىتى ھەر 5 مىنۇتتا بىر قېتىم ئىجرا قىلىنىدۇ ، شۇڭا ئۆزىڭىزنىڭ خەتىرىگە ئاساسەن ئىشلىتىڭ.",
    "Federation" : "فېدېراتسىيە",
    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "سۆھبەت فېدېراتسىيەسى قوزغىتىلغاندا «memcache.locking» نى تەڭشەش تەۋسىيە قىلىنىدۇ.",
    "High-performance backend" : "يۇقىرى ئىقتىدارلىق ئارقا سەپ",
    "No High-performance backend configured - Running Nextcloud Talk without the High-performance backend only scales for very small calls (max. 2-3 participants). Please set up the High-performance backend to ensure calls with multiple participants work seamlessly." : "يۇقىرى ئىقتىدارلىق ئارقا ئۇچى تەڭشىلىنمىدى - Nextcloud سۆھبەتنى يۇقىرى ئىقتىدارلىق ئارقا ئۇچىسىز ئىجرا قىلىۋاتىدۇ، پەقەت ناھايىتى كىچىك تېلېفونلار ئۈچۈنلا ماسلاشتۇرۇلىدۇ (ئەڭ كۆپ بولغاندا 2-3 قاتناشقۇچى). كۆپ قاتناشقۇچىلىق تېلېفونلارنىڭ راۋان ئىشلىشىگە كاپالەتلىك قىلىش ئۈچۈن يۇقىرى ئىقتىدارلىق ئارقا ئۇچىنى تەڭشەڭ.",
    "Running the High-performance backend \"conversation_cluster\" mode is deprecated and will no longer be supported in the upcoming version. The High-performance backend supports real clustering nowadays which should be used instead." : "يۇقىرى ئىقتىدارلىق ئارقا سۇپىدىكى «سۆھبەت_كلاستېر» ھالىتىنى ئىجرا قىلىش ۋاقتى ئۆتكەن ، كېيىنكى نەشرىدە ئەمدى قوللىمايدۇ. يۇقىرى ئىقتىدارلىق ئارقا سۇپى بۈگۈنكى كۈندە ھەقىقىي توپلاشنى قوللايدۇ ، ئۇنىڭ ئورنىغا ئىشلىتىشكە بولىدۇ.",
    "Defining multiple High-performance backends is deprecated and will no longer be supported in the upcoming version. Instead a load-balancer should be set up together with clustered signaling servers and configured in the Talk settings." : "كۆپ ئىقتىدارلىق يۇقىرى ئىقتىدارلىق ئارقا بەلگىنى ئېنىقلاش ۋاقتى ئۆتكەن ، كېيىنكى نەشرىدە ئەمدى قوللىمايدۇ. ئۇنىڭ ئورنىغا يۈك تەڭپۇڭلاشتۇرغۇچ توپلانغان سىگنال مۇلازىمېتىرلىرى بىلەن بىللە ئورنىتىلىپ ، پاراڭلىشىش تەڭشىكىدە تەڭشىلىشى كېرەك.",
    "The stored public key for used algorithm %1$s does not match the stored private key. Run %2$s to fix the issue." : "ئىشلىتىلگەن ئالگورىزىم %1$s نىڭ ساقلانغان ئاممىۋى ئاچقۇچى ساقلانغان شەخسىي ئاچقۇچى بىلەن ماس كەلمەيدۇ. مەسىلىنى ھەل قىلىش ئۈچۈن%2$sنى ئىجرا قىلىڭ.",
    "High-performance backend not configured correctly. Run %s for details." : "يۇقىرى ئىقتىدارلىق ئارقا ئۇچى توغرا تەڭشەلمىگەن. تەپسىلاتىنى كۆرۈش ئۈچۈن %s نى ئىجرا قىلىڭ.",
    "High-performance backend not configured correctly" : "يۇقىرى ئىقتىدارلىق ئارقا سۇپا توغرا تەڭشەلمىگەن",
    "Error: Cannot connect to server" : "خاتالىق: مۇلازىمېتىرغا ئۇلىنالمايدۇ",
    "Error: Server did not respond with proper JSON" : "خاتالىق: مۇلازىمېتىر مۇۋاپىق JSON بىلەن جاۋاب قايتۇرمىدى",
    "Error: Certificate expired" : "خاتالىق: گۇۋاھنامىنىڭ ۋاقتى توشتى",
    "Error: System times of Nextcloud server and High-performance backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "خاتالىق: Nextcloud سېرۋېرى ۋە يۇقىرى ئىقتىدارلىق ئارقا سېرۋېرنىڭ سىستېما ۋاقتى ماسلاشمىدى. ھەر ئىككى سېرۋېرنىڭ ۋاقىت سېرۋېرىغا ئۇلانغانلىقىغا ياكى ۋاقتىنى قولدا ماسلاشتۇرغانلىقىغا كاپالەتلىك قىلىڭ.",
    "Could not get version" : "نەشرىگە ئېرىشەلمىدى",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "خاتالىق: ئىجرا قىلىنىۋاتقان نەشرى: {version}; مۇلازىمېتىرنىڭ بۇ نەشرىگە ماسلىشىش ئۈچۈن يېڭىلىنىشى كېرەك",
    "Error: Server responded with: {error}" : "خاتالىق: مۇلازىمېتىر جاۋاب قايتۇردى: {error}",
    "Error: Unknown error occurred" : "خاتالىق: نامەلۇم خاتالىق كۆرۈلدى",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "ئاگاھلاندۇرۇش: ئىجرا قىلىنىش نۇسخىسى: {version}; مۇلازىمېتىر بۇ سۆھبەت نۇسخىسىنىڭ بارلىق ئىقتىدارلىرىنى قوللىمايدۇ ، يوقاپ كەتكەن ئىقتىدارلار: {features}",
    "It is highly recommended to configure a memory cache when running Nextcloud Talk with a High-performance backend." : "Nextcloud Talk نى يۇقىرى ئىقتىدارلىق ئارقا سۇپىدا ئىجرا قىلغاندا ئىچكى ساقلىغۇچنى تەڭشەش تەۋسىيە قىلىنىدۇ.",
    "Client Push" : "خېرىدار ئىتتىرىشى",
    "Recording backend" : "ئارقا خاتىرىلەش",
    "Using the recording backend requires a High-performance backend." : "خاتىرىلەش ئارقا سۇپىسىنى ئىشلىتىش يۇقىرى ئىقتىدارلىق ئارقا كۆرۈنۈشنى تەلەپ قىلىدۇ.",
    "No recording backend configured" : "ئۈنگە ئېلىش ئارقا سۇپىسى سەپلەنمىگەن",
    "SIP configuration" : "SIP سەپلىمىسى",
    "Using the SIP functionality requires a High-performance backend." : "SIP ئىقتىدارىنى ئىشلىتىش يۇقىرى ئىقتىدارلىق ئارقا كۆرۈنۈشنى تەلەپ قىلىدۇ.",
    "No SIP backend configured" : "SIP ئارقا سۇپىسى سەپلەنمىدى",
    "Invalid date, date format must be YYYY-MM-DD" : "ئىناۋەتسىز چېسلا ، چېسلا فورماتى چوقۇم YYYY-MM-DD بولۇشى كېرەك",
    "Conversation not found" : "سۆھبەت تېپىلمىدى",
    "Path is already shared with this conversation" : "يول بۇ سۆھبەت بىلەن ئورتاقلاشتى",
    "Chat, video & audio-conferencing using WebRTC" : "WebRTC ئارقىلىق پاراڭلىشىش ، سىن ۋە ئاۋازلىق يىغىن",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "WebRTC ئارقىلىق پاراڭلىشىش ، سىن ۋە ئاۋازلىق يىغىن\n\n.\n* 👥 ** شەخسىي ، گۇرۇپپا ، ئاممىۋى ۋە مەخپىي نومۇر قوغدىلىدىغان تېلېفونلار! ** باشقىلارنى ، پۈتۈن گۇرۇپپىنى تەكلىپ قىلىڭ ياكى ئاممىۋى ئۇلىنىش ئەۋەتىپ تېلېفون قىلىڭ.\n* 🌐 ** فېدېراتسىيە پاراڭلىرى ** مۇلازىمېتىردىكى Nextcloud ئىشلەتكۈچىلىرى بىلەن پاراڭلىشىڭ\n* 💻 ** ئېكران ھەمبەھىرلەش! ** تېلېفونىڭىزنى قاتناشقۇچىلار بىلەن ئورتاقلىشىڭ.\n* 🚀 ** باشقا Nextcloud ئەپلىرى بىلەن بىرلەشتۈرۈش ** ھۆججەتلەر ، كالېندار ، ئىشلەتكۈچى ھالىتى ، باش تاختا ، ئاقما ، خەرىتە ، ئەقلىي ئىقتىدارلىق تاللىغۇچ ، ئالاقىلىشىش ، پالۋان ۋە باشقىلار.\n* 🌉 ** باشقا پاراڭلىشىش ھەل قىلىش ئۇسۇللىرى بىلەن ماسقەدەملەڭ ** [Matterbridge] (https://github.com/42wim/matterbridge/) بىلەن سۆھبەتكە بىرلەشتۈرۈلگەندىن كېيىن ، Nextcloud Talk ۋە باشقا نۇرغۇن پاراڭلىشىش ھەل قىلىش ئۇسۇللىرىنى ئاسانلا ماسقەدەملىيەلەيسىز. ئەكسىچە.",
    "Leave call" : "تېلېفون قىلىڭ",
    "Navigating away from the page will leave the call in {conversation}" : "بەتتىن يىراقلاشسىڭىز تېلېفوننى {conversation} قالدۇرىدۇ",
    "Stay in call" : "تېلېفوندا تۇرۇڭ",
    "Error occurred when getting the conversation information" : "سۆھبەت ئۇچۇرىنى ئېلىشتا خاتالىق كۆرۈلدى",
    "Discuss this file" : "بۇ ھۆججەتنى مۇلاھىزە قىلىڭ",
    "Share this file with others to discuss it" : "بۇ ھۆججەتنى باشقىلار بىلەن ئورتاقلىشىڭ",
    "Share this file" : "بۇ ھۆججەتنى ھەمبەھىرلەڭ",
    "Join conversation" : "سۆھبەتكە قاتنىشىڭ",
    "This conversation is password-protected." : "بۇ سۆھبەت مەخپىي نومۇر بىلەن قوغدىلىدۇ.",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "بىز IP دىن نۇرغۇن ئىناۋەتسىز پارول سىنىقىنى بايقىدۇق. شۇڭلاشقا كېيىنكى قېتىملىق سىنىقىڭىز 30 سېكۇنتقا يېتىدۇ.",
    "The password is wrong. Try again." : "پارول خاتا. قايتا سىناڭ.",
    "Password" : "ئىم",
    "Submit" : "يوللاڭ",
    "Error requesting the password." : "پارول تەلەپ قىلىشتىكى خاتالىق.",
    "Request password" : "پارول تەلەپ قىلىڭ",
    "This conversation has ended" : "بۇ سۆھبەت ئاخىرلاشتى",
    "Error occurred when joining the conversation" : "سۆھبەتكە قاتناشقاندا خاتالىق كۆرۈلدى",
    "Close Talk sidebar" : "سۆزلىشىش يانبالدىقىنى تاقاڭ",
    "Open Talk sidebar" : "سۆزلىشىش يانبالدىقىنى ئېچىڭ",
    "Everyone" : "ھەممەيلەن",
    "Users and moderators" : "ئىشلەتكۈچى ۋە رىياسەتچى",
    "Moderators only" : "پەقەت رىياسەتچىلەر",
    "Disable calls" : "چاقىرىشنى چەكلەڭ",
    "Save changes" : "ئۆزگەرتىشلەرنى ساقلاڭ",
    "Saving …" : "ساقلاۋاتىدۇ…",
    "Saved!" : "قۇتۇلدى!",
    "Limit to groups" : "گۇرۇپپىلارغا چەك قويۇڭ",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "كەم دېگەندە بىر گۇرۇپپا تاللانغاندا ، پەقەت تىزىملىكتىكى كىشىلەرلا سۆھبەتنىڭ بىر قىسمى بولالايدۇ.",
    "Guests can still join public conversations." : "مېھمانلار يەنىلا ئاممىۋى سۆھبەتكە قاتناشسا بولىدۇ.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "پاراڭنى ئەمدى ئىشلىتەلمەيدىغان ئابونتلار يەنىلا ئىلگىرىكى سۆھبەتلىرىگە قاتناشقۇچىلار قاتارىغا تىزىلىدۇ ، شۇنداقلا ئۇلارنىڭ پاراڭ ئۇچۇرلىرىمۇ ساقلىنىدۇ.",
    "Limit using Talk" : "سۆزلىشىشنى چەكلەڭ",
    "Limit creating a public and group conversation" : "ئاممىۋى ۋە گۇرۇپپا پاراڭلىشىشنى چەكلەڭ",
    "Limit creating conversations" : "سۆھبەتلىشىشنى چەكلەڭ",
    "Limit starting a call" : "چاقىرىشنى چەكلەڭ",
    "Limit starting calls" : "چاقىرىشنى چەكلەڭ",
    "When a call has started, everyone with access to the conversation can join the call." : "تېلېفون باشلانغاندىن كېيىن ، سۆھبەتنى زىيارەت قىلالايدىغانلارنىڭ ھەممىسى تېلېفونغا قاتناشسا بولىدۇ.",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "بۇ مۇلازىمېتىرغا تۆۋەندىكى بوتلار ئورنىتىلدى. بۇ ھۆججەتتىن قانداق قىلىپ {linkstart1} ئۆزىڭىزنىڭ بوت {linkend} ياكى {linkstart2} بوتۇلكا تىزىملىكى {linkend} نى قانداق قىلىپ مۇلازىمېتىرىڭىزدا قوزغىتىدىغانلىقىنى تەپسىلىي تاپالايسىز.",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "بۇ مۇلازىمېتىرغا ھېچقانداق بوتكا ئورنىتىلمىغان. بۇ ھۆججەتتىن قانداق قىلىپ {linkstart1} ئۆزىڭىزنىڭ بوت {linkend} ياكى {linkstart2} بوتۇلكا تىزىملىكى {linkend} نى قانداق قىلىپ مۇلازىمېتىرىڭىزدا قوزغىتىدىغانلىقىنى تەپسىلىي تاپالايسىز.",
    "Description is not provided" : "چۈشەندۈرۈش تەمىنلەنمىدى",
    "Locked for moderators" : "رىياسەتچىلەر ئۈچۈن قۇلۇپلاندى",
    "Enabled" : "قوزغىتىلدى",
    "Disabled" : "چەكلەنگەن",
    "Bots settings" : "Bots تەڭشىكى",
    "State" : "دۆلەت",
    "Name" : "ئاتى",
    "Last error" : "ئاخىرقى خاتالىق",
    "Total errors count" : "ئومۇمىي خاتالىق سانى",
    "Find more bots" : "تېخىمۇ كۆپ بوتكا تېپىڭ",
    "Trusted servers can be configured at {linkstart}Sharing settings page{linkend}." : "ئىشەنچلىك مۇلازىمېتىرلارنى {linkstart} تەڭشەك تەڭشەك بېتى {linkend} at دا تەڭشىگىلى بولىدۇ.",
    "Beta" : "Beta",
    "Federated chats and calls work already. Attachment handling is coming in a future version." : "بىرلەشمە چات ۋە تېلېفونلار ئاللىبۇرۇن ئىشلەيدۇ. قوشۇمچە ئۇچۇرلارنى بىر تەرەپ قىلىش كېيىنكى نەشرىدە يولغا قويۇلىدۇ.",
    "Enable Federation in Talk app" : "سۆزلىشىش دېتالىدا فېدېراتسىيەنى قوزغىتىڭ",
    "Permissions" : "ئىجازەت",
    "Allow users to be invited to federated conversations" : "ئىشلەتكۈچىلەرنىڭ فېدېراتسىيە سۆھبەتكە تەكلىپ قىلىنىشىغا يول قويۇڭ",
    "Allow users to invite federated users into conversation" : "ئىشلەتكۈچىلەرنىڭ فېدېراتسىيە ئابونتلىرىنى سۆھبەتكە تەكلىپ قىلىشىغا يول قويۇڭ",
    "Only allow to federate with trusted servers" : "پەقەت ئىشەنچلىك مۇلازىمېتىرلار بىلەن فېدېراتسىيە قىلىشقا يول قويۇڭ",
    "When at least one group is selected, only people of the listed groups can invite federated users to conversations." : "كەم دېگەندە بىر گۇرۇپپا تاللانغاندا ، تىزىملىكتىكى كىشىلەرلا فېدېراتسىيە ئابونتلىرىنى سۆھبەتكە تەكلىپ قىلالايدۇ.",
    "Groups allowed to invite federated users" : "گۇرۇپپىلار فېدېراتسىيە ئىشلەتكۈچىلەرنى تەكلىپ قىلىشقا رۇخسەت قىلدى",
    "Select groups …" : "گۇرۇپپىلارنى تاللاڭ…",
    "All messages" : "بارلىق ئۇچۇرلار",
    "@-mentions only" : "@ -تىلغا ئېلىشلا",
    "Off" : "ئىتىك",
    "General settings" : "ئادەتتىكى تەڭشەكلەر",
    "Default notification settings" : "كۆڭۈلدىكى ئۇقتۇرۇش تەڭشىكى",
    "Default group notification" : "كۆڭۈلدىكى گۇرۇپپا ئۇقتۇرۇشى",
    "Default group notification for new groups" : "يېڭى گۇرۇپپىلارغا سۈكۈتتىكى گۇرۇپپا ئۇقتۇرۇشى",
    "Integration into other apps" : "باشقا ئەپلەرگە بىرلەشتۈرۈش",
    "Allow conversations on files" : "ھۆججەتلەردە پاراڭلىشىشقا يول قويۇڭ",
    "Allow conversations on public shares for files" : "ھۆججەتلەرنىڭ ئاممىۋى ئورتاقلىشىشىغا يول قويۇڭ",
    "End-to-end encrypted calls" : "باشتىن-ئاخىر شىفىرلانغان چاقىرىق",
    "Enable encryption" : "شىفىرلاشنى قوزغىتىڭ",
    "End-to-end encrypted calls with a configured SIP bridge require a newer version of the High-performance backend and SIP bridge." : "سەپلىمە قىلىنغان SIP كۆۋرۈكى ئارقىلىق باشتىن-ئاخىر شىفىرلانغان چاقىرىشلار يۇقىرى ئىقتىدارلىق ئارقا ئۇچى ۋە SIP كۆۋرۈكىنىڭ يېڭى نۇسخىسىنى تەلەپ قىلىدۇ.",
    "Mobile clients do not support end-to-end encrypted calls at the moment." : "ھازىر يانفون خېرىدارلىرى باشتىن-ئاخىر شىفىرلانغان چاقىرىشلارنى قوللىمايدۇ.",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "جەدۋەلدىكى ئۇچۇرنىڭ ئۈستىدىكى كۇنۇپكىنى بېسىش ئارقىلىق Struktur AG نىڭ مۇلازىمېتىرلىرىغا ئەۋەتىلىدۇ. تېخىمۇ كۆپ ئۇچۇرلارنى {linkstart} spreed.eu {linkend} at دىن تاپالايسىز.",
    "Pending" : "كۈتۈۋاتىدۇ",
    "Error" : "خاتالىق",
    "Blocked" : "چەكلەنگەن",
    "Active" : "ئاكتىپ",
    "Expired" : "ۋاقتى توشتى",
    "Never" : "ھەرگىز",
    "The trial could not be requested. Please try again later." : "سوراق قىلىنمىدى. كېيىن قايتا سىناڭ.",
    "The account could not be deleted. Please try again later." : "ھېساباتنى ئۆچۈرگىلى بولمىدى. كېيىن قايتا سىناڭ.",
    "Hosted High-performance backend" : "ساھىپخانلىق قىلغان يۇقىرى ئىقتىدارلىق ئارقا سۇپا",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "بىزنىڭ ھەمراھىمىز Struktur AG ساھىبخانلىق سىگنال مۇلازىمىتى تەلەپ قىلىدىغان مۇلازىمەت بىلەن تەمىنلەيدۇ. بۇنىڭ ئۈچۈن پەقەت تۆۋەندىكى جەدۋەلنى تولدۇرۇشىڭىز كېرەك ، Nextcloud تەلەپ قىلىدۇ. مۇلازىمېتىر سىزگە تەڭشەلگەندىن كېيىن كىنىشكا ئاپتوماتىك تولدۇرۇلىدۇ. بۇ مەۋجۇت سىگنال مۇلازىمېتىر تەڭشىكىنى قاپلىۋېتىدۇ.",
    "If your high-performance backend account includes STUN and/or TURN functionality, the settings will be updated accordingly." : "ئەگەر يۇقىرى ئىقتىدارلىق ئارقا سەھنە ھېساباتىڭىزدا STUN ۋە/ياكى TURN ئىقتىدارى بولسا، تەڭشەكلەر شۇنىڭغا ئاساسەن يېڭىلىنىدۇ.",
    "URL of this Nextcloud instance" : "بۇ Nextcloud مىسالىنىڭ URL",
    "Full name of the user requesting the trial" : "سىناق قىلىشنى تەلەپ قىلغان ئىشلەتكۈچىنىڭ تولۇق ئىسمى",
    "Email of the user" : "ئىشلەتكۈچىنىڭ ئېلېكترونلۇق خەت",
    "Language" : "تىل",
    "Country" : "دۆلەت",
    "Request signaling server trial" : "سىگنال مۇلازىمېتىر سىنىقىنى تەلەپ قىلىڭ",
    "You can see the current status of your hosted signaling server in the following table." : "تۆۋەندىكى جەدۋەلدە ساھىبخانلىق سىگنال مۇلازىمېتىرىڭىزنىڭ ھازىرقى ھالىتىنى كۆرەلەيسىز.",
    "Status" : "ھالەت",
    "Created at" : "قۇرۇلدى",
    "Expires at" : "ۋاقتى توشىدۇ",
    "Limits" : "چەكلىمىسى",
    "STUN included" : "STUN كىرگۈزۈلگەن",
    "Yes" : "ھەئە",
    "No" : "ياق",
    "TURN included" : "TURN كىرگۈزۈلگەن",
    "Delete the signaling server account" : "سىگنال مۇلازىمېتىر ھېساباتىنى ئۆچۈرۈڭ",
    "_%n user_::_%n users_" : ["%n ئىشلەتكۈچى","%n ئىشلەتكۈچى"],
    "Installed version: {version}" : "قاچىلانغان نەشرى: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "Nextcloud Talk نى باشقا مۇلازىمەتلەر بىلەن ئۇلاش ئۈچۈن Matterbridge نى قاچىلىسىڭىز بولىدۇ ، تېخىمۇ كۆپ تەپسىلاتلار ئۈچۈن ئۇلارنىڭ {linkstart1} GitHub بېتى {linkend} نى زىيارەت قىلىڭ. بۇ دېتالنى چۈشۈرۈش ۋە قاچىلاشقا بىر ئاز ۋاقىت كېتىدۇ. ۋاقتى ئۆتۈپ كەتسە ، {linkstart2} Nextcloud App {linkend} دىن قولدا قاچىلاڭ.",
    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/…/nextcloud/apps/talk_matterbridge/bin/\"." : "Matterbridge ئىككىلىك ھۆججىتىنىڭ ھوقۇقى خاتا. Matterbridge ئىككىلىك ھۆججىتىنىڭ توغرا ئىشلەتكۈچىگە تەۋە ئىكەنلىكىگە ۋە ئىجرا قىلغىلى بولىدىغانلىقىغا كاپالەتلىك قىلىڭ. ئۇنى «/…/nextcloud/apps/talk_matterbridge/bin/» دىن تاپقىلى بولىدۇ.",
    "Matterbridge binary was not found or couldn't be executed." : "Matterbridge ئىككىلىك تېپىلمىدى ياكى ئىجرا قىلىنمىدى.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "سىز يەنە تەڭشەش ئارقىلىق Matterbridge ئىككىلىك سىستېمىغا قولدا يول قويالايسىز. تېخىمۇ كۆپ ئۇچۇرغا ئېرىشىش ئۈچۈن {linkstart} Matterbridge بىرلەشتۈرۈش ھۆججىتى {linkend} Check نى تەكشۈرۈڭ.",
    "Downloading …" : "چۈشۈرۈش…",
    "Install Talk Matterbridge" : "Talk Matterbridge نى قاچىلاڭ",
    "An error occurred while installing the Matterbridge app" : "Matterbridge دېتالىنى قاچىلىغاندا خاتالىق كۆرۈلدى",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "Talk Matterbridge نى قاچىلىغاندا خاتالىق كۆرۈلدى. ئۇنى قولدا قاچىلاڭ",
    "Failed to execute Matterbridge binary." : "Matterbridge ئىككىلىك سىستېمىنى ئىجرا قىلالمىدى.",
    "Matterbridge integration" : "Matterbridge بىرلەشتۈرۈش",
    "Enable Matterbridge integration" : "Matterbridge نى بىرلەشتۈرۈشنى قوزغىتىڭ",
    "Status: Checking connection" : "ھالىتى: ئۇلىنىشنى تەكشۈرۈش",
    "OK: Running version: {version}" : "ماقۇل: ئىجرا نەشرى: {version}",
    "Error: Server seems to be a Signaling server" : "خاتالىق: مۇلازىمېتىر سىگنال مۇلازىمىتىرىدەك قىلىدۇ",
    "Error: System times of Nextcloud server and Recording backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "خاتالىق: Nextcloud سېرۋېرى ۋە خاتىرىلەش ئارقا ئۇچى سېرۋېرىنىڭ سىستېما ۋاقتى ماسلاشمىدى. ھەر ئىككى سېرۋېرنىڭ ۋاقىت سېرۋېرىغا ئۇلانغانلىقىغا ياكى ۋاقتىنى قولدا ماسلاشتۇرغانلىقىغا كاپالەتلىك قىلىڭ.",
    "Recording backend URL" : "ئارقا ئادرېسنى خاتىرىلەش",
    "Validate SSL certificate" : "SSL گۇۋاھنامىسىنى ئىناۋەتلىك قىلىڭ",
    "Delete this server" : "بۇ مۇلازىمېتىرنى ئۆچۈرۈڭ",
    "Test this server" : "بۇ مۇلازىمېتىرنى سىناپ بېقىڭ",
    "Disabled for all calls" : "بارلىق تېلېفونلار چەكلەنگەن",
    "Enabled for all calls" : "بارلىق تېلېفونلار قوزغىتىلدى",
    "Configurable on conversation level by moderators" : "رىياسەتچىلەرنىڭ سۆھبەت سەۋىيىسىگە تەڭشىگىلى بولىدۇ",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "PHP تەڭشەكلىرى \"upload_max_filesize\" ياكى \"post_max_size\" پەقەت {maxUpload} غا قەدەر ھۆججەت يوللاشقا يول قويىدۇ.",
    "Recording backend settings saved" : "ئارقا بەت تەڭشىكى خاتىرىلەندى",
    "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation." : "رىياسەتچىلەرنىڭ سۆھبەت سەۋىيىسىدە قوشۇلۇشىغا رۇخسەت قىلىنىدۇ. بۇ سۆھبەتتىكى ھەر بىر چاقىرىققا قاتنىشىشتىن بۇرۇن ھەر بىر قاتناشقۇچىغا خاتىرىلەشكە قوشۇلۇش تەلەپ قىلىنىدۇ.",
    "The consent to be recorded will be required for each participant before joining every call." : "خاتىرىلەشكە قوشۇلۇش ھەر بىر قاتناشقۇچىغا ھەر بىر تېلېفونغا قاتنىشىشتىن بۇرۇن تەلەپ قىلىنىدۇ.",
    "The consent to be recorded is not required." : "خاتىرىلەشكە قوشۇلۇش تەلەپ قىلىنمايدۇ.",
    "Recording backend configuration is only possible with a High-performance backend." : "ئارقا ئۇچىنى خاتىرىلەش پەقەت يۇقىرى ئىقتىدارلىق ئارقا ئۇچى ئارقىلىقلا مۇمكىن.",
    "Add a new recording backend server" : "يېڭى خاتىرىلەش ئارقا مۇلازىمېتىرى قوشۇڭ",
    "Shared secret" : "ئورتاق مەخپىيەتلىك",
    "Recording consent" : "خاتىرىلەش",
    "Recording transcription" : "ترانسكرىپسىيەنى خاتىرىلەش",
    "Automatically transcribe call recordings with a transcription provider" : "تېلېفون خاتىرىلىرىنى ترانسكرىپسىيە تەمىنلىگۈچىسى ئارقىلىق ئاپتوماتىك ترانسكرىپسىيە قىلىڭ",
    "Automatically summarize call recordings with transcription and summary providers" : "تېلېفون خاتىرىلىرىنى ترانسكرىپسىيە ۋە خۇلاسە تەمىنلىگۈچىلەر ئارقىلىق ئاپتوماتىك خۇلاسىلاڭ",
    "SIP configuration saved!" : "SIP سەپلىمىسى ساقلاندى!",
    "SIP configuration is only possible with a High-performance backend." : "SIP سەپلىمىسى پەقەت يۇقىرى ئىقتىدارلىق ئارقا ئۇچى ئارقىلىقلا مۇمكىن.",
    "Enable SIP Dial-out option" : "SIP چاقىرىش تاللانمىسىنى قوزغىتىڭ",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "قوللايدىغان SIP Dial-out ئىقتىدارىنى قوللاش ئۈچۈن سىگنال مۇلازىمېتىرىنى يېڭىلاش كېرەك.",
    "Do not show SIP Dial-out caller number" : "SIP تېلېفون نومۇرىنى كۆرسەتمەڭ",
    "Anonymous number should appear as \"unknown\" or \"withheld number\" to call recipient" : "تېلېفون قوبۇل قىلغۇچىغا تېلېفون قىلغاندا نامسىز نومۇر «نامەلۇم» ياكى «ياپون قىلىنغان نومۇر» دەپ كۆرسىتىلىشى كېرەك",
    "Dial-out number" : "نۇمۇر بۇراش نۇمۇرى",
    "E164 formatted number used as a fallback caller number for outgoing calls" : "چىقىش تېلېفونلىرى ئۈچۈن زاپاس تېلېفون نومۇرى سۈپىتىدە ئىشلىتىلىدىغان E164 فورماتىدىكى نومۇر",
    "Dial-out prefix" : "نۇمۇر بۇراش قۇشۇمچىسى",
    "Prefix to configured user number for outgoing calls (default is `+`)" : "چىقىش تېلېفونلىرى ئۈچۈن تەڭشەلگەن ئىشلەتكۈچى نومۇرىنىڭ ئالدىن قوشۇمچىسى (سۈكۈتتىكى ھالىتى `+`)",
    "Restrict SIP configuration" : "SIP سەپلىمىسىنى چەكلەڭ",
    "Enable SIP configuration" : "SIP سەپلىمىسىنى قوزغىتىڭ",
    "Only users of the following groups can enable SIP in conversations they moderate" : "پەقەت تۆۋەندىكى گۇرۇپپىلارنى ئىشلەتكۈچىلەرلا ئوتتۇراھال بولغان سۆھبەتتە SIP نى قوزغىتالايدۇ",
    "Phone number (Country)" : "تېلېفون نومۇرى (دۆلەت)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "بۇ ئۇچۇرلار تەكلىپلىك ئېلېكترونلۇق خەتتە ئەۋەتىلگەن شۇنداقلا يانبالداقتا بارلىق قاتناشقۇچىلارغا كۆرسىتىلىدۇ.",
    "Nextcloud base URL" : "Nextcloud ئاساسىي URL",
    "Talk Backend URL" : "پاراڭ ئارقا سۇپا URL",
    "WebSocket URL" : "WebSocket URL",
    "Available features" : "مەۋجۇت ئىقتىدارلار",
    "Error: Websocket connection failed" : "خاتالىق: Websocket قا ئۇلىنىش مەغلۇپ بولدى",
    "Error code" : "خاتالىق كودى",
    "Error message" : "خاتالىق ئۇچۇرى",
    "Error: Websocket connection failed. Check browser console" : "خاتالىق: تور بېكەتكە ئۇلىنىش مەغلۇپ بولدى. تور كۆرگۈچ كونترول تاختىسىنى تەكشۈرۈڭ.",
    "High-performance backend URL" : "يۇقىرى ئىقتىدارلىق ئارقا كۆرۈنۈش URL",
    "Missing High-performance backend warning hidden" : "يۇقىرى ئىقتىدارلىق ئارقا سۇپا ئاگاھلاندۇرۇشى يوقاپ كەتتى",
    "High-performance backend settings saved" : "يۇقىرى ئىقتىدارلىق ئارقا سەپلىمىسى ساقلاندى",
    "Nextcloud Talk setup not complete" : "Nextcloud پاراڭنى قاچىلاش تاماملانمىدى",
    "Please note that in calls with more than 2 participants without the High-performance backend, participants will most likely experience connectivity issues and cause high load on participating devices." : "يۇقىرى ئىقتىدارلىق ئارقا ئۇچى بولمىغان 2 دىن ئارتۇق قاتناشقۇچىسى بار تېلېفونلاردا، قاتناشقۇچىلارنىڭ ئۇلىنىش مەسىلىسىگە دۇچ كېلىشى ۋە قاتناشقۇچى ئۈسكۈنىلەرگە ئېغىر يۈك ئېلىپ كېلىشى مۇمكىنلىكىنى ئۇنۇتماڭ.",
    "Install the High-performance backend to ensure calls with multiple participants work seamlessly." : "كۆپ قاتناشقۇچىلىق تېلېفونلارنىڭ راۋان ئىشلىشىگە كاپالەتلىك قىلىش ئۈچۈن يۇقىرى ئىقتىدارلىق ئارقا ئۇچىنى ئورنىتىڭ.",
    "Nextcloud portal" : "Nextcloud پورتالى",
    "Quick installation guide" : "تېز قاچىلاش قوللانمىسى",
    "The High-performance backend is required for calls and conversations with multiple participants. Without the backend, all participants have to upload their own video individually for each other participant, which will most likely cause connectivity issues and a high load on participating devices." : "يۇقىرى ئىقتىدارلىق ئارقا ئۇچى كۆپ قاتناشقۇچىلار بىلەن تېلېفون قىلىش ۋە سۆھبەتلىشىش ئۈچۈن تەلەپ قىلىنىدۇ. ئارقا ئۇچى بولمىسا، بارلىق قاتناشقۇچىلار بىر-بىرى ئۈچۈن ئايرىم-ئايرىم ھالدا ئۆزلىرىنىڭ سىنلىرىنى يوللىشى كېرەك، بۇ بولسا ئۇلىنىش مەسىلىسى ۋە قاتناشقۇچى ئۈسكۈنىلەرنىڭ يۈكىنىڭ ئېغىرلىشىشىنى كەلتۈرۈپ چىقىرىدۇ.",
    "It is highly recommended to set up a distributed cache when using Nextcloud Talk with a High-performance backend." : "يۇقىرى ئىقتىدارلىق ئارقا ئۇچى بىلەن Nextcloud Talk ئىشلەتكەندە، تارقىتىلغان كېش ساقلاش بوشلۇقىنى تەڭشەش تەۋسىيە قىلىنىدۇ.",
    "Add High-performance backend server" : "يېڭى يۇقىرى ئىقتىدارلىق ئارقا سۇپا مۇلازىمېتىرنى قوشۇڭ",
    "Warn about connectivity issues in calls with more than 2 participants" : "2 دىن ئارتۇق قاتناشقۇچىسى بار تېلېفونلاردا ئۇلىنىش مەسىلىسى توغرىسىدا ئاگاھلاندۇرۇش",
    "STUN server URL" : "STUN مۇلازىمېتىر ئادرېسى",
    "The server address is invalid" : "مۇلازىمېتىر ئادرېسى ئىناۋەتسىز",
    "STUN settings saved" : "STUN تەڭشىكى ساقلاندى",
    "STUN servers" : "STUN مۇلازىمېتىرلىرى",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN مۇلازىمېتىرى روتېرنىڭ ئارقىسىدىكى قاتناشقۇچىلارنىڭ ئاممىۋى IP ئادرېسىنى ئېنىقلاشقا ئىشلىتىلىدۇ.",
    "Add a new STUN server" : "يېڭى STUN مۇلازىمېتىرنى قوشۇڭ",
    "{schema} scheme must be used with a domain" : "{schema} پىلانى چوقۇم تور دائىرىسى بىلەن ئىشلىتىلىشى كېرەك",
    "{option1} and {option2}" : "{option1} ۋە {option2}",
    "{option} only" : "{option} پەقەت",
    "OK: Successful ICE candidates returned by the TURN server" : "بولىدۇ: مۇۋەپپەقىيەتلىك ICE كاندىداتلىرى TURN مۇلازىمېتىرى تەرىپىدىن قايتۇرۇلغان",
    "Error: No working ICE candidates returned by the TURN server" : "خاتالىق: TURN مۇلازىمېتىرى تەرىپىدىن قايتۇرۇلغان ICE كاندىداتلىرى يوق",
    "Testing whether the TURN server returns ICE candidates" : "TURN مۇلازىمېتىرىنىڭ ICE كاندىداتلىرىنى قايتۇرغان-قايتۇرمىغانلىقىنى سىناش",
    "TURN server schemes" : "TURN مۇلازىمېتىر لايىھەلىرى",
    "TURN server URL" : "مۇلازىمېتىر ئادرېسى",
    "TURN server secret" : "مۇلازىمېتىرنىڭ مەخپىيىتى",
    "TURN server protocols" : "TURN مۇلازىمېتىر كېلىشىمنامىسى",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "TURN مۇلازىمېتىرى مۇداپىئە تامنىڭ كەينىدىكى قاتناشقۇچىلارنىڭ ئېقىمىنى ۋاكالەتچى قىلىشقا ئىشلىتىلىدۇ. ئەگەر ئايرىم قاتناشقۇچىلار باشقىلارغا ئۇلىنالمىسا TURN مۇلازىمېتىرى تەلەپ قىلىنىدۇ. تەڭشەش كۆرسەتمىسى ئۈچۈن {linkstart} بۇ ھۆججەت {linkend} See دىن كۆرۈڭ.",
    "TURN settings saved" : "TURN تەڭشىكى ساقلاندى",
    "TURN servers" : "TURN مۇلازىمېتىرلىرى",
    "Add a new TURN server" : "يېڭى TURN مۇلازىمېتىرنى قوشۇڭ",
    "Failed" : "مەغلۇب بولدى",
    "OK" : "جەزملە",
    "Checking …" : "تەكشۈرۈش…",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "مەغلۇپ بولدى: بۇ توركۆرگۈدە WebAssemble چەكلەنگەن ياكى قوللىمايدۇ. WebAssemble نى قوزغىتىڭ ياكى ئۇنى قوللاش ئۈچۈن توركۆرگۈ ئىشلىتىڭ.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "مەغلۇپ بولدى: \".wasm\" ۋە \".tflite\" ھۆججەتلىرى تور مۇلازىمېتىرى تەرىپىدىن توغرا قايتۇرۇلمىدى. سۆھبەت ھۆججىتىدىكى «سىستېما تەلىپى» بۆلىكىنى تەكشۈرۈپ بېقىڭ.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "بولىدۇ: \".wasm\" ۋە \".tflite\" ھۆججەتلىرى تور مۇلازىمېتىرى تەرىپىدىن مۇۋاپىق قايتۇرۇلدى.",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "قارىغاندا PHP ۋە Apache سەپلىمىسى ماسلاشمىغاندەك قىلىدۇ. شۇنىڭغا دىققەت قىلىڭكى ، PHP نى پەقەت MPM_PREFORK مودۇلى بىلەنلا ئىشلەتكىلى بولىدۇ ، PHP-FPM پەقەت MPM_EVENT مودۇلىدىلا ئىشلىتىلىدۇ.",
    "Web server setup checks" : "تور مۇلازىمېتىرنى تەڭشەش",
    "Files required for virtual background can be loaded" : "مەۋھۇم تەگلىك ئۈچۈن لازىملىق ھۆججەتلەرنى يۈكلەشكە بولىدۇ",
    "Federated user" : "فېدېراتسىيە ئىشلەتكۈچى",
    "Assign participants to rooms" : "قاتناشقۇچىلارنى ياتاققا تەقسىم قىلىڭ",
    "Configure breakout rooms" : "بۆسۈش ئۆيلىرىنى سەپلەڭ",
    "Number of breakout rooms" : "بۆسۈش ئۆي سانى",
    "You can create from 1 to 20 breakout rooms." : "1 دىن 20 گىچە بۆسۈش ئۆيى قۇرالايسىز.",
    "Assignment method" : "تاپشۇرۇش ئۇسۇلى",
    "Automatically assign participants" : "قاتناشقۇچىلارنى ئاپتوماتىك تەقسىملەيدۇ",
    "Manually assign participants" : "قاتناشقۇچىلارنى قولدا تەقسىم قىلىڭ",
    "Allow participants to choose" : "قاتناشقۇچىلارنىڭ تاللىشىغا يول قويۇڭ",
    "Create rooms" : "ياتاق قۇرۇش",
    "Confirm" : "جەزملەشتۈرۈڭ",
    "Create breakout rooms" : "بۆسۈش ئۆيى قۇرۇش",
    "Reset" : "ئەسلىگە قايتۇرۇش",
    "Delete breakout rooms" : "بۆسۈش ئۆيلىرىنى ئۆچۈرۈڭ",
    "Room {roomNumber}" : "ياتاق {roomNumber}",
    "Current breakout rooms and settings will be lost" : "نۆۋەتتىكى بۆسۈش ئۆيى ۋە تەڭشەكلىرى يوقاپ كېتىدۇ",
    "Cancel" : "ۋاز كەچ",
    "Unassigned participants" : "ئىمزا قويمىغان قاتناشقۇچىلار",
    "Back" : "قايتىش",
    "Assign" : "تاپشۇرۇق",
    "Add participant \"{user}\"" : "قاتناشقۇچى \"{user}\" نى قوشۇڭ",
    "Now" : "ھازىر",
    "Invalid calendar selected" : "ئىناۋەتسىز يىلنامە تاللاندى",
    "Invalid start time selected" : "ئىناۋەتسىز باشلاش ۋاقتى تاللاندى",
    "Invalid end time selected" : "ئىناۋەتسىز ئاخىرلىشىش ۋاقتى تاللاندى",
    "Unknown error occurred" : "نامەلۇم خاتالىق كۆرۈلدى",
    "Sending no invitations" : "تەكلىپنامە ئەۋەتمەيۋاتىدۇ",
    "{participant0} will receive an invitation" : "{participant0} تەكلىپ تاپشۇرۋالىدۇ",
    "{participant0} and {participant1} will receive invitations" : "{participant0} بىلەن {participant1} تەكلىپ تاپشۇرۋالىدۇ",
    "_{participant0}, {participant1} and %n other will receive invitations_::_{participant0}, {participant1} and %n others will receive invitations_" : ["{participant0}، {participant1}، %n باشقىلار تەكلىپ تاپشۇرۋالىدۇ","{participant0}، {participant1}، %n باشقىلار تەكلىپ تاپشۇرۋالىدۇ"],
    "Invite {user}" : "{user} نى تەكلىپ قىل",
    "Invite all users and emails in this conversation" : "بۇ سۆھبەتتىكى بارلىق ئىشلەتكۈچىلەرنى ۋە ئېلخەتلەرنى تەكلىپ قىلىڭ",
    "Meeting created" : "يىغىن قۇرۇلدى",
    "Upcoming meetings" : "كىيىنكى يىغىنلار",
    "Loading …" : "يۈكلەۋاتىدۇ…",
    "No upcoming meetings" : "كىلىدىغان يىغىنلار يوق",
    "Schedule a meeting" : "بىر يىغىن ئورۇنلاشتۇر",
    "Meeting title" : "يىغىن ماۋزۇسى",
    "From" : "دىن",
    "To" : "غا",
    "Calendar" : "كالېندار",
    "Attendees" : "قاتناشقۇچىلار",
    "No other participants to send invitations to." : "تەكلىپنى ئەۋەتىدىغان باشقا قاتناشقۇچى يوق.",
    "Add attendees" : "قاتناشقۇچىلارنى قوش",
    "Save" : "ساقلا",
    "Search participants" : "قاتناشقۇچىلارنى ئىزدە",
    "No results" : "ھېچقانداق نەتىجە يوق",
    "Done" : "تامام",
    "Disable live transcription" : "نەق-مەيدان ترانسكرىپسىيەلەشنى ئەت",
    "Raise hand" : "قولىنى كۆتۈرۈڭ",
    "Raise hand (R)" : "قولىنى كۆتۈرۈڭ (R)",
    "Lower hand" : "تۆۋەن قول",
    "Lower hand (R)" : "تۆۋەن قول (R)",
    "Exit full screen (F)" : "تولۇق ئېكراندىن چىقىڭ (F)",
    "Full screen (F)" : "تولۇق ئېكران (F)",
    "Speaker view" : "ياڭراتقۇ كۆرۈنۈشى",
    "Grid view" : "كاتەكچە كۆرۈنۈش",
    "Error when trying to load the available live transcription languages" : "مەۋجۇت بولغان نەق مەيدان كۆچۈرۈش تىللىرىنى يۈكلەشتە خاتالىق كۆرۈلدى",
    "Failed to enable live transcription" : "نەق-مەيدان ترانسكرىپسىيەلەشنى قوزغىتىش مەغلۇپ بولدى",
    "Recording consent is required" : "خاتىرىلەش ئىجازىتى تەلەپ قىلىنىدۇ",
    "This conversation is read-only" : "بۇ سۆھبەت پەقەت ئوقۇلىدۇ",
    "Conversation not found or not joined" : "سۆھبەت تېپىلمىدى ياكى قوشۇلمىدى",
    "Lobby is still active and you're not a moderator" : "لوبى يەنىلا ئاكتىپ ، سىز رىياسەتچى ئەمەس",
    "Connection failed" : "ئۇلىنىش مەغلۇپ بولدى",
    "Reload" : "قايتا يۈكلەڭ",
    "{nickName} raised their hand." : "{nickName} ئۇلارنىڭ قولىنى كۆتۈردى.",
    "A participant raised their hand." : "بىر قاتناشقۇچى قولىنى كۆتۈردى.",
    "Collapse stripe" : "يىمىرىلىش يولى",
    "Expand stripe" : "بەلۋاغنى كېڭەيتىش",
    "Previous page of videos" : "سىنلارنىڭ ئالدىنقى بېتى",
    "Next page of videos" : "سىنلارنىڭ كېيىنكى بېتى",
    "Connecting …" : "ئۇلىنىش…",
    "Calling …" : "چاقىرىش…",
    "Waiting for {user} to join the call" : "{user} نىڭ چاقىرىققا قاتنىشىشىنى ساقلاش",
    "Waiting for others to join the call …" : "باشقىلارنىڭ تېلېفونغا قاتنىشىشىنى ساقلاش…",
    "You can invite others in the participant tab of the sidebar" : "يان كۆزنەكنىڭ قاتناشقۇچىلار بەتكۈچىدە باشقىلارنى تەكلىپ قىلسىڭىز بولىدۇ",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "سىز يان كۆزنەكنىڭ قاتناشقۇچىلار بەتكۈچىدە باشقىلارنى تەكلىپ قىلالايسىز ياكى بۇ ئۇلىنىشنى ھەمبەھىرلەپ باشقىلارنى تەكلىپ قىلالايسىز!",
    "Share this link to invite others!" : "باشقىلارنى تەكلىپ قىلىش ئۈچۈن بۇ ئۇلىنىشنى ھەمبەھىرلەڭ!",
    "Copy link" : "ئۇلانمىنى كۆچۈرۈڭ",
    "You are not allowed to enable audio" : "ئاۋازنى قوزغىتىشىڭىزغا رۇخسەت قىلىنمايدۇ",
    "No audio. Click to select device" : "ئاۋاز يوق. ئۈسكۈنىنى تاللاش ئۈچۈن چېكىڭ",
    "Mute audio" : "ئاۋازسىز",
    "Mute audio (M)" : "ئاۋازسىز ئاۋاز (M)",
    "Unmute audio" : "ئاۋازسىز ئاۋاز",
    "Unmute audio (M)" : "ئاۋازسىز ئاۋاز (M)",
    "None" : "يوق",
    "Select a microphone" : "مىكروفوننى تاللاڭ",
    "Select a speaker" : "بىر سۆزلىگۈچى تاللا",
    "Check devices" : "ئۈسكۈنىلەرنى تەكشۈر",
    "Access to camera was denied" : "كامېراغا كىرىش رەت قىلىندى",
    "Error while accessing camera: It is likely in use by another program" : "كامېرانى زىيارەت قىلغاندا خاتالىق: ئۇنى باشقا پروگرامما ئىشلىتىشى مۇمكىن",
    "Error while accessing camera" : "كامېرانى زىيارەت قىلغاندا خاتالىق",
    "You have been muted by a moderator" : "سىز بىر رىياسەتچى تەرىپىدىن ئاۋازسىز قىلىندى",
    "Hide presenter video" : "رىياسەتچى سىننى يوشۇرۇش",
    "You are not allowed to enable video" : "سىننى قوزغىتىشىڭىزغا رۇخسەت قىلىنمايدۇ",
    "No video. Click to select device" : "سىن يوق. ئۈسكۈنىنى تاللاش ئۈچۈن چېكىڭ",
    "Disable video" : "سىننى چەكلەڭ",
    "Disable video (V)" : "سىننى چەكلەش (V)",
    "Enable video" : "سىننى قوزغىتىڭ",
    "Enable video (V)" : "سىننى قوزغىتىش (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "سىننى قوزغىتىش - سىننى تۇنجى قېتىم قوزغىتىپ قويسىڭىز ئۇلىنىشىڭىز ئۈزۈلۈپ قالىدۇ",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "سىننى قوزغىتىش (V) - سىننى تۇنجى قېتىم قوزغىتىپ قويسىڭىز ئۇلىنىشىڭىز ئۈزۈلۈپ قالىدۇ",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "سىننى قوزغىتىڭ. بۇ فىلىمنى تۇنجى قېتىم قوزغىتىپ قويسىڭىز ئۇلىنىشىڭىز ئۈزۈلۈپ قالىدۇ",
    "Select a video device" : "بىر سىن ئۈسكۈنىسى تاللا",
    "Show presenter" : "رىياسەتچى كۆرسەت",
    "You" : "سەن",
    "Mute" : "جىمجىتلا",
    "Muted" : "ئاۋازسىز",
    "Show screen" : "ئېكراننى كۆرسىتىش",
    "Stop following" : "ئەگىشىشنى توختىتىڭ",
    "Connection could not be established …" : "ئۇلىنىش قۇرۇلمىدى…",
    "Connection was lost and could not be re-established …" : "ئۇلىنىش يوقاپ كەتتى ، قايتا قۇرغىلى بولمىدى…",
    "Connection could not be established. Trying again …" : "ئۇلىنىش قۇرۇلمىدى. قايتا سىناڭ…",
    "Connection lost. Trying to reconnect …" : "ئۇلىنىش يوقاپ كەتتى. قايتا ئۇلىماقچى بولۇۋاتىدۇ…",
    "Connection problems …" : "ئۇلىنىش مەسىلىسى…",
    "Collapse" : "يىمىرىلىش",
    "Expand" : "كېڭەيتىش",
    "You need to be logged in to upload files" : "ھۆججەتلەرنى يوللاش ئۈچۈن تىزىملىتىشىڭىز كېرەك",
    "Drop your files to upload" : "يۈكلەش ئۈچۈن ھۆججەتلىرىڭىزنى تاشلاڭ",
    "Conversation messages" : "سۆھبەت ئۇچۇرلىرى",
    "Scroll to bottom" : "ئاستىغا يۆتكەڭ",
    "Post message" : "ئۇچۇر يوللاش",
    "Federated conversation" : "فېدېراتسىيە سۆھبەت",
    "Public conversation" : "ئاممىۋى سۆھبەت",
    "Favorite" : "يىغقۇچ",
    "Banned users" : "چەكلەنگەن ئىشلەتكۈچى",
    "Manage the list of banned users in this conversation." : "بۇ سۆھبەتتە چەكلەنگەن ئابونتلارنىڭ تىزىملىكىنى باشقۇرۇڭ.",
    "Manage bans" : "چەكلەشنى باشقۇرۇش",
    "No banned users" : "چەكلەنگەن ئىشلەتكۈچى يوق",
    "Banned by:" : "چەكلىگەن:",
    "Date:" : "چېسلا:",
    "Note:" : "ئەسكەرتىش:",
    "Hide details" : "تەپسىلاتلارنى يوشۇرۇش",
    "Show details" : "تەپسىلاتلارنى كۆرسەت",
    "Unban" : "چەكلىمە",
    "You can change the title and the description in {linkstart}Calendar ↗{linkend}." : "ماۋزۇ ۋە چۈشەندۈرۈشنى {linkstart}Calendar ↗{linkend} دىن ئۆزگەرتەلەيسىز.",
    "Error while updating conversation name" : "سۆھبەت نامىنى يېڭىلىغاندا خاتالىق",
    "Error while updating conversation description" : "سۆھبەت تەسۋىرىنى يېڭىلىغاندا خاتالىق",
    "Enter a name for this conversation" : "بۇ سۆھبەتكە ئىسىم كىرگۈزۈڭ",
    "Edit conversation name" : "سۆھبەت نامىنى تەھرىرلەڭ",
    "Edit conversation description" : "سۆھبەت چۈشەندۈرۈشىنى تەھرىرلەڭ",
    "Enter a description for this conversation" : "بۇ سۆھبەتنىڭ چۈشەندۈرۈشىنى كىرگۈزۈڭ",
    "Picture" : "رەسىم",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "بۇ سۆھبەتتە تۆۋەندىكى بوتۇلكىلارنى قوزغىتىشقا بولىدۇ. بۇ مۇلازىمېتىرغا تېخىمۇ كۆپ بوتكا ئورنىتىش ئۈچۈن باشقۇرۇشقا ئالاقىلىشىڭ.",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "بۇ مۇلازىمېتىرغا ھېچقانداق بوتكا ئورنىتىلمىغان. بۇ مۇلازىمېتىرغا بوتكا ئورنىتىش ئۈچۈن باشقۇرۇشقا ئالاقىلىشىڭ.",
    "Disable" : "چەكلە",
    "Enable" : "قوزغىتىش",
    "Breakout rooms" : "ياتاق ئۆي",
    "Manage breakout rooms" : "بۆسۈش ئۆيلىرىنى باشقۇرۇش",
    "Set up breakout rooms for this conversation" : "بۇ سۆھبەت ئۈچۈن بۆسۈش ئۆيى تەسىس قىلىڭ",
    "Please select a valid PNG or JPG file" : "ئىناۋەتلىك PNG ياكى JPG ھۆججىتىنى تاللاڭ",
    "Choose your conversation picture" : "سۆھبەت رەسىمىڭىزنى تاللاڭ",
    "Choose" : "تاللاڭ",
    "Error setting conversation picture" : "سۆھبەت رەسىمىنى تەڭشەشتە خاتالىق",
    "Could not set the conversation picture: {error}" : "سۆھبەت رەسىمىنى تەڭشىيەلمىدى: {error}",
    "Error cropping conversation picture" : "سۆھبەت رەسىمىنى كېسىشتە خاتالىق",
    "Error removing conversation picture" : "سۆھبەت رەسىمىنى ئۆچۈرۈشتە خاتالىق",
    "Set emoji as conversation picture" : "Emoji نى سۆھبەت رەسىمى قىلىپ تەڭشەڭ",
    "Set background color for conversation picture" : "سۆھبەت رەسىمىنىڭ تەگلىك رەڭگىنى بەلگىلەڭ",
    "Upload conversation picture" : "سۆھبەت رەسىمىنى يۈكلەڭ",
    "Choose conversation picture from files" : "ھۆججەتلەردىن سۆھبەت رەسىمىنى تاللاڭ",
    "Remove conversation picture" : "سۆھبەت رەسىمىنى ئۆچۈرۈڭ",
    "The file must be a PNG or JPG" : "ھۆججەت چوقۇم PNG ياكى JPG بولۇشى كېرەك",
    "Set picture" : "رەسىم بەلگىلەڭ",
    "Default permissions modified for {conversationName}" : "كۆڭۈلدىكى سۆھبەت {conversationName} غا ئۆزگەرتىلدى",
    "Could not modify default permissions for {conversationName}" : "{conversationName} نىڭ كۆڭۈلدىكى ئىجازەتلىرىنى ئۆزگەرتەلمىدى",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "بۇ سۆھبەتكە قاتناشقۇچىلارنىڭ كۆڭۈلدىكى ئىجازەتلىرىنى تەھرىرلەڭ. بۇ تەڭشەكلەر رىياسەتچىلەرگە تەسىر كۆرسەتمەيدۇ.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "بۇ بۆلەكتە ھەر قېتىم ئىجازەت ئۆزگەرتىلگەندە ، ئىلگىرى ئايرىم قاتناشقۇچىلارغا تەقسىم قىلىنغان ئىختىيارى ئىجازەتلەر يوقىلىدۇ.",
    "All permissions" : "بارلىق ئىجازەتلەر",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "قاتناشقۇچىلارنىڭ چاقىرىشنى باشلاش ، چاقىرىشقا قاتنىشىش ، ئاۋاز ۋە سىننى قوزغىتىش ۋە ئېكراننى ھەمبەھىرلەش ھوقۇقى بار.",
    "Restricted" : "چەكلەنگەن",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "قاتناشقۇچىلار تېلېفونغا قاتناشسا بولىدۇ ، ئەمما رىياسەتچى ئۇلارغا ئىجازەت بەرمىگۈچە ئاۋاز ، سىن ياكى ئېكراننى ھەمبەھىرلىيەلمەيدۇ.",
    "Advanced permissions" : "ئالىي ئىجازەت",
    "Edit permissions" : "ئىجازەتلەرنى تەھرىرلەڭ",
    "Conversation settings" : "سۆھبەت تەڭشەكلىرى",
    "Basic Info" : "ئاساسىي ئۇچۇر",
    "Personal" : "شەخسىي",
    "Moderation" : "ئوتتۇراھال",
    "Setup overview" : "تەڭشەش ئومۇمىي ئەھۋالى",
    "Live transcription" : "نەق-مەيدان ترانسكرىپسىيەلەش",
    "Enable live transcription" : "نەق-مەيدان ترانسكرىپسىيەلەشنى قوزغات",
    "Breakout Rooms" : "ئارام ئېلىش ئۆيلىرى",
    "Matterbridge" : "Matterbridge",
    "Bots" : "بوتلار",
    "Danger zone" : "خەتەر رايونى",
    "Archive conversation" : "ئارخىپ سۆھبىتى",
    "Archived conversations are hidden from the conversation list by default. However, they will still appear when you search for the conversation name or access a list of archived conversations." : "ئارخىپلانغان سۆھبەتلەر ئۆزلۈكىدىن سۆھبەت تىزىملىكىدىن يوشۇرۇلىدۇ. قانداقلا بولمىسۇن، سىز سۆھبەت نامىنى ئىزدىگەندە ياكى ئارخىپلانغان سۆھبەتلەر تىزىملىكىگە كىرگىنىڭىزدە، ئۇلار يەنىلا كۆرۈنىدۇ.",
    "Do you really want to leave \"{displayName}\"?" : "راستىنلا \"{displayName}\" دىن ئايرىلغۇڭىز بارمۇ؟",
    "You can archive this conversation instead." : "ئۇنىڭ ئورنىغا بۇ سۆھبەتنى ئارخىپلاشتۇرالايسىز.",
    "Leave conversation" : "سۆھبەتتىن ۋاز كېچىڭ",
    "You need to promote a new moderator before you can leave the conversation" : "سۆھبەتتىن ئايرىلىشتىن بۇرۇن يېڭى رىياسەتچىنى تەشۋىق قىلىشىڭىز كېرەك",
    "Delete conversation" : "سۆھبەتنى ئۆچۈرۈڭ",
    "Do you really want to delete \"{displayName}\"?" : "راستىنلا \"{displayName}\" نى ئۆچۈرمەكچىمۇ؟",
    "Error while deleting conversation" : "سۆھبەتنى ئۆچۈرگەندە خاتالىق",
    "Delete all chat messages" : "بارلىق پاراڭ ئۇچۇرلىرىنى ئۆچۈرۈڭ",
    "Do you really want to delete all messages in \"{displayName}\"?" : "«{displayName}» دىكى بارلىق ئۇچۇرلارنى ئۆچۈرمەكچىمۇ؟",
    "Error while clearing chat history" : "پاراڭلىشىش تارىخىنى تازىلاشتا خاتالىق",
    "Be careful, these actions cannot be undone." : "ئېھتىيات قىلىڭ ، بۇ ھەرىكەتلەرنى ئەمەلدىن قالدۇرغىلى بولمايدۇ.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "سۆھبەت ئاخىرلاشقاندىن كېيىن ، يېپىق سۆھبەتكە قايتا قاتنىشىش ئۈچۈن تەكلىپ قىلىش كېرەك. ئوچۇق سۆھبەتنى ھەر ۋاقىت قايتا جەم قىلغىلى بولىدۇ.",
    "Permanently delete this conversation." : "بۇ سۆھبەتنى مەڭگۈلۈك ئۆچۈرۈڭ.",
    "Delete chat messages" : "پاراڭ ئۇچۇرلىرىنى ئۆچۈرۈڭ",
    "Permanently delete all the messages in this conversation." : "بۇ سۆھبەتتىكى بارلىق ئۇچۇرلارنى مەڭگۈلۈك ئۆچۈرۈڭ.",
    "_%n hour_::_%n hours_" : ["%n سائەت","%n سائەت"],
    "_%n day_::_%n days_" : ["%n كۈن","%n كۈن"],
    "_%n week_::_%n weeks_" : ["%n ھەپتە","%n ھەپتە"],
    "Custom expiration time" : "ئىختىيارى ئىشلىتىش ۋاقتى",
    "Message expiration disabled" : "ئۇچۇرنىڭ مۇددىتى چەكلەنگەن",
    "Message expiration set: {duration}" : "ئۇچۇرنىڭ ۋاقتى: {duration}",
    "Error when trying to set message expiration" : "ئۇچۇرنىڭ مۇددىتى توشماقچى بولغاندا خاتالىق",
    "Message expiration" : "ئۇچۇرنىڭ ۋاقتى توشىدۇ",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "پاراڭلىشىش ئۇچۇرلىرى مەلۇم ۋاقىتتىن كېيىن توشىدۇ. ئەسكەرتىش: پاراڭدا ھەمبەھىرلەنگەن ھۆججەتلەر ئىگىسى ئۈچۈن ئۆچۈرۈلمەيدۇ ، ئەمما سۆھبەتتە ئەمدى ھەمبەھىرلەنمەيدۇ.",
    "Set message expiration" : "ئۇچۇرنىڭ ۋاقتى توشىدۇ",
    "Current message expiration" : "نۆۋەتتىكى ئۇچۇرنىڭ ۋاقتى توشىدۇ",
    "Password copied to clipboard" : "پارول كۆچۈرۈش تاختىسىغا كۆچۈرۈلدى",
    "Password could not be copied" : "پارولنى كۆچۈرگىلى بولمىدى",
    "Guest access" : "مېھمان زىيارەت قىلىش",
    "Breakout rooms are not allowed in public conversations." : "ئاممىۋى پاراڭلاردا دەم ئېلىش ئۆيى رۇخسەت قىلىنمايدۇ.",
    "Allow guests to join this conversation via link" : "مېھمانلارنىڭ ئۇلىنىش ئارقىلىق بۇ سۆھبەتكە قاتنىشىشىغا يول قويۇڭ",
    "Password protection" : "پارول قوغداش",
    "This conversation is password-protected. Guests need password to join" : "بۇ سۆھبەت مەخپىي نومۇر بىلەن قوغدىلىدۇ. مىھمانلار مەخپىي نۇمۇر ئارقىلىق كىرىدۇ",
    "Password protection is needed for public conversations" : "ئاممىۋى سۆھبەتلەرنى پارول بىلەن قوغداش كېرەك",
    "Set a password" : "پارول بەلگىلەڭ",
    "Change password" : "پارولنى ئۆزگەرتىڭ",
    "Enter new password" : "يېڭى پارول كىرگۈزۈڭ",
    "Save password" : "پارولنى ساقلاڭ",
    "Copy password" : "پارول كۆچۈر",
    "Guests are allowed to join this conversation via link" : "مېھمانلارنىڭ ئۇلىنىش ئارقىلىق بۇ سۆھبەتكە قاتنىشىشىغا رۇخسەت قىلىنىدۇ",
    "Guests are not allowed to join this conversation" : "مېھمانلارنىڭ بۇ سۆھبەتكە قاتنىشىشىغا رۇخسەت قىلىنمايدۇ",
    "Resend invitations" : "تەكلىپنامىنى قايتۇرۇڭ",
    "This conversation is open to both registered users and users created with the Guests app" : "بۇ سۆھبەت مېھمانلار دېتالى بىلەن قۇرۇلغان تىزىملاتقان ئابونتلار ۋە ئىشلەتكۈچىلەر ئۈچۈن ئوچۇق",
    "This conversation is open to registered users" : "بۇ سۆھبەت تىزىملاتقان ئابونتلارغا ئوچۇق",
    "This conversation is limited to the current participants" : "بۇ سۆھبەت نۆۋەتتىكى قاتناشقۇچىلار بىلەنلا چەكلىنىدۇ",
    "You opened the conversation to both registered users and users created with the Guests app" : "سىز مېھمانلار دېتالى بىلەن قۇرغان تىزىملاتقان ئابونتلار ۋە ئىشلەتكۈچىلەرگە سۆھبەتنى ئاچتىڭىز",
    "Error occurred when opening or limiting the conversation" : "سۆھبەتنى ئاچقاندا ياكى چەكلىگەندە خاتالىق كۆرۈلدى",
    "Open conversation to registered users, showing it in search results" : "تىزىملاتقان ئىشلەتكۈچىلەرگە سۆھبەتنى ئېچىڭ ، ئىزدەش نەتىجىسىدە كۆرسىتىڭ",
    "Also open to users created with the Guests app" : "مېھمانلار دېتالى بىلەن قۇرۇلغان ئىشلەتكۈچىلەرگىمۇ ئېچىڭ",
    "Open conversation" : "ئوچۇق سۆھبەت",
    "Set language spoken in calls" : "بۇ چاقىرىقتا سۆزلەنگەن تىلنى بىكىت",
    "Languages could not be loaded" : "تىلنى يۈكلىگىلى بولمىدى",
    "Loading languages …" : "تىللارنى يۈكلەۋاتىدۇ ...",
    "Invalid language" : "ئىناۋەتسىز تىل",
    "Default language (English)" : "كۆڭۈلدىكى تىل (ئىنگىلىزچە)",
    "Default live transcription language set" : "كۆڭۈلدىكى نەق-مەيدان ترانسكرىپسىيەلەشنى تىللىرى",
    "Live transcription language set: {languageName}" : " نەق-مەيدان ترانسكرىپسىيەلەش تىللىرى: {languageName}",
    "Error when trying to set live transcription language" : " نەق-مەيدان ترانسكرىپسىيەلەش تىلىنى بېكىتىۋاتقاندا خاتالىق كۆرۈلدى",
    "Start time: {date}" : "باشلىنىش ۋاقتى: {date}",
    "Start time has been updated" : "باشلىنىش ۋاقتى يېڭىلاندى",
    "Error occurred while updating start time" : "باشلىنىش ۋاقتىنى يېڭىلىغاندا خاتالىق كۆرۈلدى",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "لوبىسىنى قوزغىتىپ ، رىياسەتچى بولمىغان تېلېفوننى ئۆچۈرۈۋېتىدۇ.",
    "Enable lobby, restricting the conversation to moderators" : "لوبىنى قوزغىتىڭ ، رىياسەتچىلەر بىلەن سۆھبەتنى چەكلەڭ",
    "Meeting start time" : "يىغىن باشلىنىش ۋاقتى",
    "Start time (optional)" : "باشلاش ۋاقتى (ئىختىيارى)",
    "Import email participants" : "ئېلىخەت قاتناشقۇچىلىرىنى كىرگۈز",
    "You can import a list of email participants from a CSV file." : "CSV ھۆججىتىدىن ئېلخەت قاتناشقۇچىلىرىنىڭ تىزىملىكىنى ئىمپورت قىلالايسىز.",
    "Poll drafts" : "راي سىناش لايىھىسى",
    "Browse poll drafts" : "راي سىناش لايىھىسىنى كۆرۈڭ",
    "Error occurred when locking the conversation" : "سۆھبەتنى قۇلۇپلىغاندا خاتالىق كۆرۈلدى",
    "Error occurred when unlocking the conversation" : "سۆھبەتنى ئاچقاندا خاتالىق كۆرۈلدى",
    "Lock conversation" : "سۆھبەتنى قۇلۇپلاڭ",
    "This will also terminate the ongoing call." : "بۇمۇ داۋاملىشىۋاتقان تېلېفوننى ئاخىرلاشتۇرىدۇ.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "سۆھبەتنى قۇلۇپلاپ ، ھەر قانداق كىشىنىڭ ئۇچۇر يوللىشى ياكى تېلېفون باشلىشىنىڭ ئالدىنى ئالىدۇ",
    "Edit" : "تەھرىر",
    "More information" : "تېخىمۇ كۆپ ئۇچۇرلار",
    "Delete" : "ئۆچۈر",
    "Add new bridged channel to current conversation" : "نۆۋەتتىكى سۆھبەتكە يېڭى كۆۋرۈك قانىلى قوشۇڭ",
    "unknown state" : "نامەلۇم دۆلەت",
    "running" : "ئىجرا بولۇۋاتىدۇ",
    "not running, check Matterbridge log" : "ئىجرا بولمايدۇ ، Matterbridge خاتىرىسىنى تەكشۈرۈڭ",
    "not running" : "ئىجرا ئەمەس",
    "Bridge saved" : "كۆۋرۈك ساقلاندى",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "سىز Matterbridge ئارقىلىق ھەرخىل تېز ئۇچۇر سىستېمىسىدىكى قاناللارنى كۆۋرۈك قىلالايسىز.",
    "More info on Matterbridge" : "Matterbridge ھەققىدە تېخىمۇ كۆپ ئۇچۇرلار",
    "Messaging systems" : "ئۇچۇر سىستېمىسى",
    "Enable bridge" : "كۆۋرۈكنى قوزغىتىش",
    "Show Matterbridge log" : "Matterbridge خاتىرىسىنى كۆرسەت",
    "Log content" : "خاتىرە مەزمۇنى",
    "Only moderators are allowed to mention @all" : "پەقەت رىياسەتچىلەرلا @all نى تىلغا ئالىدۇ",
    "All participants are allowed to mention @all" : "بارلىق قاتناشقۇچىلارنىڭ @all نى تىلغا ئېلىشىغا رۇخسەت قىلىنىدۇ",
    "Participants are now allowed to mention @all." : "ھازىر قاتناشقۇچىلارنىڭ @all نى تىلغا ئېلىشىغا رۇخسەت قىلىندى.",
    "Mentioning @all has been limited to moderators." : "@All نى تىلغا ئېلىش پەقەت رىياسەتچىلەر بىلەنلا چەكلىنىپ قالدى.",
    "Allow participants to mention @all" : "قاتناشقۇچىلارنىڭ @all نى تىلغا ئېلىشىغا يول قويۇڭ",
    "Mention permissions" : "ئىجازەتنامە",
    "Notifications" : "ئۇقتۇرۇش",
    "Notify about calls in this conversation" : "بۇ سۆھبەتتىكى تېلېفونلار ھەققىدە خەۋەر قىلىڭ",
    "Important conversation" : "مۇھىم سۆھبەت",
    "\"Do not disturb\" user status is ignored for important conversations" : "\"دەخلى قىلما\" ئىشلەتكۈچى ھالىتى مۇھىم سۆھبەتلەرگە ئىشلىمەيدۇ",
    "Sensitive conversation" : "نازۇك سۆھبەت",
    "Message preview will be disabled in conversation list and notifications" : "سۆھبەت تىزىملىكى ۋە ئۇقتۇرۇشلاردا خەۋەرنى ئالدىن كۆرۈش چەكلىنىدۇ",
    "Recording consent is required for calls in this conversation" : "بۇ سۆھبەتتىكى تېلېفون ئۈچۈن خاتىرىلەش رۇخسىتى تەلەپ قىلىنىدۇ",
    "Recording consent is not required for calls in this conversation" : "بۇ سۆھبەتتىكى تېلېفون ئۈچۈن خاتىرىلەش رۇخسىتى تەلەپ قىلىنمايدۇ",
    "Recording consent requirement was updated" : "خاتىرىلەش ئىجازەت تەلىپى يېڭىلاندى",
    "Error occurred while updating recording consent" : "خاتىرىلەش ئىجازىتىنى يېڭىلىغاندا خاتالىق كۆرۈلدى",
    "Recording Consent" : "خاتىرىلەش",
    "Recording consent cannot be changed once a call or breakout session has started." : "چاقىرىش ياكى بۆسۈش يىغىنى باشلانغاندىن كېيىن خاتىرىلەش ئىجازەتنامىسىنى ئۆزگەرتىشكە بولمايدۇ.",
    "Require recording consent before joining call in this conversation" : "بۇ سۆھبەتكە چاقىرىشقا قاتنىشىشتىن بۇرۇن خاتىرىلەش ئىجازىتىنى تەلەپ قىلىڭ",
    "Recording consent is required for all calls" : "بارلىق تېلېفونلاردا خاتىرىلەش رۇخسىتى تەلەپ قىلىنىدۇ",
    "SIP dial-in is now possible without PIN requirement" : "PIN تەلىپى بولمىسا SIP چاقىرىش ھازىر مۇمكىن",
    "SIP dial-in is now enabled" : "ھازىر SIP چاقىرىش ئىقتىدارى قوزغىتىلدى",
    "SIP dial-in is now disabled" : "SIP چاقىرىش ھازىر چەكلەنگەن",
    "Error occurred when enabling SIP dial-in" : "SIP چاقىرىشنى قوزغىغاندا خاتالىق كۆرۈلدى",
    "Error occurred when disabling SIP dial-in" : "SIP چاقىرىشنى چەكلىگەندە خاتالىق كۆرۈلدى",
    "Phone and SIP dial-in" : "تېلېفون ۋە SIP چاقىرىش",
    "Enable phone and SIP dial-in" : "تېلېفون ۋە SIP چاقىرىشنى قوزغىتىڭ",
    "Allow to dial-in without a PIN" : "PIN بولمىسا تېلېفون ئۇرسىڭىز بولىدۇ",
    "Ongoing" : "يۈز بېرىۋاتقان",
    "{dayPrefix} {dateTime}" : "{dayPrefix} {dateTime}",
    "_%n person accepted_::_%n people accepted_" : ["%n كىشلەر قۇبۇل قىلدى","%n كىشلەر قۇبۇل قىلدى"],
    "_%n person declined_::_%n people declined_" : ["%n كىشلەر رەت قىلدى","%n كىشلەر رەت قىلدى"],
    "_and %n other attachment_::_and %n other attachments_" : ["ھەمدە باشقا %n قۇشۇمچە ھۆججەتلەر","ھەمدە باشقا %n قۇشۇمچە ھۆججەتلەر"],
    "With {displayName}" : "{displayName} بىلەن",
    "In {conversation}" : "{conversation} دا",
    "View attachment" : "قۇشۇمچە ھۆججەتلەرنى كۆر",
    "Join" : "قوشۇلۇڭ",
    "View conversation" : "سۆھبەتنى كۆر",
    "View event on Calendar" : "پائالىيەتنى يىلنامىدە كۆر",
    "Error while creating the conversation" : "سۆھبەتنى قۇرغاندا خاتالىق",
    "Hello, {displayName}" : "ياخشىمۇسىز، {displayName}",
    "Start meeting now" : "يىغىننى ھازىر باشلا",
    "Give your meeting a title" : "يىغىنىڭىزغا بىر ماۋزو قۇيۇڭ",
    "Create and copy link" : "ئۇلىنىش قۇرۇڭ ھەمدە كۆچۈرۈڭ",
    "Create a new conversation" : "يېڭى سۆھبەت قۇر",
    "Join open conversations" : "ئوچۇق سۆھبەتكە قاتنىشىڭ",
    "Call a phone number" : "تېلېفون نومۇرىغا تېلېفون قىلىڭ",
    "Scroll backward" : "كەينىگە قايت",
    "Scroll forward" : "ئالدىغا سىيرىل",
    "Schedule meetings" : "يىغىن ئورۇنلاشتۇر",
    "You don't have any upcoming meetings" : "سىزنىڭ كىلىدىغان ھېچقانداق يىغىنىڭىز يوق",
    "Open calendar" : "كالېندارنى ئېچىڭ",
    "Unread mentions" : "ئوقۇلمىغان تىلغا ئېلىنغان",
    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "سىز تىلغا ئېلىنغان ئۇچۇرلار بۇ يەردە كۆرسىتىلىدۇ. سىز كىشىلەرنى تىلغا ئېلىش ئۈچۈن @ بەلگىسىنى كىرگۈزۈپ، ئاندىن ئۇلارنىڭ ئىسمىنى يازسىڭىز بولىدۇ.",
    "Upcoming reminders" : "كىلىدىغان ئەسكەرتمىلەر",
    "Message reminders" : "ئۇچۇر ئەسكەرتمىلەر",
    "Set a reminder on a message to be notified" : "ئۇچۇرغا ئۇقتۇرۇش قىلىنىدىغان ئەسكەرتىش قويۇڭ",
    "Start a group conversation" : "گۇرۇپپا سۆھبىتىنى باشلاڭ",
    "Create conversation" : "سۆھبەت قۇرۇش",
    "Enter your name" : "ئىسمىڭىزنى كىرگۈزۈڭ",
    "Submit name and join" : "ئىسىم يوللاڭ ۋە قوشۇلۇڭ",
    "Do you already have an account?" : "ھېساباتىڭىز بارمۇ؟",
    "Log in" : "كىرىڭ",
    "Error while verifying uploaded file" : "يۈكلەنگەن ھۆججەتنى تەكشۈرۈشتە خاتالىق يۈز بەردى",
    "Uploaded file is verified" : "چىقىرىلغان ھۆججەت تەكشۈرۈلدى",
    "Content format is comma-separated values (CSV):<br/>- Header line is required and must match <samp>\"name\",\"email\"</samp> or just <samp>\"email\"</samp><br/>- One entry per line (e.g. <samp>\"John Doe\",\"john@example.tld\"</samp>)" : "مەزمۇن فورماتى پەش بىلەن ئايرىلغان قىممەتلەر (CSV): 1- باشلىق قۇر تەلەپ قىلىنىدۇ ۋە 2\"name\",\"email\"2 ياكى پەقەت 3\"email\"34- ھەر قۇردا بىردىن كىرگۈزۈش (مەسىلەن 5\"John Doe\",\"john@example.tld\"5)",
    "Participants added successfully" : "قاتناشقۇچى مۇۋەپپەقىيەتلىك قوشۇلدى",
    "Error while adding participants" : "قاتناشقۇچىنى قوشقاندا خاتالىق",
    "Import a file" : "بىر ھۆججەت كىرگۈز",
    "Browse" : "زىيارەت قىل",
    "Verifying uploaded file …" : "يۈكلەنگەن ھۆججەتنى تەكشۈرۋاتىدۇ..",
    "This might take a moment" : "بۇنىڭغا بىر ئاز ۋاقىت كېتىشى مۇمكىن",
    "Send invitations" : "تەكلىپنامە يوللا",
    "_%n invalid email_::_%n invalid emails_" : ["ئىناۋەتسىز ئېلېكترونلۇق خەت","ئىناۋەتسىز ئېلېكترونلۇق خەت"],
    "_%n email is already imported or a duplicate_::_%n emails are already imported or duplicates_" : ["%n ئېلىخەت ئاللىبۇرۇن كىرگۈزۈلگەن ياكى كۆپەيتىلىدۇ","%n ئېلىخەت ئاللىبۇرۇن كىرگۈزۈلگەن ياكى كۆپەيتىلىدۇ"],
    "_%n invitation can be sent_::_%n invitations can be sent_" : ["%n تەكلىپ ئەۋەتىلدۇ","%n تەكلىپ ئەۋەتىلدۇ"],
    "An error occurred while calling a phone number" : "تېلېفون نومۇرىغا تېلېفون قىلغاندا خاتالىق كۆرۈلدى",
    "Phone number could not be called: {error}" : "تېلېفون نومۇرىنى چاقىرىشقا بولمايدۇ: {error}",
    "Phone number could not be called" : "تېلېفون نومۇرىغا تېلېفون قىلغىلى بولمايدۇ",
    "Search participants or phone numbers" : "قاتناشقۇچىلار ياكى تېلېفون نومۇرىنى ئىزدەڭ",
    "Creating the conversation …" : "سۆھبەت قۇرۇش…",
    "Mark as read" : "ئوقۇغاندەك بەلگە قويۇڭ",
    "Mark as unread" : "ئوقۇلمىغان دەپ بەلگە قويۇڭ",
    "Remove from favorites" : "ياقتۇردىغاندىن چىقىرۋەت",
    "Add to favorites" : "ياقتۇردىغانغا قوش",
    "Unarchive conversation" : "قالايمىقان سۆھبەت",
    "Ignore \"Do not disturb\"" : "\"دەخلى قىلما\" غا كارىڭ بولمىسۇن",
    "You need to promote a new moderator before you can leave the conversation." : "سۆھبەتتىن ئايرىلىشتىن بۇرۇن يېڭى رىياسەتچىنى تەشۋىق قىلىشىڭىز كېرەك.",
    "Conversation actions" : "سۆھبەت ھەرىكىتى",
    "Notify about calls" : "بارلىق چاقىرىقلارغا ئۇقتۇر",
    "Hide message text" : "ئۇچۇر تىكىستىنى يۇشۇر",
    "Pending invitations" : "تەكلىپنامە ساقلىنىۋاتىدۇ",
    "From {user} at {remoteServer}" : "{user} مۇلازىمېتىردىكى {remoteServer} دىن",
    "Decline invitation" : "تەكلىپنى رەت قىلىش",
    "Accept invitation" : "تەكلىپنى قوبۇل قىلىڭ",
    "No pending invitations" : "كۈتۈلمىگەن تەكلىپلەر يوق",
    "Home" : "ئۆي",
    "Unread" : "ئوقۇمىغان",
    "Mentions" : "تىلغا ئېلىشلار",
    "Meetings" : "يىغىنلار",
    "Alphabetically" : "ئېلىپبە شەكلىدە",
    "No followed threads" : "ئەگەشكەن يىپلار يوق",
    "No matches found" : "ماس كەلمىدى",
    "No conversations found" : "پاراڭ تېپىلمىدى",
    "You have no archived conversations." : "ئارخىپ پاراڭلىرىڭىز يوق.",
    "Subscribe to an existing thread or start your own." : "مەۋجۇت بىر يىپقا مۇشتەرى بول ياكى ئۆزەڭنىڭكىنى باشلا",
    "You have no unread mentions." : "سىزدە ئوقۇلمىغان تىلغا ئېلىنمىدى.",
    "You have no unread messages." : "ئوقۇمىغان ئۇچۇرلىرىڭىز يوق.",
    "An error occurred while performing the search" : "ئىزدەش جەريانىدا خاتالىق كۆرۈلدى",
    "Conversation list" : "سۆھبەت تىزىملىكى",
    "Filter conversations by" : "سۆھبەتنى بىلەن سۈز",
    "Unread messages" : "ئوقۇلمىغان ئۇچۇرلار",
    "Meeting conversations" : "يىغىن سۆھبەتلىرى",
    "Clear filters" : "سۈزگۈچنى تازىلاش",
    "New personal note" : "يېڭى شەخسىي خاتىرە",
    "Back to conversations" : "سۆھبەتكە قايتىش",
    "Archived conversations" : "ئارخىپلاشتۇرۇلغان سۆھبەت",
    "Threads" : "يىپلار",
    "Clear filter" : "سۈزگۈچنى تازىلاش",
    "Show more threads" : "جىقراق يىپنى كۆرسەت",
    "App settings" : "ئەپ تەڭشىكى",
    "Users" : "ئىشلەتكۈچىلەر",
    "Groups" : "گۇرۇپپا",
    "Teams" : "كوماندىلار",
    "Federated users" : "فېدېراتسىيە ئىشلەتكۈچىلەر",
    "New private conversation" : "يېڭى شەخسىي سۆھبەت",
    "Other sources" : "باشقا مەنبەلەر",
    "Open conversations" : "ئوچۇق سۆھبەت",
    "No search results" : "ئىزدەش نەتىجىسى يوق",
    "Users, groups and teams" : "ئىشلەتكۈچى ، گۇرۇپپا ۋە گۇرۇپپىلار",
    "Users and groups" : "ئىشلەتكۈچى ۋە گۇرۇپپىلار",
    "Users and teams" : "ئىشلەتكۈچى ۋە گۇرۇپپىلار",
    "Groups and teams" : "گۇرۇپپا ۋە گۇرۇپپىلار",
    "New group conversation" : "يېڭى گۇرۇپپا سۆھبىتى",
    "The meeting will start soon" : "يىغىن پات يېقىندا باشلىنىدۇ",
    "This meeting is scheduled for {startTime}" : "بۇ يىغىن {startTime} ئۈچۈن ئورۇنلاشتۇرۇلغان",
    "You are currently waiting in the lobby" : "سىز ھازىر كۈتۈپخانىدا ساقلاۋاتىسىز",
    "Select microphone" : "مىكروفوننى تاللاڭ",
    "No microphone available" : "مىكروفون يوق",
    "Select speaker" : "سۆزلىگۈچى تاللا",
    "No speaker available" : "سۆزلىگۈچى يوق",
    "Select camera" : "كامېرانى تاللاڭ",
    "No camera available" : "كامېرا يوق",
    "Select a device" : "ئۈسكۈنىنى تاللاڭ",
    "Playing …" : "ئويناش…",
    "Test speakers" : "سىناق ياڭراتقۇ",
    "Test" : "سىناق",
    "Devices" : "ئۈسكۈنىلەر",
    "Backgrounds" : "تەگلىك",
    "No audio" : "ئاۋاز يوق",
    "No camera" : "كامېرا يوق",
    "Display video as you will see it (mirrored)" : "سىننى كۆرگەندەك كۆرسىتىڭ (ئەينەك)",
    "Display video as others will see it" : "سىننى باشقىلار كۆرگەندەك كۆرسىتىڭ",
    "Calls are not supported in your browser" : "تور كۆرگۈڭىزدە چاقىرىشنى قوللىمايدۇ",
    "Access to microphone is only possible with HTTPS" : "مىكروفونغا ئېرىشىش پەقەت HTTPS ئارقىلىقلا بولىدۇ",
    "Access to microphone was denied" : "مىكروفونغا ئېرىشىش رەت قىلىندى",
    "Error while accessing microphone" : "مىكروفوننى زىيارەت قىلغاندا خاتالىق",
    "Access to camera is only possible with HTTPS" : "كامېراغا كىرىش پەقەت HTTPS ئارقىلىقلا مۇمكىن",
    "The call is being recorded." : "تېلېفون خاتىرىلىنىۋاتىدۇ.",
    "The call might be recorded." : "تېلېفون خاتىرىلەنگەن بولۇشى مۇمكىن.",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "بۇ خاتىرىدە ئاۋازىڭىز ، كامېرادىكى سىن ۋە ئېكران ھەمبەھىرلىنىشىڭىز بولۇشى مۇمكىن. تېلېفونغا قاتنىشىشتىن بۇرۇن سىزنىڭ رۇخسىتىڭىز تەلەپ قىلىنىدۇ.",
    "Give consent to the recording of this call" : "بۇ تېلېفوننىڭ خاتىرىسىگە قوشۇلۇڭ",
    "Show more info" : "تېخىمۇ كۆپ ئۇچۇرنى كۆرسەت",
    "Audio is not available" : "ئاۋاز يوق",
    "Video is not available" : "سىن يوق",
    "Start recording immediately with the call" : "چاقىرىش بىلەن دەرھال خاتىرىلەشنى باشلاڭ",
    "Notify all participants about this call" : "بارلىق قاتناشقۇچىلارغا بۇ چاقىرىقنى ئۇقتۇر",
    "Apply settings" : "تەڭشەكلەرنى ئىشلىتىڭ",
    "Select virtual office background" : "مەۋھۇم ئىشخانا تەگلىكىنى تاللاڭ",
    "Select virtual home background" : "مەۋھۇم ئائىلە تەگلىكىنى تاللاڭ",
    "Select virtual abstract background" : "مەۋھۇم ئابستراكت تەگلىكنى تاللاڭ",
    "Select virtual beach background" : "مەۋھۇم ساھىل تەگلىكىنى تاللاڭ",
    "Select virtual park background" : "مەۋھۇم باغچا تەگلىكىنى تاللاڭ",
    "Select virtual theater background" : "مەۋھۇم تىياتىر تەگلىكىنى تاللاڭ",
    "Select virtual library background" : "مەۋھۇم كۇتۇپخانا تەگلىكىنى تاللاڭ",
    "Select virtual space station background" : "مەۋھۇم بوشلۇق پونكىتى تەگلىكىنى تاللاڭ",
    "Error while uploading the file" : "ھۆججەتنى يۈكلەۋاتقاندا خاتالىق",
    "Select a file" : "ھۆججەت تاللاڭ",
    "Invalid path selected" : "ئىناۋەتسىز يول تاللانغان",
    "Select virtual background from file {fileName}" : "ھۆججەتتىن مەۋھۇم تەگلىكنى تاللاڭ {fileName}",
    "Blur" : "تۇتۇق",
    "Upload" : "يۈكلە",
    "Files" : "ھۆججەتلەر",
    "(editing)" : "(تەھرىرلەش)",
    "(edited)" : "(تەھرىرلەندى)",
    "The message has expired or has been deleted" : "ئۇچۇرنىڭ ۋاقتى توشتى ياكى ئۆچۈرۈلدى",
    "Cancel quote" : "نەقىلنى بىكار قىلىڭ",
    "24 hours" : "24 hours",
    "7 days" : "7 كۈن",
    "30 days" : "30 كۈن",
    "Until unpin" : "مىخلاشتىن چىقارغىچە",
    "Clear reminder – {timeLocale}" : "ئەسكەرتىشنى تازىلاش - {timeLocale}",
    "Edited by {actor}" : "تەھرىرلىگەن {actor}",
    "Pinned by you" : "سىز مىخلىدىڭىز",
    "Pinned by {actor}" : "{actor} تەرىپىدىن مىخلاندى",
    "Until {absoluteDate}" : "{absoluteDate} غىچە",
    "Message text copied to clipboard" : "چاپلاش تاختىسىغا كۆچۈرۈلگەن ئۇچۇر تېكىستى",
    "Message text could not be copied" : "ئۇچۇر تېكىستىنى كۆچۈرگىلى بولمايدۇ",
    "Message forwarded to \"Note to self\"" : "ئۇچۇر «ئۆزىگە ئەسكەرتىش» كە يوللاندى",
    "Error while forwarding message to \"Note to self\"" : "«ئۆزىڭىزگە ئەسكەرتىش» گە ئۇچۇر يوللاشتا خاتالىق",
    "A reminder was successfully removed" : "ئەسكەرتىش مۇۋەپپەقىيەتلىك ئۆچۈرۈلدى",
    "Error occurred when removing a reminder" : "ئەسكەرتىشنى ئۆچۈرگەندە خاتالىق كۆرۈلدى",
    "A reminder was successfully set at {datetime}" : "ئەسكەرتىش {datetime} دا مۇۋەپپەقىيەتلىك تەڭشەلدى",
    "Error occurred when creating a reminder" : "ئەسكەرتىش قۇرغاندا خاتالىق كۆرۈلدى",
    "Add a reaction to this message" : "بۇ ئۇچۇرغا ئىنكاس قوشۇڭ",
    "Reply" : "جاۋاب قايتۇر",
    "More actions" : "تېخىمۇ كۆپ ھەرىكەت",
    "Set reminder" : "ئەسكەرتىش بەلگىلەڭ",
    "Pin message" : "مىخلاش ئۇچۇرى",
    "Unpin message" : "مىختىن چىقىرىش ئۇچۇرى",
    "Reply privately" : "شەخسىي جاۋاب قايتۇرۇڭ",
    "Edit message" : "ئۇچۇرنى تەھرىرلەش",
    "Copy message" : "ئۇچۇرنى كۆچۈرۈڭ",
    "Copy message link" : "ئۇچۇر ئۇلانمىسىنى كۆچۈرۈڭ",
    "Go to file" : "ھۆججەتكە بېرىڭ",
    "Download file" : "ھۆججەت چۈشۈرۈش",
    "Go to thread" : "يىپقا بار",
    "Edit thread details" : "يىپ تەپسىلاتىنى تەھرىرلە",
    "Forward message" : "ئۇچۇر يوللاش",
    "Translate" : "تەرجىمە",
    "Set custom reminder" : "ئىختىيارى ئەسكەرتىش بەلگىلەڭ",
    "Keep pinned for" : "مىخلاشنى ساقلا",
    "Set custom period" : "خاس مەزگىل بېكىت",
    "Close reactions menu" : "ئىنكاس تىزىملىكىنى تاقاش",
    "React with {emoji}" : "{emoji} بىلەن ئىنكاس قايتۇرۇڭ",
    "React with another emoji" : "باشقا بىر emoji بىلەن ئىنكاس قايتۇرۇڭ",
    "Choose a conversation to forward the selected message." : "تاللانغان ئۇچۇرنى يوللاش ئۈچۈن سۆھبەتنى تاللاڭ.",
    "Error while forwarding message" : "ئۇچۇر يوللاشتا خاتالىق",
    "The message has been forwarded to {selectedConversationName}" : "بۇ ئۇچۇر {selectedConversationName} غا يوللاندى",
    "Dismiss" : "خىزمەتتىن ھەيدەش",
    "Go to conversation" : "سۆھبەتكە بېرىڭ",
    "Detect language" : "تىلنى ئېنىقلاش",
    "The message could not be translated" : "بۇ ئۇچۇرنى تەرجىمە قىلىشقا بولمىدى",
    "Translation copied to clipboard" : "تەرجىمە تاختىسىغا كۆچۈرۈلگەن",
    "Translation could not be copied" : "تەرجىمىنى كۆچۈرگىلى بولمىدى",
    "Translate message" : "ئۇچۇرنى تەرجىمە قىلىڭ",
    "Source language to translate from" : "تەرجىمە قىلىدىغان مەنبە تىلى",
    "Translate from" : "دىن تەرجىمە قىلىڭ",
    "Target language to translate into" : "تەرجىمە قىلىدىغان نىشان تىل",
    "Translate to" : "تەرجىمە قىلىڭ",
    "Translating" : "تەرجىمە قىلىش",
    "Copy translated text" : "تەرجىمە قىلىنغان تېكىستنى كۆچۈرۈڭ",
    "Send now" : "ھازىر ئەۋەتىڭ",
    "Message read by everyone who shares their reading status" : "ئوقۇش ھالىتىنى ھەمبەھىرلىگەن ھەممە ئادەم ئوقۇغان ئۇچۇر",
    "Message sent" : "ئۇچۇر ئەۋەتىلدى",
    "Sent without notification" : "ئۇقتۇرۇشسىز ئەۋەتىلدى",
    "Deleting message" : "ئۇچۇرنى ئۆچۈرۈش",
    "Message deleted successfully, but a bot or Matterbridge is configured and the message might already be distributed to other services" : "ئۇچۇر مۇۋەپپەقىيەتلىك ئۆچۈرۈلدى ، ئەمما بىر bot ياكى Matterbridge سەپلەندى ، بۇ ئۇچۇر باشقا مۇلازىمەتلەرگە تارقىتىلغان بولۇشى مۇمكىن",
    "Message deleted successfully" : "ئۇچۇر مۇۋەپپەقىيەتلىك ئۆچۈرۈلدى",
    "Message could not be deleted because it is too old" : "ئۇچۇر بەك كونا بولغاچقا ئۆچۈرۈلمىدى",
    "Only normal chat messages can be deleted" : "پەقەت نورمال پاراڭلىشىش ئۇچۇرلىرىنىلا ئۆچۈرگىلى بولىدۇ",
    "An error occurred while deleting the message" : "ئۇچۇرنى ئۆچۈرگەندە خاتالىق كۆرۈلدى",
    "Pinned" : "مىخلاندى",
    "Your browser does not support playing audio files" : "توركۆرگۈڭىز ئاۋاز ھۆججىتىنى قويۇشنى قوللىمايدۇ",
    "Contact" : "ئالاقىلىشىڭ",
    "{stack} in {board}" : "{board} دا {stack}",
    "Deck Card" : "پالۋان كارتىسى",
    "Remove {fileName}" : "ئۆچۈرۈڭ {fileName}",
    "Open this location in OpenStreetMap" : "بۇ ئورۇننى OpenStreetMap دا ئېچىڭ",
    "_%n reply_::_%n replies_" : ["%n جاۋاپ","%n جاۋاپلار"],
    "Sending message" : "ئۇچۇر ئەۋەتىش",
    "Failed to send the message. Click to try again" : "ئۇچۇر ئەۋەتەلمىدى. قايتا سىناڭ",
    "Not enough free space to upload file" : "ھۆججەت يوللاشقا يېتەرلىك بوشلۇق يوق",
    "You cannot send messages to this conversation at the moment" : "ھازىرچە بۇ سۆھبەتكە ئۇچۇر ئەۋەتەلمەيسىز",
    "Could not update the message" : "ئۇچۇرنى يېڭىلىيالمىدى",
    "_Poll draft • %n option_::_Poll draft • %n options_" : ["راي-سىناش ئورگىنالى • %n تاللانما","راي-سىناش ئورگىنالى • %n تاللانمىلار"],
    "_%n vote_::_%n votes_" : ["%n vote","%n بېلەت"],
    "Edit poll draft" : "راي سىناش لايىھىسىنى تەھرىرلە",
    "Delete poll draft" : "راي سىناش لايىھىسىنى ئۆچۈرۈڭ",
    "Open poll" : "راي سىناش",
    "See results" : "نەتىجىنى كۆرۈڭ",
    "Reactions" : "ئىنكاس",
    "No permission to post reactions in this conversation" : "بۇ سۆھبەتتە ئىنكاس يوللاشقا ئىجازەت يوق",
    "and {participant}" : "ۋە {participant}",
    "_and %n other participant_::_and %n other participants_" : ["ھەمدە باشقا %n قاتناشقۇچى","ھەمدە باشقا %n قاتناشقۇچىلار"],
    "Show all reactions" : "بارلىق ئىنكاسلارنى كۆرسەت",
    "Add more reactions" : "تېخىمۇ كۆپ ئىنكاسلارنى قوشۇڭ",
    "Show or collapse system messages" : "سىستېما ئۇچۇرلىرىنى كۆرسىتىش ياكى يىمىرىلىش",
    "No messages" : "ھېچقانداق ئۇچۇر يوق",
    "All messages have expired or have been deleted." : "بارلىق ئۇچۇرلارنىڭ ۋاقتى توشتى ياكى ئۆچۈرۈلدى.",
    "{author} (pinned by you)" : "{author} (سىز مىخلىدىڭىز)",
    "{author} (pinned by {actor})" : "{author} ({actor} مىخلىدى)",
    "Unpin" : "مىخلىما",
    "Cancel search" : "ئىزدەشنى ئەمەلدىن قالدۇرۇڭ",
    "Add a phone number" : "تېلېفون نومۇرىنى قوشۇڭ",
    "Error: A password is required to create the conversation." : "خاتالىق: بۇ سۆھبەتنى قۇرۇش ئۈچۈن پارول تەلەپ قىلىندى.",
    "All set, the conversation \"{conversationName}\" was created." : "ھەممىسى تەڭشەلدى ، سۆھبەت \"{conversationName}\" قۇرۇلدى.",
    "Create a new group conversation" : "يېڭى گۇرۇپپا سۆھبىتى قۇر",
    "Add participants" : "قاتناشقۇچىلارنى قوشۇڭ",
    "Maximum length exceeded ({maxlength} characters)" : "ئەڭ چوڭ ئۇزۇنلۇقىتىن ({maxlength}) ئېشىپ كەتتى",
    "Conversation visibility" : "سۆھبەتنىڭ كۆرۈنۈشچانلىقى",
    "Allow guests to join via link" : "مېھمانلارنىڭ ئۇلىنىش ئارقىلىق قاتنىشىشىغا يول قويۇڭ",
    "Enter password" : "پارول كىرگۈزۈڭ",
    "This conversation has been locked" : "بۇ سۆھبەت قۇلۇپلاندى",
    "No permission to post messages in this conversation" : "بۇ سۆھبەتتە ئۇچۇر يوللاشقا ئىجازەت يوق",
    "Joining conversation …" : "سۆھبەتكە قاتنىشىش…",
    "Write a message without notification" : "ئۇقتۇرۇشسىز بىر ئۇچۇر ياز",
    "Create a thread silently" : "بىر يىپنى جىمجىت قۇر",
    "Create a thread" : "بىر يىپ قۇر",
    "Send message silently" : "ئۈن-تىنسىز ئۇچۇر ئەۋەتىڭ",
    "Send message" : "ئۇچۇر ئەۋەتىڭ",
    "Send without notification" : "ئۇقتۇرۇشسىز ئەۋەتىڭ",
    "The participant will not be notified about new messages" : "قاتناشقۇچىلارغا يېڭى ئۇچۇرلار توغرىسىدا ئۇقتۇرۇش قىلىنمايدۇ",
    "Participants will not be notified about new messages" : "قاتناشقۇچىلارغا يېڭى ئۇچۇرلار توغرىسىدا ئۇقتۇرۇش قىلىنمايدۇ",
    "Thread title is required" : "يىپ ماۋزوسى تەلەپ قىلىنىدۇ",
    "Message text is required" : "ئۇچۇر مەزمۇنى تەلەپ قىلىنىدۇ",
    "The message could not be edited" : "بۇ ئۇچۇرنى تەھرىرلىگىلى بولمىدى",
    "File to share" : "ھەمبەھىرلىنىدىغان ھۆججەت",
    "File upload is not available in this conversation" : "بۇ سۆھبەتتە ھۆججەت يوللاش مۇمكىن ئەمەس",
    "Add emoji" : "Emoji نى قوشۇڭ",
    "Adding a mention will only notify users who did not read the message." : "ئەسكەرتىش قوشقاندا ئۇچۇرنى ئوقۇمىغان ئابونتلارغا ئۇقتۇرۇش قىلىدۇ.",
    "Thread title" : "يىپ ماۋزوسى",
    "Send later" : "كېيىن ئەۋەتىڭ",
    "Cancel editing" : "تەھرىرلەشنى ئەمەلدىن قالدۇرۇڭ",
    "{user} is out of office and might not respond." : "{user} ئىشخانىدىن چىقتى ، جاۋاب قايتۇرماسلىقى مۇمكىن.",
    "Absence period: {startDate} - {endDate}" : "يوقلۇق مەزگىلى: {startDate} - {endDate}",
    "Replacement:" : "ئالماشتۇرۇش: ",
    "Share from {nextcloud}" : "{nextcloud} دىن ئورتاقلىشىش",
    "Share from Files" : "ھۆججەتلەردىن ئورتاقلىشىش",
    "Share files to the conversation" : "سۆھبەتكە ھۆججەتلەرنى ھەمبەھىرلەڭ",
    "Upload from device" : "ئۈسكۈنىدىن يۈكلەش",
    "Create new poll" : "يېڭى راي سىناش",
    "Smart picker" : "ئەقىللىق تاللىغۇچ",
    "Record voice message" : "ئاۋازلىق ئۇچۇرنى خاتىرىلەڭ",
    "End recording and send" : "خاتىرىلەشنى ئاخىرلاشتۇرۇڭ",
    "Dismiss recording" : "خاتىرىسىنى ئەمەلدىن قالدۇرۇش",
    "Access to the microphone was denied" : "مىكروفونغا كىرىش رەت قىلىندى",
    "Microphone either not available or disabled in settings" : "مىكروفون تەڭشەكلەردە ئىشلەتكىلى بولمايدۇ ياكى چەكلىنىدۇ",
    "Error while recording audio" : "ئاۋاز خاتىرىلەۋاتقاندا خاتالىق",
    "Generating summary of unread messages …" : "ئوقۇلمىغان ئۇچۇرلارغا خۇلاسە يېزىۋاتىدۇ...",
    "Summary is AI generated and might contain mistakes" : "خۇلاسىنى AI يازغان ھەمدە خاتالىقلار بولىشى مۇمكىن",
    "Error occurred during a summary generation" : "خۇلاسە يېزىۋاتقاندا جەريانىدا خاتالىق كۆرۈلدى",
    "New file" : "يېڭى ھۆججەت",
    "Blank" : "ئوچۇق",
    "Error while creating file" : "ھۆججەت قۇرغاندا خاتالىق",
    "Create and share a new file" : "يېڭى ھۆججەت قۇرۇش ۋە ئورتاقلىشىش",
    "Name of the new file" : "يېڭى ھۆججەتنىڭ ئىسمى",
    "Create file" : "ھۆججەت قۇرۇش",
    "Someone is typing …" : "بىرەيلەن خەت يېزىۋاتىدۇ…",
    "{user1} is typing …" : "{user1} يېزىۋاتىدۇ…",
    "{user1} and {user2} are typing …" : "{user1} ۋە {user2} يېزىۋاتىدۇ…",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} ۋە {user3} يېزىۋاتىدۇ…",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}، {user2}، {user3} ھەمدە %n يېزىۋاتىدۇ","{user1}، {user2}، {user3} ھەمدە %n باشقىلار يېزىۋاتىدۇ"],
    "Add more files" : "تېخىمۇ كۆپ ھۆججەت قوشۇڭ",
    "Send" : "يوللا",
    "In this conversation <strong>{user}</strong> can:" : "بۇ سۆھبەتتە <strong> {user} </strong> بولىدۇ:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "<strong> {conversationName} </strong> غا قاتناشقۇچىلارنىڭ سۈكۈتتىكى ئىجازەتلىرىنى تەھرىرلەڭ",
    "Start a call" : "تېلېفوننى باشلاڭ",
    "Skip the lobby" : "لوبىدىن ئاتلاڭ",
    "Can post messages and reactions" : "ئۇچۇر ۋە ئىنكاسلارنى يوللىيالايدۇ",
    "Enable the microphone" : "مىكروفوننى قوزغىتىڭ",
    "Enable the camera" : "كامېرانى قوزغىتىڭ",
    "Share the screen" : "ئېكراننى ھەمبەھىرلەڭ",
    "Update permissions" : "ئىجازەتلەرنى يېڭىلاش",
    "Updating permissions" : "ئىجازەتلەرنى يېڭىلاش",
    "No poll drafts" : "راي سىناش لايىھىسى يوق",
    "There is no poll drafts yet saved for this conversation" : "بۇ سۆھبەت ئۈچۈن ھازىرغىچە ھېچقانداق بېلەت تاشلاش لايىھىسى ساقلانمىدى",
    "Create poll in {name}" : "{name} نامىدا راي-سىناش قۇر",
    "Create poll" : "راي سىناش",
    "Error while importing poll" : "راي سىناشتا خاتالىق",
    "Question" : "سوئال",
    "Ask a question" : "سوئال سوراڭ",
    "Import draft from file" : "ھۆججەتنى ھۆججەتتىن ئەكىرىڭ",
    "Answers" : "جاۋاب",
    "Answer {option}" : "جاۋاب {option}",
    "Delete poll option" : "راي سىناش تاللانمىسىنى ئۆچۈرۈڭ",
    "Add answer" : "جاۋاب قوشۇڭ",
    "Settings" : "تەڭشەكلەر",
    "Anonymous poll" : "نامسىز راي سىناش",
    "Multiple answers" : "كۆپ جاۋاب",
    "Save as draft" : "لايىھە سۈپىتىدە ساقلىۋېلىڭ",
    "Export draft to file" : "ھۆججەتنى ھۆججەتكە چىقىرىش",
    "You voted for this option" : "سىز بۇ تاللاشقا بېلەت تاشلىدىڭىز",
    "End poll" : "راي سىناشنى ئاخىرلاشتۇرۇڭ",
    "Change your vote" : "ئاۋازىڭىزنى ئۆزگەرتىڭ",
    "Results" : "نەتىجە",
    "Voted participants" : "بېلەت تاشلىغۇچىلار",
    "Send a message to \"{roomName}\"" : "\"{roomName}\" غا ئۇچۇر ئەۋەتىڭ",
    "Hide list of participants" : "قاتناشقۇچىلارنىڭ تىزىملىكىنى يوشۇرۇش",
    "Show list of participants" : "قاتناشقۇچىلارنىڭ تىزىملىكىنى كۆرسىتىش",
    "Assistance requested in {roomName}" : "{roomName} دا تەلەپ قىلىنغان ياردەم",
    "The message was sent to \"{roomName}\"" : "بۇ ئۇچۇر \"{roomName}\" غا ئەۋەتىلگەن",
    "Dismiss request for assistance" : "ياردەم ئىلتىماسىنى رەت قىلىش",
    "Send message to room" : "ياتاققا ئۇچۇر ئەۋەتىڭ",
    "Back to main room" : "ئاساسلىق ئۆيگە قايتىش",
    "Back to your room" : "ئۆيىڭىزگە قايتىڭ",
    "Message all rooms" : "بارلىق ئۆيلەرگە ئۇچۇر قىلىڭ",
    "Start session" : "ئولتۇرۇشنى باشلاش",
    "Start a call before you start a breakout room session" : "بۆسۈش ئۆيى ئولتۇرۇشنى باشلاشتىن بۇرۇن تېلېفوننى باشلاڭ",
    "Stop session" : "يىغىننى توختىتىڭ",
    "The message was sent to all breakout rooms" : "بۇ ئۇچۇر بارلىق بۆسۈش ئۆيلىرىگە ئەۋەتىلدى",
    "Send a message to all breakout rooms" : "بارلىق بۆسۈش ئۆيلىرىگە ئۇچۇر ئەۋەتىڭ",
    "Breakout rooms are not started" : "بۆسۈش ئۆيى باشلانمىدى",
    "Calls without High-performance backend can cause connectivity issues and high load on devices. {linkstart}Learn more{linkend}" : "يۇقىرى ئىقتىدارلىق ئارقا ئۇچى بولمىغان تېلېفونلار ئۇلىنىش مەسىلىسىنى كەلتۈرۈپ چىقىرىشى ۋە ئۈسكۈنىلەرنىڭ يۈكلىنىشىنى كەلتۈرۈپ چىقىرىشى مۇمكىن. {linkstart}تېخىمۇ كۆپ ئۆگىنىڭ{linkend}",
    "Talk setup incomplete" : "پاراڭنى تەڭشەش تۇلۇق ئەمەس",
    "Disable lobby" : "لوبىنى چەكلەش",
    "Settings for participant \"{user}\"" : "قاتناشقۇچىنىڭ تەڭشىكى \"{user}\"",
    "Participant \"{user}\"" : "قاتناشقۇچى \"{user}\"",
    "moderator" : "رىياسەتچى",
    "bot" : "بوت",
    "guest" : "مېھمان",
    "Ringing …" : "ئۈزۈك…",
    "Call rejected" : "تېلېفون رەت قىلىندى",
    "{time} talking …" : "{time} پاراڭ…",
    "{time} talking time" : "{time} پاراڭلىشىش ۋاقتى",
    "Raised their hand" : "ئۇلارنىڭ قولىنى كۆتۈردى",
    "Joined with video" : "سىنغا قوشۇلدى",
    "Joined via phone" : "تېلېفون ئارقىلىق قوشۇلدى",
    "Joined with audio" : "ئاۋاز بىلەن قوشۇلدى",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "بۇ تېكىست چوقۇم {maxLength} ھەرپتىن ئۇزۇن ياكى تەڭ بولۇشى كېرەك. سىزنىڭ ھازىرقى تېكىستىڭىز {charactersCount} ھەرپ ئۇزۇن.",
    "Remove group and members" : "گۇرۇپپا ۋە ئەزالارنى چىقىرىۋېتىڭ",
    "Remove team and members" : "گۇرۇپپا ۋە ئەزالارنى چىقىرىۋېتىڭ",
    "Remove participant" : "قاتناشقۇچىنى ئېلىۋېتىڭ",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "بۇ سۆھبەتتىن «{displayName}» ۋە ئۇنىڭ ئەزالىرىنى ئۆچۈرمەكچىمۇ؟",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "بۇ سۆھبەتتىن «{displayName}» ۋە ئۇنىڭ ئەزالىرىنى ئۆچۈرمەكچىمۇ؟",
    "Do you really want to remove {displayName} from this conversation?" : "بۇ سۆھبەتتىن {displayName} نى ئۆچۈرمەكچىمۇ؟",
    "Notification was sent to {displayName}" : "ئۇقتۇرۇش {displayName} غا ئەۋەتىلدى",
    "Could not send notification to {displayName}" : "{displayName} to غا ئۇقتۇرۇش ئەۋەتەلمىدى",
    "Permissions granted to {displayName}" : "{displayName} غا بېرىلگەن ئىجازەت",
    "Could not modify permissions for {displayName}" : "{displayName} ئىجازەتنامىسىنى ئۆزگەرتەلمىدى",
    "Permissions removed for {displayName}" : "{displayName} ئۈچۈن رۇخسەت چىقىرىۋېتىلدى",
    "Permissions set to default for {displayName}" : "ئىجازەتنامە {displayName} غا تەڭشەلدى",
    "Phone number could not be hung up" : "تېلېفون نومۇرىنى ئېسىپ قويغىلى بولمايدۇ",
    "Phone number could not be put on hold" : "تېلېفون نومۇرىنى توختىتىشقا بولمايدۇ",
    "Phone number could not be muted" : "تېلېفون نومۇرىنى ئۆزگەرتكىلى بولمايدۇ",
    "Phone number could not be unmuted" : "تېلېفون نومۇرىنى ئۆزگەرتكىلى بولمايدۇ",
    "DTMF message could not be sent" : "DTMF ئۇچۇرى ئەۋەتىلمىدى",
    "Phone number copied to clipboard" : "چاپلاش تاختىسىغا كۆچۈرۈلگەن تېلېفون نومۇرى",
    "Phone number could not be copied" : "تېلېفون نومۇرىنى كۆچۈرگىلى بولمايدۇ",
    "in the lobby" : "زالدا",
    "Dial out phone" : "تېلېفوننى تېلېفون قىلىڭ",
    "Hang up phone" : "تېلېفوننى ئېسىپ قويۇڭ",
    "Move back to lobby" : "لوبىغا قايتىڭ",
    "Move to conversation" : "سۆھبەتكە يۆتكەڭ",
    "Dial-in PIN" : "نۇمۇر بۇراش PIN",
    "Demote from moderator" : "رىياسەتچىدىن تۆۋەنلەش",
    "Promote to moderator" : "رىياسەتچىگە تەشۋىق قىلىڭ",
    "Resend invitation" : "تەكلىپنامىنى قايتۇرۇڭ",
    "Send call notification" : "چاقىرىش ئۇقتۇرۇشى ئەۋەتىڭ",
    "Dial out phone number" : "تېلېفون نومۇرىنى تېلىفۇن قىلىڭ",
    "Resume call for phone number" : "تېلېفون نومۇرىغا تېلېفون قىلىشنى ئەسلىگە كەلتۈرۈش",
    "Put phone number on hold" : "تېلېفون نومۇرىنى توختىتىڭ",
    "Unmute phone number" : "تېلېفون نومۇرىنى بىكار قىلىڭ",
    "Mute phone number" : "تېلېفون نومۇرى",
    "Copy phone number" : "تېلېفون نومۇرىنى كۆچۈرۈڭ",
    "Reset custom permissions" : "ئىختىيارى ئىجازەتنى ئەسلىگە كەلتۈرۈڭ",
    "Grant all permissions" : "بارلىق ئىجازەتلەرنى بېرىڭ",
    "Remove all permissions" : "بارلىق ئىجازەتلەرنى ئۆچۈرۈڭ",
    "Also ban from this conversation" : "بۇ سۆھبەتتىن چەكلەڭ",
    "Internal note (reason to ban)" : "ئىچكى خاتىرە (چەكلەش سەۋەبى)",
    "Remove" : "ئۆچۈرۈڭ",
    "Permissions modified for {displayName}" : "ئىجازەتنامە {displayName} غا ئۆزگەرتىلدى",
    "Add users, groups or teams" : "ئىشلەتكۈچى ، گۇرۇپپا ياكى گۇرۇپپا قوشۇڭ",
    "Add users or groups" : "ئىشلەتكۈچى ياكى گۇرۇپپا قوش",
    "Add users or teams" : "ئىشلەتكۈچى ياكى گۇرۇپپا قوشۇڭ",
    "Add users" : "ئىشلەتكۈچى قوشۇڭ",
    "Add groups or teams" : "گۇرۇپپا ياكى گۇرۇپپا قوشۇڭ",
    "Add groups" : "گۇرۇپپا قوشۇڭ",
    "Add teams" : "گۇرۇپپا قوشۇڭ",
    "Add other sources" : "باشقا مەنبەلەرنى قوشۇڭ",
    "Add emails" : "ئېلېكترونلۇق خەت قوشۇڭ",
    "Integrations" : "بىرىكتۈرۈش",
    "Add federated users" : "فېدېراتسىيە ئىشلەتكۈچىلەرنى قوشۇڭ",
    "Searching …" : "ئىزدەش…",
    "Search for more users" : "تېخىمۇ كۆپ ئىشلەتكۈچىنى ئىزدەڭ",
    "You can search or add participants via name, email, or Federated Cloud ID" : "ئىسىم ، ئېلېكترونلۇق خەت ياكى فېدېراتسىيە بۇلۇت كىملىكى ئارقىلىق قاتناشقۇچىلارنى ئىزدىسىڭىز ياكى قوشالايسىز",
    "Search or add participants" : "قاتناشقۇچىلارنى ئىزدەڭ ياكى قوشۇڭ",
    "Invitation was sent to {actorId}" : "تەكلىپنامە {actorId} غا ئەۋەتىلدى",
    "An error occurred while adding the participants" : "قاتناشقۇچىلارنى قوشقاندا خاتالىق كۆرۈلدى",
    "A new group conversation with selected participant will be created" : "تاللانغان قاتناشقۇچىلار بىلەن بىر گۇرۇپپا سۆھبىتى قۇرۇلىدۇ",
    "Participants" : "قاتناشقۇچىلار",
    "Pinned by a deleted user" : "بىر ئۆچۈرۋېتىلگەن ئىشلەتكۈچى مىخلىغان",
    "Participants ({count})" : "قاتناشقۇچىلار ({count})",
    "Open chat" : "پاراڭنى ئېچىڭ",
    "You have new unread messages in the chat." : "پاراڭدا يېڭى ئوقۇلمىغان ئۇچۇرلار بار.",
    "You have been mentioned in the chat." : "سىز پاراڭدا تىلغا ئېلىنغان.",
    "Search messages" : "ئۇچۇرلارنى ئىزدە",
    "Chat" : "پاراڭ",
    "Details" : "تەپسىلاتى",
    "Shared items" : "ئورتاق بەھرىلىنىدىغان بۇيۇملار",
    "Search in {name}" : "{name}دا ئىزدە",
    "Threads in {name}" : "{name} نامىدىكى يىپ",
    "{actor} in {conversation}" : "{conversation} دىكى {actor}",
    "Search messages …" : "ئۇچۇرلارنى ئىزدە...",
    "Search options" : "ئىزدەش تاللانمىلىرى",
    "From User" : "ئىشلەتكۈچىدىن",
    "Since" : "بۇيان",
    "Until" : "تاكى ھازىرغىچە",
    "No results found" : "ھېچقانداق نەتىجە تېپىلمىدى",
    "Load more results" : "تېخىمۇ كۆپ نەتىجىلەرنى يۈكلەڭ",
    "Recent threads" : "يېقىنقى يىپلار",
    "Projects" : "تۈر",
    "No shared items" : "ئورتاق بەھرىلىنىدىغان تۈر يوق",
    "Thread notifications" : "يىپ ئۇقتۇرۇشى",
    "Thread actions" : "يىپ ھەركىتى",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "سۆھبەتكە ئۇلىنىش",
    "No open conversations found" : "ئوچۇق سۆھبەت تېپىلمىدى",
    "Either there are no open conversations or you joined all of them." : "ياكى ئوچۇق سۆھبەت يوق ياكى ئۇلارنىڭ ھەممىسىگە قوشۇلدىڭىز.",
    "Check spelling or use complete words." : "ئىملانى تەكشۈرۈڭ ياكى تولۇق سۆز ئىشلىتىڭ.",
    "Search conversations or users" : "پاراڭ ياكى ئىشلەتكۈچىنى ئىزدەڭ",
    "Select conversation" : "سۆھبەتنى تاللاڭ",
    "Number length is not valid" : "ساننىڭ ئۇزۇنلۇقى ئىناۋەتلىك ئەمەس",
    "Region code is not valid" : "رايون كودى ئىناۋەتلىك ئەمەس",
    "Number length is too short" : "ساننىڭ ئۇزۇنلۇقى بەك قىسقا",
    "Number length is too long" : "ساننىڭ ئۇزۇنلۇقى بەك ئۇزۇن",
    "Number is not valid" : "سان ئىناۋەتلىك ئەمەس",
    "Phone numbers" : "تېلېفون نومۇرى",
    "Display name: {name}" : "كۆرسىتىش ئىسمى: {name}",
    "Edit display name" : "كۆرسىتىش نامىنى تەھرىرلەش",
    "Display name (required)" : "كۆرسىتىش ئىسمى (مەجبۇرىي)",
    "Save name" : "ئىسىمنى ساقلاڭ",
    "Error while setting personal setting" : "شەخسىي تەڭشەكنى تەڭشەۋاتقاندا خاتالىق",
    "Error while saving sounds setting" : "ئاۋاز تەڭشىكىنى ساقلاشتا خاتالىق",
    "Compact conversations list" : "ئىخچام سۆھبەت تىزىملىكى",
    "Play sounds when participants join or leave a call" : "قاتناشقۇچىلار قاتناشقاندا ياكى تېلېفوندىن ئايرىلغاندا ئاۋاز قويۇڭ",
    "Currently not available on iPhone and iPad due to technical restrictions by the manufacturer" : "ئىشلەپچىقارغۇچىنىڭ تېخنىكىلىق چەكلىمىسى سەۋەبىدىن ھازىر iPhone ۋە iPad دا يوق",
    "Notification settings" : "ئۇقتۇرۇش تەڭشىكى",
    "Sounds for chat and call notifications" : "پاراڭ ھەمدە تېلىفۇن ئۇقتۇرۇشلىرىنىڭ ئاۋازى",
    "Default language" : "كۆڭۈلدىكى تىل",
    "Select location for attachments" : "قوشۇمچە ھۆججەتلەرنىڭ ئورنىنى تاللاڭ",
    "Error while setting attachment folder" : "قوشۇمچە ھۆججەت قىسقۇچنى تەڭشەشتە خاتالىق",
    "Error while setting read status privacy" : "ئوقۇش ھالىتىنىڭ مەخپىيەتلىكىنى تەڭشەشتە خاتالىق",
    "Error while setting typing status privacy" : "خەت ھالىتى مەخپىيەتلىكىنى تەڭشەشتە خاتالىق",
    "Error while setting default media state" : "سۈكۈتتىكى مېدىيا ھالىتىنى تەڭشىگەندە خاتالىق",
    "Turn camera and microphone off by default" : "كامىرا بىلەن مىكروفۇننى سۈكۈتتە ئۆچۈر",
    "Blur camera background by default" : "كامىرا ئارقا كۆرۈنۈشىنى سۈكۈتتە تۇتۇق قىل",
    "Skip device preview before joining a call" : "چاقىرىققا كىرىشتىن بۇرۇن ئۈسكۈنە ئالدىن-كۆرسىتىشنى ئاتلا",
    "Appearance & Sounds" : "كۆرۈنۈش & ئاۋاز",
    "Privacy" : "مەخپىيەتلىك",
    "Send read receipts" : "ئۇقۇغان تىلخەتنى يوللا",
    "When off, all read statuses will be hidden" : "ئېتىلسە، بارلىق ئوقۇغانلىق ھالەتلىرى يۇشۇرۇلدۇ",
    "Share typing status" : "يېزىۋاتقانلىق ھالىتىنى ئورتاقلاش",
    "When off, all typing indicators will be hidden" : "ئېتىلسە، بارلىق يېزىۋاتقانلىق ئۇچۇرلىرى يۇشۇرۇلدۇ",
    "Attachments folder" : "قوشۇمچە ھۆججەت قىسقۇچ",
    "Toggle full screen" : "تولۇق ئېكراننى ئېچىڭ",
    "Return to Home screen" : "باشبەتكە قايت",
    "Search" : "ئىزدە",
    "Shortcuts while in a chat" : "پاراڭلىشۋاتقاندىكى قىسقا يوللار",
    "Focus the chat input" : "پاراڭلىشىشنى كىرگۈزۈڭ",
    "Unfocus the chat input to use shortcuts" : "تېزلەتمە ئىشلىتىش ئۈچۈن پاراڭ كىرگۈزۈشنى بىكار قىلىڭ",
    "Edit your last message" : "ئاخىرقى ئۇچۇرىڭىزنى تەھرىرلەڭ",
    "Shortcuts while in a call" : "تېلېفون قىلغاندا تېزلەتمە",
    "Camera on and off" : "كامېرا ئوچۇق ۋە تاقالغان",
    "Microphone on and off" : "مىكروفون ئېچىش ۋە تاقاش",
    "Raise or lower hand" : "قولىنى كۆتۈرۈڭ ياكى تۆۋەن قىلىڭ",
    "Push to talk or push to mute" : "سۆزلەشكە ئىتتىرىش ياكى ئۈنسىز ھالەتكە كەلتۈرۈش",
    "Zoom-in / zoom-out a screen share" : "ئېكراننى ئورتاقلىشىشنى كىچىكلەت / چوڭلات",
    "Mouse wheel" : "مائۇس چاقى",
    "Start call silently" : "ئۈن-تىنسىز تېلېفون قىلىشنى باشلاڭ",
    "Start call" : "چاقىرىشنى باشلاڭ",
    "End call" : "ئاخىرلىشىش تېلېفونى",
    "This call has just ended" : "بۇ تېلېفون ئاخىرلاشتى",
    "You will be able to join the call only after a moderator starts it." : "رىياسەتچى قوزغىغاندىن كېيىن ئاندىن تېلېفونغا قوشۇلالايسىز.",
    "End call for everyone" : "ھەممەيلەنگە تېلېفون قىلىش",
    "Starting the recording" : "خاتىرىلەشنى باشلاش",
    "Recording" : "خاتىرىلەش",
    "The call has been running for one hour." : "تېلېفون بىر سائەت داۋاملاشتى.",
    "Cancel recording start" : "خاتىرىلەشنى باشلاشنى ئەمەلدىن قالدۇرۇڭ",
    "Stop recording" : "خاتىرىلەشنى توختىتىڭ",
    "Send a reaction" : "ئىنكاس قايتۇرۇڭ",
    "React with {reaction}" : "{reaction}",
    "All tasks done!" : "بارلىق ۋەزىپىلەر تاماملاندى!",
    "_{done} of %n task_::_{done} of %n tasks_" : ["%n دىن {done} ۋەزىپە","%n دىن {done} ۋەزىپىلەر"],
    "Add participants to this call" : "قاتناشقۇچىلارنى بۇ چاقىرىققا قوش",
    "_%n participant in call_::_%n participants in call_" : ["چاقىرىقتا %n قاتناشقۇچى","چاقىرىقتا %n قاتناشقۇچى"],
    "You are not allowed to enable screensharing" : "ئېكران ئېكرانىنى قوزغىتىشقا رۇخسەت قىلىنمايدۇ",
    "No screensharing" : "ئېكران ئېكرانى يوق",
    "Screensharing options" : "ئېكران ئورتاقلىشىش تاللانمىلىرى",
    "Enable screensharing" : "ئېكراننى قوزغىتىشنى قوزغىتىڭ",
    "Bad sent video and screen quality." : "ئەۋەتىلگەن سىن ۋە ئېكران سۈپىتى ناچار.",
    "Bad sent screen quality." : "ئەۋەتىلگەن ئېكران سۈپىتى ناچار.",
    "Bad sent video quality." : "ئەۋەتكەن سىن سۈپىتى ناچار.",
    "Bad sent audio, video and screen quality." : "ئەۋەتىلگەن ئاۋاز ، سىن ۋە ئېكران سۈپىتى ناچار.",
    "Bad sent audio and screen quality." : "ئەۋەتىلگەن ئاۋاز ۋە ئېكران سۈپىتى ناچار.",
    "Bad sent audio and video quality." : "ئەۋەتكەن ئاۋاز ۋە سىن سۈپىتى ناچار.",
    "Bad sent audio quality." : "ئەۋەتىلگەن ئاۋاز سۈپىتى ناچار.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "تور ئۇلىنىشىڭىز ياكى كومپيۇتېرىڭىز ئالدىراش ، باشقا قاتناشقۇچىلار ئېكراننى كۆرەلمەسلىكى مۇمكىن. ۋەزىيەتنى ياخشىلاش ئۈچۈن ئېكران ھەمبەھىرلىگەندە ئارقا كۆرۈنۈشنى ياكى سىننى چەكلەڭ.",
    "Disable background blur" : "تەگلىك تۇتۇقلىقىنى چەكلەڭ",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "تور ئۇلىنىشىڭىز ياكى كومپيۇتېرىڭىز ئالدىراش ، باشقا قاتناشقۇچىلار ئېكراننى كۆرەلمەسلىكى مۇمكىن. ۋەزىيەتنى ياخشىلاش ئۈچۈن ئېكران ئېكرانى قىلىۋاتقاندا سىننى ئىناۋەتسىز قىلىڭ.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "تور ئۇلىنىشىڭىز ياكى كومپيۇتېرىڭىز ئالدىراش ، باشقا قاتناشقۇچىلار ئېكراننى كۆرەلمەسلىكى مۇمكىن.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "تور ئۇلىنىشىڭىز ياكى كومپيۇتېرىڭىز ئالدىراش ، باشقا قاتناشقۇچىلار سىزنى كۆرەلمەسلىكى مۇمكىن.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "تور ئۇلىنىشىڭىز ياكى كومپيۇتېرىڭىز ئالدىراش ، باشقا قاتناشقۇچىلار سىزنى چۈشىنىشكە ۋە كۆرەلمەسلىكى مۇمكىن. ۋەزىيەتنى ياخشىلاش ئۈچۈن ئېكران ئېكرانى قىلغاندا ئارقا كۆرۈنۈشنى ياكى سىننى ئىناۋەتسىز قىلىڭ.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "تور ئۇلىنىشىڭىز ياكى كومپيۇتېرىڭىز ئالدىراش ، باشقا قاتناشقۇچىلار سىزنى چۈشىنىشكە ۋە كۆرەلمەسلىكى مۇمكىن. ۋەزىيەتنى ياخشىلاش ئۈچۈن ئېكران ئېكرانى قىلىۋاتقاندا سىننى ئىناۋەتسىز قىلىڭ.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "تور ئۇلىنىشىڭىز ياكى كومپيۇتېرىڭىز ئالدىراش ، باشقا قاتناشقۇچىلار سىزنى چۈشىنىپ ئېكراننى كۆرەلمەسلىكى مۇمكىن. ۋەزىيەتنى ياخشىلاش ئۈچۈن ئېكران ئېكرانىنى چەكلەڭ.",
    "Disable screenshare" : "ئېكران ئېكرانىنى چەكلەڭ",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "تور ئۇلىنىشىڭىز ياكى كومپيۇتېرىڭىز ئالدىراش ، باشقا قاتناشقۇچىلار سىزنى چۈشىنىشكە ۋە كۆرەلمەسلىكى مۇمكىن. ۋەزىيەتنى ياخشىلاش ئۈچۈن تەگلىك ياكى سىننى ئىناۋەتسىز قىلىڭ.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "تور ئۇلىنىشىڭىز ياكى كومپيۇتېرىڭىز ئالدىراش ، باشقا قاتناشقۇچىلار سىزنى چۈشىنىشكە ۋە كۆرەلمەسلىكى مۇمكىن. ۋەزىيەتنى ياخشىلاش ئۈچۈن سىننى چەكلەڭ.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "تور ئۇلىنىشىڭىز ياكى كومپيۇتېرىڭىز ئالدىراش ، باشقا قاتناشقۇچىلار سىزنى چۈشىنىشكە ئامالسىز قېلىشى مۇمكىن.",
    "Screen sharing is not supported by your browser." : "ئېكران ئورتاقلىشىشنى توركۆرگۈڭىز قوللىمايدۇ.",
    "Screen sharing requires the page to be loaded through HTTPS." : "ئېكراندىن ئورتاقلىشىش بۇ بەتنى HTTPS ئارقىلىق يۈكلەشنى تەلەپ قىلىدۇ.",
    "Screensharing requires the page to be loaded through HTTPS." : "ئېكراندىن ئورتاقلىشىش بۇ بەتنى HTTPS ئارقىلىق يۈكلەشنى تەلەپ قىلىدۇ.",
    "An error occurred while starting screensharing." : "ئېكراننى باشلىغاندا خاتالىق كۆرۈلدى.",
    "Select virtual background" : "مەۋھۇم ئارقا-كۆرۈنۈش تاللا",
    "Show your screen" : "ئېكرانىڭىزنى كۆرسىتىڭ",
    "Stop screensharing" : "ئېكراننى توختىتىڭ",
    "Mute others" : "باشقىلارنى تىللاڭ",
    "Start recording" : "خاتىرىلەشنى باشلاڭ",
    "Set up breakout rooms" : "بۆسۈش ئۆيى تەسىس قىلىڭ",
    "Download attendance list" : "قاتنىشىش تىزىملىكىنى چۈشۈرۈڭ",
    "Open Calendar" : "كالېندارنى ئېچىڭ",
    "Remove participant {name}" : "قاتناشقۇچىنى ئۆچۈرۈڭ {name}",
    "Would you like to delete this conversation?" : "سىز بۇ سۆھبەتنى ئۆچۈرمەكچىمۇ؟",
    "Are you sure you want to delete this conversation?" : "بۇ سۆھبەتنى سىز راستىنلا ئۆچۈرمەكچىمۇ؟",
    "Delete now" : "ھازىرلا ئۆچۈر",
    "Keep" : "ساقلاڭ",
    "Open dialpad" : "سۆزلىشىش تاختىسىنى ئېچىڭ",
    "Select a region" : "رايون تاللاڭ",
    "Local time: {time}" : "يەرلىك ۋاقىت:{time}",
    "Search …" : "ئىزدەش…",
    "Message without mention" : "تىلغا ئېلىنمىغان ئۇچۇر",
    "Mention myself" : "ئۆزۈمنى تىلغا ئېلىڭ",
    "Mention everyone" : "ھەممەيلەننى تىلغا ئېلىڭ",
    "Select a conversation" : "سۆھبەتنى تاللاڭ",
    "Select a mode" : "بىر ھالەتنى تاللاڭ",
    "You do not have permissions to access this conversation." : "بۇ سۆھبەتنى زىيارەت قىلىش ھوقۇقىڭىز يوق.",
    "Join a different conversation or start a new one." : "باشقا سۆھبەتكە قاتنىشىڭ ياكى يېڭى سۆھبەتنى باشلاڭ.",
    "The conversation does not exist" : "سۆھبەت مەۋجۇت ئەمەس",
    "Join a conversation or start a new one!" : "سۆھبەتكە قاتنىشىڭ ياكى يېڭى باشلاڭ!",
    "Duplicate session" : "تەكرار يىغىن",
    "Creating and joining a conversation with \"{userid}\"" : "\"{userid}\" بىلەن سۆھبەت قۇرۇش ۋە ئۇنىڭغا قاتنىشىش",
    "Join a conversation or start a new one" : "سۆھبەتكە قاتنىشىڭ ياكى يېڭى باشلاڭ",
    "Error while joining the conversation" : "سۆھبەتكە قاتناشقاندا خاتالىق",
    "Nextcloud URL" : "Nextcloud URL",
    "Nextcloud user" : "Nextcloud ئىشلەتكۈچى",
    "User password" : "ئىشلەتكۈچى پارولى",
    "Talk conversation" : "پاراڭلىشىش",
    "Skip TLS verification" : "TLS دەلىللەشتىن ئاتلاڭ",
    "Matrix server URL" : "Matrix مۇلازىمېتىر URL",
    "User" : "ئىشلەتكۈچى",
    "Matrix channel" : "ماترىتسا قانىلى",
    "Mattermost server URL" : "ئەڭ مۇھىم مۇلازىمېتىر URL",
    "Mattermost user" : "ئەڭ مۇھىم ئىشلەتكۈچى",
    "Team name" : "گۇرۇپپا ئىسمى",
    "Channel name" : "قانال ئىسمى",
    "Rocket.Chat server URL" : "راكېتا. مۇلازىمېتىر URL",
    "User name or email address" : "ئىشلەتكۈچى ئىسمى ياكى ئېلېكترونلۇق خەت ئادرېسى",
    "Rocket.Chat channel" : "Rocket.Chat قانىلى",
    "Zulip server URL" : "Zulip مۇلازىمېتىر URL",
    "Bot user name" : "Bot ئىشلەتكۈچى ئىسمى",
    "Bot API key" : "Bot API ئاچقۇچى",
    "Zulip channel" : "Zulip قانىلى",
    "API token" : "API بەلگىسى",
    "Slack channel" : "Slack قانىلى",
    "Server ID or name" : "مۇلازىمېتىر كىملىكى ياكى ئىسمى",
    "Channel ID (prefixed with \"ID:\") or name" : "قانال ID (\"ID\" بىلەن باشلىندۇ) ياكى ئىسىم",
    "Channel" : "قانال",
    "Login" : "كىرىش",
    "Chat ID" : "پاراڭ كىملىكى",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "IRC مۇلازىمېتىر ئادرېسى (مەسىلەن chat.freenode.net:6667)",
    "Nickname" : "تەخەللۇس",
    "Connection password" : "ئۇلىنىش پارولى",
    "IRC channel" : "IRC قانىلى",
    "Channel password" : "قانال پارولى",
    "NickServ nickname" : "NickServ لەقىمى",
    "NickServ password" : "NickServ پارولى",
    "Use TLS" : "TLS نى ئىشلىتىڭ",
    "Use SASL" : "SASL نى ئىشلىتىڭ",
    "Tenant ID" : "ئىجارە ئالغۇچى كىملىكى",
    "Client ID" : "خېرىدار ID",
    "Team ID" : "گۇرۇپپا كىملىكى",
    "Thread ID" : "تېما كىملىكى",
    "XMPP/Jabber server URL" : "XMPP / Jabber مۇلازىمېتىر URL",
    "MUC server URL" : "MUC مۇلازىمېتىر ئادرېسى",
    "Jabber ID" : "Jabber ID",
    "Pinned messages" : "مىخلانغان ئۇچۇرلار",
    "Media" : "كۆپ-ۋاستە",
    "Polls" : "راي سىناش",
    "Deck cards" : "پالۋان كارتىلىرى",
    "Voice messages" : "ئاۋازلىق ئۇچۇرلار",
    "Locations" : "ئورۇنلار",
    "Call recordings" : "چاقىرىش خاتىرىسى",
    "Audio" : "ئاۋاز",
    "Show all pinned messages" : "بارلىق مىخلانغان ئۇچۇرلارنى كۆرسەت",
    "Show all media" : "بارلىق تاراتقۇلارنى كۆرسەت",
    "Show all files" : "بارلىق ھۆججەتلەرنى كۆرسەت",
    "Show all polls" : "بارلىق راي سىناشلارنى كۆرسەت",
    "Show all deck cards" : "بارلىق كارتا كارتىلىرىنى كۆرسەت",
    "Show all voice messages" : "بارلىق ئاۋازلىق ئۇچۇرلارنى كۆرسەت",
    "Show all locations" : "بارلىق ئورۇنلارنى كۆرسەت",
    "Show all call recordings" : "بارلىق چاقىرىش خاتىرىسىنى كۆرسەت",
    "Show all audio" : "بارلىق ئاۋازنى كۆرسەت",
    "Show all other" : "باشقىلىرىنى كۆرسەت",
    "Follow conversation settings" : "سۆھبەت تەڭشەكلىرىگە ئەگەش",
    "Group" : "گۇرۇپپا",
    "Team" : "ئەتىرەت",
    "You reconnected to the call" : "سىز تېلېفونغا قايتا ئۇلاندىڭىز",
    "{actor} reconnected to the call" : "{actor} تېلېفونغا قايتا ئۇلاندى",
    "You added {user0} and {user1}" : "سىز {user0} ۋە {user1} added نى قوشتىڭىز",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["سىز {user0}، {user1} ھەمدە باشقا %n قاتناشقۇچىنى قوشتىڭىز","سىز {user0}، {user1} ھەمدە باشقا %n قاتناشقۇچىنى قوشتىڭىز"],
    "An administrator added you and {user0}" : "باشقۇرغۇچى سىزنى ۋە {user0} نى قوشتى",
    "{actor} added you and {user0}" : "{actor} سىزنى ۋە {user0} نى قوشتى",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["بىر باشقۇرغۇچى سىزنى، {user0} ھەمدە يەنە %n قاتناشقۇچىنى قوشتى","بىر باشقۇرغۇچى سىزنى، {user0} ھەمدە يەنە %n قاتناشقۇچىنى قوشتى"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["{actor} سىزنى، {user0} ھەمدە يەنە %n قاتناشقۇچىنى قوشتى","{actor} سىزنى، {user0} ھەمدە يەنە %n قاتناشقۇچىنى قوشتى"],
    "An administrator added {user0} and {user1}" : "باشقۇرغۇچى {user0} ۋە {user1} added نى قوشتى",
    "{actor} added {user0} and {user1}" : "{actor} قوشۇلدى {user0} ۋە {user1}",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["بىر باشقۇرغۇچى {user0}، {user1} ھەمدە يەنە %n قاتناشقۇچىنى قوشتى","بىر باشقۇرغۇچى {user0}، {user1} ھەمدە يەنە %n قاتناشقۇچىنى قوشتى"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["{actor} سىزنى، {user0}، {user1} ھەمدە يەنە %n قاتناشقۇچىنى قوشتى","{actor} سىزنى، {user0}، {user1} ھەمدە يەنە %n قاتناشقۇچىنى قوشتى"],
    "You removed {user0} and {user1}" : "{user0} ۋە {user1} نى ئۆچۈردىڭىز",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["سىز {user0}، {user1} ھەمدە باشقا %n قاتناشقۇچىنى چىقاردىڭىز","سىز {user0}، {user1} ھەمدە باشقا %n قاتناشقۇچىنى چىقاردىڭىز"],
    "An administrator removed you and {user0}" : "باشقۇرغۇچى سىزنى ۋە {user0} نى ئېلىۋەتتى",
    "{actor} removed you and {user0}" : "{actor} سىزنى ۋە {user0} نى ئېلىۋەتتى",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["بىر باشقۇرغۇچى سىزنى، {user0} ھەمدە يەنە %n قاتناشقۇچىنى چىقىرۋەتتى","بىر باشقۇرغۇچى سىزنى، {user0} ھەمدە يەنە %n قاتناشقۇچىنى چىقىرۋەتتى"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["{actor} سىزنى، {user0} ھەمدە يەنە %n قاتناشقۇچىنى چىقىرۋەتتى","{actor} سىزنى، {user0} ھەمدە يەنە %n قاتناشقۇچىنى چىقىرۋەتتى"],
    "An administrator removed {user0} and {user1}" : "باشقۇرغۇچى {user0} ۋە {user1} نى ئۆچۈرۈۋەتتى",
    "{actor} removed {user0} and {user1}" : "{actor} چىقىرىۋېتىلدى {user0} ۋە {user1}",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["بىر باشقۇرغۇچى {user0}، {user1} ھەمدە يەنە %n قاتناشقۇچىنى چىقىرۋەتتى","بىر باشقۇرغۇچى {user0}، {user1} ھەمدە يەنە %n قاتناشقۇچىنى چىقىرۋەتتى"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["{actor} سىزنى، {user0}، {user1} ھەمدە يەنە %n قاتناشقۇچىنى چىقىرۋەتتى","{actor} سىزنى، {user0}، {user1} ھەمدە يەنە %n قاتناشقۇچىنى چىقىرۋەتتى"],
    "You and {user0} joined the call" : "سىز ۋە {user0} چاقىرىققا قوشۇلدىڭىز",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["سىز {user0} ھمدە يەنە %n قاتناشقۇچى چاقىرىققا قاتناشتى","سىز {user0} ھمدە يەنە %n قاتناشقۇچى چاقىرىققا قاتناشتى"],
    "{user0} and {user1} joined the call" : "{user0} ۋە {user1} چاقىرىققا قوشۇلدى",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["{user0}، {user1} ھەمدە يەنە %n قاتناشقۇچىلار چاقىرىققا قاتناشتى","{user0}، {user1} ھەمدە يەنە %n قاتناشقۇچىلار چاقىرىققا قاتناشتى"],
    "You and {user0} left the call" : "سىز ۋە {user0} تېلېفوندىن ئايرىلدى",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["سىز {user0} ھمدە يەنە %n قاتناشقۇچى چاقىرىقتىن ئايرىلدى","سىز {user0} ھمدە يەنە %n قاتناشقۇچى چاقىرىقتىن ئايرىلدى"],
    "{user0} and {user1} left the call" : "{user0} ۋە {user1} تېلېفوندىن ئايرىلدى",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["{user0}، {user1} ھەمدە يەنە %n قاتناشقۇچىلار چاقىرىقتىن ئايرىلدى","{user0}، {user1} ھەمدە يەنە %n قاتناشقۇچىلار چاقىرىقتىن ئايرىلدى"],
    "You promoted {user0} and {user1} to moderators" : "سىز {user0} ۋە {user1} نى رىياسەتچىگە ئۆستۈردىڭىز",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["سىز {user0}، {user1} ھەمدە باشقا %n قاتناشقۇچىنى مۇرەسسە قىلغۇچىلىققا ئۆستۈردىڭىز","سىز {user0}، {user1} ھەمدە باشقا %n قاتناشقۇچىنى مۇرەسسە قىلغۇچىلىققا ئۆستۈردىڭىز"],
    "An administrator promoted you and {user0} to moderators" : "باشقۇرغۇچى سىزنى ۋە {user0} نى رىياسەتچىگە ئۆستۈردى",
    "{actor} promoted you and {user0} to moderators" : "{actor} you سىزنى ۋە {user0} mod رىياسەتچىلەرگە ئۆستۈردى",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["بىر باشقۇرغۇچى سىزنى، {user0} ھەمدە يەنە %n قاتناشقۇچىنى مۇرەسسە قىلغۇچىلىققا ئۆستۈردى","بىر باشقۇرغۇچى سىزنى، {user0} ھەمدە يەنە %n قاتناشقۇچىنى مۇرەسسە قىلغۇچىلىققا ئۆستۈردى"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["{actor} سىزنى {user0} ھەمدە يەنە %n قاتناشقۇچىلارنى رىياسەتچىگە ئۆستۈردى","{actor} سىزنى {user0} ھەمدە يەنە %n قاتناشقۇچىلارنى رىياسەتچىگە ئۆستۈردى"],
    "An administrator promoted {user0} and {user1} to moderators" : "باشقۇرغۇچى باشقۇرغۇچىغا {user0} ۋە {user1} نى ئۆستۈردى",
    "{actor} promoted {user0} and {user1} to moderators" : "{actor} باشقۇرغۇچىغا {user0} ۋە {user1} نى ئۆستۈردى",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["بىر باشقۇرغۇچى سىزنى، {user0}، {user1} ھەمدە يەنە %n قاتناشقۇچىنى رىياسەتچىلىككە ئۆستۈردى","بىر باشقۇرغۇچى سىزنى، {user0}، {user1} ھەمدە يەنە %n قاتناشقۇچىنى رىياسەتچىلىككە ئۆستۈردى"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["{actor} سىزنى {user0}، {user1} ھەمدە يەنە %n قاتناشقۇچىلارنى رىياسەتچىگە ئۆستۈردى","{actor} سىزنى {user0}، {user1} ھەمدە يەنە %n قاتناشقۇچىلارنى رىياسەتچىگە ئۆستۈردى"],
    "You demoted {user0} and {user1} from moderators" : "رىياسەتچىلەردىن {user0} ۋە {user1} نى چۈشۈردىڭىز",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["سىز {user0}، {user1} ھەمدە باشقا %n قاتناشقۇچىنى رىياسەتچىلىكتىن چۈشۈردىڭىز","سىز {user0}، {user1} ھەمدە باشقا %n قاتناشقۇچىنى رىياسەتچىلىكتىن چۈشۈردىڭىز"],
    "An administrator demoted you and {user0} from moderators" : "باشقۇرغۇچى سىزنى ۋە {user0} نى رىياسەتچىلىكتىن چۈشۈردى",
    "{actor} demoted you and {user0} from moderators" : "{actor} سىزنى ۋە {user0} رىياسەتچىلىكتىن چۈشۈردى",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["بىر باشقۇرغۇچى سىزنى، {user0} ھەمدە يەنە %n قاتناشقۇچىنى رىياسەتچىلىكتىن چۈشۈردى","بىر باشقۇرغۇچى سىزنى، {user0} ھەمدە يەنە %n قاتناشقۇچىنى رىياسەتچىلىكتىن چۈشۈردى"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["{actor} سىزنى {user0} ھەمدە يەنە %n قاتناشقۇچىلارنى رىياسەتچىلىكتىن چۈشۈردى","{actor} سىزنى {user0} ھەمدە يەنە %n قاتناشقۇچىلارنى رىياسەتچىلىكتىن چۈشۈردى"],
    "An administrator demoted {user0} and {user1} from moderators" : "باشقۇرغۇچى باشقۇرغۇچىدىن {user0} ۋە {user1} نى چۈشۈردى",
    "{actor} demoted {user0} and {user1} from moderators" : "{actor} رىياسەتچىلەردىن {user0} ۋە {user1} نى چۈشۈردى",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["بىر باشقۇرغۇچى سىزنى، {user0}، {user1} ھەمدە يەنە %n قاتناشقۇچىنى رىياسەتچىلىكتىن چۈشۈردى","بىر باشقۇرغۇچى سىزنى، {user0}، {user1} ھەمدە يەنە %n قاتناشقۇچىنى رىياسەتچىلىكتىن چۈشۈردى"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["{actor} سىزنى {user0}، {user1} ھەمدە يەنە %n قاتناشقۇچىلارنى رىياسەتچىلىكتىن چۈشۈردى","{actor} سىزنى {user0}، {user1} ھەمدە يەنە %n قاتناشقۇچىلارنى رىياسەتچىلىكتىن چۈشۈردى"],
    "You:" : "سىز:",
    "You: {lastMessage}" : "سىز: {lastMessage}",
    "{actor}:" : "{actor}:",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "(edited by you)" : "(تەھرىرلىگەن)",
    "(edited by a deleted user)" : "(ئۆچۈرۈلگەن ئىشلەتكۈچى تەھرىرلىگەن)",
    "(edited by {moderator})" : "({moderator} تەرىپىدىن تەھرىرلىگەن)",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "سىز باشقا كۆزنەك ياكى ئۈسكۈنىدە ئاكتىپ يىغىن ئاچقاندا سۆھبەتكە قاتناشماقچى بولۇۋاتىسىز. بۇنى Nextcloud Talk قوللىمايدۇ. نېمە قىلماقچى؟",
    "Leave this page" : "بۇ بەتنى قالدۇرۇڭ",
    "Join here" : "بۇ يەرگە قوشۇلۇڭ",
    "Deck card has been posted to {conversation}" : "پالۋان كارتىسى {conversation} يوللاندى",
    "An error occurred while posting deck card to conversation" : "تاختاي كارتىسىنى چاپلاۋاتقاندا بىر خاتالىق كۆرۈلدى",
    "Post to a conversation" : "بىر سۆھبەتكە يوللا",
    "Post to conversation" : "سۆھبەتكە يوللاڭ",
    "The recording failed. Please contact your administrator." : "خاتىرىلەش مەغلۇپ بولدى. باشقۇرغۇچىڭىز بىلەن ئالاقىلىشىڭ.",
    "Location has been posted to {conversation}" : "ئورنى {conversation} يوللاندى",
    "An error occurred while posting location to conversation" : "ئورۇننى بىر سۆھبەتكە يوللاۋاتقاندا بىر خاتالىق كۆرۈلدى",
    "Share to a conversation" : "بىر سۆھبەتكە ئورتاقلىشىڭ",
    "Share to conversation" : "سۆھبەتكە ئورتاقلىشىڭ",
    "In conversation" : "سۆھبەتتە",
    "Search in conversation: {conversation}" : "سۆھبەتتە ئىزدەش: {conversation}",
    "Your requests are throttled at the moment due to brute force protection" : "تەلىپىڭىز ھازىرچە رەھىمسىز كۈچ قوغداش سەۋەبىدىن ئىتتىرىلدى",
    "Error while clearing conversation history" : "سۆھبەت تارىخىنى تازىلاش جەريانىدا خاتالىق",
    "Error occurred while allowing guests" : "مېھمانلارغا يول قويغاندا خاتالىق كۆرۈلدى",
    "Error occurred while disallowing guests" : "مېھمانلارنى رەت قىلغاندا خاتالىق كۆرۈلدى",
    "Error occurred when restricting the conversation to moderator" : "رىياسەتچى بىلەن سۆھبەتنى چەكلىگەندە خاتالىق كۆرۈلدى",
    "Error occurred when opening the conversation to everyone" : "سۆھبەتنى كۆپچىلىككە ئاچقاندا خاتالىق كۆرۈلدى",
    "Conversation password has been saved" : "سۆھبەت پارولى ساقلاندى",
    "Conversation password has been removed" : "سۆھبەت پارولى ئۆچۈرۈلدى",
    "Error occurred while saving conversation password" : "پاراڭ پارولىنى ساقلىغاندا خاتالىق كۆرۈلدى",
    "Call recording is starting." : "تېلېفون خاتىرىلەش باشلىنىۋاتىدۇ.",
    "Call recording stopped while starting." : "قوزغالغاندا تېلېفون خاتىرىلەش توختىتىلدى.",
    "Call recording stopped. You will be notified once the recording is available." : "تېلېفون خاتىرىلەش توختىتىلدى. خاتىرىلەنگەندىن كېيىن سىزگە ئۇقتۇرۇلىدۇ.",
    "Conversation picture set" : "سۆھبەت رەسىملىرى",
    "Conversation picture deleted" : "سۆھبەت رەسىمى ئۆچۈرۈلدى",
    "Could not delete the conversation picture" : "سۆھبەت رەسىمىنى ئۆچۈرەلمىدى",
    "Could not remove the automatic expiration" : "ئاپتۇماتىك مۇددەتنى ئۆچۈرەلمىدى",
    "Could not post message: {errorMessage}" : "ئۇچۇر يوللىيالمىدى: {errorMessage}",
    "Participant is banned successfully" : "قاتناشقۇچى مۇۋەپپەقىيەتلىك چەكلەنگەن",
    "Error while banning the participant" : "قاتناشقۇچىنى چەكلىگەندە خاتالىق",
    "An error occurred while fetching the participants" : "قاتناشقۇچىلارنى ئەكەلگەندە خاتالىق كۆرۈلدى",
    "Could not send invitation to {actorId}" : "{actorId} to غا تەكلىپ ئەۋەتەلمىدى",
    "Invitations sent" : "تەكلىپنامە ئەۋەتىلدى",
    "Error occurred when sending invitations" : "تەكلىپنامە ئەۋەتكەندە خاتالىق كۆرۈلدى",
    "Failed to join the conversation." : "سۆھبەتكە قاتنىشالمىدى",
    "An error occurred while creating breakout rooms" : "بۆسۈش ئۆيى قۇرغاندا خاتالىق كۆرۈلدى",
    "An error occurred while re-ordering the attendees" : "يىغىنغا قاتناشقانلارنى قايتا زاكاز قىلغاندا خاتالىق كۆرۈلدى",
    "An error occurred while deleting breakout rooms" : "بۆسۈش ئۆيلىرىنى ئۆچۈرگەندە خاتالىق كۆرۈلدى",
    "An error occurred while starting breakout rooms" : "بۆسۈش ئۆيلىرىنى باشلىغاندا خاتالىق كۆرۈلدى",
    "An error occurred while stopping breakout rooms" : "بۆسۈش ئۆيلىرىنى توختاتقاندا خاتالىق كۆرۈلدى",
    "An error occurred while sending a message to the breakout rooms" : "بۆسۈش ئۆيىگە ئۇچۇر ئەۋەتكەندە خاتالىق كۆرۈلدى",
    "An error occurred while requesting assistance" : "ياردەم تەلەپ قىلغاندا خاتالىق كۆرۈلدى",
    "An error occurred while resetting the request for assistance" : "ياردەم ئىلتىماسىنى ئەسلىگە كەلتۈرۈشتە خاتالىق كۆرۈلدى",
    "An error occurred while joining breakout room" : "بۆسۈش ئۆيىگە قوشۇلغاندا خاتالىق كۆرۈلدى",
    "Failed to rename the thread" : "بۇ يىپنىڭ نامىنى ئۆزگەرتەلمىدى",
    "Error fetching upcoming events" : "كىلىدىغان پائالىيەتلەرنى چۈشۈرۈش خاتالىقى",
    "Error fetching upcoming reminders" : "كىلىدىغان ئەسكەرتمىلەرنى چۈشۈرۈش خاتالىقى",
    "An error occurred while accepting an invitation" : "تەكلىپنى قوبۇل قىلغاندا خاتالىق كۆرۈلدى",
    "An error occurred while rejecting an invitation" : "تەكلىپنى رەت قىلغاندا خاتالىق كۆرۈلدى",
    "{guest} (guest)" : "{guest} (مېھمان)",
    "Poll draft has been saved" : "راي سىناش لايىھىسى ساقلاندى",
    "An error occurred while saving the draft" : "لايىھەنى ساقلاۋاتقاندا خاتالىق كۆرۈلدى",
    "An error occurred while submitting your vote" : "ئاۋازىڭىزنى تاپشۇرغاندا خاتالىق كۆرۈلدى",
    "An error occurred while ending the poll" : "بېلەت تاشلاش ئاخىرلاشقاندا خاتالىق كۆرۈلدى",
    "An error occurred while deleting the poll draft" : "بېلەت تاشلاش لايىھىسىنى ئۆچۈرگەندە خاتالىق كۆرۈلدى",
    "Poll \"{name}\" was created by {user}. Click to vote" : "راي سىناش \"{name}\" {user} تەرىپىدىن قۇرۇلدى. بېلەت تاشلاش ئۈچۈن چېكىڭ",
    "Failed to add reaction" : "ئىنكاس قوشالمىدى",
    "Failed to remove reaction" : "ئىنكاسنى ئۆچۈرەلمىدى",
    "Error while uploading file \"{fileName}\"" : "\"{fileName}\" ھۆججىتىنى يۈكلەۋاتقاندا خاتالىق",
    "Not enough free space to upload file \"{fileName}\"" : "\"{fileName}\" ھۆججىتىنى يۈكلەشكە يېتەرلىك بوشلۇق يوق",
    "You are not allowed to share files" : "ھۆججەتلەرنى ئورتاقلىشىڭىزغا رۇخسەت قىلىنمايدۇ",
    "Error while sharing file" : "ھۆججەتنى ھەمبەھىرلەشتە خاتالىق",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "سىز ئىشلىتىۋاتقان توركۆرگۈچ Nextcloud Talk تەرىپىدىن تولۇق قوللىمايدۇ. Mozilla Firefox ، Microsoft Edge ، Google Chrome ، Opera ياكى Apple Safari نىڭ ئەڭ يېڭى نەشرىنى ئىشلىتىڭ.",
    "_In %n hour_::_In %n hours_" : ["%n سائەتتە","%n سائەتتە"],
    "_%n minute _::_%n minutes_" : ["%n مىنۇتتا","%n مىنۇتتا"],
    "In {hours} and {minutes}" : "{hours} ۋە {minutes}",
    "_In %n minute_::_In %n minutes_" : ["%n مىنۇتتا","%n مىنۇتتا"],
    "Later today – {timeLocale}" : "كېيىن بۈگۈن - {timeLocale}",
    "Set time for later today" : "ۋاقىتنى بۈگۈنكى كىيىنرەك ۋاقىتقا بېكىت",
    "Tomorrow – {timeLocale}" : "ئەتە - {timeLocale}",
    "Set time for tomorrow" : "ۋاقىتنى ئەتىگە بېكىت",
    "This weekend – {timeLocale}" : "بۇ ھەپتە ئاخىرى - {timeLocale}",
    "Set time for this weekend" : "ۋاقىتنى بۇ ھەپتىگە بېكىت",
    "Next week – {timeLocale}" : "كېلەر ھەپتە - {timeLocale}",
    "Set time for next week" : "ۋاقىتنى كىيىنكى ھەپتىگە بېكىت",
    "Conversation link copied to clipboard" : "چاپلاش تاختىسىغا كۆچۈرۈلگەن سۆھبەت ئۇلىنىشى",
    "The link could not be copied" : "ئۇلانمىنى كۆچۈرگىلى بولمايدۇ",
    "Error while parsing a PROPFIND error" : "PROPFIND خاتالىقىنى تەھلىل قىلغاندا خاتالىق",
    "Sending signaling message has failed" : "سىگنال ئۇچۇرى ئەۋەتىش مەغلۇپ بولدى",
    "Lost connection to signaling server. Trying to reconnect." : "سىگنال مۇلازىمىتىرىغا ئۇلىنىش يوقاپ كەتتى. قايتا ئۇلىماقچى بولۇۋاتىدۇ.",
    "Lost connection to signaling server." : "سىگنال مۇلازىمىتىرىغا ئۇلىنىش يوقاپ كەتتى.",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "سەپلىمە سىگنال مۇلازىمېتىرى بۇ نەشرىدىكى Talk بىلەن ماسلىشىش ئۈچۈن يېڭىلىنىشى كېرەك. باشقۇرغۇچىڭىز بىلەن ئالاقىلىشىڭ.",
    "Please restart the app." : "بۇ ئەپنى قايتا قوزغىتىڭ.",
    "Please reload the page." : "بۇ بەتنى قايتا يۈكلەڭ.",
    "Please try to restart the app." : "بۇ ئەپنى قايتا قوزغىتىپ سىناپ بېقىڭ.",
    "Please try to reload the page." : "بۇ بەتنى قايتا يۈكلەپ سىناپ بېقىڭ",
    "Do not disturb" : "ئاۋارە قىلماڭ",
    "Away" : "يىراق",
    "Microphone {number}" : "مىكروفون {number}",
    "Camera {number}" : "كامېرا {number}",
    "Speaker {number}" : "سۆزلىگۈچى {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "ئۈنسىز ھالەتتە پاراڭلاشقاندەك قىلىسىز ، باشقىلارنىڭ گېپىنى ئاڭلىشى ئۈچۈن ئۆزىڭىزنى تىللاڭ",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "كەم دېگەندە بىر قاتناشقۇچى بىلەن ئۇلىنىش قۇرالمىدى. سىنارىيەڭىز ئۈچۈن TURN مۇلازىمېتىرى لازىم بولۇشى مۇمكىن. باشقۇرغۇچىڭىزدىن تۆۋەندىكى {linkstart} بۇ ھۆججەت {linkend} نى تەڭشەشنى تەلەپ قىلىڭ.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "بۇ مۆلچەردىكىدىن ئۇزۇنراق ۋاقىت كېتىۋاتىدۇ. ئاخبارات ئىجازىتى ئاللىقاچان بېرىلگەنمۇ (ياكى رەت قىلىنغان)؟ ئەگەر شۇنداق بولسا ئاۋاز ۋە سىن مەغلۇپ بولغانلىقتىن تور كۆرگۈچىڭىزنى قايتا قوزغىتىڭ",
    "Access to microphone & camera is only possible with HTTPS" : "مىكروفون ۋە كامېراغا ئېرىشىش پەقەت HTTPS ئارقىلىقلا مۇمكىن",
    "Please move your setup to HTTPS" : "تەڭشەكلىرىڭىزنى HTTPS غا يۆتكەڭ",
    "Access to microphone & camera was denied" : "مىكروفون ۋە كامېراغا ئېرىشىش رەت قىلىندى",
    "WebRTC is not supported in your browser" : "تور كۆرگۈچىڭىزدە WebRTC قوللىمايدۇ",
    "Please use a different browser like Firefox or Chrome" : "Firefox ياكى Chrome غا ئوخشاش باشقا توركۆرگۈچ ئىشلىتىڭ",
    "Error while accessing microphone & camera" : "مىكروفون ۋە كامېرانى زىيارەت قىلغاندا خاتالىق",
    "%s Talk on your mobile devices" : "%s كۆچمە ئۈسكۈنىڭىزدە سۆزلەڭ",
    "Join conversations at any time, anywhere, on any device." : "ھەر قانداق ۋاقىتتا ، ھەر قانداق جايدا ، ھەرقانداق ئۈسكۈنىدە سۆھبەتكە قاتنىشىڭ.",
    "Android app" : "ئاندىرويىد دېتالى",
    "iOS app" : "iOS ئەپ",
    "__language_name__" : "ئۇيغۇرچە",
    "Webhook Demo" : "Webhook كۆرگەزمىسى",
    "Call summary (%s)" : "چاقىرىش خۇلاسىسى (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "چاقىرىش خۇلاسىسى بوت تېلېفوندىن كېيىن بارلىق قاتناشقۇچىلار ۋە تىزىملىكتىكى ۋەزىپىلەرنى كۆرسىتىپ بەرگەندىن كېيىن ئومۇمىي ئۇچۇر يوللايدۇ",
    "Tasks" : "ۋەزىپە",
    "Notes" : "ئىزاھات",
    "Reports" : "دوكلات",
    "Decisions" : "قارار",
    "Agenda" : "كۈن تەرتىپى",
    "Call summary" : "چاقىرىش خۇلاسىسى",
    "Call summary - {title}" : "چاقىرىش خۇلاسىسى - {title}",
    "Talk conversation for event" : "پائالىيەتنىڭ پاراڭ سۆھپىتى",
    "Client Push is installed, this improves the performance of desktop clients." : "Client Push ئورنىتىلغان بولۇپ، بۇ ئۈستەل يۈزى خېرىدارلىرىنىڭ ئىقتىدارىنى ياخشىلايدۇ.",
    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "{notify_push} ئورنىتىلمىغان، بۇ ئۈستەل يۈزى خېرىدارلىرىنى ئىشلەتكەندە ئىقتىدار مەسىلىسىنى كەلتۈرۈپ چىقىرىشى مۇمكىن.",
    "Next meeting" : "كىيىنكى يىغىن",
    "Schedule a meeting from your calendar. A Talk conversation needs to be set as location to show up here" : "كالېندارىڭىزدىن يىغىن پىلانلاڭ. بۇ يەردە كۆرسىتىلىشى ئۈچۈن سۆھبەت سۆھبىتىنى ئورۇن قىلىپ بەلگىلەش كېرەك.",
    "Join conversations from remote Nextcloud servers" : "يىراقتىكى Nextcloud مۇلازىمېتىرلىرىدىكى سۆھبەتكە قاتنىشىڭ",
    "Your default media state has been saved" : "سۈكۈتتىكى مېدىيا ھالىتىڭىز ساقلاندى",
    "Set reminder for later today" : "بۈگۈنگە ئەسكەرتىش بەلگىلەڭ",
    "Set reminder for tomorrow" : "ئەتە ئۈچۈن ئەسكەرتىش بەلگىلەڭ",
    "Set reminder for this weekend" : "بۇ ھەپتە ئاخىرىدا ئەسكەرتىش بەلگىلەڭ",
    "Set reminder for next week" : "كېلەر ھەپتە ئەسكەرتىش بەلگىلەڭ",
    "Generate summary" : "خۇلاسە ياز",
    "Open poll • You voted already" : "ئوچۇق راي سىناش • سىز ئاللىبۇرۇن بېلەت تاشلىدىڭىز",
    "Open poll • Click to vote" : "ئوچۇق راي سىناش • بېلەت تاشلاش ئۈچۈن چېكىڭ",
    "Poll • Ended" : "راي سىناش • ئاخىرلاشتى",
    "Talk recording from {time} ({conversation})" : "{time} ({conversation}) دىن سۆز خاتىرىلەش",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["راي-سىناش نەتىنجىسى • %n بېلەت","راي-سىناش نەتىنجىسى • %n بېلەت"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["راي-سىناشنى ئېچىش • %n بېلەت","راي-سىناشنى ئېچىش • %n بېلەت"],
    "Submit vote" : "بېلەت تاشلاڭ",
    "Your privacy setting has been saved" : "مەخپىيەتلىكىڭىز ساقلاندى",
    "Your personal setting has been saved" : "شەخسىي تەڭشىكىڭىز ساقلاندى",
    "Failed to save sounds setting" : "ئاۋاز تەڭشىكىنى ساقلىيالمىدى",
    "Sounds setting saved" : "ئاۋاز تەڭشىكى ساقلاندى",
    "Always shown if recording consent is required" : "ئەگەر خاتىرلەش ماقۇللۇقى تەلەپ قىلىنسا ھەر-دائىم كۆرسىتىلىدۇ",
    "Nextcloud Talk was updated, you cannot start or join a call." : "Nextcloud Talk يېڭىلاندى ، سىز پاراڭنى باشلىيالمايسىز ياكى قاتنىشالمايسىز.",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "سىز باشقا كۆزنەك ياكى ئۈسكۈنىدە سۆھبەتكە قاتناشتىڭىز. بۇنى Nextcloud Talk قوللىمايدۇ ، شۇڭا بۇ يىغىن يېپىلدى.",
    "Nextcloud Talk was updated." : "Nextcloud پاراڭ يېڭىلاندى.",
    "Nextcloud is in maintenance mode." : "Nextcloud ئاسراش ھالىتىدە",
    "Nextcloud Talk Federation was updated." : "Nextcloud پاراڭلىشىش بىرلەشمىسى يېڭىلاندى."
},
"nplurals=2; plural=(n != 1);");
